Class: Aws::SecurityAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SecurityAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-securityagent/client.rb,
sig/client.rbs
Overview
An API client for SecurityAgent. To construct a client, you need to configure a :region and :credentials.
client = Aws::SecurityAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddArtifactResponseSuccess, _BatchCreateSecurityRequirementsResponseSuccess, _BatchDeleteCodeReviewsResponseSuccess, _BatchDeletePentestsResponseSuccess, _BatchDeleteSecurityRequirementsResponseSuccess, _BatchDeleteThreatModelsResponseSuccess, _BatchGetAgentSpacesResponseSuccess, _BatchGetArtifactMetadataResponseSuccess, _BatchGetCodeReviewJobTasksResponseSuccess, _BatchGetCodeReviewJobsResponseSuccess, _BatchGetCodeReviewsResponseSuccess, _BatchGetFindingsResponseSuccess, _BatchGetPentestJobTasksResponseSuccess, _BatchGetPentestJobsResponseSuccess, _BatchGetPentestsResponseSuccess, _BatchGetSecurityRequirementsResponseSuccess, _BatchGetTargetDomainsResponseSuccess, _BatchGetThreatModelJobTasksResponseSuccess, _BatchGetThreatModelJobsResponseSuccess, _BatchGetThreatModelsResponseSuccess, _BatchGetThreatsResponseSuccess, _BatchUpdateSecurityRequirementsResponseSuccess, _CreateAgentSpaceResponseSuccess, _CreateApplicationResponseSuccess, _CreateCodeReviewResponseSuccess, _CreateIntegrationResponseSuccess, _CreateMembershipResponseSuccess, _CreatePentestResponseSuccess, _CreatePrivateConnectionResponseSuccess, _CreateSecurityRequirementPackResponseSuccess, _CreateTargetDomainResponseSuccess, _CreateThreatModelResponseSuccess, _CreateThreatResponseSuccess, _DeleteAgentSpaceResponseSuccess, _DeleteArtifactResponseSuccess, _DeleteIntegrationResponseSuccess, _DeleteMembershipResponseSuccess, _DeletePrivateConnectionResponseSuccess, _DeleteSecurityRequirementPackResponseSuccess, _DeleteTargetDomainResponseSuccess, _DescribePrivateConnectionResponseSuccess, _GetApplicationResponseSuccess, _GetArtifactResponseSuccess, _GetIntegrationResponseSuccess, _GetSecurityRequirementPackResponseSuccess, _ImportSecurityRequirementsResponseSuccess, _InitiateProviderRegistrationResponseSuccess, _ListAgentSpacesResponseSuccess, _ListApplicationsResponseSuccess, _ListArtifactsResponseSuccess, _ListCodeReviewJobTasksResponseSuccess, _ListCodeReviewJobsForCodeReviewResponseSuccess, _ListCodeReviewsResponseSuccess, _ListDiscoveredEndpointsResponseSuccess, _ListFindingsResponseSuccess, _ListIntegratedResourcesResponseSuccess, _ListIntegrationsResponseSuccess, _ListMembershipsResponseSuccess, _ListPentestJobTasksResponseSuccess, _ListPentestJobsForPentestResponseSuccess, _ListPentestsResponseSuccess, _ListPrivateConnectionsResponseSuccess, _ListSecurityRequirementPacksResponseSuccess, _ListSecurityRequirementsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTargetDomainsResponseSuccess, _ListThreatModelJobTasksResponseSuccess, _ListThreatModelJobsResponseSuccess, _ListThreatModelsResponseSuccess, _ListThreatsResponseSuccess, _StartCodeRemediationResponseSuccess, _StartCodeReviewJobResponseSuccess, _StartPentestJobResponseSuccess, _StartThreatModelJobResponseSuccess, _StopCodeReviewJobResponseSuccess, _StopPentestJobResponseSuccess, _StopThreatModelJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAgentSpaceResponseSuccess, _UpdateApplicationResponseSuccess, _UpdateCodeReviewResponseSuccess, _UpdateFindingResponseSuccess, _UpdateIntegratedResourcesResponseSuccess, _UpdatePentestResponseSuccess, _UpdatePrivateConnectionCertificateResponseSuccess, _UpdateSecurityRequirementPackResponseSuccess, _UpdateTargetDomainResponseSuccess, _UpdateThreatModelResponseSuccess, _UpdateThreatResponseSuccess, _VerifyTargetDomainResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space.
-
#batch_create_security_requirements(params = {}) ⇒ Types::BatchCreateSecurityRequirementsOutput
Batch creates security requirements in a customer managed pack.
-
#batch_delete_code_reviews(params = {}) ⇒ Types::BatchDeleteCodeReviewsOutput
Deletes one or more code reviews from an agent space.
-
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
-
#batch_delete_security_requirements(params = {}) ⇒ Types::BatchDeleteSecurityRequirementsOutput
Batch deletes security requirements from a customer managed pack.
-
#batch_delete_threat_models(params = {}) ⇒ Types::BatchDeleteThreatModelsOutput
Deletes one or more threat models from an agent space.
-
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
-
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
-
#batch_get_code_review_job_tasks(params = {}) ⇒ Types::BatchGetCodeReviewJobTasksOutput
Retrieves information about one or more tasks within a code review job.
-
#batch_get_code_review_jobs(params = {}) ⇒ Types::BatchGetCodeReviewJobsOutput
Retrieves information about one or more code review jobs in an agent space.
-
#batch_get_code_reviews(params = {}) ⇒ Types::BatchGetCodeReviewsOutput
Retrieves information about one or more code reviews in an agent space.
-
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
-
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
-
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
-
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
-
#batch_get_security_requirements(params = {}) ⇒ Types::BatchGetSecurityRequirementsOutput
Batch retrieves security requirements from a pack.
-
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
-
#batch_get_threat_model_job_tasks(params = {}) ⇒ Types::BatchGetThreatModelJobTasksOutput
Retrieves information about one or more tasks within a threat model job.
-
#batch_get_threat_model_jobs(params = {}) ⇒ Types::BatchGetThreatModelJobsOutput
Retrieves information about one or more threat model jobs in an agent space.
-
#batch_get_threat_models(params = {}) ⇒ Types::BatchGetThreatModelsOutput
Retrieves information about one or more threat models in an agent space.
-
#batch_get_threats(params = {}) ⇒ Types::BatchGetThreatsOutput
Retrieves information about one or more threats.
-
#batch_update_security_requirements(params = {}) ⇒ Types::BatchUpdateSecurityRequirementsOutput
Batch updates security requirements within a customer managed pack.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application.
-
#create_code_review(params = {}) ⇒ Types::CreateCodeReviewOutput
Creates a new code review configuration in an agent space.
-
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
-
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
-
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space.
-
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a private connection for reaching a self-hosted provider instance over private networking using Amazon VPC Lattice.
-
#create_security_requirement_pack(params = {}) ⇒ Types::CreateSecurityRequirementPackOutput
Creates a customer managed security requirement pack.
-
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing.
-
#create_threat(params = {}) ⇒ Types::CreateThreatOutput
Creates a new threat under a threat model job.
-
#create_threat_model(params = {}) ⇒ Types::CreateThreatModelOutput
Creates a new threat model configuration in an agent space.
-
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
-
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
-
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
-
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user's access to an agent space.
-
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a private connection.
-
#delete_security_requirement_pack(params = {}) ⇒ Struct
Deletes a customer managed security requirement pack and all its associated security requirements.
-
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration.
-
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves the details of a private connection.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
-
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
-
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
-
#get_security_requirement_pack(params = {}) ⇒ Types::GetSecurityRequirementPackOutput
Retrieves information about a security requirement pack.
-
#import_security_requirements(params = {}) ⇒ Types::ImportSecurityRequirementsOutput
Imports security requirements from uploaded documents into a customer managed security requirement pack.
-
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
-
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
-
#list_code_review_job_tasks(params = {}) ⇒ Types::ListCodeReviewJobTasksOutput
Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.
-
#list_code_review_jobs_for_code_review(params = {}) ⇒ Types::ListCodeReviewJobsForCodeReviewOutput
Returns a paginated list of code review job summaries for the specified code review configuration.
-
#list_code_reviews(params = {}) ⇒ Types::ListCodeReviewsOutput
Returns a paginated list of code review summaries for the specified agent space.
-
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
-
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
-
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
-
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
-
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
-
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
-
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
-
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
-
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists the private connections in your account.
-
#list_security_requirement_packs(params = {}) ⇒ Types::ListSecurityRequirementPacksOutput
Lists all security requirement packs in the caller's account.
-
#list_security_requirements(params = {}) ⇒ Types::ListSecurityRequirementsOutput
Lists security requirements within a pack.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
-
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
-
#list_threat_model_job_tasks(params = {}) ⇒ Types::ListThreatModelJobTasksOutput
Returns a paginated list of task summaries for the specified threat model job.
-
#list_threat_model_jobs(params = {}) ⇒ Types::ListThreatModelJobsOutput
Returns a paginated list of threat model job summaries for the specified threat model.
-
#list_threat_models(params = {}) ⇒ Types::ListThreatModelsOutput
Returns a paginated list of threat model summaries for the specified agent space.
-
#list_threats(params = {}) ⇒ Types::ListThreatsOutput
Returns a paginated list of threats for a threat model job.
-
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings.
-
#start_code_review_job(params = {}) ⇒ Types::StartCodeReviewJobOutput
Starts a new code review job for a code review configuration.
-
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration.
-
#start_threat_model_job(params = {}) ⇒ Types::StartThreatModelJobOutput
Starts a new threat model job for a threat model configuration.
-
#stop_code_review_job(params = {}) ⇒ Struct
Stops a running code review job.
-
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job.
-
#stop_threat_model_job(params = {}) ⇒ Struct
Stops a running threat model job.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
-
#update_code_review(params = {}) ⇒ Types::UpdateCodeReviewOutput
Updates an existing code review configuration.
-
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
-
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
-
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
-
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a private connection.
-
#update_security_requirement_pack(params = {}) ⇒ Types::UpdateSecurityRequirementPackOutput
Updates a security requirement pack.
-
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
-
#update_threat(params = {}) ⇒ Types::UpdateThreatOutput
Updates a threat.
-
#update_threat_model(params = {}) ⇒ Types::UpdateThreatModelOutput
Updates an existing threat model configuration.
-
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-securityagent/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6000 6001 6002 |
# File 'lib/aws-sdk-securityagent/client.rb', line 6000 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6003 6004 6005 |
# File 'lib/aws-sdk-securityagent/client.rb', line 6003 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space. Artifacts provide additional context for security testing, such as architecture diagrams, API specifications, or configuration files.
86 |
# File 'sig/client.rbs', line 86
def add_artifact: (
|
#batch_create_security_requirements(params = {}) ⇒ Types::BatchCreateSecurityRequirementsOutput
Batch creates security requirements in a customer managed pack.
100 |
# File 'sig/client.rbs', line 100
def batch_create_security_requirements: (
|
#batch_delete_code_reviews(params = {}) ⇒ Types::BatchDeleteCodeReviewsOutput
Deletes one or more code reviews from an agent space.
120 |
# File 'sig/client.rbs', line 120
def batch_delete_code_reviews: (
|
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
132 |
# File 'sig/client.rbs', line 132
def batch_delete_pentests: (
|
#batch_delete_security_requirements(params = {}) ⇒ Types::BatchDeleteSecurityRequirementsOutput
Batch deletes security requirements from a customer managed pack.
144 |
# File 'sig/client.rbs', line 144
def batch_delete_security_requirements: (
|
#batch_delete_threat_models(params = {}) ⇒ Types::BatchDeleteThreatModelsOutput
Deletes one or more threat models from an agent space.
156 |
# File 'sig/client.rbs', line 156
def batch_delete_threat_models: (
|
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
168 |
# File 'sig/client.rbs', line 168
def batch_get_agent_spaces: (
|
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
178 |
# File 'sig/client.rbs', line 178
def batch_get_artifact_metadata: (
|
#batch_get_code_review_job_tasks(params = {}) ⇒ Types::BatchGetCodeReviewJobTasksOutput
Retrieves information about one or more tasks within a code review job.
190 |
# File 'sig/client.rbs', line 190
def batch_get_code_review_job_tasks: (
|
#batch_get_code_review_jobs(params = {}) ⇒ Types::BatchGetCodeReviewJobsOutput
Retrieves information about one or more code review jobs in an agent space.
202 |
# File 'sig/client.rbs', line 202
def batch_get_code_review_jobs: (
|
#batch_get_code_reviews(params = {}) ⇒ Types::BatchGetCodeReviewsOutput
Retrieves information about one or more code reviews in an agent space.
214 |
# File 'sig/client.rbs', line 214
def batch_get_code_reviews: (
|
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
226 |
# File 'sig/client.rbs', line 226
def batch_get_findings: (
|
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
238 |
# File 'sig/client.rbs', line 238
def batch_get_pentest_job_tasks: (
|
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
250 |
# File 'sig/client.rbs', line 250
def batch_get_pentest_jobs: (
|
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
262 |
# File 'sig/client.rbs', line 262
def batch_get_pentests: (
|
#batch_get_security_requirements(params = {}) ⇒ Types::BatchGetSecurityRequirementsOutput
Batch retrieves security requirements from a pack.
274 |
# File 'sig/client.rbs', line 274
def batch_get_security_requirements: (
|
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
286 |
# File 'sig/client.rbs', line 286
def batch_get_target_domains: (
|
#batch_get_threat_model_job_tasks(params = {}) ⇒ Types::BatchGetThreatModelJobTasksOutput
Retrieves information about one or more tasks within a threat model job.
297 |
# File 'sig/client.rbs', line 297
def batch_get_threat_model_job_tasks: (
|
#batch_get_threat_model_jobs(params = {}) ⇒ Types::BatchGetThreatModelJobsOutput
Retrieves information about one or more threat model jobs in an agent space.
309 |
# File 'sig/client.rbs', line 309
def batch_get_threat_model_jobs: (
|
#batch_get_threat_models(params = {}) ⇒ Types::BatchGetThreatModelsOutput
Retrieves information about one or more threat models in an agent space.
321 |
# File 'sig/client.rbs', line 321
def batch_get_threat_models: (
|
#batch_get_threats(params = {}) ⇒ Types::BatchGetThreatsOutput
Retrieves information about one or more threats.
333 |
# File 'sig/client.rbs', line 333
def batch_get_threats: (
|
#batch_update_security_requirements(params = {}) ⇒ Types::BatchUpdateSecurityRequirementsOutput
Batch updates security requirements within a customer managed pack.
345 |
# File 'sig/client.rbs', line 345
def batch_update_security_requirements: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5973 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SecurityAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-securityagent' context[:gem_version] = '1.10.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space. An agent space is a dedicated workspace for securing a specific application.
372 |
# File 'sig/client.rbs', line 372
def create_agent_space: (
|
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application. An application is the top-level organizational unit that supports IAM Identity Center integration.
391 |
# File 'sig/client.rbs', line 391
def create_application: (
|
#create_code_review(params = {}) ⇒ Types::CreateCodeReviewOutput
Creates a new code review configuration in an agent space. A code review defines the parameters for automated security-focused code analysis.
413 |
# File 'sig/client.rbs', line 413
def create_code_review: (
|
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
432 |
# File 'sig/client.rbs', line 432
def create_integration: (
|
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
472 |
# File 'sig/client.rbs', line 472
def create_membership: (
|
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space. A pentest defines the security test parameters, including target assets, risk type exclusions, and logging configuration.
498 |
# File 'sig/client.rbs', line 498
def create_pentest: (
|
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a private connection for reaching a self-hosted provider instance over private networking using Amazon VPC Lattice.
534 |
# File 'sig/client.rbs', line 534
def create_private_connection: (
|
#create_security_requirement_pack(params = {}) ⇒ Types::CreateSecurityRequirementPackOutput
Creates a customer managed security requirement pack.
564 |
# File 'sig/client.rbs', line 564
def create_security_requirement_pack: (
|
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing. A target domain is a web domain that must be registered and verified before it can be tested.
584 |
# File 'sig/client.rbs', line 584
def create_target_domain: (
|
#create_threat(params = {}) ⇒ Types::CreateThreatOutput
Creates a new threat under a threat model job.
616 |
# File 'sig/client.rbs', line 616
def create_threat: (
|
#create_threat_model(params = {}) ⇒ Types::CreateThreatModelOutput
Creates a new threat model configuration in an agent space. A threat model defines the parameters for automated threat analysis.
659 |
# File 'sig/client.rbs', line 659
def create_threat_model: (
|
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
686 |
# File 'sig/client.rbs', line 686
def delete_agent_space: (
|
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
692 |
# File 'sig/client.rbs', line 692
def delete_application: (
|
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
701 |
# File 'sig/client.rbs', line 701
def delete_artifact: (
|
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
711 |
# File 'sig/client.rbs', line 711
def delete_integration: (
|
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user's access to an agent space.
720 |
# File 'sig/client.rbs', line 720
def delete_membership: (
|
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a private connection.
743 |
# File 'sig/client.rbs', line 743
def delete_private_connection: (
|
#delete_security_requirement_pack(params = {}) ⇒ Struct
Deletes a customer managed security requirement pack and all its associated security requirements.
752 |
# File 'sig/client.rbs', line 752
def delete_security_requirement_pack: (
|
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration. After deletion, the domain can no longer be used for penetration testing.
762 |
# File 'sig/client.rbs', line 762
def delete_target_domain: (
|
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves the details of a private connection.
782 |
# File 'sig/client.rbs', line 782
def describe_private_connection: (
|
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
797 |
# File 'sig/client.rbs', line 797
def get_application: (
|
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
811 |
# File 'sig/client.rbs', line 811
def get_artifact: (
|
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
829 |
# File 'sig/client.rbs', line 829
def get_integration: (
|
#get_security_requirement_pack(params = {}) ⇒ Types::GetSecurityRequirementPackOutput
Retrieves information about a security requirement pack.
848 |
# File 'sig/client.rbs', line 848
def get_security_requirement_pack: (
|
#import_security_requirements(params = {}) ⇒ Types::ImportSecurityRequirementsOutput
Imports security requirements from uploaded documents into a customer managed security requirement pack. The import process asynchronously extracts and generates structured security requirements from the provided source files.
859 |
# File 'sig/client.rbs', line 859
def import_security_requirements: (
|
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider. Returns a redirect URL and CSRF state token for completing the authorization.
879 |
# File 'sig/client.rbs', line 879
def initiate_provider_registration: (
|
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
890 |
# File 'sig/client.rbs', line 890
def list_agent_spaces: (
|
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
902 |
# File 'sig/client.rbs', line 902
def list_applications: (
|
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
914 |
# File 'sig/client.rbs', line 914
def list_artifacts: (
|
#list_code_review_job_tasks(params = {}) ⇒ Types::ListCodeReviewJobTasksOutput
Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
927 |
# File 'sig/client.rbs', line 927
def list_code_review_job_tasks: (
|
#list_code_review_jobs_for_code_review(params = {}) ⇒ Types::ListCodeReviewJobsForCodeReviewOutput
Returns a paginated list of code review job summaries for the specified code review configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
943 |
# File 'sig/client.rbs', line 943
def list_code_review_jobs_for_code_review: (
|
#list_code_reviews(params = {}) ⇒ Types::ListCodeReviewsOutput
Returns a paginated list of code review summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
957 |
# File 'sig/client.rbs', line 957
def list_code_reviews: (
|
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
970 |
# File 'sig/client.rbs', line 970
def list_discovered_endpoints: (
|
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
985 |
# File 'sig/client.rbs', line 985
def list_findings: (
|
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1005 |
# File 'sig/client.rbs', line 1005
def list_integrated_resources: (
|
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1020 |
# File 'sig/client.rbs', line 1020
def list_integrations: (
|
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1036 |
# File 'sig/client.rbs', line 1036
def list_memberships: (
|
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1051 |
# File 'sig/client.rbs', line 1051
def list_pentest_job_tasks: (
|
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1067 |
# File 'sig/client.rbs', line 1067
def list_pentest_jobs_for_pentest: (
|
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1081 |
# File 'sig/client.rbs', line 1081
def list_pentests: (
|
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists the private connections in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1094 |
# File 'sig/client.rbs', line 1094
def list_private_connections: (
|
#list_security_requirement_packs(params = {}) ⇒ Types::ListSecurityRequirementPacksOutput
Lists all security requirement packs in the caller's account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1106 |
# File 'sig/client.rbs', line 1106
def list_security_requirement_packs: (
|
#list_security_requirements(params = {}) ⇒ Types::ListSecurityRequirementsOutput
Lists security requirements within a pack.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1122 |
# File 'sig/client.rbs', line 1122
def list_security_requirements: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
1134 |
# File 'sig/client.rbs', line 1134
def list_tags_for_resource: (
|
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1145 |
# File 'sig/client.rbs', line 1145
def list_target_domains: (
|
#list_threat_model_job_tasks(params = {}) ⇒ Types::ListThreatModelJobTasksOutput
Returns a paginated list of task summaries for the specified threat model job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1157 |
# File 'sig/client.rbs', line 1157
def list_threat_model_job_tasks: (
|
#list_threat_model_jobs(params = {}) ⇒ Types::ListThreatModelJobsOutput
Returns a paginated list of threat model job summaries for the specified threat model.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1171 |
# File 'sig/client.rbs', line 1171
def list_threat_model_jobs: (
|
#list_threat_models(params = {}) ⇒ Types::ListThreatModelsOutput
Returns a paginated list of threat model summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1185 |
# File 'sig/client.rbs', line 1185
def list_threat_models: (
|
#list_threats(params = {}) ⇒ Types::ListThreatsOutput
Returns a paginated list of threats for a threat model job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1198 |
# File 'sig/client.rbs', line 1198
def list_threats: (
|
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings. This creates pull requests in integrated repositories to fix the identified vulnerabilities.
1210 |
# File 'sig/client.rbs', line 1210
def start_code_remediation: (
|
#start_code_review_job(params = {}) ⇒ Types::StartCodeReviewJobOutput
Starts a new code review job for a code review configuration. The job executes the security-focused code analysis defined in the code review.
1229 |
# File 'sig/client.rbs', line 1229
def start_code_review_job: (
|
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration. The job executes the security tests defined in the pentest.
1249 |
# File 'sig/client.rbs', line 1249
def start_pentest_job: (
|
#start_threat_model_job(params = {}) ⇒ Types::StartThreatModelJobOutput
Starts a new threat model job for a threat model configuration.
1266 |
# File 'sig/client.rbs', line 1266
def start_threat_model_job: (
|
#stop_code_review_job(params = {}) ⇒ Struct
Stops a running code review job. The job transitions to a stopping state and then to stopped after cleanup completes.
1276 |
# File 'sig/client.rbs', line 1276
def stop_code_review_job: (
|
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job. The job transitions to a stopping state and then to stopped after cleanup completes.
1286 |
# File 'sig/client.rbs', line 1286
def stop_pentest_job: (
|
#stop_threat_model_job(params = {}) ⇒ Struct
Stops a running threat model job.
1296 |
# File 'sig/client.rbs', line 1296
def stop_threat_model_job: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
1306 |
# File 'sig/client.rbs', line 1306
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
1316 |
# File 'sig/client.rbs', line 1316
def untag_resource: (
|
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
1334 |
# File 'sig/client.rbs', line 1334
def update_agent_space: (
|
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
1352 |
# File 'sig/client.rbs', line 1352
def update_application: (
|
#update_code_review(params = {}) ⇒ Types::UpdateCodeReviewOutput
Updates an existing code review configuration.
1373 |
# File 'sig/client.rbs', line 1373
def update_code_review: (
|
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
1392 |
# File 'sig/client.rbs', line 1392
def update_finding: (
|
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
1411 |
# File 'sig/client.rbs', line 1411
def update_integrated_resources: (
|
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
1474 |
# File 'sig/client.rbs', line 1474
def update_pentest: (
|
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a private connection. Certificates can be added or replaced but not removed.
1511 |
# File 'sig/client.rbs', line 1511
def update_private_connection_certificate: (
|
#update_security_requirement_pack(params = {}) ⇒ Types::UpdateSecurityRequirementPackOutput
Updates a security requirement pack. For customer managed packs, both metadata and status can be updated. For AWS managed packs, only status can be updated.
1525 |
# File 'sig/client.rbs', line 1525
def update_security_requirement_pack: (
|
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
1544 |
# File 'sig/client.rbs', line 1544
def update_target_domain: (
|
#update_threat(params = {}) ⇒ Types::UpdateThreatOutput
Updates a threat.
1575 |
# File 'sig/client.rbs', line 1575
def update_threat: (
|
#update_threat_model(params = {}) ⇒ Types::UpdateThreatModelOutput
Updates an existing threat model configuration.
1618 |
# File 'sig/client.rbs', line 1618
def update_threat_model: (
|
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain. This checks whether the domain ownership verification token has been properly configured.
1646 |
# File 'sig/client.rbs', line 1646
def verify_target_domain: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5993 5994 5995 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5993 def waiter_names [] end |