Class: Aws::SecurityAgent::Types::AWSResources

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

The AWS resources associated with an agent space, including VPCs, log groups, S3 buckets, secrets, Lambda functions, and IAM roles.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#iam_rolesArray<String>

The IAM roles associated with the agent space.

Returns:

  • (Array<String>)


46
47
48
49
50
51
52
53
54
55
# File 'lib/aws-sdk-securityagent/types.rb', line 46

class AWSResources < Struct.new(
  :vpcs,
  :log_groups,
  :s3_buckets,
  :secret_arns,
  :lambda_function_arns,
  :iam_roles)
  SENSITIVE = []
  include Aws::Structure
end

#lambda_function_arnsArray<String>

The Amazon Resource Names (ARNs) of the Lambda functions associated with the agent space.

Returns:

  • (Array<String>)


46
47
48
49
50
51
52
53
54
55
# File 'lib/aws-sdk-securityagent/types.rb', line 46

class AWSResources < Struct.new(
  :vpcs,
  :log_groups,
  :s3_buckets,
  :secret_arns,
  :lambda_function_arns,
  :iam_roles)
  SENSITIVE = []
  include Aws::Structure
end

#log_groupsArray<String>

The Amazon Resource Names (ARNs) of the CloudWatch log groups associated with the agent space.

Returns:

  • (Array<String>)


46
47
48
49
50
51
52
53
54
55
# File 'lib/aws-sdk-securityagent/types.rb', line 46

class AWSResources < Struct.new(
  :vpcs,
  :log_groups,
  :s3_buckets,
  :secret_arns,
  :lambda_function_arns,
  :iam_roles)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucketsArray<String>

The Amazon Resource Names (ARNs) of the S3 buckets associated with the agent space.

Returns:

  • (Array<String>)


46
47
48
49
50
51
52
53
54
55
# File 'lib/aws-sdk-securityagent/types.rb', line 46

class AWSResources < Struct.new(
  :vpcs,
  :log_groups,
  :s3_buckets,
  :secret_arns,
  :lambda_function_arns,
  :iam_roles)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnsArray<String>

The Amazon Resource Names (ARNs) of the Secrets Manager secrets associated with the agent space.

Returns:

  • (Array<String>)


46
47
48
49
50
51
52
53
54
55
# File 'lib/aws-sdk-securityagent/types.rb', line 46

class AWSResources < Struct.new(
  :vpcs,
  :log_groups,
  :s3_buckets,
  :secret_arns,
  :lambda_function_arns,
  :iam_roles)
  SENSITIVE = []
  include Aws::Structure
end

#vpcsArray<Types::VpcConfig>

The VPC configurations associated with the agent space.

Returns:



46
47
48
49
50
51
52
53
54
55
# File 'lib/aws-sdk-securityagent/types.rb', line 46

class AWSResources < Struct.new(
  :vpcs,
  :log_groups,
  :s3_buckets,
  :secret_arns,
  :lambda_function_arns,
  :iam_roles)
  SENSITIVE = []
  include Aws::Structure
end