Class: Aws::SecurityAgent::Types::Actor

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents an actor used during penetration testing. An actor defines a user or entity that interacts with the target application, including authentication credentials and target URIs.

Constant Summary collapse

SENSITIVE =
[:mfa_forwarding_address]

Instance Attribute Summary collapse

Instance Attribute Details

#authenticationTypes::Authentication

The authentication configuration for the actor.



101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-securityagent/types.rb', line 101

class Actor < Struct.new(
  :identifier,
  :uris,
  :authentication,
  :description,
  :enable_email_mfa,
  :mfa_forwarding_address)
  SENSITIVE = [:mfa_forwarding_address]
  include Aws::Structure
end

#descriptionString

A description of the actor.

Returns:

  • (String)


101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-securityagent/types.rb', line 101

class Actor < Struct.new(
  :identifier,
  :uris,
  :authentication,
  :description,
  :enable_email_mfa,
  :mfa_forwarding_address)
  SENSITIVE = [:mfa_forwarding_address]
  include Aws::Structure
end

#enable_email_mfaBoolean

Whether email-based MFA is enabled for this actor.

Returns:

  • (Boolean)


101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-securityagent/types.rb', line 101

class Actor < Struct.new(
  :identifier,
  :uris,
  :authentication,
  :description,
  :enable_email_mfa,
  :mfa_forwarding_address)
  SENSITIVE = [:mfa_forwarding_address]
  include Aws::Structure
end

#identifierString

The unique identifier for the actor.

Returns:

  • (String)


101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-securityagent/types.rb', line 101

class Actor < Struct.new(
  :identifier,
  :uris,
  :authentication,
  :description,
  :enable_email_mfa,
  :mfa_forwarding_address)
  SENSITIVE = [:mfa_forwarding_address]
  include Aws::Structure
end

#mfa_forwarding_addressString

Server-generated email forwarding address for receiving MFA codes.

Returns:

  • (String)


101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-securityagent/types.rb', line 101

class Actor < Struct.new(
  :identifier,
  :uris,
  :authentication,
  :description,
  :enable_email_mfa,
  :mfa_forwarding_address)
  SENSITIVE = [:mfa_forwarding_address]
  include Aws::Structure
end

#urisArray<String>

The list of URIs that the actor targets during testing.

Returns:

  • (Array<String>)


101
102
103
104
105
106
107
108
109
110
# File 'lib/aws-sdk-securityagent/types.rb', line 101

class Actor < Struct.new(
  :identifier,
  :uris,
  :authentication,
  :description,
  :enable_email_mfa,
  :mfa_forwarding_address)
  SENSITIVE = [:mfa_forwarding_address]
  include Aws::Structure
end