Class: Aws::SecurityAgent::Types::AgentSpace

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents an agent space, which is a dedicated workspace for securing a specific application. An agent space contains the configuration, resources, and settings needed for security testing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-securityagent/types.rb', line 186

class AgentSpace < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#aws_resourcesTypes::AWSResources

The AWS resources associated with the agent space.

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-securityagent/types.rb', line 186

class AgentSpace < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_settingsTypes::CodeReviewSettings

The code review settings for the agent space.



186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-securityagent/types.rb', line 186

class AgentSpace < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the agent space was created, in UTC format.

Returns:

  • (Time)


186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-securityagent/types.rb', line 186

class AgentSpace < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the agent space.

Returns:

  • (String)


186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-securityagent/types.rb', line 186

class AgentSpace < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The identifier of the AWS KMS key used to encrypt data in the agent space.

Returns:

  • (String)


186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-securityagent/types.rb', line 186

class AgentSpace < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the agent space.

Returns:

  • (String)


186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-securityagent/types.rb', line 186

class AgentSpace < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#target_domain_idsArray<String>

The list of target domain identifiers associated with the agent space.

Returns:

  • (Array<String>)


186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-securityagent/types.rb', line 186

class AgentSpace < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the agent space was last updated, in UTC format.

Returns:

  • (Time)


186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/aws-sdk-securityagent/types.rb', line 186

class AgentSpace < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end