Class: Aws::SecurityAgent::Types::AgentSpaceSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about an agent space.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


220
221
222
223
224
225
226
227
# File 'lib/aws-sdk-securityagent/types.rb', line 220

class AgentSpaceSummary < Struct.new(
  :agent_space_id,
  :name,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the agent space was created, in UTC format.

Returns:

  • (Time)


220
221
222
223
224
225
226
227
# File 'lib/aws-sdk-securityagent/types.rb', line 220

class AgentSpaceSummary < Struct.new(
  :agent_space_id,
  :name,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the agent space.

Returns:

  • (String)


220
221
222
223
224
225
226
227
# File 'lib/aws-sdk-securityagent/types.rb', line 220

class AgentSpaceSummary < Struct.new(
  :agent_space_id,
  :name,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the agent space was last updated, in UTC format.

Returns:

  • (Time)


220
221
222
223
224
225
226
227
# File 'lib/aws-sdk-securityagent/types.rb', line 220

class AgentSpaceSummary < Struct.new(
  :agent_space_id,
  :name,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end