Class: Aws::SecurityAgent::Types::ArtifactMetadataItem

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains metadata about an artifact.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the artifact.

Returns:

  • (String)


299
300
301
302
303
304
305
306
# File 'lib/aws-sdk-securityagent/types.rb', line 299

class ArtifactMetadataItem < Struct.new(
  :agent_space_id,
  :artifact_id,
  :file_name,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#artifact_idString

The unique identifier of the artifact.

Returns:

  • (String)


299
300
301
302
303
304
305
306
# File 'lib/aws-sdk-securityagent/types.rb', line 299

class ArtifactMetadataItem < Struct.new(
  :agent_space_id,
  :artifact_id,
  :file_name,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#file_nameString

The file name of the artifact.

Returns:

  • (String)


299
300
301
302
303
304
305
306
# File 'lib/aws-sdk-securityagent/types.rb', line 299

class ArtifactMetadataItem < Struct.new(
  :agent_space_id,
  :artifact_id,
  :file_name,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the artifact was last updated, in UTC format.

Returns:

  • (Time)


299
300
301
302
303
304
305
306
# File 'lib/aws-sdk-securityagent/types.rb', line 299

class ArtifactMetadataItem < Struct.new(
  :agent_space_id,
  :artifact_id,
  :file_name,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end