Class: Aws::SecurityAgent::Types::BatchDeleteCodeReviewsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the BatchDeleteCodeReviews operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletedArray<String>

The list of identifiers of the code reviews that were successfully deleted.

Returns:

  • (Array<String>)


532
533
534
535
536
537
# File 'lib/aws-sdk-securityagent/types.rb', line 532

class BatchDeleteCodeReviewsOutput < Struct.new(
  :deleted,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end

#failedArray<Types::DeleteCodeReviewFailure>

The list of code reviews that failed to delete, including the reason for each failure.

Returns:



532
533
534
535
536
537
# File 'lib/aws-sdk-securityagent/types.rb', line 532

class BatchDeleteCodeReviewsOutput < Struct.new(
  :deleted,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end