Class: Aws::SecurityAgent::Types::BatchDeletePentestsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchDeletePentestsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for deleting multiple pentests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentests to delete.
-
#pentest_ids ⇒ Array<String>
The list of pentest identifiers to delete.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentests to delete.
403 404 405 406 407 408 |
# File 'lib/aws-sdk-securityagent/types.rb', line 403 class BatchDeletePentestsInput < Struct.new( :pentest_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#pentest_ids ⇒ Array<String>
The list of pentest identifiers to delete.
403 404 405 406 407 408 |
# File 'lib/aws-sdk-securityagent/types.rb', line 403 class BatchDeletePentestsInput < Struct.new( :pentest_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |