Class: Aws::SecurityAgent::Types::BatchDeletePentestsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchDeletePentestsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchDeletePentests operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deleted ⇒ Array<Types::Pentest>
The list of pentests that were successfully deleted.
-
#failed ⇒ Array<Types::DeletePentestFailure>
The list of pentests that failed to delete, including the reason for each failure.
Instance Attribute Details
#deleted ⇒ Array<Types::Pentest>
The list of pentests that were successfully deleted.
423 424 425 426 427 428 |
# File 'lib/aws-sdk-securityagent/types.rb', line 423 class BatchDeletePentestsOutput < Struct.new( :deleted, :failed) SENSITIVE = [] include Aws::Structure end |
#failed ⇒ Array<Types::DeletePentestFailure>
The list of pentests that failed to delete, including the reason for each failure.
423 424 425 426 427 428 |
# File 'lib/aws-sdk-securityagent/types.rb', line 423 class BatchDeletePentestsOutput < Struct.new( :deleted, :failed) SENSITIVE = [] include Aws::Structure end |