Class: Aws::SecurityAgent::Types::BatchDeleteThreatModelsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the BatchDeleteThreatModels operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletedArray<String>

The list of threat model identifiers that were successfully deleted.

Returns:

  • (Array<String>)


631
632
633
634
635
636
# File 'lib/aws-sdk-securityagent/types.rb', line 631

class BatchDeleteThreatModelsOutput < Struct.new(
  :deleted,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end

#failedArray<Types::DeleteThreatModelFailure>

The list of threat models that failed to delete, including the reason for each failure.



631
632
633
634
635
636
# File 'lib/aws-sdk-securityagent/types.rb', line 631

class BatchDeleteThreatModelsOutput < Struct.new(
  :deleted,
  :failed)
  SENSITIVE = []
  include Aws::Structure
end