Class: Aws::SecurityAgent::Types::BatchGetArtifactMetadataInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the artifacts.

Returns:

  • (String)


474
475
476
477
478
479
# File 'lib/aws-sdk-securityagent/types.rb', line 474

class BatchGetArtifactMetadataInput < Struct.new(
  :agent_space_id,
  :artifact_ids)
  SENSITIVE = []
  include Aws::Structure
end

#artifact_idsArray<String>

The list of artifact identifiers to retrieve metadata for.

Returns:

  • (Array<String>)


474
475
476
477
478
479
# File 'lib/aws-sdk-securityagent/types.rb', line 474

class BatchGetArtifactMetadataInput < Struct.new(
  :agent_space_id,
  :artifact_ids)
  SENSITIVE = []
  include Aws::Structure
end