Class: Aws::SecurityAgent::Types::BatchGetArtifactMetadataOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetArtifactMetadataOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_metadata_list ⇒ Array<Types::ArtifactMetadataItem>
The list of artifact metadata items that were found.
Instance Attribute Details
#artifact_metadata_list ⇒ Array<Types::ArtifactMetadataItem>
The list of artifact metadata items that were found.
487 488 489 490 491 |
# File 'lib/aws-sdk-securityagent/types.rb', line 487 class BatchGetArtifactMetadataOutput < Struct.new( :artifact_metadata_list) SENSITIVE = [] include Aws::Structure end |