Class: Aws::SecurityAgent::Types::BatchGetCodeReviewJobsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the BatchGetCodeReviewJobs operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_review_jobsArray<Types::CodeReviewJob>

The list of code review jobs that were found.

Returns:



771
772
773
774
775
776
# File 'lib/aws-sdk-securityagent/types.rb', line 771

class BatchGetCodeReviewJobsOutput < Struct.new(
  :code_review_jobs,
  :not_found)
  SENSITIVE = []
  include Aws::Structure
end

#not_foundArray<String>

The list of code review job identifiers that were not found.

Returns:

  • (Array<String>)


771
772
773
774
775
776
# File 'lib/aws-sdk-securityagent/types.rb', line 771

class BatchGetCodeReviewJobsOutput < Struct.new(
  :code_review_jobs,
  :not_found)
  SENSITIVE = []
  include Aws::Structure
end