Class: Aws::SecurityAgent::Types::BatchGetCodeReviewsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for retrieving multiple code reviews by their IDs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the code reviews.

Returns:

  • (String)


791
792
793
794
795
796
# File 'lib/aws-sdk-securityagent/types.rb', line 791

class BatchGetCodeReviewsInput < Struct.new(
  :code_review_ids,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_idsArray<String>

The list of code review identifiers to retrieve.

Returns:

  • (Array<String>)


791
792
793
794
795
796
# File 'lib/aws-sdk-securityagent/types.rb', line 791

class BatchGetCodeReviewsInput < Struct.new(
  :code_review_ids,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end