Class: Aws::SecurityAgent::Types::BatchGetFindingsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetFindingsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for BatchGetFindings operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the findings.
-
#finding_ids ⇒ Array<String>
The list of finding identifiers to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the findings.
505 506 507 508 509 510 |
# File 'lib/aws-sdk-securityagent/types.rb', line 505 class BatchGetFindingsInput < Struct.new( :finding_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#finding_ids ⇒ Array<String>
The list of finding identifiers to retrieve.
505 506 507 508 509 510 |
# File 'lib/aws-sdk-securityagent/types.rb', line 505 class BatchGetFindingsInput < Struct.new( :finding_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |