Class: Aws::SecurityAgent::Types::BatchGetFindingsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetFindingsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchGetFindings operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#findings ⇒ Array<Types::Finding>
The list of findings that were found.
-
#not_found ⇒ Array<String>
The list of finding identifiers that were not found.
Instance Attribute Details
#findings ⇒ Array<Types::Finding>
The list of findings that were found.
524 525 526 527 528 529 |
# File 'lib/aws-sdk-securityagent/types.rb', line 524 class BatchGetFindingsOutput < Struct.new( :findings, :not_found) SENSITIVE = [] include Aws::Structure end |
#not_found ⇒ Array<String>
The list of finding identifiers that were not found.
524 525 526 527 528 529 |
# File 'lib/aws-sdk-securityagent/types.rb', line 524 class BatchGetFindingsOutput < Struct.new( :findings, :not_found) SENSITIVE = [] include Aws::Structure end |