Class: Aws::SecurityAgent::Types::BatchGetPentestJobTasksInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for retrieving multiple tasks associated with a pentest job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the tasks.

Returns:

  • (String)


543
544
545
546
547
548
# File 'lib/aws-sdk-securityagent/types.rb', line 543

class BatchGetPentestJobTasksInput < Struct.new(
  :agent_space_id,
  :task_ids)
  SENSITIVE = []
  include Aws::Structure
end

#task_idsArray<String>

The list of task identifiers to retrieve.

Returns:

  • (Array<String>)


543
544
545
546
547
548
# File 'lib/aws-sdk-securityagent/types.rb', line 543

class BatchGetPentestJobTasksInput < Struct.new(
  :agent_space_id,
  :task_ids)
  SENSITIVE = []
  include Aws::Structure
end