Class: Aws::SecurityAgent::Types::BatchGetPentestJobTasksOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetPentestJobTasksOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchGetPentestJobTasks operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#not_found ⇒ Array<String>
The list of task identifiers that were not found.
-
#tasks ⇒ Array<Types::Task>
The list of tasks that were found.
Instance Attribute Details
#not_found ⇒ Array<String>
The list of task identifiers that were not found.
562 563 564 565 566 567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 562 class BatchGetPentestJobTasksOutput < Struct.new( :tasks, :not_found) SENSITIVE = [] include Aws::Structure end |
#tasks ⇒ Array<Types::Task>
The list of tasks that were found.
562 563 564 565 566 567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 562 class BatchGetPentestJobTasksOutput < Struct.new( :tasks, :not_found) SENSITIVE = [] include Aws::Structure end |