Class: Aws::SecurityAgent::Types::BatchGetPentestJobsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetPentestJobsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for BatchGetPentestJobs operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest jobs.
-
#pentest_job_ids ⇒ Array<String>
The list of pentest job identifiers to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest jobs.
582 583 584 585 586 587 |
# File 'lib/aws-sdk-securityagent/types.rb', line 582 class BatchGetPentestJobsInput < Struct.new( :pentest_job_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#pentest_job_ids ⇒ Array<String>
The list of pentest job identifiers to retrieve.
582 583 584 585 586 587 |
# File 'lib/aws-sdk-securityagent/types.rb', line 582 class BatchGetPentestJobsInput < Struct.new( :pentest_job_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |