Class: Aws::SecurityAgent::Types::BatchGetPentestJobsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetPentestJobsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchGetPentestJobs operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#not_found ⇒ Array<String>
The list of pentest job identifiers that were not found.
-
#pentest_jobs ⇒ Array<Types::PentestJob>
The list of pentest jobs that were found.
Instance Attribute Details
#not_found ⇒ Array<String>
The list of pentest job identifiers that were not found.
601 602 603 604 605 606 |
# File 'lib/aws-sdk-securityagent/types.rb', line 601 class BatchGetPentestJobsOutput < Struct.new( :pentest_jobs, :not_found) SENSITIVE = [] include Aws::Structure end |
#pentest_jobs ⇒ Array<Types::PentestJob>
The list of pentest jobs that were found.
601 602 603 604 605 606 |
# File 'lib/aws-sdk-securityagent/types.rb', line 601 class BatchGetPentestJobsOutput < Struct.new( :pentest_jobs, :not_found) SENSITIVE = [] include Aws::Structure end |