Class: Aws::SecurityAgent::Types::BatchGetPentestsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetPentestsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for retrieving multiple pentests by their IDs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentests.
-
#pentest_ids ⇒ Array<String>
The list of pentest identifiers to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentests.
620 621 622 623 624 625 |
# File 'lib/aws-sdk-securityagent/types.rb', line 620 class BatchGetPentestsInput < Struct.new( :pentest_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#pentest_ids ⇒ Array<String>
The list of pentest identifiers to retrieve.
620 621 622 623 624 625 |
# File 'lib/aws-sdk-securityagent/types.rb', line 620 class BatchGetPentestsInput < Struct.new( :pentest_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |