Class: Aws::SecurityAgent::Types::BatchGetPentestsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetPentestsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchGetPentests operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#not_found ⇒ Array<String>
The list of pentest identifiers that were not found.
-
#pentests ⇒ Array<Types::Pentest>
The list of pentests that were found.
Instance Attribute Details
#not_found ⇒ Array<String>
The list of pentest identifiers that were not found.
639 640 641 642 643 644 |
# File 'lib/aws-sdk-securityagent/types.rb', line 639 class BatchGetPentestsOutput < Struct.new( :pentests, :not_found) SENSITIVE = [] include Aws::Structure end |
#pentests ⇒ Array<Types::Pentest>
The list of pentests that were found.
639 640 641 642 643 644 |
# File 'lib/aws-sdk-securityagent/types.rb', line 639 class BatchGetPentestsOutput < Struct.new( :pentests, :not_found) SENSITIVE = [] include Aws::Structure end |