Class: Aws::SecurityAgent::Types::BatchGetSecurityRequirementsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorsArray<Types::BatchSecurityRequirementError>

The list of errors for security requirements that failed to be retrieved.



1053
1054
1055
1056
1057
1058
# File 'lib/aws-sdk-securityagent/types.rb', line 1053

class BatchGetSecurityRequirementsOutput < Struct.new(
  :security_requirements,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end

#security_requirementsArray<Types::BatchGetSecurityRequirementResult>

The list of security requirements that were successfully retrieved.



1053
1054
1055
1056
1057
1058
# File 'lib/aws-sdk-securityagent/types.rb', line 1053

class BatchGetSecurityRequirementsOutput < Struct.new(
  :security_requirements,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end