Class: Aws::SecurityAgent::Types::BatchGetTargetDomainsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetTargetDomainsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchGetTargetDomains operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#not_found ⇒ Array<String>
The list of target domain identifiers that were not found.
-
#target_domains ⇒ Array<Types::TargetDomain>
The list of target domains that were found.
Instance Attribute Details
#not_found ⇒ Array<String>
The list of target domain identifiers that were not found.
672 673 674 675 676 677 |
# File 'lib/aws-sdk-securityagent/types.rb', line 672 class BatchGetTargetDomainsOutput < Struct.new( :target_domains, :not_found) SENSITIVE = [] include Aws::Structure end |
#target_domains ⇒ Array<Types::TargetDomain>
The list of target domains that were found.
672 673 674 675 676 677 |
# File 'lib/aws-sdk-securityagent/types.rb', line 672 class BatchGetTargetDomainsOutput < Struct.new( :target_domains, :not_found) SENSITIVE = [] include Aws::Structure end |