Class: Aws::SecurityAgent::Types::BatchGetThreatModelJobTasksInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetThreatModelJobTasksInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for retrieving multiple tasks associated with a threat model job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the tasks.
-
#threat_model_job_task_ids ⇒ Array<String>
The list of task identifiers to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the tasks.
1106 1107 1108 1109 1110 1111 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1106 class BatchGetThreatModelJobTasksInput < Struct.new( :agent_space_id, :threat_model_job_task_ids) SENSITIVE = [] include Aws::Structure end |
#threat_model_job_task_ids ⇒ Array<String>
The list of task identifiers to retrieve.
1106 1107 1108 1109 1110 1111 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1106 class BatchGetThreatModelJobTasksInput < Struct.new( :agent_space_id, :threat_model_job_task_ids) SENSITIVE = [] include Aws::Structure end |