Class: Aws::SecurityAgent::Types::BatchGetThreatModelJobTasksOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the BatchGetThreatModelJobTasks operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#not_foundArray<String>

The list of task identifiers that were not found.

Returns:

  • (Array<String>)


1135
1136
1137
1138
1139
1140
# File 'lib/aws-sdk-securityagent/types.rb', line 1135

class BatchGetThreatModelJobTasksOutput < Struct.new(
  :threat_model_job_tasks,
  :not_found)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_job_tasksArray<Types::ThreatModelJobTask>

The list of threat model job tasks that were found.

Returns:



1135
1136
1137
1138
1139
1140
# File 'lib/aws-sdk-securityagent/types.rb', line 1135

class BatchGetThreatModelJobTasksOutput < Struct.new(
  :threat_model_job_tasks,
  :not_found)
  SENSITIVE = []
  include Aws::Structure
end