Class: Aws::SecurityAgent::Types::BatchGetThreatModelJobsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the BatchGetThreatModelJobs operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#not_foundArray<String>

The list of threat model job identifiers that were not found.

Returns:

  • (Array<String>)


1164
1165
1166
1167
1168
1169
# File 'lib/aws-sdk-securityagent/types.rb', line 1164

class BatchGetThreatModelJobsOutput < Struct.new(
  :threat_model_jobs,
  :not_found)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_jobsArray<Types::ThreatModelJob>

The list of threat model jobs that were found.

Returns:



1164
1165
1166
1167
1168
1169
# File 'lib/aws-sdk-securityagent/types.rb', line 1164

class BatchGetThreatModelJobsOutput < Struct.new(
  :threat_model_jobs,
  :not_found)
  SENSITIVE = []
  include Aws::Structure
end