Class: Aws::SecurityAgent::Types::BatchGetThreatModelsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for retrieving multiple threat models by their IDs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the threat models.

Returns:

  • (String)


1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-securityagent/types.rb', line 1184

class BatchGetThreatModelsInput < Struct.new(
  :threat_model_ids,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_idsArray<String>

The list of threat model identifiers to retrieve.

Returns:

  • (Array<String>)


1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-securityagent/types.rb', line 1184

class BatchGetThreatModelsInput < Struct.new(
  :threat_model_ids,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end