Class: Aws::SecurityAgent::Types::BatchGetThreatModelsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetThreatModelsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchGetThreatModels operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#not_found ⇒ Array<String>
The list of threat model identifiers that were not found.
-
#threat_models ⇒ Array<Types::ThreatModel>
The list of threat models that were found.
Instance Attribute Details
#not_found ⇒ Array<String>
The list of threat model identifiers that were not found.
1203 1204 1205 1206 1207 1208 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1203 class BatchGetThreatModelsOutput < Struct.new( :threat_models, :not_found) SENSITIVE = [] include Aws::Structure end |
#threat_models ⇒ Array<Types::ThreatModel>
The list of threat models that were found.
1203 1204 1205 1206 1207 1208 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1203 class BatchGetThreatModelsOutput < Struct.new( :threat_models, :not_found) SENSITIVE = [] include Aws::Structure end |