Class: Aws::SecurityAgent::Types::BatchUpdateSecurityRequirementsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchUpdateSecurityRequirementsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#errors ⇒ Array<Types::BatchSecurityRequirementError>
The list of errors for security requirements that failed to be updated.
-
#updated_security_requirement_names ⇒ Array<String>
The list of security requirement names that were successfully updated.
Instance Attribute Details
#errors ⇒ Array<Types::BatchSecurityRequirementError>
The list of errors for security requirements that failed to be updated.
1303 1304 1305 1306 1307 1308 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1303 class BatchUpdateSecurityRequirementsOutput < Struct.new( :updated_security_requirement_names, :errors) SENSITIVE = [] include Aws::Structure end |
#updated_security_requirement_names ⇒ Array<String>
The list of security requirement names that were successfully updated.
1303 1304 1305 1306 1307 1308 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1303 class BatchUpdateSecurityRequirementsOutput < Struct.new( :updated_security_requirement_names, :errors) SENSITIVE = [] include Aws::Structure end |