Class: Aws::SecurityAgent::Types::BitbucketIntegrationInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

The configuration for creating a Bitbucket integration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The OAuth 2.0 authorization code returned from the consent redirect.

Returns:

  • (String)


1332
1333
1334
1335
1336
1337
1338
1339
# File 'lib/aws-sdk-securityagent/types.rb', line 1332

class BitbucketIntegrationInput < Struct.new(
  :installation_id,
  :workspace,
  :code,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#installation_idString

The Atlassian installation identifier, available from the Atlassian administration console.

Returns:

  • (String)


1332
1333
1334
1335
1336
1337
1338
1339
# File 'lib/aws-sdk-securityagent/types.rb', line 1332

class BitbucketIntegrationInput < Struct.new(
  :installation_id,
  :workspace,
  :code,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The CSRF state token echoed back from the OAuth redirect.

Returns:

  • (String)


1332
1333
1334
1335
1336
1337
1338
1339
# File 'lib/aws-sdk-securityagent/types.rb', line 1332

class BitbucketIntegrationInput < Struct.new(
  :installation_id,
  :workspace,
  :code,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#workspaceString

The Bitbucket workspace slug that identifies the workspace to integrate, for example acme-corp.

Returns:

  • (String)


1332
1333
1334
1335
1336
1337
1338
1339
# File 'lib/aws-sdk-securityagent/types.rb', line 1332

class BitbucketIntegrationInput < Struct.new(
  :installation_id,
  :workspace,
  :code,
  :state)
  SENSITIVE = []
  include Aws::Structure
end