Class: Aws::SecurityAgent::Types::CodeLocation

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a location in source code associated with a security finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#file_pathString

The absolute path to the file containing the code location.

Returns:

  • (String)


896
897
898
899
900
901
902
903
# File 'lib/aws-sdk-securityagent/types.rb', line 896

class CodeLocation < Struct.new(
  :file_path,
  :line_start,
  :line_end,
  :label)
  SENSITIVE = []
  include Aws::Structure
end

#labelString

The role of this location in the vulnerability, such as source or sink.

Returns:

  • (String)


896
897
898
899
900
901
902
903
# File 'lib/aws-sdk-securityagent/types.rb', line 896

class CodeLocation < Struct.new(
  :file_path,
  :line_start,
  :line_end,
  :label)
  SENSITIVE = []
  include Aws::Structure
end

#line_endInteger

The ending line number of the code location.

Returns:

  • (Integer)


896
897
898
899
900
901
902
903
# File 'lib/aws-sdk-securityagent/types.rb', line 896

class CodeLocation < Struct.new(
  :file_path,
  :line_start,
  :line_end,
  :label)
  SENSITIVE = []
  include Aws::Structure
end

#line_startInteger

The starting line number of the code location.

Returns:

  • (Integer)


896
897
898
899
900
901
902
903
# File 'lib/aws-sdk-securityagent/types.rb', line 896

class CodeLocation < Struct.new(
  :file_path,
  :line_start,
  :line_end,
  :label)
  SENSITIVE = []
  include Aws::Structure
end