Class: Aws::SecurityAgent::Types::CodeRemediationTask
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CodeRemediationTask
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a code remediation task that was initiated to fix a security finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The current status of the code remediation task.
-
#status_reason ⇒ String
The reason for the current status of the code remediation task.
-
#task_details ⇒ Array<Types::CodeRemediationTaskDetails>
The list of details for the code remediation task, including repository name, code diff link, and pull request link.
Instance Attribute Details
#status ⇒ String
The current status of the code remediation task.
735 736 737 738 739 740 741 |
# File 'lib/aws-sdk-securityagent/types.rb', line 735 class CodeRemediationTask < Struct.new( :status, :status_reason, :task_details) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The reason for the current status of the code remediation task.
735 736 737 738 739 740 741 |
# File 'lib/aws-sdk-securityagent/types.rb', line 735 class CodeRemediationTask < Struct.new( :status, :status_reason, :task_details) SENSITIVE = [] include Aws::Structure end |
#task_details ⇒ Array<Types::CodeRemediationTaskDetails>
The list of details for the code remediation task, including repository name, code diff link, and pull request link.
735 736 737 738 739 740 741 |
# File 'lib/aws-sdk-securityagent/types.rb', line 735 class CodeRemediationTask < Struct.new( :status, :status_reason, :task_details) SENSITIVE = [] include Aws::Structure end |