Class: Aws::SecurityAgent::Types::CodeRemediationTaskDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CodeRemediationTaskDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains details about a code remediation task, including links to the code diff and pull request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_diff_link ⇒ String
The link to the code diff for the remediation.
-
#pull_request_link ⇒ String
The link to the pull request created for the remediation.
-
#repo_name ⇒ String
The name of the repository where the remediation was applied.
Instance Attribute Details
#code_diff_link ⇒ String
The link to the code diff for the remediation.
760 761 762 763 764 765 766 |
# File 'lib/aws-sdk-securityagent/types.rb', line 760 class CodeRemediationTaskDetails < Struct.new( :repo_name, :code_diff_link, :pull_request_link) SENSITIVE = [] include Aws::Structure end |
#pull_request_link ⇒ String
The link to the pull request created for the remediation.
760 761 762 763 764 765 766 |
# File 'lib/aws-sdk-securityagent/types.rb', line 760 class CodeRemediationTaskDetails < Struct.new( :repo_name, :code_diff_link, :pull_request_link) SENSITIVE = [] include Aws::Structure end |
#repo_name ⇒ String
The name of the repository where the remediation was applied.
760 761 762 763 764 765 766 |
# File 'lib/aws-sdk-securityagent/types.rb', line 760 class CodeRemediationTaskDetails < Struct.new( :repo_name, :code_diff_link, :pull_request_link) SENSITIVE = [] include Aws::Structure end |