Class: Aws::SecurityAgent::Types::CodeReview
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CodeReview
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a code review configuration that defines the parameters for automated security-focused code analysis, including target assets and logging configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the code review.
-
#assets ⇒ Types::Assets
The assets included in the code review.
-
#code_remediation_strategy ⇒ String
The code remediation strategy for the code review.
-
#code_review_id ⇒ String
The unique identifier of the code review.
-
#created_at ⇒ Time
The date and time the code review was created, in UTC format.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the code review.
-
#max_task_hours ⇒ Float
The maximum number of billable task hours allowed for jobs started from this code review.
-
#service_role ⇒ String
The IAM service role used for the code review.
-
#title ⇒ String
The title of the code review.
-
#updated_at ⇒ Time
The date and time the code review was last updated, in UTC format.
-
#validation_mode ⇒ String
The validation mode for the code review.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the code review.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets included in the code review.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The code remediation strategy for the code review.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_id ⇒ String
The unique identifier of the code review.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the code review was created, in UTC format.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the code review.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#max_task_hours ⇒ Float
The maximum number of billable task hours allowed for jobs started from this code review. If a job reaches the configured limit, it is gracefully stopped. If not set, jobs run to completion with no budget cap.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role used for the code review.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the code review.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the code review was last updated, in UTC format.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#validation_mode ⇒ String
The validation mode for the code review. Valid values are SIMULATED and DISABLED.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1594 class CodeReview < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode, :max_task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |