Class: Aws::SecurityAgent::Types::CodeReviewJobTask
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CodeReviewJobTask
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents an individual security test task within a code review job. Each task targets a specific risk type and executes independently.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#categories ⇒ Array<Types::Category>
The list of categories assigned to the task.
-
#code_review_id ⇒ String
The unique identifier of the code review associated with the task.
-
#code_review_job_id ⇒ String
The unique identifier of the code review job that contains the task.
-
#created_at ⇒ Time
The date and time the task was created, in UTC format.
-
#description ⇒ String
A description of the task.
-
#execution_status ⇒ String
The current execution status of the task.
-
#logs_location ⇒ Types::LogLocation
The location of the task execution logs.
-
#risk_type ⇒ String
The type of security risk the task is testing for.
-
#task_id ⇒ String
The unique identifier of the task.
-
#title ⇒ String
The title of the task.
-
#updated_at ⇒ Time
The date and time the task was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#categories ⇒ Array<Types::Category>
The list of categories assigned to the task.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_id ⇒ String
The unique identifier of the code review associated with the task.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_job_id ⇒ String
The unique identifier of the code review job that contains the task.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the task was created, in UTC format.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the task.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#execution_status ⇒ String
The current execution status of the task.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#logs_location ⇒ Types::LogLocation
The location of the task execution logs.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_type ⇒ String
The type of security risk the task is testing for.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the task.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the task was last updated, in UTC format.
1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class CodeReviewJobTask < Struct.new( :task_id, :code_review_id, :code_review_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |