Class: Aws::SecurityAgent::Types::CodeReviewSettings

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

The code review settings for an agent space, controlling which types of scanning are enabled.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#controls_scanningBoolean

Indicates whether controls scanning is enabled for code reviews.

Returns:

  • (Boolean)


782
783
784
785
786
787
# File 'lib/aws-sdk-securityagent/types.rb', line 782

class CodeReviewSettings < Struct.new(
  :controls_scanning,
  :general_purpose_scanning)
  SENSITIVE = []
  include Aws::Structure
end

#general_purpose_scanningBoolean

Indicates whether general-purpose scanning is enabled for code reviews.

Returns:

  • (Boolean)


782
783
784
785
786
787
# File 'lib/aws-sdk-securityagent/types.rb', line 782

class CodeReviewSettings < Struct.new(
  :controls_scanning,
  :general_purpose_scanning)
  SENSITIVE = []
  include Aws::Structure
end