Class: Aws::SecurityAgent::Types::ConflictException

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

The request could not be completed due to a conflict with the current state of the resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Error description.

Returns:

  • (String)


1940
1941
1942
1943
1944
# File 'lib/aws-sdk-securityagent/types.rb', line 1940

class ConflictException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end