Class: Aws::SecurityAgent::Types::ConfluenceIntegrationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ConfluenceIntegrationInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
The configuration for creating a Confluence integration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The OAuth 2.0 authorization code returned from the consent redirect.
-
#installation_id ⇒ String
The Atlassian installation identifier, available from the Atlassian administration console.
-
#site_url ⇒ String
The Confluence Cloud site URL, for example mysite.atlassian.net.
-
#state ⇒ String
The CSRF state token echoed back from the OAuth redirect.
Instance Attribute Details
#code ⇒ String
The OAuth 2.0 authorization code returned from the consent redirect.
2016 2017 2018 2019 2020 2021 2022 2023 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2016 class ConfluenceIntegrationInput < Struct.new( :installation_id, :code, :state, :site_url) SENSITIVE = [] include Aws::Structure end |
#installation_id ⇒ String
The Atlassian installation identifier, available from the Atlassian administration console.
2016 2017 2018 2019 2020 2021 2022 2023 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2016 class ConfluenceIntegrationInput < Struct.new( :installation_id, :code, :state, :site_url) SENSITIVE = [] include Aws::Structure end |
#site_url ⇒ String
The Confluence Cloud site URL, for example mysite.atlassian.net.
2016 2017 2018 2019 2020 2021 2022 2023 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2016 class ConfluenceIntegrationInput < Struct.new( :installation_id, :code, :state, :site_url) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The CSRF state token echoed back from the OAuth redirect.
2016 2017 2018 2019 2020 2021 2022 2023 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2016 class ConfluenceIntegrationInput < Struct.new( :installation_id, :code, :state, :site_url) SENSITIVE = [] include Aws::Structure end |