Class: Aws::SecurityAgent::Types::CreateAgentSpaceInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for creating a new agent space.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_resourcesTypes::AWSResources

The AWS resources to associate with the agent space.

Returns:



838
839
840
841
842
843
844
845
846
847
848
# File 'lib/aws-sdk-securityagent/types.rb', line 838

class CreateAgentSpaceInput < Struct.new(
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_settingsTypes::CodeReviewSettings

The code review settings for the agent space.



838
839
840
841
842
843
844
845
846
847
848
# File 'lib/aws-sdk-securityagent/types.rb', line 838

class CreateAgentSpaceInput < Struct.new(
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the agent space.

Returns:

  • (String)


838
839
840
841
842
843
844
845
846
847
848
# File 'lib/aws-sdk-securityagent/types.rb', line 838

class CreateAgentSpaceInput < Struct.new(
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The identifier of the AWS KMS key to use for encrypting data in the agent space.

Returns:

  • (String)


838
839
840
841
842
843
844
845
846
847
848
# File 'lib/aws-sdk-securityagent/types.rb', line 838

class CreateAgentSpaceInput < Struct.new(
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the agent space.

Returns:

  • (String)


838
839
840
841
842
843
844
845
846
847
848
# File 'lib/aws-sdk-securityagent/types.rb', line 838

class CreateAgentSpaceInput < Struct.new(
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to associate with the agent space.

Returns:

  • (Hash<String,String>)


838
839
840
841
842
843
844
845
846
847
848
# File 'lib/aws-sdk-securityagent/types.rb', line 838

class CreateAgentSpaceInput < Struct.new(
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#target_domain_idsArray<String>

The list of target domain identifiers to associate with the agent space.

Returns:

  • (Array<String>)


838
839
840
841
842
843
844
845
846
847
848
# File 'lib/aws-sdk-securityagent/types.rb', line 838

class CreateAgentSpaceInput < Struct.new(
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end