Class: Aws::SecurityAgent::Types::CreateAgentSpaceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateAgentSpaceOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the CreateAgentSpace operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the created agent space.
-
#aws_resources ⇒ Types::AWSResources
The AWS resources associated with the agent space.
-
#code_review_settings ⇒ Types::CodeReviewSettings
The code review settings for the agent space.
-
#created_at ⇒ Time
The date and time the agent space was created, in UTC format.
-
#description ⇒ String
The description of the agent space.
-
#kms_key_id ⇒ String
The identifier of the AWS KMS key used to encrypt data in the agent space.
-
#name ⇒ String
The name of the agent space.
-
#target_domain_ids ⇒ Array<String>
The list of target domain identifiers associated with the agent space.
-
#updated_at ⇒ Time
The date and time the agent space was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the created agent space.
892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-securityagent/types.rb', line 892 class CreateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#aws_resources ⇒ Types::AWSResources
The AWS resources associated with the agent space.
892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-securityagent/types.rb', line 892 class CreateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_settings ⇒ Types::CodeReviewSettings
The code review settings for the agent space.
892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-securityagent/types.rb', line 892 class CreateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the agent space was created, in UTC format.
892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-securityagent/types.rb', line 892 class CreateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the agent space.
892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-securityagent/types.rb', line 892 class CreateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier of the AWS KMS key used to encrypt data in the agent space.
892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-securityagent/types.rb', line 892 class CreateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the agent space.
892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-securityagent/types.rb', line 892 class CreateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#target_domain_ids ⇒ Array<String>
The list of target domain identifiers associated with the agent space.
892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-securityagent/types.rb', line 892 class CreateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the agent space was last updated, in UTC format.
892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-securityagent/types.rb', line 892 class CreateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |