Class: Aws::SecurityAgent::Types::CreateApplicationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_kms_key_idString

The identifier of the default AWS KMS key to use for encrypting data in the application.

Returns:

  • (String)


927
928
929
930
931
932
933
934
# File 'lib/aws-sdk-securityagent/types.rb', line 927

class CreateApplicationRequest < Struct.new(
  :idc_instance_arn,
  :role_arn,
  :default_kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idc_instance_arnString

The Amazon Resource Name (ARN) of the IAM Identity Center instance to associate with the application.

Returns:

  • (String)


927
928
929
930
931
932
933
934
# File 'lib/aws-sdk-securityagent/types.rb', line 927

class CreateApplicationRequest < Struct.new(
  :idc_instance_arn,
  :role_arn,
  :default_kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role to associate with the application.

Returns:

  • (String)


927
928
929
930
931
932
933
934
# File 'lib/aws-sdk-securityagent/types.rb', line 927

class CreateApplicationRequest < Struct.new(
  :idc_instance_arn,
  :role_arn,
  :default_kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to associate with the application.

Returns:

  • (Hash<String,String>)


927
928
929
930
931
932
933
934
# File 'lib/aws-sdk-securityagent/types.rb', line 927

class CreateApplicationRequest < Struct.new(
  :idc_instance_arn,
  :role_arn,
  :default_kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end