Class: Aws::SecurityAgent::Types::CreateCodeReviewInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for creating a new code review.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space to create the code review in.

Returns:

  • (String)


2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
# File 'lib/aws-sdk-securityagent/types.rb', line 2229

class CreateCodeReviewInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets to include in the code review, such as documents and source code.

Returns:



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
# File 'lib/aws-sdk-securityagent/types.rb', line 2229

class CreateCodeReviewInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The code remediation strategy for the code review. Valid values are AUTOMATIC and DISABLED.

Returns:

  • (String)


2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
# File 'lib/aws-sdk-securityagent/types.rb', line 2229

class CreateCodeReviewInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the code review.



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
# File 'lib/aws-sdk-securityagent/types.rb', line 2229

class CreateCodeReviewInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role to use for the code review.

Returns:

  • (String)


2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
# File 'lib/aws-sdk-securityagent/types.rb', line 2229

class CreateCodeReviewInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the code review.

Returns:

  • (String)


2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
# File 'lib/aws-sdk-securityagent/types.rb', line 2229

class CreateCodeReviewInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#validation_modeString

The validation mode for the code review. Valid values are SIMULATED and DISABLED.

Returns:

  • (String)


2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
# File 'lib/aws-sdk-securityagent/types.rb', line 2229

class CreateCodeReviewInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end