Class: Aws::SecurityAgent::Types::CreateCodeReviewOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the CreateCodeReview operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the code review.

Returns:

  • (String)


2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets included in the code review.

Returns:



2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The code remediation strategy for the code review.

Returns:

  • (String)


2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_idString

The unique identifier of the created code review.

Returns:

  • (String)


2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the code review was created, in UTC format.

Returns:

  • (Time)


2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the code review.



2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#max_task_hoursFloat

The maximum number of billable task hours configured for jobs started from this code review. Null if no budget cap is set.

Returns:

  • (Float)


2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the code review.

Returns:

  • (String)


2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the code review.

Returns:

  • (String)


2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the code review was last updated, in UTC format.

Returns:

  • (Time)


2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#validation_modeString

The validation mode for the code review.

Returns:

  • (String)


2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-securityagent/types.rb', line 2323

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end