Class: Aws::SecurityAgent::Types::CreateIntegrationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateIntegrationInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input ⇒ Types::ProviderInput
The provider-specific input required to create the integration.
-
#integration_display_name ⇒ String
The display name for the integration.
-
#kms_key_id ⇒ String
The identifier of the AWS KMS key to use for encrypting data associated with the integration.
-
#private_connection_name ⇒ String
The name of an active private connection used to reach a self-hosted provider instance over private networking.
-
#provider ⇒ String
The integration provider.
-
#tags ⇒ Hash<String,String>
The tags to associate with the integration.
Instance Attribute Details
#input ⇒ Types::ProviderInput
The provider-specific input required to create the integration.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2330 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#integration_display_name ⇒ String
The display name for the integration.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2330 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier of the AWS KMS key to use for encrypting data associated with the integration.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2330 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#private_connection_name ⇒ String
The name of an active private connection used to reach a self-hosted provider instance over private networking. Specify this when the instance is not publicly reachable.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2330 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The integration provider. Currently, only GITHUB is supported.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2330 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to associate with the integration.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2330 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags, :private_connection_name) SENSITIVE = [] include Aws::Structure end |