Class: Aws::SecurityAgent::Types::CreateMembershipRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Request structure for adding a single member to an agent space.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space to grant access to.

Returns:

  • (String)


1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-securityagent/types.rb', line 1018

class CreateMembershipRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :membership_id,
  :member_type,
  :config)
  SENSITIVE = []
  include Aws::Structure
end

#application_idString

The unique identifier of the application that contains the agent space.

Returns:

  • (String)


1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-securityagent/types.rb', line 1018

class CreateMembershipRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :membership_id,
  :member_type,
  :config)
  SENSITIVE = []
  include Aws::Structure
end

#configTypes::MembershipConfig

The configuration for the membership, such as the user role.



1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-securityagent/types.rb', line 1018

class CreateMembershipRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :membership_id,
  :member_type,
  :config)
  SENSITIVE = []
  include Aws::Structure
end

#member_typeString

The type of member. Currently, only USER is supported.

Returns:

  • (String)


1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-securityagent/types.rb', line 1018

class CreateMembershipRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :membership_id,
  :member_type,
  :config)
  SENSITIVE = []
  include Aws::Structure
end

#membership_idString

The unique identifier for the membership.

Returns:

  • (String)


1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/aws-sdk-securityagent/types.rb', line 1018

class CreateMembershipRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :membership_id,
  :member_type,
  :config)
  SENSITIVE = []
  include Aws::Structure
end