Class: Aws::SecurityAgent::Types::CreatePentestInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreatePentestInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for creating a new pentest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to create the pentest in.
-
#assets ⇒ Types::Assets
The assets to include in the pentest, such as endpoints, actors, documents, and source code.
-
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest.
-
#disable_managed_skills ⇒ Array<String>
A list of managed skills to disable for this pentest.
-
#exclude_risk_types ⇒ Array<String>
The list of risk types to exclude from the pentest.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest.
-
#max_task_hours ⇒ Float
The maximum number of billable task hours allowed for jobs started from this pentest.
-
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest, including custom headers and traffic rules.
-
#service_role ⇒ String
The IAM service role to use for the pentest.
-
#title ⇒ String
The title of the pentest.
-
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to create the pentest in.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets to include in the pentest, such as endpoints, actors, documents, and source code.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest. Valid values are AUTOMATIC and DISABLED.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#disable_managed_skills ⇒ Array<String>
A list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#exclude_risk_types ⇒ Array<String>
The list of risk types to exclude from the pentest.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#max_task_hours ⇒ Float
The maximum number of billable task hours allowed for jobs started from this pentest. Must be a positive number. If not set, jobs run to completion with no budget cap.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest, including custom headers and traffic rules.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role to use for the pentest.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the pentest.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2530 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |