Class: Aws::SecurityAgent::Types::CreatePrivateConnectionOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_expiry_timeTime

The date and time the connection’s certificate expires, in UTC format.

Returns:

  • (Time)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#dns_resolutionString

The DNS resolution mode for the resource gateway.

Returns:

  • (String)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

A message describing why the private connection entered a failed state, if applicable.

Returns:

  • (String)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#host_addressString

The IP address or DNS name of the target resource.

Returns:

  • (String)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the private connection.

Returns:

  • (String)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configuration_idString

The identifier or ARN of the VPC Lattice resource configuration.

Returns:

  • (String)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_gateway_idString

The identifier or ARN of the VPC Lattice resource gateway.

Returns:

  • (String)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the private connection.

Returns:

  • (String)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags attached to the private connection.

Returns:

  • (Hash<String,String>)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the private connection, indicating whether it is service-managed or self-managed.

Returns:

  • (String)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The identifier of the VPC the resource gateway is created in.

Returns:

  • (String)


2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
# File 'lib/aws-sdk-securityagent/types.rb', line 2583

class CreatePrivateConnectionOutput < Struct.new(
  :name,
  :type,
  :status,
  :resource_gateway_id,
  :host_address,
  :vpc_id,
  :resource_configuration_id,
  :certificate_expiry_time,
  :dns_resolution,
  :failure_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end