Class: Aws::SecurityAgent::Types::CreateSecurityRequirementPackInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateSecurityRequirementPackInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the security requirement pack.
-
#kms_key_id ⇒ String
The identifier of the AWS KMS key used to encrypt pack contents.
-
#name ⇒ String
The name of the security requirement pack.
-
#status ⇒ String
The status of the pack.
-
#tags ⇒ Hash<String,String>
The tags to associate with the security requirement pack.
Instance Attribute Details
#description ⇒ String
A description of the security requirement pack.
2657 2658 2659 2660 2661 2662 2663 2664 2665 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2657 class CreateSecurityRequirementPackInput < Struct.new( :name, :description, :status, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier of the AWS KMS key used to encrypt pack contents.
2657 2658 2659 2660 2661 2662 2663 2664 2665 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2657 class CreateSecurityRequirementPackInput < Struct.new( :name, :description, :status, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the security requirement pack.
2657 2658 2659 2660 2661 2662 2663 2664 2665 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2657 class CreateSecurityRequirementPackInput < Struct.new( :name, :description, :status, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the pack. Defaults to ENABLED if not provided.
2657 2658 2659 2660 2661 2662 2663 2664 2665 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2657 class CreateSecurityRequirementPackInput < Struct.new( :name, :description, :status, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to associate with the security requirement pack.
2657 2658 2659 2660 2661 2662 2663 2664 2665 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2657 class CreateSecurityRequirementPackInput < Struct.new( :name, :description, :status, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |