Class: Aws::SecurityAgent::Types::CreateSecurityRequirementPackOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateSecurityRequirementPackOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The identifier of the AWS KMS key used to encrypt pack contents.
-
#pack_id ⇒ String
The unique identifier of the created security requirement pack.
-
#status ⇒ String
The status of the created security requirement pack.
Instance Attribute Details
#kms_key_id ⇒ String
The identifier of the AWS KMS key used to encrypt pack contents.
2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2681 class CreateSecurityRequirementPackOutput < Struct.new( :pack_id, :status, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#pack_id ⇒ String
The unique identifier of the created security requirement pack.
2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2681 class CreateSecurityRequirementPackOutput < Struct.new( :pack_id, :status, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the created security requirement pack.
2681 2682 2683 2684 2685 2686 2687 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2681 class CreateSecurityRequirementPackOutput < Struct.new( :pack_id, :status, :kms_key_id) SENSITIVE = [] include Aws::Structure end |