Class: Aws::SecurityAgent::Types::CreateTargetDomainInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateTargetDomainInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for creating a new target domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tags ⇒ Hash<String,String>
The tags to associate with the target domain.
-
#target_domain_name ⇒ String
The domain name to register as a target domain.
-
#verification_method ⇒ String
The method to use for verifying domain ownership.
Instance Attribute Details
#tags ⇒ Hash<String,String>
The tags to associate with the target domain.
1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1162 class CreateTargetDomainInput < Struct.new( :target_domain_name, :verification_method, :tags) SENSITIVE = [] include Aws::Structure end |
#target_domain_name ⇒ String
The domain name to register as a target domain.
1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1162 class CreateTargetDomainInput < Struct.new( :target_domain_name, :verification_method, :tags) SENSITIVE = [] include Aws::Structure end |
#verification_method ⇒ String
The method to use for verifying domain ownership. Valid values are DNS_TXT, HTTP_ROUTE, and PRIVATE_VPC.
1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1162 class CreateTargetDomainInput < Struct.new( :target_domain_name, :verification_method, :tags) SENSITIVE = [] include Aws::Structure end |