Class: Aws::SecurityAgent::Types::CreateTargetDomainOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateTargetDomainOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the CreateTargetDomain operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the target domain was created, in UTC format.
-
#domain_name ⇒ String
The domain name of the target domain.
-
#target_domain_id ⇒ String
The unique identifier of the created target domain.
-
#verification_details ⇒ Types::VerificationDetails
The verification details for the target domain, including the verification token and instructions.
-
#verification_status ⇒ String
The current verification status of the target domain.
-
#verification_status_reason ⇒ String
The reason for the current target domain verification status.
-
#verified_at ⇒ Time
The date and time the target domain was verified, in UTC format.
Instance Attribute Details
#created_at ⇒ Time
The date and time the target domain was created, in UTC format.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1203 class CreateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name of the target domain.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1203 class CreateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#target_domain_id ⇒ String
The unique identifier of the created target domain.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1203 class CreateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verification_details ⇒ Types::VerificationDetails
The verification details for the target domain, including the verification token and instructions.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1203 class CreateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verification_status ⇒ String
The current verification status of the target domain.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1203 class CreateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verification_status_reason ⇒ String
The reason for the current target domain verification status.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1203 class CreateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verified_at ⇒ Time
The date and time the target domain was verified, in UTC format.
1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1203 class CreateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |