Class: Aws::SecurityAgent::Types::CreateThreatInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for creating a new threat.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#anchorTypes::ThreatAnchorShape

The DFD element this threat is anchored to.



2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#commentsString

Optional customer comment on the threat.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#evidenceArray<Types::ThreatEvidenceShape>

The source code files supporting the threat.

Returns:



2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#impacted_assetsArray<String>

The specific assets affected by the threat.

Returns:

  • (Array<String>)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#impacted_goalArray<String>

The security goals affected by the threat.

Returns:

  • (Array<String>)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#prerequisitesString

The conditions required for the threat to be exploitable.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#recommendationString

The recommended mitigation guidance for this threat.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

The severity level of the threat.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#statementString

The natural-language threat statement.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#strideArray<String>

The STRIDE categories applicable to this threat.

Returns:

  • (Array<String>)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#threat_actionString

What the threat source can do.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#threat_impactString

The direct consequence of the threat action.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#threat_job_idString

The unique identifier of the threat model job the threat belongs to.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#threat_sourceString

The actor or origin of the threat.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

A short title summarizing the threat.

Returns:

  • (String)


2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
# File 'lib/aws-sdk-securityagent/types.rb', line 2827

class CreateThreatInput < Struct.new(
  :agent_space_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :comments,
  :stride,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end