Class: Aws::SecurityAgent::Types::CreateThreatModelInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for creating a new threat model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space to create the threat model in.

Returns:

  • (String)


2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
# File 'lib/aws-sdk-securityagent/types.rb', line 2887

class CreateThreatModelInput < Struct.new(
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets to include in the threat model.

Returns:



2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
# File 'lib/aws-sdk-securityagent/types.rb', line 2887

class CreateThreatModelInput < Struct.new(
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the application or system being threat modeled.

Returns:

  • (String)


2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
# File 'lib/aws-sdk-securityagent/types.rb', line 2887

class CreateThreatModelInput < Struct.new(
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the threat model.



2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
# File 'lib/aws-sdk-securityagent/types.rb', line 2887

class CreateThreatModelInput < Struct.new(
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#report_destinationTypes::ReportDestination

The destination for publishing scan reports to an integrated document provider.



2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
# File 'lib/aws-sdk-securityagent/types.rb', line 2887

class CreateThreatModelInput < Struct.new(
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#scope_docsArray<Types::DocumentInfo>

The scoped documents for the agent to focus on during threat modeling.

Returns:



2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
# File 'lib/aws-sdk-securityagent/types.rb', line 2887

class CreateThreatModelInput < Struct.new(
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role to use for the threat model.

Returns:

  • (String)


2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
# File 'lib/aws-sdk-securityagent/types.rb', line 2887

class CreateThreatModelInput < Struct.new(
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the threat model.

Returns:

  • (String)


2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
# File 'lib/aws-sdk-securityagent/types.rb', line 2887

class CreateThreatModelInput < Struct.new(
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end