Class: Aws::SecurityAgent::Types::CreateThreatModelOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateThreatModelOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the CreateThreatModel operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the threat model.
-
#assets ⇒ Types::Assets
The assets included in the threat model.
-
#created_at ⇒ Time
The date and time the threat model was created, in UTC format.
-
#description ⇒ String
A description of the application or system being threat modeled.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the threat model.
-
#scope_docs ⇒ Array<Types::DocumentInfo>
The scoped documents for the agent to focus on during threat modeling.
-
#service_role ⇒ String
The IAM service role used for the threat model.
-
#threat_model_id ⇒ String
The unique identifier of the created threat model.
-
#title ⇒ String
The title of the threat model.
-
#updated_at ⇒ Time
The date and time the threat model was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the threat model.
2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2991 class CreateThreatModelOutput < Struct.new( :threat_model_id, :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets included in the threat model.
2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2991 class CreateThreatModelOutput < Struct.new( :threat_model_id, :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the threat model was created, in UTC format.
2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2991 class CreateThreatModelOutput < Struct.new( :threat_model_id, :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the application or system being threat modeled.
2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2991 class CreateThreatModelOutput < Struct.new( :threat_model_id, :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the threat model.
2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2991 class CreateThreatModelOutput < Struct.new( :threat_model_id, :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#scope_docs ⇒ Array<Types::DocumentInfo>
The scoped documents for the agent to focus on during threat modeling.
2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2991 class CreateThreatModelOutput < Struct.new( :threat_model_id, :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role used for the threat model.
2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2991 class CreateThreatModelOutput < Struct.new( :threat_model_id, :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_model_id ⇒ String
The unique identifier of the created threat model.
2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2991 class CreateThreatModelOutput < Struct.new( :threat_model_id, :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the threat model.
2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2991 class CreateThreatModelOutput < Struct.new( :threat_model_id, :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the threat model was last updated, in UTC format.
2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2991 class CreateThreatModelOutput < Struct.new( :threat_model_id, :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |