Class: Aws::SecurityAgent::Types::DeleteAgentSpaceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::DeleteAgentSpaceInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for deleting an agent space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to delete.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to delete.
3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3103 class DeleteAgentSpaceInput < Struct.new( :agent_space_id) SENSITIVE = [] include Aws::Structure end |