Class: Aws::SecurityAgent::Types::DeleteArtifactInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::DeleteArtifactInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the artifact.
-
#artifact_id ⇒ String
The unique identifier of the artifact to delete.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the artifact.
1285 1286 1287 1288 1289 1290 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1285 class DeleteArtifactInput < Struct.new( :agent_space_id, :artifact_id) SENSITIVE = [] include Aws::Structure end |
#artifact_id ⇒ String
The unique identifier of the artifact to delete.
1285 1286 1287 1288 1289 1290 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1285 class DeleteArtifactInput < Struct.new( :agent_space_id, :artifact_id) SENSITIVE = [] include Aws::Structure end |