Class: Aws::SecurityAgent::Types::DeleteCodeReviewFailure

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains information about a code review that failed to delete.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_review_idString

The unique identifier of the code review that failed to delete.

Returns:

  • (String)


3178
3179
3180
3181
3182
3183
# File 'lib/aws-sdk-securityagent/types.rb', line 3178

class DeleteCodeReviewFailure < Struct.new(
  :code_review_id,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The reason the code review failed to delete.

Returns:

  • (String)


3178
3179
3180
3181
3182
3183
# File 'lib/aws-sdk-securityagent/types.rb', line 3178

class DeleteCodeReviewFailure < Struct.new(
  :code_review_id,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end