Class: Aws::SecurityAgent::Types::DeleteMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::DeleteMembershipRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Request structure for removing a single member from an agent space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to revoke access from.
-
#application_id ⇒ String
The unique identifier of the application that contains the agent space.
-
#member_type ⇒ String
The type of member to remove.
-
#membership_id ⇒ String
The unique identifier of the membership to delete.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to revoke access from.
3212 3213 3214 3215 3216 3217 3218 3219 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3212 class DeleteMembershipRequest < Struct.new( :application_id, :agent_space_id, :membership_id, :member_type) SENSITIVE = [] include Aws::Structure end |
#application_id ⇒ String
The unique identifier of the application that contains the agent space.
3212 3213 3214 3215 3216 3217 3218 3219 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3212 class DeleteMembershipRequest < Struct.new( :application_id, :agent_space_id, :membership_id, :member_type) SENSITIVE = [] include Aws::Structure end |
#member_type ⇒ String
The type of member to remove.
3212 3213 3214 3215 3216 3217 3218 3219 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3212 class DeleteMembershipRequest < Struct.new( :application_id, :agent_space_id, :membership_id, :member_type) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique identifier of the membership to delete.
3212 3213 3214 3215 3216 3217 3218 3219 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3212 class DeleteMembershipRequest < Struct.new( :application_id, :agent_space_id, :membership_id, :member_type) SENSITIVE = [] include Aws::Structure end |