Class: Aws::SecurityAgent::Types::DeleteSecurityRequirementPackInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::DeleteSecurityRequirementPackInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pack_id ⇒ String
The unique identifier of the security requirement pack to delete.
Instance Attribute Details
#pack_id ⇒ String
The unique identifier of the security requirement pack to delete.
3329 3330 3331 3332 3333 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3329 class DeleteSecurityRequirementPackInput < Struct.new( :pack_id) SENSITIVE = [] include Aws::Structure end |