Class: Aws::SecurityAgent::Types::DeleteThreatModelFailure

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains information about a threat model that failed to delete.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#reasonString

The reason the threat model failed to delete.

Returns:

  • (String)


3379
3380
3381
3382
3383
3384
# File 'lib/aws-sdk-securityagent/types.rb', line 3379

class DeleteThreatModelFailure < Struct.new(
  :threat_model_id,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_idString

The unique identifier of the threat model that failed to delete.

Returns:

  • (String)


3379
3380
3381
3382
3383
3384
# File 'lib/aws-sdk-securityagent/types.rb', line 3379

class DeleteThreatModelFailure < Struct.new(
  :threat_model_id,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end