Class: Aws::SecurityAgent::Types::DescribePrivateConnectionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::DescribePrivateConnectionOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_expiry_time ⇒ Time
The date and time the connection’s certificate expires, in UTC format.
-
#dns_resolution ⇒ String
The DNS resolution mode for the resource gateway.
-
#failure_message ⇒ String
A message describing why the private connection entered a failed state, if applicable.
-
#host_address ⇒ String
The IP address or DNS name of the target resource.
-
#name ⇒ String
The name of the private connection.
-
#resource_configuration_id ⇒ String
The identifier or ARN of the VPC Lattice resource configuration.
-
#resource_gateway_id ⇒ String
The identifier or ARN of the VPC Lattice resource gateway.
-
#status ⇒ String
The current status of the private connection.
-
#tags ⇒ Hash<String,String>
The tags attached to the private connection.
-
#type ⇒ String
The type of the private connection, indicating whether it is service-managed or self-managed.
-
#vpc_id ⇒ String
The identifier of the VPC the resource gateway is created in.
Instance Attribute Details
#certificate_expiry_time ⇒ Time
The date and time the connection’s certificate expires, in UTC format.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#dns_resolution ⇒ String
The DNS resolution mode for the resource gateway.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
A message describing why the private connection entered a failed state, if applicable.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#host_address ⇒ String
The IP address or DNS name of the target resource.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the private connection.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_id ⇒ String
The identifier or ARN of the VPC Lattice resource configuration.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_gateway_id ⇒ String
The identifier or ARN of the VPC Lattice resource gateway.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the private connection.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags attached to the private connection.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the private connection, indicating whether it is service-managed or self-managed.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The identifier of the VPC the resource gateway is created in.
3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3447 class DescribePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |