Class: Aws::SecurityAgent::Types::DiscoveredEndpoint

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents an endpoint discovered during a pentest job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space associated with the discovered endpoint.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
# File 'lib/aws-sdk-securityagent/types.rb', line 1429

class DiscoveredEndpoint < Struct.new(
  :uri,
  :pentest_job_id,
  :task_id,
  :agent_space_id,
  :evidence,
  :operation,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the discovered endpoint.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
# File 'lib/aws-sdk-securityagent/types.rb', line 1429

class DiscoveredEndpoint < Struct.new(
  :uri,
  :pentest_job_id,
  :task_id,
  :agent_space_id,
  :evidence,
  :operation,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#evidenceString

The evidence that led to the discovery of the endpoint.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
# File 'lib/aws-sdk-securityagent/types.rb', line 1429

class DiscoveredEndpoint < Struct.new(
  :uri,
  :pentest_job_id,
  :task_id,
  :agent_space_id,
  :evidence,
  :operation,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#operationString

The HTTP operation associated with the discovered endpoint.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
# File 'lib/aws-sdk-securityagent/types.rb', line 1429

class DiscoveredEndpoint < Struct.new(
  :uri,
  :pentest_job_id,
  :task_id,
  :agent_space_id,
  :evidence,
  :operation,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job that discovered the endpoint.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
# File 'lib/aws-sdk-securityagent/types.rb', line 1429

class DiscoveredEndpoint < Struct.new(
  :uri,
  :pentest_job_id,
  :task_id,
  :agent_space_id,
  :evidence,
  :operation,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The unique identifier of the task that discovered the endpoint.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
# File 'lib/aws-sdk-securityagent/types.rb', line 1429

class DiscoveredEndpoint < Struct.new(
  :uri,
  :pentest_job_id,
  :task_id,
  :agent_space_id,
  :evidence,
  :operation,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#uriString

The URI of the discovered endpoint.

Returns:

  • (String)


1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
# File 'lib/aws-sdk-securityagent/types.rb', line 1429

class DiscoveredEndpoint < Struct.new(
  :uri,
  :pentest_job_id,
  :task_id,
  :agent_space_id,
  :evidence,
  :operation,
  :description)
  SENSITIVE = []
  include Aws::Structure
end