Class: Aws::SecurityAgent::Types::DocumentInfo

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a document that provides context for security testing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifact_idString

The unique identifier of the artifact associated with the document.

Returns:

  • (String)


3573
3574
3575
3576
3577
3578
3579
# File 'lib/aws-sdk-securityagent/types.rb', line 3573

class DocumentInfo < Struct.new(
  :s3_location,
  :artifact_id,
  :integrated_document)
  SENSITIVE = []
  include Aws::Structure
end

#integrated_documentTypes::IntegratedDocument

A reference to a document in an integrated third-party provider.



3573
3574
3575
3576
3577
3578
3579
# File 'lib/aws-sdk-securityagent/types.rb', line 3573

class DocumentInfo < Struct.new(
  :s3_location,
  :artifact_id,
  :integrated_document)
  SENSITIVE = []
  include Aws::Structure
end

#s3_locationString

The Amazon S3 location of the document.

Returns:

  • (String)


3573
3574
3575
3576
3577
3578
3579
# File 'lib/aws-sdk-securityagent/types.rb', line 3573

class DocumentInfo < Struct.new(
  :s3_location,
  :artifact_id,
  :integrated_document)
  SENSITIVE = []
  include Aws::Structure
end