Class: Aws::SecurityAgent::Types::ExecutionContext

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains contextual information about the execution of a pentest job, such as errors, warnings, or informational messages.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contextString

The context message.

Returns:

  • (String)


1538
1539
1540
1541
1542
1543
1544
# File 'lib/aws-sdk-securityagent/types.rb', line 1538

class ExecutionContext < Struct.new(
  :context_type,
  :context,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#context_typeString

The type of context. Valid values include ERROR, CLIENT_ERROR, WARNING, and INFO.

Returns:

  • (String)


1538
1539
1540
1541
1542
1543
1544
# File 'lib/aws-sdk-securityagent/types.rb', line 1538

class ExecutionContext < Struct.new(
  :context_type,
  :context,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The date and time the context was recorded, in UTC format.

Returns:

  • (Time)


1538
1539
1540
1541
1542
1543
1544
# File 'lib/aws-sdk-securityagent/types.rb', line 1538

class ExecutionContext < Struct.new(
  :context_type,
  :context,
  :timestamp)
  SENSITIVE = []
  include Aws::Structure
end