Class: Aws::SecurityAgent::Types::Finding
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::Finding
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a security finding discovered during a pentest job. A finding contains details about a vulnerability, including its risk level, confidence, and remediation status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space associated with the finding.
-
#alignment_rationale ⇒ String
The rationale provided by the alignment agent explaining how the finding was adjusted based on customer preferences.
-
#attack_script ⇒ String
The attack script used to reproduce the finding.
-
#code_locations ⇒ Array<Types::CodeLocation>
The file locations involved in the vulnerability, as reported by the code scanner.
-
#code_remediation_task ⇒ Types::CodeRemediationTask
The code remediation task associated with the finding, if code remediation was initiated.
-
#code_review_id ⇒ String
The unique identifier of the code review associated with the finding.
-
#code_review_job_id ⇒ String
The unique identifier of the code review job that produced the finding.
-
#confidence ⇒ String
The confidence level of the finding.
-
#created_at ⇒ Time
The date and time the finding was created, in UTC format.
-
#customer_note ⇒ String
A customer-provided note on the finding.
-
#description ⇒ String
A description of the finding.
-
#finding_id ⇒ String
The unique identifier of the finding.
-
#last_updated_by ⇒ String
The identifier of the entity that last updated the finding.
-
#name ⇒ String
The name of the finding.
-
#pentest_id ⇒ String
The unique identifier of the pentest associated with the finding.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job that produced the finding.
-
#reasoning ⇒ String
The reasoning behind the finding, explaining why it was identified as a vulnerability.
-
#risk_level ⇒ String
The risk level of the finding.
-
#risk_score ⇒ String
The numerical risk score of the finding.
-
#risk_type ⇒ String
The type of security risk identified by the finding.
-
#status ⇒ String
The current status of the finding.
-
#task_id ⇒ String
The unique identifier of the task that produced the finding.
-
#updated_at ⇒ Time
The date and time the finding was last updated, in UTC format.
-
#validation_status ⇒ String
The simulated validation status of the finding.
-
#verification_script ⇒ Types::VerificationScript
The verification script metadata for reproducing the finding, including download URL, instructions, and required environment variables.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space associated with the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#alignment_rationale ⇒ String
The rationale provided by the alignment agent explaining how the finding was adjusted based on customer preferences.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#attack_script ⇒ String
The attack script used to reproduce the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_locations ⇒ Array<Types::CodeLocation>
The file locations involved in the vulnerability, as reported by the code scanner.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_remediation_task ⇒ Types::CodeRemediationTask
The code remediation task associated with the finding, if code remediation was initiated.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_id ⇒ String
The unique identifier of the code review associated with the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_job_id ⇒ String
The unique identifier of the code review job that produced the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#confidence ⇒ String
The confidence level of the finding. Valid values include FALSE_POSITIVE, UNCONFIRMED, LOW, MEDIUM, and HIGH.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the finding was created, in UTC format.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#customer_note ⇒ String
A customer-provided note on the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#finding_id ⇒ String
The unique identifier of the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_by ⇒ String
The identifier of the entity that last updated the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest associated with the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job that produced the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#reasoning ⇒ String
The reasoning behind the finding, explaining why it was identified as a vulnerability.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_level ⇒ String
The risk level of the finding. Valid values include UNKNOWN, INFORMATIONAL, LOW, MEDIUM, HIGH, and CRITICAL.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_score ⇒ String
The numerical risk score of the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_type ⇒ String
The type of security risk identified by the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the finding. Valid values include ACTIVE, RESOLVED, ACCEPTED, and FALSE_POSITIVE.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task that produced the finding.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the finding was last updated, in UTC format.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#validation_status ⇒ String
The simulated validation status of the finding. Valid values are NOT_VALIDATED, VALIDATING, CONFIRMED, NOT_REPRODUCED, and VALIDATION_FAILED.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#verification_script ⇒ Types::VerificationScript
The verification script metadata for reproducing the finding, including download URL, instructions, and required environment variables.
3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3762 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :validation_status, :attack_script, :code_remediation_task, :last_updated_by, :customer_note, :code_locations, :verification_script, :alignment_rationale, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |