Class: Aws::SecurityAgent::Types::GetApplicationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::GetApplicationResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The unique identifier of the application.
-
#application_name ⇒ String
The name of the application.
-
#default_kms_key_id ⇒ String
The identifier of the default AWS KMS key used to encrypt data for the application.
-
#domain ⇒ String
The domain associated with the application.
-
#idc_configuration ⇒ Types::IdCConfiguration
The IAM Identity Center configuration for the application.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role associated with the application.
Instance Attribute Details
#application_id ⇒ String
The unique identifier of the application.
1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1758 class GetApplicationResponse < Struct.new( :application_id, :domain, :application_name, :idc_configuration, :role_arn, :default_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#application_name ⇒ String
The name of the application.
1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1758 class GetApplicationResponse < Struct.new( :application_id, :domain, :application_name, :idc_configuration, :role_arn, :default_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#default_kms_key_id ⇒ String
The identifier of the default AWS KMS key used to encrypt data for the application.
1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1758 class GetApplicationResponse < Struct.new( :application_id, :domain, :application_name, :idc_configuration, :role_arn, :default_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The domain associated with the application.
1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1758 class GetApplicationResponse < Struct.new( :application_id, :domain, :application_name, :idc_configuration, :role_arn, :default_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#idc_configuration ⇒ Types::IdCConfiguration
The IAM Identity Center configuration for the application.
1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1758 class GetApplicationResponse < Struct.new( :application_id, :domain, :application_name, :idc_configuration, :role_arn, :default_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role associated with the application.
1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1758 class GetApplicationResponse < Struct.new( :application_id, :domain, :application_name, :idc_configuration, :role_arn, :default_kms_key_id) SENSITIVE = [] include Aws::Structure end |