Class: Aws::SecurityAgent::Types::GetArtifactInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::GetArtifactInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the artifact.
-
#artifact_id ⇒ String
The unique identifier of the artifact to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the artifact.
1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class GetArtifactInput < Struct.new( :agent_space_id, :artifact_id) SENSITIVE = [] include Aws::Structure end |
#artifact_id ⇒ String
The unique identifier of the artifact to retrieve.
1779 1780 1781 1782 1783 1784 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1779 class GetArtifactInput < Struct.new( :agent_space_id, :artifact_id) SENSITIVE = [] include Aws::Structure end |