Class: Aws::SecurityAgent::Types::GetArtifactOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::GetArtifactOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the artifact.
-
#artifact ⇒ Types::Artifact
The artifact content and type.
-
#artifact_id ⇒ String
The unique identifier of the artifact.
-
#file_name ⇒ String
The file name of the artifact.
-
#updated_at ⇒ Time
The date and time the artifact was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the artifact.
1808 1809 1810 1811 1812 1813 1814 1815 1816 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1808 class GetArtifactOutput < Struct.new( :agent_space_id, :artifact_id, :artifact, :file_name, :updated_at) SENSITIVE = [] include Aws::Structure end |
#artifact ⇒ Types::Artifact
The artifact content and type.
1808 1809 1810 1811 1812 1813 1814 1815 1816 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1808 class GetArtifactOutput < Struct.new( :agent_space_id, :artifact_id, :artifact, :file_name, :updated_at) SENSITIVE = [] include Aws::Structure end |
#artifact_id ⇒ String
The unique identifier of the artifact.
1808 1809 1810 1811 1812 1813 1814 1815 1816 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1808 class GetArtifactOutput < Struct.new( :agent_space_id, :artifact_id, :artifact, :file_name, :updated_at) SENSITIVE = [] include Aws::Structure end |
#file_name ⇒ String
The file name of the artifact.
1808 1809 1810 1811 1812 1813 1814 1815 1816 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1808 class GetArtifactOutput < Struct.new( :agent_space_id, :artifact_id, :artifact, :file_name, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the artifact was last updated, in UTC format.
1808 1809 1810 1811 1812 1813 1814 1815 1816 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1808 class GetArtifactOutput < Struct.new( :agent_space_id, :artifact_id, :artifact, :file_name, :updated_at) SENSITIVE = [] include Aws::Structure end |