Class: Aws::SecurityAgent::Types::GetIntegrationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::GetIntegrationOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name of the integration.
-
#installation_id ⇒ String
The installation identifier from the integration provider.
-
#integration_id ⇒ String
The unique identifier of the integration.
-
#kms_key_id ⇒ String
The identifier of the AWS KMS key used to encrypt data associated with the integration.
-
#private_connection_name ⇒ String
The name of the private connection used to reach the integration’s self-hosted instance over private networking, if one is configured.
-
#provider ⇒ String
The integration provider.
-
#provider_type ⇒ String
The type of the integration provider.
-
#target_url ⇒ String
The HTTPS URL of the customer self-hosted instance, such as a GitHub Enterprise Server or self-managed GitLab instance.
Instance Attribute Details
#display_name ⇒ String
The display name of the integration.
4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4024 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id, :target_url, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#installation_id ⇒ String
The installation identifier from the integration provider.
4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4024 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id, :target_url, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#integration_id ⇒ String
The unique identifier of the integration.
4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4024 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id, :target_url, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier of the AWS KMS key used to encrypt data associated with the integration.
4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4024 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id, :target_url, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#private_connection_name ⇒ String
The name of the private connection used to reach the integration’s self-hosted instance over private networking, if one is configured.
4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4024 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id, :target_url, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The integration provider.
4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4024 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id, :target_url, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#provider_type ⇒ String
The type of the integration provider.
4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4024 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id, :target_url, :private_connection_name) SENSITIVE = [] include Aws::Structure end |
#target_url ⇒ String
The HTTPS URL of the customer self-hosted instance, such as a GitHub Enterprise Server or self-managed GitLab instance. This value is absent for SaaS integrations.
4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4024 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id, :target_url, :private_connection_name) SENSITIVE = [] include Aws::Structure end |