Class: Aws::SecurityAgent::Types::GetSecurityRequirementPackOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time the security requirement pack was created, in UTC format.

Returns:

  • (Time)


4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/aws-sdk-securityagent/types.rb', line 4095

class GetSecurityRequirementPackOutput < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :import_status,
  :created_at,
  :updated_at,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the security requirement pack.

Returns:

  • (String)


4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/aws-sdk-securityagent/types.rb', line 4095

class GetSecurityRequirementPackOutput < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :import_status,
  :created_at,
  :updated_at,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#import_statusString

The status of the security requirements import workflow for this pack.

Returns:

  • (String)


4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/aws-sdk-securityagent/types.rb', line 4095

class GetSecurityRequirementPackOutput < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :import_status,
  :created_at,
  :updated_at,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The identifier of the AWS KMS key used to encrypt pack contents.

Returns:

  • (String)


4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/aws-sdk-securityagent/types.rb', line 4095

class GetSecurityRequirementPackOutput < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :import_status,
  :created_at,
  :updated_at,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#management_typeString

The management type of the pack. Valid values are AWS_MANAGED and CUSTOMER_MANAGED.

Returns:

  • (String)


4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/aws-sdk-securityagent/types.rb', line 4095

class GetSecurityRequirementPackOutput < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :import_status,
  :created_at,
  :updated_at,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the security requirement pack.

Returns:

  • (String)


4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/aws-sdk-securityagent/types.rb', line 4095

class GetSecurityRequirementPackOutput < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :import_status,
  :created_at,
  :updated_at,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#pack_idString

The unique identifier of the security requirement pack.

Returns:

  • (String)


4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/aws-sdk-securityagent/types.rb', line 4095

class GetSecurityRequirementPackOutput < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :import_status,
  :created_at,
  :updated_at,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the security requirement pack.

Returns:

  • (String)


4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/aws-sdk-securityagent/types.rb', line 4095

class GetSecurityRequirementPackOutput < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :import_status,
  :created_at,
  :updated_at,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the security requirement pack was last updated, in UTC format.

Returns:

  • (Time)


4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/aws-sdk-securityagent/types.rb', line 4095

class GetSecurityRequirementPackOutput < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :import_status,
  :created_at,
  :updated_at,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_nameString

The vendor name for AWS managed packs, such as ISO or NIST.

Returns:

  • (String)


4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/aws-sdk-securityagent/types.rb', line 4095

class GetSecurityRequirementPackOutput < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :import_status,
  :created_at,
  :updated_at,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end