Class: Aws::SecurityAgent::Types::HttpVerification

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains HTTP route verification details for a target domain, including the route path and token to serve for domain ownership verification.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#route_pathString

The HTTP route path where the verification token must be served.

Returns:

  • (String)


1978
1979
1980
1981
1982
1983
# File 'lib/aws-sdk-securityagent/types.rb', line 1978

class HttpVerification < Struct.new(
  :token,
  :route_path)
  SENSITIVE = []
  include Aws::Structure
end

#tokenString

The verification token to serve at the specified route path.

Returns:

  • (String)


1978
1979
1980
1981
1982
1983
# File 'lib/aws-sdk-securityagent/types.rb', line 1978

class HttpVerification < Struct.new(
  :token,
  :route_path)
  SENSITIVE = []
  include Aws::Structure
end