Class: Aws::SecurityAgent::Types::InitiateProviderRegistrationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::InitiateProviderRegistrationOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#csrf_state ⇒ String
The CSRF state token to use when completing the OAuth flow.
-
#redirect_to ⇒ String
The URL to redirect the user to for completing the OAuth authorization.
Instance Attribute Details
#csrf_state ⇒ String
The CSRF state token to use when completing the OAuth flow.
2029 2030 2031 2032 2033 2034 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2029 class InitiateProviderRegistrationOutput < Struct.new( :redirect_to, :csrf_state) SENSITIVE = [] include Aws::Structure end |
#redirect_to ⇒ String
The URL to redirect the user to for completing the OAuth authorization.
2029 2030 2031 2032 2033 2034 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2029 class InitiateProviderRegistrationOutput < Struct.new( :redirect_to, :csrf_state) SENSITIVE = [] include Aws::Structure end |