Class: Aws::SecurityAgent::Types::IntegratedDocument

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

A reference to a document in a third-party provider, such as a Confluence page linked via an integration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#integration_idString

The identifier of the integration that provides access to the document.

Returns:

  • (String)


4463
4464
4465
4466
4467
4468
# File 'lib/aws-sdk-securityagent/types.rb', line 4463

class IntegratedDocument < Struct.new(
  :integration_id,
  :resource_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The provider-specific resource identifier for the document.

Returns:

  • (String)


4463
4464
4465
4466
4467
4468
# File 'lib/aws-sdk-securityagent/types.rb', line 4463

class IntegratedDocument < Struct.new(
  :integration_id,
  :resource_id)
  SENSITIVE = []
  include Aws::Structure
end