Class: Aws::SecurityAgent::Types::IntegratedRepository

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a code repository that is integrated with the service through a third-party provider.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#branchString

An optional override for the repository branch.

Returns:

  • (String)


4488
4489
4490
4491
4492
4493
4494
# File 'lib/aws-sdk-securityagent/types.rb', line 4488

class IntegratedRepository < Struct.new(
  :integration_id,
  :provider_resource_id,
  :branch)
  SENSITIVE = []
  include Aws::Structure
end

#integration_idString

The unique identifier of the integration that provides access to the repository.

Returns:

  • (String)


4488
4489
4490
4491
4492
4493
4494
# File 'lib/aws-sdk-securityagent/types.rb', line 4488

class IntegratedRepository < Struct.new(
  :integration_id,
  :provider_resource_id,
  :branch)
  SENSITIVE = []
  include Aws::Structure
end

#provider_resource_idString

The provider-specific resource identifier for the repository.

Returns:

  • (String)


4488
4489
4490
4491
4492
4493
4494
# File 'lib/aws-sdk-securityagent/types.rb', line 4488

class IntegratedRepository < Struct.new(
  :integration_id,
  :provider_resource_id,
  :branch)
  SENSITIVE = []
  include Aws::Structure
end