Class: Aws::SecurityAgent::Types::ListCodeReviewJobTasksInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for listing tasks associated with a code review job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
# File 'lib/aws-sdk-securityagent/types.rb', line 4971

class ListCodeReviewJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :code_review_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#category_nameString

Filter tasks by category name.

Returns:

  • (String)


4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
# File 'lib/aws-sdk-securityagent/types.rb', line 4971

class ListCodeReviewJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :code_review_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_job_idString

The unique identifier of the code review job to list tasks for.

Returns:

  • (String)


4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
# File 'lib/aws-sdk-securityagent/types.rb', line 4971

class ListCodeReviewJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :code_review_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
# File 'lib/aws-sdk-securityagent/types.rb', line 4971

class ListCodeReviewJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :code_review_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:

  • (String)


4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
# File 'lib/aws-sdk-securityagent/types.rb', line 4971

class ListCodeReviewJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :code_review_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#step_nameString

Filter tasks by step name.

Returns:

  • (String)


4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
# File 'lib/aws-sdk-securityagent/types.rb', line 4971

class ListCodeReviewJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :code_review_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end