Class: Aws::SecurityAgent::Types::ListCodeReviewsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListCodeReviewsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the ListCodeReviews operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_review_summaries ⇒ Array<Types::CodeReviewSummary>
The list of code review summaries.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
Instance Attribute Details
#code_review_summaries ⇒ Array<Types::CodeReviewSummary>
The list of code review summaries.
5100 5101 5102 5103 5104 5105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5100 class ListCodeReviewsOutput < Struct.new( :code_review_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5100 5101 5102 5103 5104 5105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5100 class ListCodeReviewsOutput < Struct.new( :code_review_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |