Class: Aws::SecurityAgent::Types::ListDiscoveredEndpointsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for ListDiscoveredEndpoints operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


5135
5136
5137
5138
5139
5140
5141
5142
5143
# File 'lib/aws-sdk-securityagent/types.rb', line 5135

class ListDiscoveredEndpointsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :agent_space_id,
  :prefix,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


5135
5136
5137
5138
5139
5140
5141
5142
5143
# File 'lib/aws-sdk-securityagent/types.rb', line 5135

class ListDiscoveredEndpointsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :agent_space_id,
  :prefix,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:

  • (String)


5135
5136
5137
5138
5139
5140
5141
5142
5143
# File 'lib/aws-sdk-securityagent/types.rb', line 5135

class ListDiscoveredEndpointsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :agent_space_id,
  :prefix,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job to list discovered endpoints for.

Returns:

  • (String)


5135
5136
5137
5138
5139
5140
5141
5142
5143
# File 'lib/aws-sdk-securityagent/types.rb', line 5135

class ListDiscoveredEndpointsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :agent_space_id,
  :prefix,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#prefixString

A prefix to filter discovered endpoints by URI.

Returns:

  • (String)


5135
5136
5137
5138
5139
5140
5141
5142
5143
# File 'lib/aws-sdk-securityagent/types.rb', line 5135

class ListDiscoveredEndpointsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :agent_space_id,
  :prefix,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end