Class: Aws::SecurityAgent::Types::ListFindingsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for ListFindings operation with filtering support.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
# File 'lib/aws-sdk-securityagent/types.rb', line 5215

class ListFindingsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :code_review_job_id,
  :agent_space_id,
  :next_token,
  :risk_type,
  :risk_level,
  :status,
  :confidence,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_job_idString

The unique identifier of the code review job to list findings for. Mutually exclusive with pentestJobId.

Returns:

  • (String)


5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
# File 'lib/aws-sdk-securityagent/types.rb', line 5215

class ListFindingsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :code_review_job_id,
  :agent_space_id,
  :next_token,
  :risk_type,
  :risk_level,
  :status,
  :confidence,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#confidenceString

Filter findings by confidence level.

Returns:

  • (String)


5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
# File 'lib/aws-sdk-securityagent/types.rb', line 5215

class ListFindingsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :code_review_job_id,
  :agent_space_id,
  :next_token,
  :risk_type,
  :risk_level,
  :status,
  :confidence,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
# File 'lib/aws-sdk-securityagent/types.rb', line 5215

class ListFindingsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :code_review_job_id,
  :agent_space_id,
  :next_token,
  :risk_type,
  :risk_level,
  :status,
  :confidence,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Filter findings by name.

Returns:

  • (String)


5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
# File 'lib/aws-sdk-securityagent/types.rb', line 5215

class ListFindingsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :code_review_job_id,
  :agent_space_id,
  :next_token,
  :risk_type,
  :risk_level,
  :status,
  :confidence,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:

  • (String)


5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
# File 'lib/aws-sdk-securityagent/types.rb', line 5215

class ListFindingsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :code_review_job_id,
  :agent_space_id,
  :next_token,
  :risk_type,
  :risk_level,
  :status,
  :confidence,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job to list findings for.

Returns:

  • (String)


5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
# File 'lib/aws-sdk-securityagent/types.rb', line 5215

class ListFindingsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :code_review_job_id,
  :agent_space_id,
  :next_token,
  :risk_type,
  :risk_level,
  :status,
  :confidence,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#risk_levelString

Filter findings by risk level.

Returns:

  • (String)


5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
# File 'lib/aws-sdk-securityagent/types.rb', line 5215

class ListFindingsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :code_review_job_id,
  :agent_space_id,
  :next_token,
  :risk_type,
  :risk_level,
  :status,
  :confidence,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#risk_typeString

Filter findings by risk type.

Returns:

  • (String)


5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
# File 'lib/aws-sdk-securityagent/types.rb', line 5215

class ListFindingsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :code_review_job_id,
  :agent_space_id,
  :next_token,
  :risk_type,
  :risk_level,
  :status,
  :confidence,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Filter findings by status.

Returns:

  • (String)


5215
5216
5217
5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
# File 'lib/aws-sdk-securityagent/types.rb', line 5215

class ListFindingsInput < Struct.new(
  :max_results,
  :pentest_job_id,
  :code_review_job_id,
  :agent_space_id,
  :next_token,
  :risk_type,
  :risk_level,
  :status,
  :confidence,
  :name)
  SENSITIVE = []
  include Aws::Structure
end