Class: Aws::SecurityAgent::Types::ListFindingsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the ListFindings operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#findings_summariesArray<Types::FindingSummary>

The list of finding summaries.

Returns:



5245
5246
5247
5248
5249
5250
# File 'lib/aws-sdk-securityagent/types.rb', line 5245

class ListFindingsOutput < Struct.new(
  :findings_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:



5245
5246
5247
5248
5249
5250
# File 'lib/aws-sdk-securityagent/types.rb', line 5245

class ListFindingsOutput < Struct.new(
  :findings_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end