Class: Aws::SecurityAgent::Types::ListIntegratedResourcesInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space to list integrated resources for.

Returns:

  • (String)


5278
5279
5280
5281
5282
5283
5284
5285
5286
# File 'lib/aws-sdk-securityagent/types.rb', line 5278

class ListIntegratedResourcesInput < Struct.new(
  :agent_space_id,
  :integration_id,
  :resource_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#integration_idString

The unique identifier of the integration to filter by.

Returns:

  • (String)


5278
5279
5280
5281
5282
5283
5284
5285
5286
# File 'lib/aws-sdk-securityagent/types.rb', line 5278

class ListIntegratedResourcesInput < Struct.new(
  :agent_space_id,
  :integration_id,
  :resource_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


5278
5279
5280
5281
5282
5283
5284
5285
5286
# File 'lib/aws-sdk-securityagent/types.rb', line 5278

class ListIntegratedResourcesInput < Struct.new(
  :agent_space_id,
  :integration_id,
  :resource_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:

  • (String)


5278
5279
5280
5281
5282
5283
5284
5285
5286
# File 'lib/aws-sdk-securityagent/types.rb', line 5278

class ListIntegratedResourcesInput < Struct.new(
  :agent_space_id,
  :integration_id,
  :resource_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource to filter by.

Returns:

  • (String)


5278
5279
5280
5281
5282
5283
5284
5285
5286
# File 'lib/aws-sdk-securityagent/types.rb', line 5278

class ListIntegratedResourcesInput < Struct.new(
  :agent_space_id,
  :integration_id,
  :resource_type,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end