Class: Aws::SecurityAgent::Types::ListIntegrationsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterTypes::IntegrationFilter

A filter to apply to the list of integrations.

Returns:



5325
5326
5327
5328
5329
5330
5331
# File 'lib/aws-sdk-securityagent/types.rb', line 5325

class ListIntegrationsInput < Struct.new(
  :filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:



5325
5326
5327
5328
5329
5330
5331
# File 'lib/aws-sdk-securityagent/types.rb', line 5325

class ListIntegrationsInput < Struct.new(
  :filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:



5325
5326
5327
5328
5329
5330
5331
# File 'lib/aws-sdk-securityagent/types.rb', line 5325

class ListIntegrationsInput < Struct.new(
  :filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end