Class: Aws::SecurityAgent::Types::ListIntegrationsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#integration_summariesArray<Types::IntegrationSummary>

The list of integration summaries.

Returns:



5346
5347
5348
5349
5350
5351
# File 'lib/aws-sdk-securityagent/types.rb', line 5346

class ListIntegrationsOutput < Struct.new(
  :integration_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:

  • (String)


5346
5347
5348
5349
5350
5351
# File 'lib/aws-sdk-securityagent/types.rb', line 5346

class ListIntegrationsOutput < Struct.new(
  :integration_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end