Class: Aws::SecurityAgent::Types::ListMembershipsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Request structure for listing agent space members.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space to list memberships for.

Returns:

  • (String)


5381
5382
5383
5384
5385
5386
5387
5388
5389
# File 'lib/aws-sdk-securityagent/types.rb', line 5381

class ListMembershipsRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :member_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#application_idString

The unique identifier of the application that contains the agent space.

Returns:

  • (String)


5381
5382
5383
5384
5385
5386
5387
5388
5389
# File 'lib/aws-sdk-securityagent/types.rb', line 5381

class ListMembershipsRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :member_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


5381
5382
5383
5384
5385
5386
5387
5388
5389
# File 'lib/aws-sdk-securityagent/types.rb', line 5381

class ListMembershipsRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :member_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#member_typeString

Filter memberships by member type.

Returns:

  • (String)


5381
5382
5383
5384
5385
5386
5387
5388
5389
# File 'lib/aws-sdk-securityagent/types.rb', line 5381

class ListMembershipsRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :member_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:

  • (String)


5381
5382
5383
5384
5385
5386
5387
5388
5389
# File 'lib/aws-sdk-securityagent/types.rb', line 5381

class ListMembershipsRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :member_type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end