Class: Aws::SecurityAgent::Types::ListPentestJobTasksInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for listing tasks associated with a pentest job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:



5445
5446
5447
5448
5449
5450
5451
5452
5453
5454
# File 'lib/aws-sdk-securityagent/types.rb', line 5445

class ListPentestJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :pentest_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#category_nameString

Filter tasks by category name.

Returns:



5445
5446
5447
5448
5449
5450
5451
5452
5453
5454
# File 'lib/aws-sdk-securityagent/types.rb', line 5445

class ListPentestJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :pentest_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:



5445
5446
5447
5448
5449
5450
5451
5452
5453
5454
# File 'lib/aws-sdk-securityagent/types.rb', line 5445

class ListPentestJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :pentest_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:



5445
5446
5447
5448
5449
5450
5451
5452
5453
5454
# File 'lib/aws-sdk-securityagent/types.rb', line 5445

class ListPentestJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :pentest_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job to list tasks for.

Returns:



5445
5446
5447
5448
5449
5450
5451
5452
5453
5454
# File 'lib/aws-sdk-securityagent/types.rb', line 5445

class ListPentestJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :pentest_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#step_nameString

Filter tasks by step name. Valid values include PREFLIGHT, STATIC_ANALYSIS, PENTEST, VALIDATION, and FINALIZING.

Returns:



5445
5446
5447
5448
5449
5450
5451
5452
5453
5454
# File 'lib/aws-sdk-securityagent/types.rb', line 5445

class ListPentestJobTasksInput < Struct.new(
  :agent_space_id,
  :max_results,
  :pentest_job_id,
  :step_name,
  :category_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end