Class: Aws::SecurityAgent::Types::ListPentestJobTasksOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the ListPentestJobTasks operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:



5471
5472
5473
5474
5475
5476
# File 'lib/aws-sdk-securityagent/types.rb', line 5471

class ListPentestJobTasksOutput < Struct.new(
  :task_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#task_summariesArray<Types::TaskSummary>

The list of task summaries.

Returns:



5471
5472
5473
5474
5475
5476
# File 'lib/aws-sdk-securityagent/types.rb', line 5471

class ListPentestJobTasksOutput < Struct.new(
  :task_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end