Class: Aws::SecurityAgent::Types::ListPentestsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for listing pentests with optional filtering.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space to list pentests for.

Returns:

  • (String)


5551
5552
5553
5554
5555
5556
5557
# File 'lib/aws-sdk-securityagent/types.rb', line 5551

class ListPentestsInput < Struct.new(
  :max_results,
  :next_token,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


5551
5552
5553
5554
5555
5556
5557
# File 'lib/aws-sdk-securityagent/types.rb', line 5551

class ListPentestsInput < Struct.new(
  :max_results,
  :next_token,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:

  • (String)


5551
5552
5553
5554
5555
5556
5557
# File 'lib/aws-sdk-securityagent/types.rb', line 5551

class ListPentestsInput < Struct.new(
  :max_results,
  :next_token,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end