Class: Aws::SecurityAgent::Types::ListPentestsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the ListPentests operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:

  • (String)


5574
5575
5576
5577
5578
5579
# File 'lib/aws-sdk-securityagent/types.rb', line 5574

class ListPentestsOutput < Struct.new(
  :pentest_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_summariesArray<Types::PentestSummary>

The list of pentest summaries.

Returns:



5574
5575
5576
5577
5578
5579
# File 'lib/aws-sdk-securityagent/types.rb', line 5574

class ListPentestsOutput < Struct.new(
  :pentest_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end