Class: Aws::SecurityAgent::Types::ListPrivateConnectionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListPrivateConnectionsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of private connections to return in a single response.
-
#next_token ⇒ String
The token for the next page of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of private connections to return in a single response.
5592 5593 5594 5595 5596 5597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5592 class ListPrivateConnectionsInput < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next page of results.
5592 5593 5594 5595 5596 5597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5592 class ListPrivateConnectionsInput < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |