Class: Aws::SecurityAgent::Types::ListPrivateConnectionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListPrivateConnectionsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to retrieve the next page of results, if more results are available.
-
#private_connections ⇒ Array<Types::PrivateConnectionSummary>
The list of private connections.
Instance Attribute Details
#next_token ⇒ String
The token to use to retrieve the next page of results, if more results are available.
5610 5611 5612 5613 5614 5615 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5610 class ListPrivateConnectionsOutput < Struct.new( :private_connections, :next_token) SENSITIVE = [] include Aws::Structure end |
#private_connections ⇒ Array<Types::PrivateConnectionSummary>
The list of private connections.
5610 5611 5612 5613 5614 5615 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5610 class ListPrivateConnectionsOutput < Struct.new( :private_connections, :next_token) SENSITIVE = [] include Aws::Structure end |