Class: Aws::SecurityAgent::Types::ListSecurityRequirementsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return in a single request.

Returns:

  • (Integer)


5694
5695
5696
5697
5698
5699
5700
# File 'lib/aws-sdk-securityagent/types.rb', line 5694

class ListSecurityRequirementsInput < Struct.new(
  :pack_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token from a previous request to retrieve the next page of results.

Returns:

  • (String)


5694
5695
5696
5697
5698
5699
5700
# File 'lib/aws-sdk-securityagent/types.rb', line 5694

class ListSecurityRequirementsInput < Struct.new(
  :pack_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#pack_idString

The unique identifier of the security requirement pack to list requirements for.

Returns:

  • (String)


5694
5695
5696
5697
5698
5699
5700
# File 'lib/aws-sdk-securityagent/types.rb', line 5694

class ListSecurityRequirementsInput < Struct.new(
  :pack_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end