Class: Aws::SecurityAgent::Types::ListTargetDomainsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for listing target domains.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


5763
5764
5765
5766
5767
5768
# File 'lib/aws-sdk-securityagent/types.rb', line 5763

class ListTargetDomainsInput < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:

  • (String)


5763
5764
5765
5766
5767
5768
# File 'lib/aws-sdk-securityagent/types.rb', line 5763

class ListTargetDomainsInput < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end