Class: Aws::SecurityAgent::Types::ListTargetDomainsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the ListTargetDomains operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.

Returns:



5785
5786
5787
5788
5789
5790
# File 'lib/aws-sdk-securityagent/types.rb', line 5785

class ListTargetDomainsOutput < Struct.new(
  :target_domain_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#target_domain_summariesArray<Types::TargetDomainSummary>

The list of target domain summaries.

Returns:



5785
5786
5787
5788
5789
5790
# File 'lib/aws-sdk-securityagent/types.rb', line 5785

class ListTargetDomainsOutput < Struct.new(
  :target_domain_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end