Class: Aws::SecurityAgent::Types::ListThreatModelJobTasksOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListThreatModelJobTasksOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the ListThreatModelJobTasks operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#threat_model_job_task_summaries ⇒ Array<Types::ThreatModelJobTaskSummary>
The list of threat model job task summaries.
Instance Attribute Details
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
5835 5836 5837 5838 5839 5840 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5835 class ListThreatModelJobTasksOutput < Struct.new( :threat_model_job_task_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#threat_model_job_task_summaries ⇒ Array<Types::ThreatModelJobTaskSummary>
The list of threat model job task summaries.
5835 5836 5837 5838 5839 5840 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5835 class ListThreatModelJobTasksOutput < Struct.new( :threat_model_job_task_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |