Class: Aws::SecurityAgent::Types::ListThreatModelJobsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListThreatModelJobsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for ListThreatModelJobs operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#threat_model_id ⇒ String
The unique identifier of the threat model to list jobs for.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
5863 5864 5865 5866 5867 5868 5869 5870 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5863 class ListThreatModelJobsInput < Struct.new( :max_results, :threat_model_id, :agent_space_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
5863 5864 5865 5866 5867 5868 5869 5870 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5863 class ListThreatModelJobsInput < Struct.new( :max_results, :threat_model_id, :agent_space_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
5863 5864 5865 5866 5867 5868 5869 5870 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5863 class ListThreatModelJobsInput < Struct.new( :max_results, :threat_model_id, :agent_space_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#threat_model_id ⇒ String
The unique identifier of the threat model to list jobs for.
5863 5864 5865 5866 5867 5868 5869 5870 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5863 class ListThreatModelJobsInput < Struct.new( :max_results, :threat_model_id, :agent_space_id, :next_token) SENSITIVE = [] include Aws::Structure end |