Class: Aws::SecurityAgent::Types::ListThreatModelJobsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListThreatModelJobsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the ListThreatModelJobs operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#threat_model_job_summaries ⇒ Array<Types::ThreatModelJobSummary>
The list of threat model job summaries.
Instance Attribute Details
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
5885 5886 5887 5888 5889 5890 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5885 class ListThreatModelJobsOutput < Struct.new( :threat_model_job_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#threat_model_job_summaries ⇒ Array<Types::ThreatModelJobSummary>
The list of threat model job summaries.
5885 5886 5887 5888 5889 5890 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5885 class ListThreatModelJobsOutput < Struct.new( :threat_model_job_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |