Class: Aws::SecurityAgent::Types::ListThreatModelsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for listing threat models.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space to list threat models for.

Returns:

  • (String)


5909
5910
5911
5912
5913
5914
5915
# File 'lib/aws-sdk-securityagent/types.rb', line 5909

class ListThreatModelsInput < Struct.new(
  :max_results,
  :next_token,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.

Returns:

  • (Integer)


5909
5910
5911
5912
5913
5914
5915
# File 'lib/aws-sdk-securityagent/types.rb', line 5909

class ListThreatModelsInput < Struct.new(
  :max_results,
  :next_token,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response.

Returns:

  • (String)


5909
5910
5911
5912
5913
5914
5915
# File 'lib/aws-sdk-securityagent/types.rb', line 5909

class ListThreatModelsInput < Struct.new(
  :max_results,
  :next_token,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end