Class: Aws::SecurityAgent::Types::ListThreatModelsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListThreatModelsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the ListThreatModels operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#threat_model_summaries ⇒ Array<Types::ThreatModelSummary>
The list of threat model summaries.
Instance Attribute Details
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5930 class ListThreatModelsOutput < Struct.new( :threat_model_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#threat_model_summaries ⇒ Array<Types::ThreatModelSummary>
The list of threat model summaries.
5930 5931 5932 5933 5934 5935 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5930 class ListThreatModelsOutput < Struct.new( :threat_model_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |