Class: Aws::SecurityAgent::Types::ListThreatsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for listing threats.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.



5958
5959
5960
5961
5962
5963
5964
5965
# File 'lib/aws-sdk-securityagent/types.rb', line 5958

class ListThreatsInput < Struct.new(
  :threat_job_id,
  :agent_space_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single call.



5958
5959
5960
5961
5962
5963
5964
5965
# File 'lib/aws-sdk-securityagent/types.rb', line 5958

class ListThreatsInput < Struct.new(
  :threat_job_id,
  :agent_space_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response.



5958
5959
5960
5961
5962
5963
5964
5965
# File 'lib/aws-sdk-securityagent/types.rb', line 5958

class ListThreatsInput < Struct.new(
  :threat_job_id,
  :agent_space_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#threat_job_idString

The unique identifier of the threat model job to list threats for.



5958
5959
5960
5961
5962
5963
5964
5965
# File 'lib/aws-sdk-securityagent/types.rb', line 5958

class ListThreatsInput < Struct.new(
  :threat_job_id,
  :agent_space_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end