Class: Aws::SecurityAgent::Types::ListThreatsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListThreatsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the ListThreats operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#threats ⇒ Array<Types::ThreatSummary>
The list of threat summaries.
Instance Attribute Details
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
5980 5981 5982 5983 5984 5985 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5980 class ListThreatsOutput < Struct.new( :threats, :next_token) SENSITIVE = [] include Aws::Structure end |
#threats ⇒ Array<Types::ThreatSummary>
The list of threat summaries.
5980 5981 5982 5983 5984 5985 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5980 class ListThreatsOutput < Struct.new( :threats, :next_token) SENSITIVE = [] include Aws::Structure end |