Class: Aws::SecurityAgent::Types::MemberMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::MemberMetadata
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Note:
MemberMetadata is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MemberMetadata corresponding to the set member.
Contains metadata about a member. This is a union type that contains member-type-specific metadata.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#user ⇒ Types::UserMetadata
The user metadata for the member.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
5974 5975 5976 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5974 def unknown @unknown end |
#user ⇒ Types::UserMetadata
The user metadata for the member.
5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5974 class MemberMetadata < Struct.new( :user, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class User < MemberMetadata; end class Unknown < MemberMetadata; end end |