Class: Aws::SecurityAgent::Types::MembershipConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Note:

MembershipConfig is a union - when making an API calls you must set exactly one of the members.

Note:

MembershipConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MembershipConfig corresponding to the set member.

The configuration for a membership. This is a union type that contains member-type-specific configuration.

Direct Known Subclasses

Unknown, User

Defined Under Namespace

Classes: Unknown, User

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2946
2947
2948
# File 'lib/aws-sdk-securityagent/types.rb', line 2946

def unknown
  @unknown
end

#userTypes::UserConfig

The user configuration for the membership.

Returns:



2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
# File 'lib/aws-sdk-securityagent/types.rb', line 2946

class MembershipConfig < Struct.new(
  :user,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class User < MembershipConfig; end
  class Unknown < MembershipConfig; end
end