Class: Aws::SecurityAgent::Types::MembershipSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a membership.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
# File 'lib/aws-sdk-securityagent/types.rb', line 5991

class MembershipSummary < Struct.new(
  :membership_id,
  :application_id,
  :agent_space_id,
  :member_type,
  :config,
  :metadata,
  :created_at,
  :updated_at,
  :created_by,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#application_idString

The unique identifier of the application.

Returns:

  • (String)


5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
# File 'lib/aws-sdk-securityagent/types.rb', line 5991

class MembershipSummary < Struct.new(
  :membership_id,
  :application_id,
  :agent_space_id,
  :member_type,
  :config,
  :metadata,
  :created_at,
  :updated_at,
  :created_by,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#configTypes::MembershipConfig

The configuration for the membership.



5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
# File 'lib/aws-sdk-securityagent/types.rb', line 5991

class MembershipSummary < Struct.new(
  :membership_id,
  :application_id,
  :agent_space_id,
  :member_type,
  :config,
  :metadata,
  :created_at,
  :updated_at,
  :created_by,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the membership was created, in UTC format.

Returns:

  • (Time)


5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
# File 'lib/aws-sdk-securityagent/types.rb', line 5991

class MembershipSummary < Struct.new(
  :membership_id,
  :application_id,
  :agent_space_id,
  :member_type,
  :config,
  :metadata,
  :created_at,
  :updated_at,
  :created_by,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The identifier of the entity that created the membership.

Returns:

  • (String)


5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
# File 'lib/aws-sdk-securityagent/types.rb', line 5991

class MembershipSummary < Struct.new(
  :membership_id,
  :application_id,
  :agent_space_id,
  :member_type,
  :config,
  :metadata,
  :created_at,
  :updated_at,
  :created_by,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#member_typeString

The type of member.

Returns:

  • (String)


5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
# File 'lib/aws-sdk-securityagent/types.rb', line 5991

class MembershipSummary < Struct.new(
  :membership_id,
  :application_id,
  :agent_space_id,
  :member_type,
  :config,
  :metadata,
  :created_at,
  :updated_at,
  :created_by,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#membership_idString

The unique identifier of the membership.

Returns:

  • (String)


5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
# File 'lib/aws-sdk-securityagent/types.rb', line 5991

class MembershipSummary < Struct.new(
  :membership_id,
  :application_id,
  :agent_space_id,
  :member_type,
  :config,
  :metadata,
  :created_at,
  :updated_at,
  :created_by,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#metadataTypes::MemberMetadata

The metadata for the member.



5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
# File 'lib/aws-sdk-securityagent/types.rb', line 5991

class MembershipSummary < Struct.new(
  :membership_id,
  :application_id,
  :agent_space_id,
  :member_type,
  :config,
  :metadata,
  :created_at,
  :updated_at,
  :created_by,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the membership was last updated, in UTC format.

Returns:

  • (Time)


5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
# File 'lib/aws-sdk-securityagent/types.rb', line 5991

class MembershipSummary < Struct.new(
  :membership_id,
  :application_id,
  :agent_space_id,
  :member_type,
  :config,
  :metadata,
  :created_at,
  :updated_at,
  :created_by,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

The identifier of the entity that last updated the membership.

Returns:

  • (String)


5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
# File 'lib/aws-sdk-securityagent/types.rb', line 5991

class MembershipSummary < Struct.new(
  :membership_id,
  :application_id,
  :agent_space_id,
  :member_type,
  :config,
  :metadata,
  :created_at,
  :updated_at,
  :created_by,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end