Class: Aws::SecurityAgent::Types::NetworkTrafficConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

The network traffic configuration for a pentest, including custom headers and traffic rules.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_headersArray<Types::CustomHeader>

The list of custom HTTP headers to include in network traffic during testing.

Returns:



3031
3032
3033
3034
3035
3036
# File 'lib/aws-sdk-securityagent/types.rb', line 3031

class NetworkTrafficConfig < Struct.new(
  :rules,
  :custom_headers)
  SENSITIVE = []
  include Aws::Structure
end

#rulesArray<Types::NetworkTrafficRule>

The list of network traffic rules that control which URLs are allowed or denied during testing.

Returns:



3031
3032
3033
3034
3035
3036
# File 'lib/aws-sdk-securityagent/types.rb', line 3031

class NetworkTrafficConfig < Struct.new(
  :rules,
  :custom_headers)
  SENSITIVE = []
  include Aws::Structure
end