Class: Aws::SecurityAgent::Types::Pentest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a pentest configuration that defines the parameters for security testing, including target assets, risk type exclusions, and infrastructure settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the pentest.

Returns:

  • (String)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets included in the pentest.

Returns:



6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#clean_up_strategyString

Strategy for cleaning up resources after pentest job completion.

Returns:

  • (String)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The code remediation strategy for the pentest.

Returns:

  • (String)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the pentest was created, in UTC format.

Returns:

  • (Time)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#disable_managed_skillsArray<String>

A list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.

Returns:

  • (Array<String>)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_risk_typesArray<String>

The list of risk types excluded from the pentest.

Returns:

  • (Array<String>)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the pentest.



6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#max_task_hoursFloat

The maximum number of billable task hours allowed for jobs started from this pentest. If a job reaches the configured limit, it is gracefully stopped. If not set, jobs run to completion with no budget cap.

Returns:

  • (Float)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_traffic_configTypes::NetworkTrafficConfig

The network traffic configuration for the pentest.



6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest.

Returns:

  • (String)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the pentest.

Returns:

  • (String)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the pentest.

Returns:

  • (String)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the pentest was last updated, in UTC format.

Returns:

  • (Time)


6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

The VPC configuration for the pentest.

Returns:



6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
# File 'lib/aws-sdk-securityagent/types.rb', line 6186

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :max_task_hours,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end