Class: Aws::SecurityAgent::Types::PentestJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::PentestJobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains summary information about a pentest job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the pentest job was created, in UTC format.
-
#pentest_id ⇒ String
The unique identifier of the pentest associated with the job.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job.
-
#status ⇒ String
The current status of the pentest job.
-
#title ⇒ String
The title of the pentest job.
-
#updated_at ⇒ Time
The date and time the pentest job was last updated, in UTC format.
Instance Attribute Details
#created_at ⇒ Time
The date and time the pentest job was created, in UTC format.
6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6317 class PentestJobSummary < Struct.new( :pentest_job_id, :pentest_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest associated with the job.
6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6317 class PentestJobSummary < Struct.new( :pentest_job_id, :pentest_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job.
6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6317 class PentestJobSummary < Struct.new( :pentest_job_id, :pentest_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the pentest job.
6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6317 class PentestJobSummary < Struct.new( :pentest_job_id, :pentest_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the pentest job.
6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6317 class PentestJobSummary < Struct.new( :pentest_job_id, :pentest_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the pentest job was last updated, in UTC format.
6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6317 class PentestJobSummary < Struct.new( :pentest_job_id, :pentest_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |