Class: Aws::SecurityAgent::Types::PentestSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::PentestSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains summary information about a pentest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
-
#created_at ⇒ Time
The date and time the pentest was created, in UTC format.
-
#pentest_id ⇒ String
The unique identifier of the pentest.
-
#title ⇒ String
The title of the pentest.
-
#updated_at ⇒ Time
The date and time the pentest was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
4182 4183 4184 4185 4186 4187 4188 4189 4190 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4182 class PentestSummary < Struct.new( :pentest_id, :agent_space_id, :title, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the pentest was created, in UTC format.
4182 4183 4184 4185 4186 4187 4188 4189 4190 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4182 class PentestSummary < Struct.new( :pentest_id, :agent_space_id, :title, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest.
4182 4183 4184 4185 4186 4187 4188 4189 4190 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4182 class PentestSummary < Struct.new( :pentest_id, :agent_space_id, :title, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the pentest.
4182 4183 4184 4185 4186 4187 4188 4189 4190 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4182 class PentestSummary < Struct.new( :pentest_id, :agent_space_id, :title, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the pentest was last updated, in UTC format.
4182 4183 4184 4185 4186 4187 4188 4189 4190 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4182 class PentestSummary < Struct.new( :pentest_id, :agent_space_id, :title, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |