Class: Aws::SecurityAgent::Types::PrivateConnectionMode

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Note:

PrivateConnectionMode is a union - when making an API calls you must set exactly one of the members.

The configuration for a private connection. Specify either a service-managed or a self-managed mode.

Defined Under Namespace

Classes: SelfManaged, ServiceManaged, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#self_managedTypes::SelfManagedInput

The configuration for a self-managed private connection, where you manage your own resource configuration.



6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-securityagent/types.rb', line 6452

class PrivateConnectionMode < Struct.new(
  :service_managed,
  :self_managed,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ServiceManaged < PrivateConnectionMode; end
  class SelfManaged < PrivateConnectionMode; end
  class Unknown < PrivateConnectionMode; end
end

#service_managedTypes::ServiceManagedInput

The configuration for a service-managed private connection, where the service manages the resource gateway lifecycle.



6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
# File 'lib/aws-sdk-securityagent/types.rb', line 6452

class PrivateConnectionMode < Struct.new(
  :service_managed,
  :self_managed,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ServiceManaged < PrivateConnectionMode; end
  class SelfManaged < PrivateConnectionMode; end
  class Unknown < PrivateConnectionMode; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



6452
6453
6454
# File 'lib/aws-sdk-securityagent/types.rb', line 6452

def unknown
  @unknown
end