Class: Aws::SecurityAgent::Types::ProviderResourceCapabilities
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ProviderResourceCapabilities
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Note:
ProviderResourceCapabilities is a union - when making an API calls you must set exactly one of the members.
Note:
ProviderResourceCapabilities is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProviderResourceCapabilities corresponding to the set member.
The capabilities for an integrated resource from a third-party provider. This is a union type that contains provider-specific capabilities.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#github ⇒ Types::GitHubResourceCapabilities
The GitHub-specific resource capabilities.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#github ⇒ Types::GitHubResourceCapabilities
The GitHub-specific resource capabilities.
3371 3372 3373 3374 3375 3376 3377 3378 3379 3380 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3371 class ProviderResourceCapabilities < Struct.new( :github, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Github < ProviderResourceCapabilities; end class Unknown < ProviderResourceCapabilities; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3371 3372 3373 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3371 def unknown @unknown end |