Class: Aws::SecurityAgent::Types::ReportDestination

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Destination for publishing scan reports to an integrated document provider.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_idString

The container identifier where the report will be published.

Returns:

  • (String)


6550
6551
6552
6553
6554
6555
6556
6557
# File 'lib/aws-sdk-securityagent/types.rb', line 6550

class ReportDestination < Struct.new(
  :integration_id,
  :container_id,
  :parent_id,
  :document_id)
  SENSITIVE = []
  include Aws::Structure
end

#document_idString

The existing document identifier to update instead of creating a new document.

Returns:

  • (String)


6550
6551
6552
6553
6554
6555
6556
6557
# File 'lib/aws-sdk-securityagent/types.rb', line 6550

class ReportDestination < Struct.new(
  :integration_id,
  :container_id,
  :parent_id,
  :document_id)
  SENSITIVE = []
  include Aws::Structure
end

#integration_idString

The integration identifier for the document provider.

Returns:

  • (String)


6550
6551
6552
6553
6554
6555
6556
6557
# File 'lib/aws-sdk-securityagent/types.rb', line 6550

class ReportDestination < Struct.new(
  :integration_id,
  :container_id,
  :parent_id,
  :document_id)
  SENSITIVE = []
  include Aws::Structure
end

#parent_idString

The parent document identifier under which the report will be created.

Returns:

  • (String)


6550
6551
6552
6553
6554
6555
6556
6557
# File 'lib/aws-sdk-securityagent/types.rb', line 6550

class ReportDestination < Struct.new(
  :integration_id,
  :container_id,
  :parent_id,
  :document_id)
  SENSITIVE = []
  include Aws::Structure
end