Class: Aws::SecurityAgent::Types::SecurityRequirementPackSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::SecurityRequirementPackSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains summary information about a security requirement pack.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the security requirement pack was created, in UTC format.
-
#description ⇒ String
A description of the security requirement pack.
-
#management_type ⇒ String
The management type of the pack.
-
#name ⇒ String
The name of the security requirement pack.
-
#pack_id ⇒ String
The unique identifier of the security requirement pack.
-
#status ⇒ String
The status of the security requirement pack.
-
#updated_at ⇒ Time
The date and time the security requirement pack was last updated, in UTC format.
-
#vendor_name ⇒ String
The vendor name for AWS managed packs.
Instance Attribute Details
#created_at ⇒ Time
The date and time the security requirement pack was created, in UTC format.
6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6727 class SecurityRequirementPackSummary < Struct.new( :pack_id, :name, :description, :vendor_name, :management_type, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the security requirement pack.
6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6727 class SecurityRequirementPackSummary < Struct.new( :pack_id, :name, :description, :vendor_name, :management_type, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#management_type ⇒ String
The management type of the pack.
6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6727 class SecurityRequirementPackSummary < Struct.new( :pack_id, :name, :description, :vendor_name, :management_type, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the security requirement pack.
6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6727 class SecurityRequirementPackSummary < Struct.new( :pack_id, :name, :description, :vendor_name, :management_type, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pack_id ⇒ String
The unique identifier of the security requirement pack.
6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6727 class SecurityRequirementPackSummary < Struct.new( :pack_id, :name, :description, :vendor_name, :management_type, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the security requirement pack.
6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6727 class SecurityRequirementPackSummary < Struct.new( :pack_id, :name, :description, :vendor_name, :management_type, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the security requirement pack was last updated, in UTC format.
6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6727 class SecurityRequirementPackSummary < Struct.new( :pack_id, :name, :description, :vendor_name, :management_type, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#vendor_name ⇒ String
The vendor name for AWS managed packs.
6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6727 class SecurityRequirementPackSummary < Struct.new( :pack_id, :name, :description, :vendor_name, :management_type, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |