Class: Aws::SecurityAgent::Types::ServiceManagedInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

The configuration for a service-managed private connection.

Constant Summary collapse

SENSITIVE =
[:certificate]

Instance Attribute Summary collapse

Instance Attribute Details

#certificateString

The certificate for the private connection.

Returns:

  • (String)


6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-securityagent/types.rb', line 6751

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = [:certificate]
  include Aws::Structure
end

#dns_resolutionString

The DNS resolution mode for the resource gateway. Defaults to PUBLIC when not set.

Returns:

  • (String)


6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-securityagent/types.rb', line 6751

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = [:certificate]
  include Aws::Structure
end

#host_addressString

The IP address or DNS name of the target resource.

Returns:

  • (String)


6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-securityagent/types.rb', line 6751

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = [:certificate]
  include Aws::Structure
end

#ip_address_typeString

The IP address type of the service-managed resource gateway.

Returns:

  • (String)


6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-securityagent/types.rb', line 6751

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = [:certificate]
  include Aws::Structure
end

#ipv4_addresses_per_eniInteger

The number of IPv4 addresses in each elastic network interface for the service-managed resource gateway.

Returns:

  • (Integer)


6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-securityagent/types.rb', line 6751

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = [:certificate]
  include Aws::Structure
end

#port_rangesArray<String>

The TCP port ranges that a consumer can use to access the resource.

Returns:

  • (Array<String>)


6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-securityagent/types.rb', line 6751

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = [:certificate]
  include Aws::Structure
end

#security_group_idsArray<String>

The security groups to attach to the service-managed resource gateway.

Returns:

  • (Array<String>)


6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-securityagent/types.rb', line 6751

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = [:certificate]
  include Aws::Structure
end

#subnet_idsArray<String>

The subnets that the service-managed resource gateway spans.

Returns:

  • (Array<String>)


6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-securityagent/types.rb', line 6751

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = [:certificate]
  include Aws::Structure
end

#vpc_idString

The VPC to create the service-managed resource gateway in.

Returns:

  • (String)


6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
# File 'lib/aws-sdk-securityagent/types.rb', line 6751

class ServiceManagedInput < Struct.new(
  :host_address,
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :ip_address_type,
  :ipv4_addresses_per_eni,
  :port_ranges,
  :certificate,
  :dns_resolution)
  SENSITIVE = [:certificate]
  include Aws::Structure
end