Class: Aws::SecurityAgent::Types::StartThreatModelJobInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::StartThreatModelJobInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for starting a threat model job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#threat_model_id ⇒ String
The unique identifier of the threat model to start a job for.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6976 class StartThreatModelJobInput < Struct.new( :agent_space_id, :threat_model_id) SENSITIVE = [] include Aws::Structure end |
#threat_model_id ⇒ String
The unique identifier of the threat model to start a job for.
6976 6977 6978 6979 6980 6981 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6976 class StartThreatModelJobInput < Struct.new( :agent_space_id, :threat_model_id) SENSITIVE = [] include Aws::Structure end |