Class: Aws::SecurityAgent::Types::StartThreatModelJobOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the StartThreatModelJob operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
# File 'lib/aws-sdk-securityagent/types.rb', line 7016

class StartThreatModelJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the threat model job was created, in UTC format.

Returns:

  • (Time)


7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
# File 'lib/aws-sdk-securityagent/types.rb', line 7016

class StartThreatModelJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the threat model job.

Returns:

  • (String)


7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
# File 'lib/aws-sdk-securityagent/types.rb', line 7016

class StartThreatModelJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_idString

The unique identifier of the threat model.

Returns:

  • (String)


7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
# File 'lib/aws-sdk-securityagent/types.rb', line 7016

class StartThreatModelJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_job_idString

The unique identifier of the started threat model job.

Returns:

  • (String)


7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
# File 'lib/aws-sdk-securityagent/types.rb', line 7016

class StartThreatModelJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the threat model job.

Returns:

  • (String)


7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
# File 'lib/aws-sdk-securityagent/types.rb', line 7016

class StartThreatModelJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the threat model job was last updated, in UTC format.

Returns:

  • (Time)


7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
# File 'lib/aws-sdk-securityagent/types.rb', line 7016

class StartThreatModelJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end