Class: Aws::SecurityAgent::Types::Step

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a step in the pentest job execution pipeline. Steps include preflight, static analysis, pentest, and finalizing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time the step was created, in UTC format.

Returns:

  • (Time)


3528
3529
3530
3531
3532
3533
3534
3535
# File 'lib/aws-sdk-securityagent/types.rb', line 3528

class Step < Struct.new(
  :name,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the step. Valid values include PREFLIGHT, STATIC_ANALYSIS, PENTEST, and FINALIZING.

Returns:

  • (String)


3528
3529
3530
3531
3532
3533
3534
3535
# File 'lib/aws-sdk-securityagent/types.rb', line 3528

class Step < Struct.new(
  :name,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the step.

Returns:

  • (String)


3528
3529
3530
3531
3532
3533
3534
3535
# File 'lib/aws-sdk-securityagent/types.rb', line 3528

class Step < Struct.new(
  :name,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the step was last updated, in UTC format.

Returns:

  • (Time)


3528
3529
3530
3531
3532
3533
3534
3535
# File 'lib/aws-sdk-securityagent/types.rb', line 3528

class Step < Struct.new(
  :name,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end