Class: Aws::SecurityAgent::Types::StopPentestJobInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::StopPentestJobInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for stopping the execution of a pentest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job to stop.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
7096 7097 7098 7099 7100 7101 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7096 class StopPentestJobInput < Struct.new( :agent_space_id, :pentest_job_id) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job to stop.
7096 7097 7098 7099 7100 7101 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7096 class StopPentestJobInput < Struct.new( :agent_space_id, :pentest_job_id) SENSITIVE = [] include Aws::Structure end |