Class: Aws::SecurityAgent::Types::StopThreatModelJobInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::StopThreatModelJobInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for stopping a threat model job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#threat_model_job_id ⇒ String
The unique identifier of the threat model job to stop.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
7121 7122 7123 7124 7125 7126 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7121 class StopThreatModelJobInput < Struct.new( :agent_space_id, :threat_model_job_id) SENSITIVE = [] include Aws::Structure end |
#threat_model_job_id ⇒ String
The unique identifier of the threat model job to stop.
7121 7122 7123 7124 7125 7126 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7121 class StopThreatModelJobInput < Struct.new( :agent_space_id, :threat_model_job_id) SENSITIVE = [] include Aws::Structure end |