Class: Aws::SecurityAgent::Types::TargetDomain
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::TargetDomain
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a target domain registered for penetration testing. A target domain must be verified through DNS TXT or HTTP route verification before it can be used in pentests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the target domain was created, in UTC format.
-
#domain_name ⇒ String
The domain name of the target domain.
-
#target_domain_id ⇒ String
The unique identifier of the target domain.
-
#verification_details ⇒ Types::VerificationDetails
The verification details for the target domain.
-
#verification_status ⇒ String
The current verification status of the target domain.
-
#verification_status_reason ⇒ String
The reason for the current target domain verification status.
-
#verified_at ⇒ Time
The date and time the target domain was verified, in UTC format.
Instance Attribute Details
#created_at ⇒ Time
The date and time the target domain was created, in UTC format.
3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3621 class TargetDomain < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name of the target domain.
3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3621 class TargetDomain < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#target_domain_id ⇒ String
The unique identifier of the target domain.
3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3621 class TargetDomain < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verification_details ⇒ Types::VerificationDetails
The verification details for the target domain.
3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3621 class TargetDomain < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verification_status ⇒ String
The current verification status of the target domain.
3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3621 class TargetDomain < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verification_status_reason ⇒ String
The reason for the current target domain verification status.
3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3621 class TargetDomain < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verified_at ⇒ Time
The date and time the target domain was verified, in UTC format.
3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3621 class TargetDomain < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |