Class: Aws::SecurityAgent::Types::TaskSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::TaskSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains summary information about a task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#created_at ⇒ Time
The date and time the task was created, in UTC format.
-
#execution_status ⇒ String
The current execution status of the task.
-
#pentest_id ⇒ String
The unique identifier of the pentest associated with the task.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job that contains the task.
-
#risk_type ⇒ String
The type of security risk the task is testing for.
-
#task_hours ⇒ Float
The number of active work hours consumed by the task during execution.
-
#task_id ⇒ String
The unique identifier of the task.
-
#title ⇒ String
The title of the task.
-
#updated_at ⇒ Time
The date and time the task was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7356 class TaskSummary < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :risk_type, :execution_status, :task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the task was created, in UTC format.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7356 class TaskSummary < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :risk_type, :execution_status, :task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#execution_status ⇒ String
The current execution status of the task.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7356 class TaskSummary < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :risk_type, :execution_status, :task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest associated with the task.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7356 class TaskSummary < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :risk_type, :execution_status, :task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job that contains the task.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7356 class TaskSummary < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :risk_type, :execution_status, :task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_type ⇒ String
The type of security risk the task is testing for.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7356 class TaskSummary < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :risk_type, :execution_status, :task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#task_hours ⇒ Float
The number of active work hours consumed by the task during execution.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7356 class TaskSummary < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :risk_type, :execution_status, :task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7356 class TaskSummary < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :risk_type, :execution_status, :task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the task.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7356 class TaskSummary < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :risk_type, :execution_status, :task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the task was last updated, in UTC format.
7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7356 class TaskSummary < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :risk_type, :execution_status, :task_hours, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |