Class: Aws::SecurityAgent::Types::ThreatModel
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ThreatModel
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a threat model configuration that defines the parameters for automated threat analysis, including target assets and logging configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the threat model.
-
#assets ⇒ Types::Assets
The assets included in the threat model.
-
#created_at ⇒ Time
The date and time the threat model was created, in UTC format.
-
#description ⇒ String
A description of the application or system being threat modeled.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the threat model.
-
#scope_docs ⇒ Array<Types::DocumentInfo>
The scoped documents for the agent to focus on during threat modeling.
-
#service_role ⇒ String
The IAM service role used for the threat model.
-
#threat_model_id ⇒ String
The unique identifier of the threat model.
-
#title ⇒ String
The title of the threat model.
-
#updated_at ⇒ Time
The date and time the threat model was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the threat model.
7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7679 class ThreatModel < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets included in the threat model.
7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7679 class ThreatModel < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the threat model was created, in UTC format.
7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7679 class ThreatModel < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the application or system being threat modeled.
7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7679 class ThreatModel < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the threat model.
7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7679 class ThreatModel < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#scope_docs ⇒ Array<Types::DocumentInfo>
The scoped documents for the agent to focus on during threat modeling.
7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7679 class ThreatModel < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role used for the threat model.
7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7679 class ThreatModel < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_model_id ⇒ String
The unique identifier of the threat model.
7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7679 class ThreatModel < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the threat model.
7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7679 class ThreatModel < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the threat model was last updated, in UTC format.
7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7679 class ThreatModel < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |