Class: Aws::SecurityAgent::Types::ThreatModelJob
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ThreatModelJob
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a threat model job, which is an execution instance of a threat model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#created_at ⇒ Time
The date and time the threat model job was created, in UTC format.
-
#documents ⇒ Array<Types::DocumentInfo>
The list of documents used for threat modeling.
-
#error_information ⇒ Types::ErrorInformation
Error information if the threat model job encountered an error.
-
#execution_end_time ⇒ Time
The date and time the threat model job execution ended, in UTC format.
-
#execution_start_time ⇒ Time
The date and time the threat model job execution started, in UTC format.
-
#integrated_repositories ⇒ Array<Types::IntegratedRepository>
The list of integrated repositories used for threat modeling.
-
#scope_docs ⇒ Array<Types::DocumentInfo>
The scoped documents for the agent to focus on during threat modeling.
-
#source_code ⇒ Array<Types::SourceCodeRepository>
The list of source code repositories used for threat modeling.
-
#status ⇒ String
The current status of the threat model job.
-
#system_overview ⇒ String
The system overview generated during threat modeling.
-
#threat_model_id ⇒ String
The unique identifier of the threat model associated with the job.
-
#threat_model_job_id ⇒ String
The unique identifier of the threat model job.
-
#title ⇒ String
The title of the threat model job.
-
#updated_at ⇒ Time
The date and time the threat model job was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the threat model job was created, in UTC format.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#documents ⇒ Array<Types::DocumentInfo>
The list of documents used for threat modeling.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#error_information ⇒ Types::ErrorInformation
Error information if the threat model job encountered an error.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#execution_end_time ⇒ Time
The date and time the threat model job execution ended, in UTC format.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#execution_start_time ⇒ Time
The date and time the threat model job execution started, in UTC format.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#integrated_repositories ⇒ Array<Types::IntegratedRepository>
The list of integrated repositories used for threat modeling.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#scope_docs ⇒ Array<Types::DocumentInfo>
The scoped documents for the agent to focus on during threat modeling.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#source_code ⇒ Array<Types::SourceCodeRepository>
The list of source code repositories used for threat modeling.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the threat model job.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#system_overview ⇒ String
The system overview generated during threat modeling.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#threat_model_id ⇒ String
The unique identifier of the threat model associated with the job.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#threat_model_job_id ⇒ String
The unique identifier of the threat model job.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the threat model job.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the threat model job was last updated, in UTC format.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7763 class ThreatModelJob < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at, :execution_start_time, :execution_end_time, :source_code, :integrated_repositories, :documents, :scope_docs, :error_information, :system_overview) SENSITIVE = [] include Aws::Structure end |