Class: Aws::SecurityAgent::Types::ThreatModelJobTask

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents an individual task within a threat model job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/aws-sdk-securityagent/types.rb', line 7759

class ThreatModelJobTask < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :description,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the task was created, in UTC format.

Returns:

  • (Time)


7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/aws-sdk-securityagent/types.rb', line 7759

class ThreatModelJobTask < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :description,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the task.

Returns:

  • (String)


7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/aws-sdk-securityagent/types.rb', line 7759

class ThreatModelJobTask < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :description,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_statusString

The current execution status of the task.

Returns:

  • (String)


7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/aws-sdk-securityagent/types.rb', line 7759

class ThreatModelJobTask < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :description,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#logs_locationTypes::LogLocation

The location of the task execution logs.

Returns:



7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/aws-sdk-securityagent/types.rb', line 7759

class ThreatModelJobTask < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :description,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The unique identifier of the task.

Returns:

  • (String)


7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/aws-sdk-securityagent/types.rb', line 7759

class ThreatModelJobTask < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :description,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_idString

The unique identifier of the threat model associated with the task.

Returns:

  • (String)


7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/aws-sdk-securityagent/types.rb', line 7759

class ThreatModelJobTask < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :description,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_job_idString

The unique identifier of the threat model job that contains the task.

Returns:

  • (String)


7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/aws-sdk-securityagent/types.rb', line 7759

class ThreatModelJobTask < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :description,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the task.

Returns:

  • (String)


7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/aws-sdk-securityagent/types.rb', line 7759

class ThreatModelJobTask < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :description,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the task was last updated, in UTC format.

Returns:

  • (Time)


7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
# File 'lib/aws-sdk-securityagent/types.rb', line 7759

class ThreatModelJobTask < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :description,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end