Class: Aws::SecurityAgent::Types::ThreatModelJobTaskSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a threat model job task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


7811
7812
7813
7814
7815
7816
7817
7818
7819
7820
7821
7822
# File 'lib/aws-sdk-securityagent/types.rb', line 7811

class ThreatModelJobTaskSummary < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the task was created, in UTC format.

Returns:

  • (Time)


7811
7812
7813
7814
7815
7816
7817
7818
7819
7820
7821
7822
# File 'lib/aws-sdk-securityagent/types.rb', line 7811

class ThreatModelJobTaskSummary < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_statusString

The current execution status of the task.

Returns:

  • (String)


7811
7812
7813
7814
7815
7816
7817
7818
7819
7820
7821
7822
# File 'lib/aws-sdk-securityagent/types.rb', line 7811

class ThreatModelJobTaskSummary < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The unique identifier of the task.

Returns:

  • (String)


7811
7812
7813
7814
7815
7816
7817
7818
7819
7820
7821
7822
# File 'lib/aws-sdk-securityagent/types.rb', line 7811

class ThreatModelJobTaskSummary < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_idString

The unique identifier of the threat model associated with the task.

Returns:

  • (String)


7811
7812
7813
7814
7815
7816
7817
7818
7819
7820
7821
7822
# File 'lib/aws-sdk-securityagent/types.rb', line 7811

class ThreatModelJobTaskSummary < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_job_idString

The unique identifier of the threat model job that contains the task.

Returns:

  • (String)


7811
7812
7813
7814
7815
7816
7817
7818
7819
7820
7821
7822
# File 'lib/aws-sdk-securityagent/types.rb', line 7811

class ThreatModelJobTaskSummary < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the task.

Returns:

  • (String)


7811
7812
7813
7814
7815
7816
7817
7818
7819
7820
7821
7822
# File 'lib/aws-sdk-securityagent/types.rb', line 7811

class ThreatModelJobTaskSummary < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the task was last updated, in UTC format.

Returns:

  • (Time)


7811
7812
7813
7814
7815
7816
7817
7818
7819
7820
7821
7822
# File 'lib/aws-sdk-securityagent/types.rb', line 7811

class ThreatModelJobTaskSummary < Struct.new(
  :task_id,
  :threat_model_id,
  :threat_model_job_id,
  :agent_space_id,
  :title,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end