Class: Aws::SecurityAgent::Types::ThreatModelSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a threat model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the threat model.

Returns:

  • (String)


7849
7850
7851
7852
7853
7854
7855
7856
7857
# File 'lib/aws-sdk-securityagent/types.rb', line 7849

class ThreatModelSummary < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the threat model was created, in UTC format.

Returns:

  • (Time)


7849
7850
7851
7852
7853
7854
7855
7856
7857
# File 'lib/aws-sdk-securityagent/types.rb', line 7849

class ThreatModelSummary < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_idString

The unique identifier of the threat model.

Returns:

  • (String)


7849
7850
7851
7852
7853
7854
7855
7856
7857
# File 'lib/aws-sdk-securityagent/types.rb', line 7849

class ThreatModelSummary < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the threat model.

Returns:

  • (String)


7849
7850
7851
7852
7853
7854
7855
7856
7857
# File 'lib/aws-sdk-securityagent/types.rb', line 7849

class ThreatModelSummary < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the threat model was last updated, in UTC format.

Returns:

  • (Time)


7849
7850
7851
7852
7853
7854
7855
7856
7857
# File 'lib/aws-sdk-securityagent/types.rb', line 7849

class ThreatModelSummary < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end