Class: Aws::SecurityAgent::Types::UpdateAgentSpaceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateAgentSpaceInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for updating an agent space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to update.
-
#aws_resources ⇒ Types::AWSResources
The updated AWS resources to associate with the agent space.
-
#code_review_settings ⇒ Types::CodeReviewSettings
The updated code review settings for the agent space.
-
#description ⇒ String
The updated description of the agent space.
-
#name ⇒ String
The updated name of the agent space.
-
#target_domain_ids ⇒ Array<String>
The updated list of target domain identifiers to associate with the agent space.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to update.
8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8002 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |
#aws_resources ⇒ Types::AWSResources
The updated AWS resources to associate with the agent space.
8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8002 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |
#code_review_settings ⇒ Types::CodeReviewSettings
The updated code review settings for the agent space.
8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8002 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The updated description of the agent space.
8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8002 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated name of the agent space.
8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8002 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |
#target_domain_ids ⇒ Array<String>
The updated list of target domain identifiers to associate with the agent space.
8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8002 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |