Class: Aws::SecurityAgent::Types::UpdateAgentSpaceOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the UpdateAgentSpace operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the updated agent space.

Returns:

  • (String)


3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-securityagent/types.rb', line 3913

class UpdateAgentSpaceOutput < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#aws_resourcesTypes::AWSResources

The AWS resources associated with the agent space.

Returns:



3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-securityagent/types.rb', line 3913

class UpdateAgentSpaceOutput < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_settingsTypes::CodeReviewSettings

The code review settings for the agent space.



3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-securityagent/types.rb', line 3913

class UpdateAgentSpaceOutput < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the agent space was created, in UTC format.

Returns:

  • (Time)


3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-securityagent/types.rb', line 3913

class UpdateAgentSpaceOutput < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the agent space.

Returns:

  • (String)


3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-securityagent/types.rb', line 3913

class UpdateAgentSpaceOutput < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the agent space.

Returns:

  • (String)


3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-securityagent/types.rb', line 3913

class UpdateAgentSpaceOutput < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#target_domain_idsArray<String>

The list of target domain identifiers associated with the agent space.

Returns:

  • (Array<String>)


3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-securityagent/types.rb', line 3913

class UpdateAgentSpaceOutput < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the agent space was last updated, in UTC format.

Returns:

  • (Time)


3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-securityagent/types.rb', line 3913

class UpdateAgentSpaceOutput < Struct.new(
  :agent_space_id,
  :name,
  :description,
  :aws_resources,
  :target_domain_ids,
  :code_review_settings,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end