Class: Aws::SecurityAgent::Types::UpdateCodeReviewInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for updating an existing code review.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the code review.

Returns:

  • (String)


8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
# File 'lib/aws-sdk-securityagent/types.rb', line 8256

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The updated assets for the code review.

Returns:



8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
# File 'lib/aws-sdk-securityagent/types.rb', line 8256

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The updated code remediation strategy for the code review.

Returns:

  • (String)


8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
# File 'lib/aws-sdk-securityagent/types.rb', line 8256

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_idString

The unique identifier of the code review to update.

Returns:

  • (String)


8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
# File 'lib/aws-sdk-securityagent/types.rb', line 8256

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The updated CloudWatch Logs configuration for the code review.



8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
# File 'lib/aws-sdk-securityagent/types.rb', line 8256

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#max_task_hoursFloat

The updated maximum number of billable task hours allowed for jobs started from this code review.

Returns:

  • (Float)


8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
# File 'lib/aws-sdk-securityagent/types.rb', line 8256

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The updated IAM service role for the code review.

Returns:

  • (String)


8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
# File 'lib/aws-sdk-securityagent/types.rb', line 8256

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The updated title of the code review.

Returns:

  • (String)


8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
# File 'lib/aws-sdk-securityagent/types.rb', line 8256

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end

#validation_modeString

The updated validation mode for the code review. Valid values are SIMULATED and DISABLED.

Returns:

  • (String)


8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
# File 'lib/aws-sdk-securityagent/types.rb', line 8256

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :max_task_hours)
  SENSITIVE = []
  include Aws::Structure
end