Class: Aws::SecurityAgent::Types::UpdateCodeReviewOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateCodeReviewOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the UpdateCodeReview operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the code review.
-
#assets ⇒ Types::Assets
The assets included in the code review.
-
#code_remediation_strategy ⇒ String
The code remediation strategy for the code review.
-
#code_review_id ⇒ String
The unique identifier of the code review.
-
#created_at ⇒ Time
The date and time the code review was created, in UTC format.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the code review.
-
#max_task_hours ⇒ Float
The maximum number of billable task hours configured for jobs started from this code review.
-
#service_role ⇒ String
The IAM service role used for the code review.
-
#title ⇒ String
The title of the code review.
-
#updated_at ⇒ Time
The date and time the code review was last updated, in UTC format.
-
#validation_mode ⇒ String
The validation mode for the code review.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the code review.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets included in the code review.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The code remediation strategy for the code review.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#code_review_id ⇒ String
The unique identifier of the code review.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the code review was created, in UTC format.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the code review.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#max_task_hours ⇒ Float
The maximum number of billable task hours configured for jobs started from this code review. Null if no budget cap is set.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role used for the code review.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the code review.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the code review was last updated, in UTC format.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#validation_mode ⇒ String
The validation mode for the code review.
8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8320 class UpdateCodeReviewOutput < Struct.new( :code_review_id, :title, :created_at, :updated_at, :assets, :service_role, :log_config, :agent_space_id, :code_remediation_strategy, :validation_mode, :max_task_hours) SENSITIVE = [] include Aws::Structure end |