Class: Aws::SecurityAgent::Types::UpdateFindingInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateFindingInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for updating an existing security finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the finding.
-
#attack_script ⇒ String
The updated attack script for the finding.
-
#customer_note ⇒ String
A customer-provided note on the finding.
-
#description ⇒ String
The updated description for the finding.
-
#finding_id ⇒ String
The unique identifier of the finding to update.
-
#name ⇒ String
The updated name for the finding.
-
#reasoning ⇒ String
The updated reasoning for the finding.
-
#risk_level ⇒ String
The updated risk level for the finding.
-
#risk_score ⇒ String
The updated numerical risk score for the finding.
-
#risk_type ⇒ String
The updated risk type for the finding.
-
#status ⇒ String
The updated status for the finding.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the finding.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |
#attack_script ⇒ String
The updated attack script for the finding.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |
#customer_note ⇒ String
A customer-provided note on the finding.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The updated description for the finding.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |
#finding_id ⇒ String
The unique identifier of the finding to update.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated name for the finding.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |
#reasoning ⇒ String
The updated reasoning for the finding.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |
#risk_level ⇒ String
The updated risk level for the finding.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |
#risk_score ⇒ String
The updated numerical risk score for the finding.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |
#risk_type ⇒ String
The updated risk type for the finding.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The updated status for the finding.
8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 8394 8395 8396 8397 8398 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8384 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :name, :description, :risk_type, :risk_level, :risk_score, :attack_script, :reasoning, :status, :customer_note) SENSITIVE = [] include Aws::Structure end |