Class: Aws::SecurityAgent::Types::UpdatePentestInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdatePentestInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for updating an existing pentest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
-
#assets ⇒ Types::Assets
The updated assets for the pentest.
-
#code_remediation_strategy ⇒ String
The updated code remediation strategy for the pentest.
-
#disable_managed_skills ⇒ Array<String>
The updated list of managed skills to disable for this pentest.
-
#exclude_risk_types ⇒ Array<String>
The updated list of risk types to exclude from the pentest.
-
#log_config ⇒ Types::CloudWatchLog
The updated CloudWatch Logs configuration for the pentest.
-
#max_task_hours ⇒ Float
The updated maximum number of billable task hours allowed for jobs started from this pentest.
-
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The updated network traffic configuration for the pentest.
-
#pentest_id ⇒ String
The unique identifier of the pentest to update.
-
#service_role ⇒ String
The updated IAM service role for the pentest.
-
#title ⇒ String
The updated title of the pentest.
-
#vpc_config ⇒ Types::VpcConfig
The updated VPC configuration for the pentest.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The updated assets for the pentest.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The updated code remediation strategy for the pentest.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#disable_managed_skills ⇒ Array<String>
The updated list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#exclude_risk_types ⇒ Array<String>
The updated list of risk types to exclude from the pentest.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The updated CloudWatch Logs configuration for the pentest.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#max_task_hours ⇒ Float
The updated maximum number of billable task hours allowed for jobs started from this pentest.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The updated network traffic configuration for the pentest.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest to update.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The updated IAM service role for the pentest.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The updated title of the pentest.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The updated VPC configuration for the pentest.
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8552 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :disable_managed_skills, :max_task_hours) SENSITIVE = [] include Aws::Structure end |