Class: Aws::SecurityAgent::Types::UpdatePentestOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the UpdatePentest operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the pentest.

Returns:

  • (String)


4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-securityagent/types.rb', line 4122

class UpdatePentestOutput < Struct.new(
  :pentest_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets included in the pentest.

Returns:



4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-securityagent/types.rb', line 4122

class UpdatePentestOutput < Struct.new(
  :pentest_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the pentest was created, in UTC format.

Returns:

  • (Time)


4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-securityagent/types.rb', line 4122

class UpdatePentestOutput < Struct.new(
  :pentest_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_risk_typesArray<String>

The list of risk types excluded from the pentest.

Returns:

  • (Array<String>)


4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-securityagent/types.rb', line 4122

class UpdatePentestOutput < Struct.new(
  :pentest_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the pentest.



4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-securityagent/types.rb', line 4122

class UpdatePentestOutput < Struct.new(
  :pentest_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest.

Returns:

  • (String)


4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-securityagent/types.rb', line 4122

class UpdatePentestOutput < Struct.new(
  :pentest_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the pentest.

Returns:

  • (String)


4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-securityagent/types.rb', line 4122

class UpdatePentestOutput < Struct.new(
  :pentest_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the pentest.

Returns:

  • (String)


4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-securityagent/types.rb', line 4122

class UpdatePentestOutput < Struct.new(
  :pentest_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the pentest was last updated, in UTC format.

Returns:

  • (Time)


4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
# File 'lib/aws-sdk-securityagent/types.rb', line 4122

class UpdatePentestOutput < Struct.new(
  :pentest_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end