Class: Aws::SecurityAgent::Types::UpdateSecurityRequirementPackInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateSecurityRequirementPackInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The updated description of the security requirement pack.
-
#name ⇒ String
The updated name of the security requirement pack.
-
#pack_id ⇒ String
The unique identifier of the security requirement pack to update.
-
#status ⇒ String
The updated status of the security requirement pack.
Instance Attribute Details
#description ⇒ String
The updated description of the security requirement pack.
8564 8565 8566 8567 8568 8569 8570 8571 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8564 class UpdateSecurityRequirementPackInput < Struct.new( :pack_id, :name, :description, :status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated name of the security requirement pack.
8564 8565 8566 8567 8568 8569 8570 8571 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8564 class UpdateSecurityRequirementPackInput < Struct.new( :pack_id, :name, :description, :status) SENSITIVE = [] include Aws::Structure end |
#pack_id ⇒ String
The unique identifier of the security requirement pack to update.
8564 8565 8566 8567 8568 8569 8570 8571 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8564 class UpdateSecurityRequirementPackInput < Struct.new( :pack_id, :name, :description, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The updated status of the security requirement pack.
8564 8565 8566 8567 8568 8569 8570 8571 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8564 class UpdateSecurityRequirementPackInput < Struct.new( :pack_id, :name, :description, :status) SENSITIVE = [] include Aws::Structure end |