Class: Aws::SecurityAgent::Types::UpdateTargetDomainInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateTargetDomainInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for updating a target domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target_domain_id ⇒ String
The unique identifier of the target domain to update.
-
#verification_method ⇒ String
The updated verification method for the target domain.
Instance Attribute Details
#target_domain_id ⇒ String
The unique identifier of the target domain to update.
4148 4149 4150 4151 4152 4153 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4148 class UpdateTargetDomainInput < Struct.new( :target_domain_id, :verification_method) SENSITIVE = [] include Aws::Structure end |
#verification_method ⇒ String
The updated verification method for the target domain.
4148 4149 4150 4151 4152 4153 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4148 class UpdateTargetDomainInput < Struct.new( :target_domain_id, :verification_method) SENSITIVE = [] include Aws::Structure end |