Class: Aws::SecurityAgent::Types::UpdateTargetDomainOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateTargetDomainOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the UpdateTargetDomain operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the target domain was created, in UTC format.
-
#domain_name ⇒ String
The domain name of the target domain.
-
#target_domain_id ⇒ String
The unique identifier of the target domain.
-
#verification_details ⇒ Types::VerificationDetails
The updated verification details for the target domain.
-
#verification_status ⇒ String
The current verification status of the target domain.
-
#verification_status_reason ⇒ String
The reason for the current target domain verification status.
-
#verified_at ⇒ Time
The date and time the target domain was verified, in UTC format.
Instance Attribute Details
#created_at ⇒ Time
The date and time the target domain was created, in UTC format.
4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4187 class UpdateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name of the target domain.
4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4187 class UpdateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#target_domain_id ⇒ String
The unique identifier of the target domain.
4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4187 class UpdateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verification_details ⇒ Types::VerificationDetails
The updated verification details for the target domain.
4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4187 class UpdateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verification_status ⇒ String
The current verification status of the target domain.
4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4187 class UpdateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verification_status_reason ⇒ String
The reason for the current target domain verification status.
4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4187 class UpdateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |
#verified_at ⇒ Time
The date and time the target domain was verified, in UTC format.
4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4187 class UpdateTargetDomainOutput < Struct.new( :target_domain_id, :domain_name, :verification_status, :verification_status_reason, :verification_details, :created_at, :verified_at) SENSITIVE = [] include Aws::Structure end |