Class: Aws::SecurityAgent::Types::UpdateThreatInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateThreatInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for updating an existing threat.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#anchor ⇒ Types::ThreatAnchorShape
The updated DFD element this threat is anchored to.
-
#comments ⇒ String
Optional customer comment.
-
#evidence ⇒ Array<Types::ThreatEvidenceShape>
The updated source code files supporting the threat.
-
#impacted_assets ⇒ Array<String>
The updated list of specific assets affected by the threat.
-
#impacted_goal ⇒ Array<String>
The updated security goals affected by the threat.
-
#prerequisites ⇒ String
The updated conditions required for the threat to be exploitable.
-
#recommendation ⇒ String
The updated recommended mitigation guidance for this threat.
-
#severity ⇒ String
The updated severity level of the threat.
-
#statement ⇒ String
The updated natural-language threat statement.
-
#status ⇒ String
The updated status of the threat.
-
#threat_action ⇒ String
The updated description of what the threat source can do.
-
#threat_id ⇒ String
The unique identifier of the threat to update.
-
#threat_impact ⇒ String
The updated direct consequence of the threat action.
-
#threat_source ⇒ String
The updated actor or origin of the threat.
-
#title ⇒ String
A short title summarizing the threat.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#anchor ⇒ Types::ThreatAnchorShape
The updated DFD element this threat is anchored to.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#comments ⇒ String
Optional customer comment.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#evidence ⇒ Array<Types::ThreatEvidenceShape>
The updated source code files supporting the threat.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#impacted_assets ⇒ Array<String>
The updated list of specific assets affected by the threat.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#impacted_goal ⇒ Array<String>
The updated security goals affected by the threat.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#prerequisites ⇒ String
The updated conditions required for the threat to be exploitable.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#recommendation ⇒ String
The updated recommended mitigation guidance for this threat.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
The updated severity level of the threat.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#statement ⇒ String
The updated natural-language threat statement.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The updated status of the threat.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#threat_action ⇒ String
The updated description of what the threat source can do.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#threat_id ⇒ String
The unique identifier of the threat to update.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#threat_impact ⇒ String
The updated direct consequence of the threat action.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#threat_source ⇒ String
The updated actor or origin of the threat.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
A short title summarizing the threat.
8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8863 class UpdateThreatInput < Struct.new( :threat_id, :agent_space_id, :title, :status, :comments, :statement, :severity, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation) SENSITIVE = [] include Aws::Structure end |