Class: Aws::SecurityAgent::Types::UserConfig

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

The configuration for a user membership, including the role assigned to the user within the agent space.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#roleString

The role assigned to the user. Currently, only MEMBER is supported.

Returns:

  • (String)


4208
4209
4210
4211
4212
# File 'lib/aws-sdk-securityagent/types.rb', line 4208

class UserConfig < Struct.new(
  :role)
  SENSITIVE = []
  include Aws::Structure
end