Class: Aws::SecurityAgent::Types::ValidationExceptionField
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ValidationExceptionField
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Describes one specific validation failure for an input member.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A detailed description of the validation failure.
-
#path ⇒ String
A JSONPointer expression to the structure member whose value failed to satisfy the modeled constraint.
Instance Attribute Details
#message ⇒ String
A detailed description of the validation failure.
4266 4267 4268 4269 4270 4271 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4266 class ValidationExceptionField < Struct.new( :path, :message) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
A JSONPointer expression to the structure member whose value failed to satisfy the modeled constraint.
4266 4267 4268 4269 4270 4271 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4266 class ValidationExceptionField < Struct.new( :path, :message) SENSITIVE = [] include Aws::Structure end |