Class: Aws::SecurityAgent::Types::VerifyTargetDomainOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for verifying ownership for a registered target domain in an agent space.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time the target domain was created, in UTC format.

Returns:

  • (Time)


4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
# File 'lib/aws-sdk-securityagent/types.rb', line 4346

class VerifyTargetDomainOutput < Struct.new(
  :target_domain_id,
  :domain_name,
  :created_at,
  :updated_at,
  :verified_at,
  :status,
  :verification_status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The domain name of the target domain.

Returns:

  • (String)


4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
# File 'lib/aws-sdk-securityagent/types.rb', line 4346

class VerifyTargetDomainOutput < Struct.new(
  :target_domain_id,
  :domain_name,
  :created_at,
  :updated_at,
  :verified_at,
  :status,
  :verification_status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The verification status of the target domain.

Returns:

  • (String)


4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
# File 'lib/aws-sdk-securityagent/types.rb', line 4346

class VerifyTargetDomainOutput < Struct.new(
  :target_domain_id,
  :domain_name,
  :created_at,
  :updated_at,
  :verified_at,
  :status,
  :verification_status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#target_domain_idString

The unique identifier of the target domain.

Returns:

  • (String)


4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
# File 'lib/aws-sdk-securityagent/types.rb', line 4346

class VerifyTargetDomainOutput < Struct.new(
  :target_domain_id,
  :domain_name,
  :created_at,
  :updated_at,
  :verified_at,
  :status,
  :verification_status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the target domain was last updated, in UTC format.

Returns:

  • (Time)


4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
# File 'lib/aws-sdk-securityagent/types.rb', line 4346

class VerifyTargetDomainOutput < Struct.new(
  :target_domain_id,
  :domain_name,
  :created_at,
  :updated_at,
  :verified_at,
  :status,
  :verification_status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#verification_status_reasonString

The reason for the current target domain verification status.

Returns:

  • (String)


4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
# File 'lib/aws-sdk-securityagent/types.rb', line 4346

class VerifyTargetDomainOutput < Struct.new(
  :target_domain_id,
  :domain_name,
  :created_at,
  :updated_at,
  :verified_at,
  :status,
  :verification_status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#verified_atTime

The date and time the target domain was verified, in UTC format.

Returns:

  • (Time)


4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
# File 'lib/aws-sdk-securityagent/types.rb', line 4346

class VerifyTargetDomainOutput < Struct.new(
  :target_domain_id,
  :domain_name,
  :created_at,
  :updated_at,
  :verified_at,
  :status,
  :verification_status_reason)
  SENSITIVE = []
  include Aws::Structure
end