Class: Aws::SecurityAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SecurityAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-securityagent/client.rb
Overview
An API client for SecurityAgent. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SecurityAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space.
-
#batch_create_security_requirements(params = {}) ⇒ Types::BatchCreateSecurityRequirementsOutput
Batch creates security requirements in a customer managed pack.
-
#batch_delete_code_reviews(params = {}) ⇒ Types::BatchDeleteCodeReviewsOutput
Deletes one or more code reviews from an agent space.
-
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
-
#batch_delete_security_requirements(params = {}) ⇒ Types::BatchDeleteSecurityRequirementsOutput
Batch deletes security requirements from a customer managed pack.
-
#batch_delete_threat_models(params = {}) ⇒ Types::BatchDeleteThreatModelsOutput
Deletes one or more threat models from an agent space.
-
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
-
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
-
#batch_get_code_review_job_tasks(params = {}) ⇒ Types::BatchGetCodeReviewJobTasksOutput
Retrieves information about one or more tasks within a code review job.
-
#batch_get_code_review_jobs(params = {}) ⇒ Types::BatchGetCodeReviewJobsOutput
Retrieves information about one or more code review jobs in an agent space.
-
#batch_get_code_reviews(params = {}) ⇒ Types::BatchGetCodeReviewsOutput
Retrieves information about one or more code reviews in an agent space.
-
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
-
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
-
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
-
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
-
#batch_get_security_requirements(params = {}) ⇒ Types::BatchGetSecurityRequirementsOutput
Batch retrieves security requirements from a pack.
-
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
-
#batch_get_threat_model_job_tasks(params = {}) ⇒ Types::BatchGetThreatModelJobTasksOutput
Retrieves information about one or more tasks within a threat model job.
-
#batch_get_threat_model_jobs(params = {}) ⇒ Types::BatchGetThreatModelJobsOutput
Retrieves information about one or more threat model jobs in an agent space.
-
#batch_get_threat_models(params = {}) ⇒ Types::BatchGetThreatModelsOutput
Retrieves information about one or more threat models in an agent space.
-
#batch_get_threats(params = {}) ⇒ Types::BatchGetThreatsOutput
Retrieves information about one or more threats.
-
#batch_update_security_requirements(params = {}) ⇒ Types::BatchUpdateSecurityRequirementsOutput
Batch updates security requirements within a customer managed pack.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application.
-
#create_code_review(params = {}) ⇒ Types::CreateCodeReviewOutput
Creates a new code review configuration in an agent space.
-
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
-
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
-
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space.
-
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a private connection for reaching a self-hosted provider instance over private networking using Amazon VPC Lattice.
-
#create_security_requirement_pack(params = {}) ⇒ Types::CreateSecurityRequirementPackOutput
Creates a customer managed security requirement pack.
-
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing.
-
#create_threat(params = {}) ⇒ Types::CreateThreatOutput
Creates a new threat under a threat model job.
-
#create_threat_model(params = {}) ⇒ Types::CreateThreatModelOutput
Creates a new threat model configuration in an agent space.
-
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
-
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
-
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
-
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user’s access to an agent space.
-
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a private connection.
-
#delete_security_requirement_pack(params = {}) ⇒ Struct
Deletes a customer managed security requirement pack and all its associated security requirements.
-
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration.
-
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves the details of a private connection.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
-
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
-
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
-
#get_security_requirement_pack(params = {}) ⇒ Types::GetSecurityRequirementPackOutput
Retrieves information about a security requirement pack.
-
#import_security_requirements(params = {}) ⇒ Types::ImportSecurityRequirementsOutput
Imports security requirements from uploaded documents into a customer managed security requirement pack.
-
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
-
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
-
#list_code_review_job_tasks(params = {}) ⇒ Types::ListCodeReviewJobTasksOutput
Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.
-
#list_code_review_jobs_for_code_review(params = {}) ⇒ Types::ListCodeReviewJobsForCodeReviewOutput
Returns a paginated list of code review job summaries for the specified code review configuration.
-
#list_code_reviews(params = {}) ⇒ Types::ListCodeReviewsOutput
Returns a paginated list of code review summaries for the specified agent space.
-
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
-
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
-
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
-
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
-
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
-
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
-
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
-
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
-
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists the private connections in your account.
-
#list_security_requirement_packs(params = {}) ⇒ Types::ListSecurityRequirementPacksOutput
Lists all security requirement packs in the caller’s account.
-
#list_security_requirements(params = {}) ⇒ Types::ListSecurityRequirementsOutput
Lists security requirements within a pack.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
-
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
-
#list_threat_model_job_tasks(params = {}) ⇒ Types::ListThreatModelJobTasksOutput
Returns a paginated list of task summaries for the specified threat model job.
-
#list_threat_model_jobs(params = {}) ⇒ Types::ListThreatModelJobsOutput
Returns a paginated list of threat model job summaries for the specified threat model.
-
#list_threat_models(params = {}) ⇒ Types::ListThreatModelsOutput
Returns a paginated list of threat model summaries for the specified agent space.
-
#list_threats(params = {}) ⇒ Types::ListThreatsOutput
Returns a paginated list of threats for a threat model job.
-
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings.
-
#start_code_review_job(params = {}) ⇒ Types::StartCodeReviewJobOutput
Starts a new code review job for a code review configuration.
-
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration.
-
#start_threat_model_job(params = {}) ⇒ Types::StartThreatModelJobOutput
Starts a new threat model job for a threat model configuration.
-
#stop_code_review_job(params = {}) ⇒ Struct
Stops a running code review job.
-
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job.
-
#stop_threat_model_job(params = {}) ⇒ Struct
Stops a running threat model job.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
-
#update_code_review(params = {}) ⇒ Types::UpdateCodeReviewOutput
Updates an existing code review configuration.
-
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
-
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
-
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
-
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a private connection.
-
#update_security_requirement_pack(params = {}) ⇒ Types::UpdateSecurityRequirementPackOutput
Updates a security requirement pack.
-
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
-
#update_threat(params = {}) ⇒ Types::UpdateThreatOutput
Updates a threat.
-
#update_threat_model(params = {}) ⇒ Types::UpdateThreatModelOutput
Updates an existing threat model configuration.
-
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-securityagent/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5979 5980 5981 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5979 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5982 5983 5984 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5982 def errors_module Errors end |
Instance Method Details
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space. Artifacts provide additional context for security testing, such as architecture diagrams, API specifications, or configuration files.
515 516 517 518 |
# File 'lib/aws-sdk-securityagent/client.rb', line 515 def add_artifact(params = {}, = {}) req = build_request(:add_artifact, params) req.send_request() end |
#batch_create_security_requirements(params = {}) ⇒ Types::BatchCreateSecurityRequirementsOutput
Batch creates security requirements in a customer managed pack.
569 570 571 572 |
# File 'lib/aws-sdk-securityagent/client.rb', line 569 def batch_create_security_requirements(params = {}, = {}) req = build_request(:batch_create_security_requirements, params) req.send_request() end |
#batch_delete_code_reviews(params = {}) ⇒ Types::BatchDeleteCodeReviewsOutput
Deletes one or more code reviews from an agent space.
607 608 609 610 |
# File 'lib/aws-sdk-securityagent/client.rb', line 607 def batch_delete_code_reviews(params = {}, = {}) req = build_request(:batch_delete_code_reviews, params) req.send_request() end |
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
689 690 691 692 |
# File 'lib/aws-sdk-securityagent/client.rb', line 689 def batch_delete_pentests(params = {}, = {}) req = build_request(:batch_delete_pentests, params) req.send_request() end |
#batch_delete_security_requirements(params = {}) ⇒ Types::BatchDeleteSecurityRequirementsOutput
Batch deletes security requirements from a customer managed pack.
728 729 730 731 |
# File 'lib/aws-sdk-securityagent/client.rb', line 728 def batch_delete_security_requirements(params = {}, = {}) req = build_request(:batch_delete_security_requirements, params) req.send_request() end |
#batch_delete_threat_models(params = {}) ⇒ Types::BatchDeleteThreatModelsOutput
Deletes one or more threat models from an agent space.
766 767 768 769 |
# File 'lib/aws-sdk-securityagent/client.rb', line 766 def batch_delete_threat_models(params = {}, = {}) req = build_request(:batch_delete_threat_models, params) req.send_request() end |
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
823 824 825 826 |
# File 'lib/aws-sdk-securityagent/client.rb', line 823 def batch_get_agent_spaces(params = {}, = {}) req = build_request(:batch_get_agent_spaces, params) req.send_request() end |
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
859 860 861 862 |
# File 'lib/aws-sdk-securityagent/client.rb', line 859 def (params = {}, = {}) req = build_request(:batch_get_artifact_metadata, params) req.send_request() end |
#batch_get_code_review_job_tasks(params = {}) ⇒ Types::BatchGetCodeReviewJobTasksOutput
Retrieves information about one or more tasks within a code review job.
911 912 913 914 |
# File 'lib/aws-sdk-securityagent/client.rb', line 911 def batch_get_code_review_job_tasks(params = {}, = {}) req = build_request(:batch_get_code_review_job_tasks, params) req.send_request() end |
#batch_get_code_review_jobs(params = {}) ⇒ Types::BatchGetCodeReviewJobsOutput
Retrieves information about one or more code review jobs in an agent space.
980 981 982 983 |
# File 'lib/aws-sdk-securityagent/client.rb', line 980 def batch_get_code_review_jobs(params = {}, = {}) req = build_request(:batch_get_code_review_jobs, params) req.send_request() end |
#batch_get_code_reviews(params = {}) ⇒ Types::BatchGetCodeReviewsOutput
Retrieves information about one or more code reviews in an agent space.
1046 1047 1048 1049 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1046 def batch_get_code_reviews(params = {}, = {}) req = build_request(:batch_get_code_reviews, params) req.send_request() end |
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
1121 1122 1123 1124 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1121 def batch_get_findings(params = {}, = {}) req = build_request(:batch_get_findings, params) req.send_request() end |
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
1173 1174 1175 1176 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1173 def batch_get_pentest_job_tasks(params = {}, = {}) req = build_request(:batch_get_pentest_job_tasks, params) req.send_request() end |
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
1272 1273 1274 1275 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1272 def batch_get_pentest_jobs(params = {}, = {}) req = build_request(:batch_get_pentest_jobs, params) req.send_request() end |
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
1352 1353 1354 1355 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1352 def batch_get_pentests(params = {}, = {}) req = build_request(:batch_get_pentests, params) req.send_request() end |
#batch_get_security_requirements(params = {}) ⇒ Types::BatchGetSecurityRequirementsOutput
Batch retrieves security requirements from a pack.
1398 1399 1400 1401 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1398 def batch_get_security_requirements(params = {}, = {}) req = build_request(:batch_get_security_requirements, params) req.send_request() end |
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
1441 1442 1443 1444 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1441 def batch_get_target_domains(params = {}, = {}) req = build_request(:batch_get_target_domains, params) req.send_request() end |
#batch_get_threat_model_job_tasks(params = {}) ⇒ Types::BatchGetThreatModelJobTasksOutput
Retrieves information about one or more tasks within a threat model job.
1489 1490 1491 1492 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1489 def batch_get_threat_model_job_tasks(params = {}, = {}) req = build_request(:batch_get_threat_model_job_tasks, params) req.send_request() end |
#batch_get_threat_model_jobs(params = {}) ⇒ Types::BatchGetThreatModelJobsOutput
Retrieves information about one or more threat model jobs in an agent space.
1553 1554 1555 1556 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1553 def batch_get_threat_model_jobs(params = {}, = {}) req = build_request(:batch_get_threat_model_jobs, params) req.send_request() end |
#batch_get_threat_models(params = {}) ⇒ Types::BatchGetThreatModelsOutput
Retrieves information about one or more threat models in an agent space.
1623 1624 1625 1626 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1623 def batch_get_threat_models(params = {}, = {}) req = build_request(:batch_get_threat_models, params) req.send_request() end |
#batch_get_threats(params = {}) ⇒ Types::BatchGetThreatsOutput
Retrieves information about one or more threats.
1686 1687 1688 1689 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1686 def batch_get_threats(params = {}, = {}) req = build_request(:batch_get_threats, params) req.send_request() end |
#batch_update_security_requirements(params = {}) ⇒ Types::BatchUpdateSecurityRequirementsOutput
Batch updates security requirements within a customer managed pack.
1733 1734 1735 1736 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1733 def batch_update_security_requirements(params = {}, = {}) req = build_request(:batch_update_security_requirements, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5952 5953 5954 5955 5956 5957 5958 5959 5960 5961 5962 5963 5964 5965 5966 5967 5968 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5952 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SecurityAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-securityagent' context[:gem_version] = '1.7.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space. An agent space is a dedicated workspace for securing a specific application.
1839 1840 1841 1842 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1839 def create_agent_space(params = {}, = {}) req = build_request(:create_agent_space, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application. An application is the top-level organizational unit that supports IAM Identity Center integration.
1885 1886 1887 1888 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1885 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_code_review(params = {}) ⇒ Types::CreateCodeReviewOutput
Creates a new code review configuration in an agent space. A code review defines the parameters for automated security-focused code analysis.
2020 2021 2022 2023 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2020 def create_code_review(params = {}, = {}) req = build_request(:create_code_review, params) req.send_request() end |
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
2100 2101 2102 2103 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2100 def create_integration(params = {}, = {}) req = build_request(:create_integration, params) req.send_request() end |
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
2144 2145 2146 2147 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2144 def create_membership(params = {}, = {}) req = build_request(:create_membership, params) req.send_request() end |
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space. A pentest defines the security test parameters, including target assets, risk type exclusions, and logging configuration.
2309 2310 2311 2312 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2309 def create_pentest(params = {}, = {}) req = build_request(:create_pentest, params) req.send_request() end |
#create_private_connection(params = {}) ⇒ Types::CreatePrivateConnectionOutput
Creates a private connection for reaching a self-hosted provider instance over private networking using Amazon VPC Lattice.
2386 2387 2388 2389 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2386 def create_private_connection(params = {}, = {}) req = build_request(:create_private_connection, params) req.send_request() end |
#create_security_requirement_pack(params = {}) ⇒ Types::CreateSecurityRequirementPackOutput
Creates a customer managed security requirement pack.
2436 2437 2438 2439 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2436 def create_security_requirement_pack(params = {}, = {}) req = build_request(:create_security_requirement_pack, params) req.send_request() end |
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing. A target domain is a web domain that must be registered and verified before it can be tested.
2494 2495 2496 2497 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2494 def create_target_domain(params = {}, = {}) req = build_request(:create_target_domain, params) req.send_request() end |
#create_threat(params = {}) ⇒ Types::CreateThreatOutput
Creates a new threat under a threat model job.
2638 2639 2640 2641 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2638 def create_threat(params = {}, = {}) req = build_request(:create_threat, params) req.send_request() end |
#create_threat_model(params = {}) ⇒ Types::CreateThreatModelOutput
Creates a new threat model configuration in an agent space. A threat model defines the parameters for automated threat analysis.
2793 2794 2795 2796 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2793 def create_threat_model(params = {}, = {}) req = build_request(:create_threat_model, params) req.send_request() end |
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
2822 2823 2824 2825 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2822 def delete_agent_space(params = {}, = {}) req = build_request(:delete_agent_space, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
2845 2846 2847 2848 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2845 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
2871 2872 2873 2874 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2871 def delete_artifact(params = {}, = {}) req = build_request(:delete_artifact, params) req.send_request() end |
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
2893 2894 2895 2896 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2893 def delete_integration(params = {}, = {}) req = build_request(:delete_integration, params) req.send_request() end |
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user’s access to an agent space.
2928 2929 2930 2931 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2928 def delete_membership(params = {}, = {}) req = build_request(:delete_membership, params) req.send_request() end |
#delete_private_connection(params = {}) ⇒ Types::DeletePrivateConnectionOutput
Deletes a private connection.
2977 2978 2979 2980 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2977 def delete_private_connection(params = {}, = {}) req = build_request(:delete_private_connection, params) req.send_request() end |
#delete_security_requirement_pack(params = {}) ⇒ Struct
Deletes a customer managed security requirement pack and all its associated security requirements.
3000 3001 3002 3003 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3000 def delete_security_requirement_pack(params = {}, = {}) req = build_request(:delete_security_requirement_pack, params) req.send_request() end |
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration. After deletion, the domain can no longer be used for penetration testing.
3029 3030 3031 3032 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3029 def delete_target_domain(params = {}, = {}) req = build_request(:delete_target_domain, params) req.send_request() end |
#describe_private_connection(params = {}) ⇒ Types::DescribePrivateConnectionOutput
Retrieves the details of a private connection.
3078 3079 3080 3081 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3078 def describe_private_connection(params = {}, = {}) req = build_request(:describe_private_connection, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
3117 3118 3119 3120 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3117 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
3158 3159 3160 3161 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3158 def get_artifact(params = {}, = {}) req = build_request(:get_artifact, params) req.send_request() end |
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
3200 3201 3202 3203 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3200 def get_integration(params = {}, = {}) req = build_request(:get_integration, params) req.send_request() end |
#get_security_requirement_pack(params = {}) ⇒ Types::GetSecurityRequirementPackOutput
Retrieves information about a security requirement pack.
3246 3247 3248 3249 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3246 def get_security_requirement_pack(params = {}, = {}) req = build_request(:get_security_requirement_pack, params) req.send_request() end |
#import_security_requirements(params = {}) ⇒ Types::ImportSecurityRequirementsOutput
Imports security requirements from uploaded documents into a customer managed security requirement pack. The import process asynchronously extracts and generates structured security requirements from the provided source files.
3293 3294 3295 3296 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3293 def import_security_requirements(params = {}, = {}) req = build_request(:import_security_requirements, params) req.send_request() end |
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider. Returns a redirect URL and CSRF state token for completing the authorization.
3326 3327 3328 3329 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3326 def initiate_provider_registration(params = {}, = {}) req = build_request(:initiate_provider_registration, params) req.send_request() end |
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3369 3370 3371 3372 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3369 def list_agent_spaces(params = {}, = {}) req = build_request(:list_agent_spaces, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3412 3413 3414 3415 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3412 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3459 3460 3461 3462 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3459 def list_artifacts(params = {}, = {}) req = build_request(:list_artifacts, params) req.send_request() end |
#list_code_review_job_tasks(params = {}) ⇒ Types::ListCodeReviewJobTasksOutput
Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3524 3525 3526 3527 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3524 def list_code_review_job_tasks(params = {}, = {}) req = build_request(:list_code_review_job_tasks, params) req.send_request() end |
#list_code_review_jobs_for_code_review(params = {}) ⇒ Types::ListCodeReviewJobsForCodeReviewOutput
Returns a paginated list of code review job summaries for the specified code review configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3578 3579 3580 3581 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3578 def list_code_review_jobs_for_code_review(params = {}, = {}) req = build_request(:list_code_review_jobs_for_code_review, params) req.send_request() end |
#list_code_reviews(params = {}) ⇒ Types::ListCodeReviewsOutput
Returns a paginated list of code review summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3627 3628 3629 3630 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3627 def list_code_reviews(params = {}, = {}) req = build_request(:list_code_reviews, params) req.send_request() end |
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3687 3688 3689 3690 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3687 def list_discovered_endpoints(params = {}, = {}) req = build_request(:list_discovered_endpoints, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3773 3774 3775 3776 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3773 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3854 3855 3856 3857 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3854 def list_integrated_resources(params = {}, = {}) req = build_request(:list_integrated_resources, params) req.send_request() end |
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3908 3909 3910 3911 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3908 def list_integrations(params = {}, = {}) req = build_request(:list_integrations, params) req.send_request() end |
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3972 3973 3974 3975 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3972 def list_memberships(params = {}, = {}) req = build_request(:list_memberships, params) req.send_request() end |
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4038 4039 4040 4041 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4038 def list_pentest_job_tasks(params = {}, = {}) req = build_request(:list_pentest_job_tasks, params) req.send_request() end |
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4092 4093 4094 4095 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4092 def list_pentest_jobs_for_pentest(params = {}, = {}) req = build_request(:list_pentest_jobs_for_pentest, params) req.send_request() end |
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4141 4142 4143 4144 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4141 def list_pentests(params = {}, = {}) req = build_request(:list_pentests, params) req.send_request() end |
#list_private_connections(params = {}) ⇒ Types::ListPrivateConnectionsOutput
Lists the private connections in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4190 4191 4192 4193 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4190 def list_private_connections(params = {}, = {}) req = build_request(:list_private_connections, params) req.send_request() end |
#list_security_requirement_packs(params = {}) ⇒ Types::ListSecurityRequirementPacksOutput
Lists all security requirement packs in the caller’s account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4242 4243 4244 4245 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4242 def list_security_requirement_packs(params = {}, = {}) req = build_request(:list_security_requirement_packs, params) req.send_request() end |
#list_security_requirements(params = {}) ⇒ Types::ListSecurityRequirementsOutput
Lists security requirements within a pack.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4289 4290 4291 4292 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4289 def list_security_requirements(params = {}, = {}) req = build_request(:list_security_requirements, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
4318 4319 4320 4321 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4318 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4360 4361 4362 4363 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4360 def list_target_domains(params = {}, = {}) req = build_request(:list_target_domains, params) req.send_request() end |
#list_threat_model_job_tasks(params = {}) ⇒ Types::ListThreatModelJobTasksOutput
Returns a paginated list of task summaries for the specified threat model job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4414 4415 4416 4417 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4414 def list_threat_model_job_tasks(params = {}, = {}) req = build_request(:list_threat_model_job_tasks, params) req.send_request() end |
#list_threat_model_jobs(params = {}) ⇒ Types::ListThreatModelJobsOutput
Returns a paginated list of threat model job summaries for the specified threat model.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4467 4468 4469 4470 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4467 def list_threat_model_jobs(params = {}, = {}) req = build_request(:list_threat_model_jobs, params) req.send_request() end |
#list_threat_models(params = {}) ⇒ Types::ListThreatModelsOutput
Returns a paginated list of threat model summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4514 4515 4516 4517 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4514 def list_threat_models(params = {}, = {}) req = build_request(:list_threat_models, params) req.send_request() end |
#list_threats(params = {}) ⇒ Types::ListThreatsOutput
Returns a paginated list of threats for a threat model job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4571 4572 4573 4574 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4571 def list_threats(params = {}, = {}) req = build_request(:list_threats, params) req.send_request() end |
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings. This creates pull requests in integrated repositories to fix the identified vulnerabilities.
4609 4610 4611 4612 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4609 def start_code_remediation(params = {}, = {}) req = build_request(:start_code_remediation, params) req.send_request() end |
#start_code_review_job(params = {}) ⇒ Types::StartCodeReviewJobOutput
Starts a new code review job for a code review configuration. The job executes the security-focused code analysis defined in the code review.
4662 4663 4664 4665 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4662 def start_code_review_job(params = {}, = {}) req = build_request(:start_code_review_job, params) req.send_request() end |
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration. The job executes the security tests defined in the pentest.
4707 4708 4709 4710 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4707 def start_pentest_job(params = {}, = {}) req = build_request(:start_pentest_job, params) req.send_request() end |
#start_threat_model_job(params = {}) ⇒ Types::StartThreatModelJobOutput
Starts a new threat model job for a threat model configuration.
4751 4752 4753 4754 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4751 def start_threat_model_job(params = {}, = {}) req = build_request(:start_threat_model_job, params) req.send_request() end |
#stop_code_review_job(params = {}) ⇒ Struct
Stops a running code review job. The job transitions to a stopping state and then to stopped after cleanup completes.
4778 4779 4780 4781 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4778 def stop_code_review_job(params = {}, = {}) req = build_request(:stop_code_review_job, params) req.send_request() end |
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job. The job transitions to a stopping state and then to stopped after cleanup completes.
4805 4806 4807 4808 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4805 def stop_pentest_job(params = {}, = {}) req = build_request(:stop_pentest_job, params) req.send_request() end |
#stop_threat_model_job(params = {}) ⇒ Struct
Stops a running threat model job.
4831 4832 4833 4834 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4831 def stop_threat_model_job(params = {}, = {}) req = build_request(:stop_threat_model_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
4859 4860 4861 4862 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4859 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
4885 4886 4887 4888 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4885 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
4983 4984 4985 4986 |
# File 'lib/aws-sdk-securityagent/client.rb', line 4983 def update_agent_space(params = {}, = {}) req = build_request(:update_agent_space, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
5021 5022 5023 5024 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5021 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_code_review(params = {}) ⇒ Types::UpdateCodeReviewOutput
Updates an existing code review configuration.
5157 5158 5159 5160 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5157 def update_code_review(params = {}, = {}) req = build_request(:update_code_review, params) req.send_request() end |
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
5219 5220 5221 5222 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5219 def update_finding(params = {}, = {}) req = build_request(:update_finding, params) req.send_request() end |
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
5293 5294 5295 5296 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5293 def update_integrated_resources(params = {}, = {}) req = build_request(:update_integrated_resources, params) req.send_request() end |
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
5457 5458 5459 5460 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5457 def update_pentest(params = {}, = {}) req = build_request(:update_pentest, params) req.send_request() end |
#update_private_connection_certificate(params = {}) ⇒ Types::UpdatePrivateConnectionCertificateOutput
Updates the certificate associated with a private connection. Certificates can be added or replaced but not removed.
5511 5512 5513 5514 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5511 def update_private_connection_certificate(params = {}, = {}) req = build_request(:update_private_connection_certificate, params) req.send_request() end |
#update_security_requirement_pack(params = {}) ⇒ Types::UpdateSecurityRequirementPackOutput
Updates a security requirement pack. For customer managed packs, both metadata and status can be updated. For AWS managed packs, only status can be updated.
5559 5560 5561 5562 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5559 def update_security_requirement_pack(params = {}, = {}) req = build_request(:update_security_requirement_pack, params) req.send_request() end |
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
5608 5609 5610 5611 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5608 def update_target_domain(params = {}, = {}) req = build_request(:update_target_domain, params) req.send_request() end |
#update_threat(params = {}) ⇒ Types::UpdateThreatOutput
Updates a threat.
5752 5753 5754 5755 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5752 def update_threat(params = {}, = {}) req = build_request(:update_threat, params) req.send_request() end |
#update_threat_model(params = {}) ⇒ Types::UpdateThreatModelOutput
Updates an existing threat model configuration.
5902 5903 5904 5905 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5902 def update_threat_model(params = {}, = {}) req = build_request(:update_threat_model, params) req.send_request() end |
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain. This checks whether the domain ownership verification token has been properly configured.
5943 5944 5945 5946 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5943 def verify_target_domain(params = {}, = {}) req = build_request(:verify_target_domain, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5972 5973 5974 |
# File 'lib/aws-sdk-securityagent/client.rb', line 5972 def waiter_names [] end |