Class: Aws::SecurityAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SecurityAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-securityagent/client.rb
Overview
An API client for SecurityAgent. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SecurityAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space.
-
#batch_delete_code_reviews(params = {}) ⇒ Types::BatchDeleteCodeReviewsOutput
Deletes one or more code reviews from an agent space.
-
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
-
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
-
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
-
#batch_get_code_review_job_tasks(params = {}) ⇒ Types::BatchGetCodeReviewJobTasksOutput
Retrieves information about one or more tasks within a code review job.
-
#batch_get_code_review_jobs(params = {}) ⇒ Types::BatchGetCodeReviewJobsOutput
Retrieves information about one or more code review jobs in an agent space.
-
#batch_get_code_reviews(params = {}) ⇒ Types::BatchGetCodeReviewsOutput
Retrieves information about one or more code reviews in an agent space.
-
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
-
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
-
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
-
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
-
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application.
-
#create_code_review(params = {}) ⇒ Types::CreateCodeReviewOutput
Creates a new code review configuration in an agent space.
-
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
-
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
-
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space.
-
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing.
-
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
-
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
-
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
-
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user’s access to an agent space.
-
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
-
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
-
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
-
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
-
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
-
#list_code_review_job_tasks(params = {}) ⇒ Types::ListCodeReviewJobTasksOutput
Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.
-
#list_code_review_jobs_for_code_review(params = {}) ⇒ Types::ListCodeReviewJobsForCodeReviewOutput
Returns a paginated list of code review job summaries for the specified code review configuration.
-
#list_code_reviews(params = {}) ⇒ Types::ListCodeReviewsOutput
Returns a paginated list of code review summaries for the specified agent space.
-
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
-
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
-
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
-
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
-
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
-
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
-
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
-
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
-
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
-
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings.
-
#start_code_review_job(params = {}) ⇒ Types::StartCodeReviewJobOutput
Starts a new code review job for a code review configuration.
-
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration.
-
#stop_code_review_job(params = {}) ⇒ Struct
Stops a running code review job.
-
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
-
#update_code_review(params = {}) ⇒ Types::UpdateCodeReviewOutput
Updates an existing code review configuration.
-
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
-
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
-
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
-
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
-
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-securityagent/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3857 3858 3859 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3857 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3860 3861 3862 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3860 def errors_module Errors end |
Instance Method Details
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space. Artifacts provide additional context for security testing, such as architecture diagrams, API specifications, or configuration files.
515 516 517 518 |
# File 'lib/aws-sdk-securityagent/client.rb', line 515 def add_artifact(params = {}, = {}) req = build_request(:add_artifact, params) req.send_request() end |
#batch_delete_code_reviews(params = {}) ⇒ Types::BatchDeleteCodeReviewsOutput
Deletes one or more code reviews from an agent space.
553 554 555 556 |
# File 'lib/aws-sdk-securityagent/client.rb', line 553 def batch_delete_code_reviews(params = {}, = {}) req = build_request(:batch_delete_code_reviews, params) req.send_request() end |
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
630 631 632 633 |
# File 'lib/aws-sdk-securityagent/client.rb', line 630 def batch_delete_pentests(params = {}, = {}) req = build_request(:batch_delete_pentests, params) req.send_request() end |
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
687 688 689 690 |
# File 'lib/aws-sdk-securityagent/client.rb', line 687 def batch_get_agent_spaces(params = {}, = {}) req = build_request(:batch_get_agent_spaces, params) req.send_request() end |
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
723 724 725 726 |
# File 'lib/aws-sdk-securityagent/client.rb', line 723 def (params = {}, = {}) req = build_request(:batch_get_artifact_metadata, params) req.send_request() end |
#batch_get_code_review_job_tasks(params = {}) ⇒ Types::BatchGetCodeReviewJobTasksOutput
Retrieves information about one or more tasks within a code review job.
775 776 777 778 |
# File 'lib/aws-sdk-securityagent/client.rb', line 775 def batch_get_code_review_job_tasks(params = {}, = {}) req = build_request(:batch_get_code_review_job_tasks, params) req.send_request() end |
#batch_get_code_review_jobs(params = {}) ⇒ Types::BatchGetCodeReviewJobsOutput
Retrieves information about one or more code review jobs in an agent space.
842 843 844 845 |
# File 'lib/aws-sdk-securityagent/client.rb', line 842 def batch_get_code_review_jobs(params = {}, = {}) req = build_request(:batch_get_code_review_jobs, params) req.send_request() end |
#batch_get_code_reviews(params = {}) ⇒ Types::BatchGetCodeReviewsOutput
Retrieves information about one or more code reviews in an agent space.
905 906 907 908 |
# File 'lib/aws-sdk-securityagent/client.rb', line 905 def batch_get_code_reviews(params = {}, = {}) req = build_request(:batch_get_code_reviews, params) req.send_request() end |
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
977 978 979 980 |
# File 'lib/aws-sdk-securityagent/client.rb', line 977 def batch_get_findings(params = {}, = {}) req = build_request(:batch_get_findings, params) req.send_request() end |
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
1029 1030 1031 1032 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1029 def batch_get_pentest_job_tasks(params = {}, = {}) req = build_request(:batch_get_pentest_job_tasks, params) req.send_request() end |
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
1123 1124 1125 1126 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1123 def batch_get_pentest_jobs(params = {}, = {}) req = build_request(:batch_get_pentest_jobs, params) req.send_request() end |
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
1198 1199 1200 1201 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1198 def batch_get_pentests(params = {}, = {}) req = build_request(:batch_get_pentests, params) req.send_request() end |
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
1241 1242 1243 1244 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1241 def batch_get_target_domains(params = {}, = {}) req = build_request(:batch_get_target_domains, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3830 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SecurityAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-securityagent' context[:gem_version] = '1.6.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space. An agent space is a dedicated workspace for securing a specific application.
1347 1348 1349 1350 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1347 def create_agent_space(params = {}, = {}) req = build_request(:create_agent_space, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application. An application is the top-level organizational unit that supports IAM Identity Center integration.
1393 1394 1395 1396 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1393 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_code_review(params = {}) ⇒ Types::CreateCodeReviewOutput
Creates a new code review configuration in an agent space. A code review defines the parameters for automated security-focused code analysis.
1515 1516 1517 1518 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1515 def create_code_review(params = {}, = {}) req = build_request(:create_code_review, params) req.send_request() end |
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
1569 1570 1571 1572 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1569 def create_integration(params = {}, = {}) req = build_request(:create_integration, params) req.send_request() end |
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
1613 1614 1615 1616 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1613 def create_membership(params = {}, = {}) req = build_request(:create_membership, params) req.send_request() end |
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space. A pentest defines the security test parameters, including target assets, risk type exclusions, and logging configuration.
1767 1768 1769 1770 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1767 def create_pentest(params = {}, = {}) req = build_request(:create_pentest, params) req.send_request() end |
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing. A target domain is a web domain that must be registered and verified before it can be tested.
1825 1826 1827 1828 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1825 def create_target_domain(params = {}, = {}) req = build_request(:create_target_domain, params) req.send_request() end |
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
1854 1855 1856 1857 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1854 def delete_agent_space(params = {}, = {}) req = build_request(:delete_agent_space, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
1877 1878 1879 1880 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1877 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
1903 1904 1905 1906 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1903 def delete_artifact(params = {}, = {}) req = build_request(:delete_artifact, params) req.send_request() end |
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
1925 1926 1927 1928 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1925 def delete_integration(params = {}, = {}) req = build_request(:delete_integration, params) req.send_request() end |
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user’s access to an agent space.
1960 1961 1962 1963 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1960 def delete_membership(params = {}, = {}) req = build_request(:delete_membership, params) req.send_request() end |
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration. After deletion, the domain can no longer be used for penetration testing.
1989 1990 1991 1992 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1989 def delete_target_domain(params = {}, = {}) req = build_request(:delete_target_domain, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
2028 2029 2030 2031 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2028 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
2069 2070 2071 2072 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2069 def get_artifact(params = {}, = {}) req = build_request(:get_artifact, params) req.send_request() end |
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
2107 2108 2109 2110 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2107 def get_integration(params = {}, = {}) req = build_request(:get_integration, params) req.send_request() end |
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider. Returns a redirect URL and CSRF state token for completing the authorization.
2140 2141 2142 2143 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2140 def initiate_provider_registration(params = {}, = {}) req = build_request(:initiate_provider_registration, params) req.send_request() end |
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2183 2184 2185 2186 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2183 def list_agent_spaces(params = {}, = {}) req = build_request(:list_agent_spaces, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2226 2227 2228 2229 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2226 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2273 2274 2275 2276 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2273 def list_artifacts(params = {}, = {}) req = build_request(:list_artifacts, params) req.send_request() end |
#list_code_review_job_tasks(params = {}) ⇒ Types::ListCodeReviewJobTasksOutput
Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2338 2339 2340 2341 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2338 def list_code_review_job_tasks(params = {}, = {}) req = build_request(:list_code_review_job_tasks, params) req.send_request() end |
#list_code_review_jobs_for_code_review(params = {}) ⇒ Types::ListCodeReviewJobsForCodeReviewOutput
Returns a paginated list of code review job summaries for the specified code review configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2392 2393 2394 2395 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2392 def list_code_review_jobs_for_code_review(params = {}, = {}) req = build_request(:list_code_review_jobs_for_code_review, params) req.send_request() end |
#list_code_reviews(params = {}) ⇒ Types::ListCodeReviewsOutput
Returns a paginated list of code review summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2441 2442 2443 2444 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2441 def list_code_reviews(params = {}, = {}) req = build_request(:list_code_reviews, params) req.send_request() end |
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2501 2502 2503 2504 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2501 def list_discovered_endpoints(params = {}, = {}) req = build_request(:list_discovered_endpoints, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2586 2587 2588 2589 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2586 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2646 2647 2648 2649 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2646 def list_integrated_resources(params = {}, = {}) req = build_request(:list_integrated_resources, params) req.send_request() end |
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2698 2699 2700 2701 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2698 def list_integrations(params = {}, = {}) req = build_request(:list_integrations, params) req.send_request() end |
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2762 2763 2764 2765 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2762 def list_memberships(params = {}, = {}) req = build_request(:list_memberships, params) req.send_request() end |
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2828 2829 2830 2831 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2828 def list_pentest_job_tasks(params = {}, = {}) req = build_request(:list_pentest_job_tasks, params) req.send_request() end |
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2882 2883 2884 2885 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2882 def list_pentest_jobs_for_pentest(params = {}, = {}) req = build_request(:list_pentest_jobs_for_pentest, params) req.send_request() end |
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2931 2932 2933 2934 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2931 def list_pentests(params = {}, = {}) req = build_request(:list_pentests, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
2960 2961 2962 2963 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2960 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3002 3003 3004 3005 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3002 def list_target_domains(params = {}, = {}) req = build_request(:list_target_domains, params) req.send_request() end |
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings. This creates pull requests in integrated repositories to fix the identified vulnerabilities.
3040 3041 3042 3043 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3040 def start_code_remediation(params = {}, = {}) req = build_request(:start_code_remediation, params) req.send_request() end |
#start_code_review_job(params = {}) ⇒ Types::StartCodeReviewJobOutput
Starts a new code review job for a code review configuration. The job executes the security-focused code analysis defined in the code review.
3086 3087 3088 3089 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3086 def start_code_review_job(params = {}, = {}) req = build_request(:start_code_review_job, params) req.send_request() end |
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration. The job executes the security tests defined in the pentest.
3131 3132 3133 3134 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3131 def start_pentest_job(params = {}, = {}) req = build_request(:start_pentest_job, params) req.send_request() end |
#stop_code_review_job(params = {}) ⇒ Struct
Stops a running code review job. The job transitions to a stopping state and then to stopped after cleanup completes.
3158 3159 3160 3161 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3158 def stop_code_review_job(params = {}, = {}) req = build_request(:stop_code_review_job, params) req.send_request() end |
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job. The job transitions to a stopping state and then to stopped after cleanup completes.
3185 3186 3187 3188 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3185 def stop_pentest_job(params = {}, = {}) req = build_request(:stop_pentest_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
3213 3214 3215 3216 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3213 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
3239 3240 3241 3242 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3239 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
3337 3338 3339 3340 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3337 def update_agent_space(params = {}, = {}) req = build_request(:update_agent_space, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
3375 3376 3377 3378 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3375 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_code_review(params = {}) ⇒ Types::UpdateCodeReviewOutput
Updates an existing code review configuration.
3498 3499 3500 3501 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3498 def update_code_review(params = {}, = {}) req = build_request(:update_code_review, params) req.send_request() end |
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
3532 3533 3534 3535 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3532 def update_finding(params = {}, = {}) req = build_request(:update_finding, params) req.send_request() end |
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
3578 3579 3580 3581 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3578 def update_integrated_resources(params = {}, = {}) req = build_request(:update_integrated_resources, params) req.send_request() end |
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
3731 3732 3733 3734 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3731 def update_pentest(params = {}, = {}) req = build_request(:update_pentest, params) req.send_request() end |
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
3780 3781 3782 3783 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3780 def update_target_domain(params = {}, = {}) req = build_request(:update_target_domain, params) req.send_request() end |
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain. This checks whether the domain ownership verification token has been properly configured.
3821 3822 3823 3824 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3821 def verify_target_domain(params = {}, = {}) req = build_request(:verify_target_domain, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3850 3851 3852 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3850 def waiter_names [] end |