Class: Aws::SecurityAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SecurityAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-securityagent/client.rb
Overview
An API client for SecurityAgent. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SecurityAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space.
-
#batch_delete_code_reviews(params = {}) ⇒ Types::BatchDeleteCodeReviewsOutput
Deletes one or more code reviews from an agent space.
-
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
-
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
-
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
-
#batch_get_code_review_job_tasks(params = {}) ⇒ Types::BatchGetCodeReviewJobTasksOutput
Retrieves information about one or more tasks within a code review job.
-
#batch_get_code_review_jobs(params = {}) ⇒ Types::BatchGetCodeReviewJobsOutput
Retrieves information about one or more code review jobs in an agent space.
-
#batch_get_code_reviews(params = {}) ⇒ Types::BatchGetCodeReviewsOutput
Retrieves information about one or more code reviews in an agent space.
-
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
-
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
-
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
-
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
-
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application.
-
#create_code_review(params = {}) ⇒ Types::CreateCodeReviewOutput
Creates a new code review configuration in an agent space.
-
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
-
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
-
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space.
-
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing.
-
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
-
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
-
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
-
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user’s access to an agent space.
-
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
-
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
-
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
-
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
-
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
-
#list_code_review_job_tasks(params = {}) ⇒ Types::ListCodeReviewJobTasksOutput
Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.
-
#list_code_review_jobs_for_code_review(params = {}) ⇒ Types::ListCodeReviewJobsForCodeReviewOutput
Returns a paginated list of code review job summaries for the specified code review configuration.
-
#list_code_reviews(params = {}) ⇒ Types::ListCodeReviewsOutput
Returns a paginated list of code review summaries for the specified agent space.
-
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
-
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
-
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
-
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
-
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
-
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
-
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
-
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
-
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
-
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings.
-
#start_code_review_job(params = {}) ⇒ Types::StartCodeReviewJobOutput
Starts a new code review job for a code review configuration.
-
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration.
-
#stop_code_review_job(params = {}) ⇒ Struct
Stops a running code review job.
-
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
-
#update_code_review(params = {}) ⇒ Types::UpdateCodeReviewOutput
Updates an existing code review configuration.
-
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
-
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
-
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
-
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
-
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-securityagent/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3851 3852 3853 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3851 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3854 3855 3856 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3854 def errors_module Errors end |
Instance Method Details
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space. Artifacts provide additional context for security testing, such as architecture diagrams, API specifications, or configuration files.
515 516 517 518 |
# File 'lib/aws-sdk-securityagent/client.rb', line 515 def add_artifact(params = {}, = {}) req = build_request(:add_artifact, params) req.send_request() end |
#batch_delete_code_reviews(params = {}) ⇒ Types::BatchDeleteCodeReviewsOutput
Deletes one or more code reviews from an agent space.
553 554 555 556 |
# File 'lib/aws-sdk-securityagent/client.rb', line 553 def batch_delete_code_reviews(params = {}, = {}) req = build_request(:batch_delete_code_reviews, params) req.send_request() end |
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
630 631 632 633 |
# File 'lib/aws-sdk-securityagent/client.rb', line 630 def batch_delete_pentests(params = {}, = {}) req = build_request(:batch_delete_pentests, params) req.send_request() end |
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
687 688 689 690 |
# File 'lib/aws-sdk-securityagent/client.rb', line 687 def batch_get_agent_spaces(params = {}, = {}) req = build_request(:batch_get_agent_spaces, params) req.send_request() end |
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
723 724 725 726 |
# File 'lib/aws-sdk-securityagent/client.rb', line 723 def (params = {}, = {}) req = build_request(:batch_get_artifact_metadata, params) req.send_request() end |
#batch_get_code_review_job_tasks(params = {}) ⇒ Types::BatchGetCodeReviewJobTasksOutput
Retrieves information about one or more tasks within a code review job.
775 776 777 778 |
# File 'lib/aws-sdk-securityagent/client.rb', line 775 def batch_get_code_review_job_tasks(params = {}, = {}) req = build_request(:batch_get_code_review_job_tasks, params) req.send_request() end |
#batch_get_code_review_jobs(params = {}) ⇒ Types::BatchGetCodeReviewJobsOutput
Retrieves information about one or more code review jobs in an agent space.
842 843 844 845 |
# File 'lib/aws-sdk-securityagent/client.rb', line 842 def batch_get_code_review_jobs(params = {}, = {}) req = build_request(:batch_get_code_review_jobs, params) req.send_request() end |
#batch_get_code_reviews(params = {}) ⇒ Types::BatchGetCodeReviewsOutput
Retrieves information about one or more code reviews in an agent space.
905 906 907 908 |
# File 'lib/aws-sdk-securityagent/client.rb', line 905 def batch_get_code_reviews(params = {}, = {}) req = build_request(:batch_get_code_reviews, params) req.send_request() end |
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
971 972 973 974 |
# File 'lib/aws-sdk-securityagent/client.rb', line 971 def batch_get_findings(params = {}, = {}) req = build_request(:batch_get_findings, params) req.send_request() end |
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
1023 1024 1025 1026 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1023 def batch_get_pentest_job_tasks(params = {}, = {}) req = build_request(:batch_get_pentest_job_tasks, params) req.send_request() end |
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
1117 1118 1119 1120 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1117 def batch_get_pentest_jobs(params = {}, = {}) req = build_request(:batch_get_pentest_jobs, params) req.send_request() end |
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
1192 1193 1194 1195 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1192 def batch_get_pentests(params = {}, = {}) req = build_request(:batch_get_pentests, params) req.send_request() end |
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
1235 1236 1237 1238 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1235 def batch_get_target_domains(params = {}, = {}) req = build_request(:batch_get_target_domains, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3824 3825 3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3824 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SecurityAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-securityagent' context[:gem_version] = '1.4.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space. An agent space is a dedicated workspace for securing a specific application.
1341 1342 1343 1344 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1341 def create_agent_space(params = {}, = {}) req = build_request(:create_agent_space, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application. An application is the top-level organizational unit that supports IAM Identity Center integration.
1387 1388 1389 1390 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1387 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_code_review(params = {}) ⇒ Types::CreateCodeReviewOutput
Creates a new code review configuration in an agent space. A code review defines the parameters for automated security-focused code analysis.
1509 1510 1511 1512 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1509 def create_code_review(params = {}, = {}) req = build_request(:create_code_review, params) req.send_request() end |
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
1563 1564 1565 1566 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1563 def create_integration(params = {}, = {}) req = build_request(:create_integration, params) req.send_request() end |
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
1607 1608 1609 1610 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1607 def create_membership(params = {}, = {}) req = build_request(:create_membership, params) req.send_request() end |
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space. A pentest defines the security test parameters, including target assets, risk type exclusions, and logging configuration.
1761 1762 1763 1764 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1761 def create_pentest(params = {}, = {}) req = build_request(:create_pentest, params) req.send_request() end |
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing. A target domain is a web domain that must be registered and verified before it can be tested.
1819 1820 1821 1822 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1819 def create_target_domain(params = {}, = {}) req = build_request(:create_target_domain, params) req.send_request() end |
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
1848 1849 1850 1851 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1848 def delete_agent_space(params = {}, = {}) req = build_request(:delete_agent_space, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
1871 1872 1873 1874 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1871 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
1897 1898 1899 1900 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1897 def delete_artifact(params = {}, = {}) req = build_request(:delete_artifact, params) req.send_request() end |
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
1919 1920 1921 1922 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1919 def delete_integration(params = {}, = {}) req = build_request(:delete_integration, params) req.send_request() end |
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user’s access to an agent space.
1954 1955 1956 1957 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1954 def delete_membership(params = {}, = {}) req = build_request(:delete_membership, params) req.send_request() end |
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration. After deletion, the domain can no longer be used for penetration testing.
1983 1984 1985 1986 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1983 def delete_target_domain(params = {}, = {}) req = build_request(:delete_target_domain, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
2022 2023 2024 2025 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2022 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
2063 2064 2065 2066 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2063 def get_artifact(params = {}, = {}) req = build_request(:get_artifact, params) req.send_request() end |
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
2101 2102 2103 2104 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2101 def get_integration(params = {}, = {}) req = build_request(:get_integration, params) req.send_request() end |
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider. Returns a redirect URL and CSRF state token for completing the authorization.
2134 2135 2136 2137 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2134 def initiate_provider_registration(params = {}, = {}) req = build_request(:initiate_provider_registration, params) req.send_request() end |
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2177 2178 2179 2180 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2177 def list_agent_spaces(params = {}, = {}) req = build_request(:list_agent_spaces, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2220 2221 2222 2223 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2220 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2267 2268 2269 2270 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2267 def list_artifacts(params = {}, = {}) req = build_request(:list_artifacts, params) req.send_request() end |
#list_code_review_job_tasks(params = {}) ⇒ Types::ListCodeReviewJobTasksOutput
Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2332 2333 2334 2335 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2332 def list_code_review_job_tasks(params = {}, = {}) req = build_request(:list_code_review_job_tasks, params) req.send_request() end |
#list_code_review_jobs_for_code_review(params = {}) ⇒ Types::ListCodeReviewJobsForCodeReviewOutput
Returns a paginated list of code review job summaries for the specified code review configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2386 2387 2388 2389 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2386 def list_code_review_jobs_for_code_review(params = {}, = {}) req = build_request(:list_code_review_jobs_for_code_review, params) req.send_request() end |
#list_code_reviews(params = {}) ⇒ Types::ListCodeReviewsOutput
Returns a paginated list of code review summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2435 2436 2437 2438 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2435 def list_code_reviews(params = {}, = {}) req = build_request(:list_code_reviews, params) req.send_request() end |
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2495 2496 2497 2498 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2495 def list_discovered_endpoints(params = {}, = {}) req = build_request(:list_discovered_endpoints, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2580 2581 2582 2583 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2580 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2640 2641 2642 2643 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2640 def list_integrated_resources(params = {}, = {}) req = build_request(:list_integrated_resources, params) req.send_request() end |
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2692 2693 2694 2695 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2692 def list_integrations(params = {}, = {}) req = build_request(:list_integrations, params) req.send_request() end |
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2756 2757 2758 2759 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2756 def list_memberships(params = {}, = {}) req = build_request(:list_memberships, params) req.send_request() end |
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2822 2823 2824 2825 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2822 def list_pentest_job_tasks(params = {}, = {}) req = build_request(:list_pentest_job_tasks, params) req.send_request() end |
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2876 2877 2878 2879 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2876 def list_pentest_jobs_for_pentest(params = {}, = {}) req = build_request(:list_pentest_jobs_for_pentest, params) req.send_request() end |
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2925 2926 2927 2928 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2925 def list_pentests(params = {}, = {}) req = build_request(:list_pentests, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
2954 2955 2956 2957 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2954 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2996 2997 2998 2999 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2996 def list_target_domains(params = {}, = {}) req = build_request(:list_target_domains, params) req.send_request() end |
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings. This creates pull requests in integrated repositories to fix the identified vulnerabilities.
3034 3035 3036 3037 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3034 def start_code_remediation(params = {}, = {}) req = build_request(:start_code_remediation, params) req.send_request() end |
#start_code_review_job(params = {}) ⇒ Types::StartCodeReviewJobOutput
Starts a new code review job for a code review configuration. The job executes the security-focused code analysis defined in the code review.
3080 3081 3082 3083 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3080 def start_code_review_job(params = {}, = {}) req = build_request(:start_code_review_job, params) req.send_request() end |
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration. The job executes the security tests defined in the pentest.
3125 3126 3127 3128 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3125 def start_pentest_job(params = {}, = {}) req = build_request(:start_pentest_job, params) req.send_request() end |
#stop_code_review_job(params = {}) ⇒ Struct
Stops a running code review job. The job transitions to a stopping state and then to stopped after cleanup completes.
3152 3153 3154 3155 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3152 def stop_code_review_job(params = {}, = {}) req = build_request(:stop_code_review_job, params) req.send_request() end |
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job. The job transitions to a stopping state and then to stopped after cleanup completes.
3179 3180 3181 3182 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3179 def stop_pentest_job(params = {}, = {}) req = build_request(:stop_pentest_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
3207 3208 3209 3210 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3207 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
3233 3234 3235 3236 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3233 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
3331 3332 3333 3334 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3331 def update_agent_space(params = {}, = {}) req = build_request(:update_agent_space, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
3369 3370 3371 3372 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3369 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_code_review(params = {}) ⇒ Types::UpdateCodeReviewOutput
Updates an existing code review configuration.
3492 3493 3494 3495 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3492 def update_code_review(params = {}, = {}) req = build_request(:update_code_review, params) req.send_request() end |
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
3526 3527 3528 3529 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3526 def update_finding(params = {}, = {}) req = build_request(:update_finding, params) req.send_request() end |
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
3572 3573 3574 3575 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3572 def update_integrated_resources(params = {}, = {}) req = build_request(:update_integrated_resources, params) req.send_request() end |
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
3725 3726 3727 3728 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3725 def update_pentest(params = {}, = {}) req = build_request(:update_pentest, params) req.send_request() end |
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
3774 3775 3776 3777 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3774 def update_target_domain(params = {}, = {}) req = build_request(:update_target_domain, params) req.send_request() end |
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain. This checks whether the domain ownership verification token has been properly configured.
3815 3816 3817 3818 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3815 def verify_target_domain(params = {}, = {}) req = build_request(:verify_target_domain, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3844 3845 3846 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3844 def waiter_names [] end |