Class: Aws::SecurityAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SecurityAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-securityagent/client.rb
Overview
An API client for SecurityAgent. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SecurityAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space.
-
#batch_delete_code_reviews(params = {}) ⇒ Types::BatchDeleteCodeReviewsOutput
Deletes one or more code reviews from an agent space.
-
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
-
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
-
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
-
#batch_get_code_review_job_tasks(params = {}) ⇒ Types::BatchGetCodeReviewJobTasksOutput
Retrieves information about one or more tasks within a code review job.
-
#batch_get_code_review_jobs(params = {}) ⇒ Types::BatchGetCodeReviewJobsOutput
Retrieves information about one or more code review jobs in an agent space.
-
#batch_get_code_reviews(params = {}) ⇒ Types::BatchGetCodeReviewsOutput
Retrieves information about one or more code reviews in an agent space.
-
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
-
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
-
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
-
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
-
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application.
-
#create_code_review(params = {}) ⇒ Types::CreateCodeReviewOutput
Creates a new code review configuration in an agent space.
-
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
-
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
-
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space.
-
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing.
-
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
-
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
-
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
-
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user’s access to an agent space.
-
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
-
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
-
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
-
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
-
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
-
#list_code_review_job_tasks(params = {}) ⇒ Types::ListCodeReviewJobTasksOutput
Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.
-
#list_code_review_jobs_for_code_review(params = {}) ⇒ Types::ListCodeReviewJobsForCodeReviewOutput
Returns a paginated list of code review job summaries for the specified code review configuration.
-
#list_code_reviews(params = {}) ⇒ Types::ListCodeReviewsOutput
Returns a paginated list of code review summaries for the specified agent space.
-
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
-
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
-
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
-
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
-
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
-
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
-
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
-
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
-
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
-
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings.
-
#start_code_review_job(params = {}) ⇒ Types::StartCodeReviewJobOutput
Starts a new code review job for a code review configuration.
-
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration.
-
#stop_code_review_job(params = {}) ⇒ Struct
Stops a running code review job.
-
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
-
#update_code_review(params = {}) ⇒ Types::UpdateCodeReviewOutput
Updates an existing code review configuration.
-
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
-
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
-
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
-
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
-
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-securityagent/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3853 3854 3855 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3853 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3856 3857 3858 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3856 def errors_module Errors end |
Instance Method Details
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space. Artifacts provide additional context for security testing, such as architecture diagrams, API specifications, or configuration files.
517 518 519 520 |
# File 'lib/aws-sdk-securityagent/client.rb', line 517 def add_artifact(params = {}, = {}) req = build_request(:add_artifact, params) req.send_request() end |
#batch_delete_code_reviews(params = {}) ⇒ Types::BatchDeleteCodeReviewsOutput
Deletes one or more code reviews from an agent space.
555 556 557 558 |
# File 'lib/aws-sdk-securityagent/client.rb', line 555 def batch_delete_code_reviews(params = {}, = {}) req = build_request(:batch_delete_code_reviews, params) req.send_request() end |
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
632 633 634 635 |
# File 'lib/aws-sdk-securityagent/client.rb', line 632 def batch_delete_pentests(params = {}, = {}) req = build_request(:batch_delete_pentests, params) req.send_request() end |
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
689 690 691 692 |
# File 'lib/aws-sdk-securityagent/client.rb', line 689 def batch_get_agent_spaces(params = {}, = {}) req = build_request(:batch_get_agent_spaces, params) req.send_request() end |
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
725 726 727 728 |
# File 'lib/aws-sdk-securityagent/client.rb', line 725 def (params = {}, = {}) req = build_request(:batch_get_artifact_metadata, params) req.send_request() end |
#batch_get_code_review_job_tasks(params = {}) ⇒ Types::BatchGetCodeReviewJobTasksOutput
Retrieves information about one or more tasks within a code review job.
777 778 779 780 |
# File 'lib/aws-sdk-securityagent/client.rb', line 777 def batch_get_code_review_job_tasks(params = {}, = {}) req = build_request(:batch_get_code_review_job_tasks, params) req.send_request() end |
#batch_get_code_review_jobs(params = {}) ⇒ Types::BatchGetCodeReviewJobsOutput
Retrieves information about one or more code review jobs in an agent space.
844 845 846 847 |
# File 'lib/aws-sdk-securityagent/client.rb', line 844 def batch_get_code_review_jobs(params = {}, = {}) req = build_request(:batch_get_code_review_jobs, params) req.send_request() end |
#batch_get_code_reviews(params = {}) ⇒ Types::BatchGetCodeReviewsOutput
Retrieves information about one or more code reviews in an agent space.
907 908 909 910 |
# File 'lib/aws-sdk-securityagent/client.rb', line 907 def batch_get_code_reviews(params = {}, = {}) req = build_request(:batch_get_code_reviews, params) req.send_request() end |
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
973 974 975 976 |
# File 'lib/aws-sdk-securityagent/client.rb', line 973 def batch_get_findings(params = {}, = {}) req = build_request(:batch_get_findings, params) req.send_request() end |
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
1025 1026 1027 1028 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1025 def batch_get_pentest_job_tasks(params = {}, = {}) req = build_request(:batch_get_pentest_job_tasks, params) req.send_request() end |
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
1119 1120 1121 1122 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1119 def batch_get_pentest_jobs(params = {}, = {}) req = build_request(:batch_get_pentest_jobs, params) req.send_request() end |
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
1194 1195 1196 1197 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1194 def batch_get_pentests(params = {}, = {}) req = build_request(:batch_get_pentests, params) req.send_request() end |
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
1237 1238 1239 1240 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1237 def batch_get_target_domains(params = {}, = {}) req = build_request(:batch_get_target_domains, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3826 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SecurityAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-securityagent' context[:gem_version] = '1.3.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space. An agent space is a dedicated workspace for securing a specific application.
1343 1344 1345 1346 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1343 def create_agent_space(params = {}, = {}) req = build_request(:create_agent_space, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application. An application is the top-level organizational unit that supports IAM Identity Center integration.
1389 1390 1391 1392 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1389 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_code_review(params = {}) ⇒ Types::CreateCodeReviewOutput
Creates a new code review configuration in an agent space. A code review defines the parameters for automated security-focused code analysis.
1511 1512 1513 1514 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1511 def create_code_review(params = {}, = {}) req = build_request(:create_code_review, params) req.send_request() end |
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
1565 1566 1567 1568 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1565 def create_integration(params = {}, = {}) req = build_request(:create_integration, params) req.send_request() end |
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
1609 1610 1611 1612 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1609 def create_membership(params = {}, = {}) req = build_request(:create_membership, params) req.send_request() end |
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space. A pentest defines the security test parameters, including target assets, risk type exclusions, and logging configuration.
1763 1764 1765 1766 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1763 def create_pentest(params = {}, = {}) req = build_request(:create_pentest, params) req.send_request() end |
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing. A target domain is a web domain that must be registered and verified before it can be tested.
1821 1822 1823 1824 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1821 def create_target_domain(params = {}, = {}) req = build_request(:create_target_domain, params) req.send_request() end |
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
1850 1851 1852 1853 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1850 def delete_agent_space(params = {}, = {}) req = build_request(:delete_agent_space, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
1873 1874 1875 1876 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1873 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
1899 1900 1901 1902 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1899 def delete_artifact(params = {}, = {}) req = build_request(:delete_artifact, params) req.send_request() end |
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
1921 1922 1923 1924 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1921 def delete_integration(params = {}, = {}) req = build_request(:delete_integration, params) req.send_request() end |
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user’s access to an agent space.
1956 1957 1958 1959 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1956 def delete_membership(params = {}, = {}) req = build_request(:delete_membership, params) req.send_request() end |
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration. After deletion, the domain can no longer be used for penetration testing.
1985 1986 1987 1988 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1985 def delete_target_domain(params = {}, = {}) req = build_request(:delete_target_domain, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
2024 2025 2026 2027 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2024 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
2065 2066 2067 2068 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2065 def get_artifact(params = {}, = {}) req = build_request(:get_artifact, params) req.send_request() end |
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
2103 2104 2105 2106 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2103 def get_integration(params = {}, = {}) req = build_request(:get_integration, params) req.send_request() end |
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider. Returns a redirect URL and CSRF state token for completing the authorization.
2136 2137 2138 2139 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2136 def initiate_provider_registration(params = {}, = {}) req = build_request(:initiate_provider_registration, params) req.send_request() end |
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2179 2180 2181 2182 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2179 def list_agent_spaces(params = {}, = {}) req = build_request(:list_agent_spaces, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2222 2223 2224 2225 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2222 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2269 2270 2271 2272 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2269 def list_artifacts(params = {}, = {}) req = build_request(:list_artifacts, params) req.send_request() end |
#list_code_review_job_tasks(params = {}) ⇒ Types::ListCodeReviewJobTasksOutput
Returns a paginated list of task summaries for the specified code review job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2334 2335 2336 2337 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2334 def list_code_review_job_tasks(params = {}, = {}) req = build_request(:list_code_review_job_tasks, params) req.send_request() end |
#list_code_review_jobs_for_code_review(params = {}) ⇒ Types::ListCodeReviewJobsForCodeReviewOutput
Returns a paginated list of code review job summaries for the specified code review configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2388 2389 2390 2391 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2388 def list_code_review_jobs_for_code_review(params = {}, = {}) req = build_request(:list_code_review_jobs_for_code_review, params) req.send_request() end |
#list_code_reviews(params = {}) ⇒ Types::ListCodeReviewsOutput
Returns a paginated list of code review summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2437 2438 2439 2440 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2437 def list_code_reviews(params = {}, = {}) req = build_request(:list_code_reviews, params) req.send_request() end |
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2497 2498 2499 2500 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2497 def list_discovered_endpoints(params = {}, = {}) req = build_request(:list_discovered_endpoints, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2582 2583 2584 2585 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2582 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2642 2643 2644 2645 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2642 def list_integrated_resources(params = {}, = {}) req = build_request(:list_integrated_resources, params) req.send_request() end |
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2694 2695 2696 2697 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2694 def list_integrations(params = {}, = {}) req = build_request(:list_integrations, params) req.send_request() end |
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2758 2759 2760 2761 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2758 def list_memberships(params = {}, = {}) req = build_request(:list_memberships, params) req.send_request() end |
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2824 2825 2826 2827 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2824 def list_pentest_job_tasks(params = {}, = {}) req = build_request(:list_pentest_job_tasks, params) req.send_request() end |
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2878 2879 2880 2881 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2878 def list_pentest_jobs_for_pentest(params = {}, = {}) req = build_request(:list_pentest_jobs_for_pentest, params) req.send_request() end |
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2927 2928 2929 2930 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2927 def list_pentests(params = {}, = {}) req = build_request(:list_pentests, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
2956 2957 2958 2959 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2956 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2998 2999 3000 3001 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2998 def list_target_domains(params = {}, = {}) req = build_request(:list_target_domains, params) req.send_request() end |
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings. This creates pull requests in integrated repositories to fix the identified vulnerabilities.
3036 3037 3038 3039 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3036 def start_code_remediation(params = {}, = {}) req = build_request(:start_code_remediation, params) req.send_request() end |
#start_code_review_job(params = {}) ⇒ Types::StartCodeReviewJobOutput
Starts a new code review job for a code review configuration. The job executes the security-focused code analysis defined in the code review.
3082 3083 3084 3085 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3082 def start_code_review_job(params = {}, = {}) req = build_request(:start_code_review_job, params) req.send_request() end |
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration. The job executes the security tests defined in the pentest.
3127 3128 3129 3130 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3127 def start_pentest_job(params = {}, = {}) req = build_request(:start_pentest_job, params) req.send_request() end |
#stop_code_review_job(params = {}) ⇒ Struct
Stops a running code review job. The job transitions to a stopping state and then to stopped after cleanup completes.
3154 3155 3156 3157 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3154 def stop_code_review_job(params = {}, = {}) req = build_request(:stop_code_review_job, params) req.send_request() end |
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job. The job transitions to a stopping state and then to stopped after cleanup completes.
3181 3182 3183 3184 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3181 def stop_pentest_job(params = {}, = {}) req = build_request(:stop_pentest_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
3209 3210 3211 3212 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3209 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
3235 3236 3237 3238 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3235 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
3333 3334 3335 3336 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3333 def update_agent_space(params = {}, = {}) req = build_request(:update_agent_space, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
3371 3372 3373 3374 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3371 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_code_review(params = {}) ⇒ Types::UpdateCodeReviewOutput
Updates an existing code review configuration.
3494 3495 3496 3497 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3494 def update_code_review(params = {}, = {}) req = build_request(:update_code_review, params) req.send_request() end |
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
3528 3529 3530 3531 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3528 def update_finding(params = {}, = {}) req = build_request(:update_finding, params) req.send_request() end |
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
3574 3575 3576 3577 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3574 def update_integrated_resources(params = {}, = {}) req = build_request(:update_integrated_resources, params) req.send_request() end |
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
3727 3728 3729 3730 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3727 def update_pentest(params = {}, = {}) req = build_request(:update_pentest, params) req.send_request() end |
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
3776 3777 3778 3779 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3776 def update_target_domain(params = {}, = {}) req = build_request(:update_target_domain, params) req.send_request() end |
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain. This checks whether the domain ownership verification token has been properly configured.
3817 3818 3819 3820 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3817 def verify_target_domain(params = {}, = {}) req = build_request(:verify_target_domain, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3846 3847 3848 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3846 def waiter_names [] end |