Class: Aws::SecurityAgent::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SecurityAgent::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-securityagent/client.rb
Overview
An API client for SecurityAgent. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SecurityAgent::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space.
-
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
-
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
-
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
-
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
-
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
-
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
-
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
-
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
-
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application.
-
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
-
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
-
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space.
-
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing.
-
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
-
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
-
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
-
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user’s access to an agent space.
-
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
-
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
-
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
-
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider.
-
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
-
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
-
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
-
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
-
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
-
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
-
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
-
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
-
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
-
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
-
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
-
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings.
-
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration.
-
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
-
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
-
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
-
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
-
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
-
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
-
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-securityagent/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3127 3128 3129 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3127 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3130 3131 3132 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3130 def errors_module Errors end |
Instance Method Details
#add_artifact(params = {}) ⇒ Types::AddArtifactOutput
Uploads an artifact to an agent space. Artifacts provide additional context for security testing, such as architecture diagrams, API specifications, or configuration files.
517 518 519 520 |
# File 'lib/aws-sdk-securityagent/client.rb', line 517 def add_artifact(params = {}, = {}) req = build_request(:add_artifact, params) req.send_request() end |
#batch_delete_pentests(params = {}) ⇒ Types::BatchDeletePentestsOutput
Deletes one or more pentests from an agent space.
594 595 596 597 |
# File 'lib/aws-sdk-securityagent/client.rb', line 594 def batch_delete_pentests(params = {}, = {}) req = build_request(:batch_delete_pentests, params) req.send_request() end |
#batch_get_agent_spaces(params = {}) ⇒ Types::BatchGetAgentSpacesOutput
Retrieves information about one or more agent spaces.
651 652 653 654 |
# File 'lib/aws-sdk-securityagent/client.rb', line 651 def batch_get_agent_spaces(params = {}, = {}) req = build_request(:batch_get_agent_spaces, params) req.send_request() end |
#batch_get_artifact_metadata(params = {}) ⇒ Types::BatchGetArtifactMetadataOutput
Retrieves metadata for one or more artifacts in an agent space.
687 688 689 690 |
# File 'lib/aws-sdk-securityagent/client.rb', line 687 def (params = {}, = {}) req = build_request(:batch_get_artifact_metadata, params) req.send_request() end |
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsOutput
Retrieves information about one or more security findings in an agent space.
746 747 748 749 |
# File 'lib/aws-sdk-securityagent/client.rb', line 746 def batch_get_findings(params = {}, = {}) req = build_request(:batch_get_findings, params) req.send_request() end |
#batch_get_pentest_job_tasks(params = {}) ⇒ Types::BatchGetPentestJobTasksOutput
Retrieves information about one or more tasks within a pentest job.
798 799 800 801 |
# File 'lib/aws-sdk-securityagent/client.rb', line 798 def batch_get_pentest_job_tasks(params = {}, = {}) req = build_request(:batch_get_pentest_job_tasks, params) req.send_request() end |
#batch_get_pentest_jobs(params = {}) ⇒ Types::BatchGetPentestJobsOutput
Retrieves information about one or more pentest jobs in an agent space.
892 893 894 895 |
# File 'lib/aws-sdk-securityagent/client.rb', line 892 def batch_get_pentest_jobs(params = {}, = {}) req = build_request(:batch_get_pentest_jobs, params) req.send_request() end |
#batch_get_pentests(params = {}) ⇒ Types::BatchGetPentestsOutput
Retrieves information about one or more pentests in an agent space.
967 968 969 970 |
# File 'lib/aws-sdk-securityagent/client.rb', line 967 def batch_get_pentests(params = {}, = {}) req = build_request(:batch_get_pentests, params) req.send_request() end |
#batch_get_target_domains(params = {}) ⇒ Types::BatchGetTargetDomainsOutput
Retrieves information about one or more target domains.
1010 1011 1012 1013 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1010 def batch_get_target_domains(params = {}, = {}) req = build_request(:batch_get_target_domains, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3100 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SecurityAgent') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-securityagent' context[:gem_version] = '1.1.0' Seahorse::Client::Request.new(handlers, context) end |
#create_agent_space(params = {}) ⇒ Types::CreateAgentSpaceOutput
Creates a new agent space. An agent space is a dedicated workspace for securing a specific application.
1116 1117 1118 1119 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1116 def create_agent_space(params = {}, = {}) req = build_request(:create_agent_space, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates a new application. An application is the top-level organizational unit that supports IAM Identity Center integration.
1162 1163 1164 1165 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1162 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_integration(params = {}) ⇒ Types::CreateIntegrationOutput
Creates a new integration with a third-party provider, such as GitHub, for code review and remediation.
1216 1217 1218 1219 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1216 def create_integration(params = {}, = {}) req = build_request(:create_integration, params) req.send_request() end |
#create_membership(params = {}) ⇒ Struct
Creates a new membership, granting a user access to an agent space within an application.
1260 1261 1262 1263 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1260 def create_membership(params = {}, = {}) req = build_request(:create_membership, params) req.send_request() end |
#create_pentest(params = {}) ⇒ Types::CreatePentestOutput
Creates a new pentest configuration in an agent space. A pentest defines the security test parameters, including target assets, risk type exclusions, and logging configuration.
1414 1415 1416 1417 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1414 def create_pentest(params = {}, = {}) req = build_request(:create_pentest, params) req.send_request() end |
#create_target_domain(params = {}) ⇒ Types::CreateTargetDomainOutput
Creates a new target domain for penetration testing. A target domain is a web domain that must be registered and verified before it can be tested.
1472 1473 1474 1475 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1472 def create_target_domain(params = {}, = {}) req = build_request(:create_target_domain, params) req.send_request() end |
#delete_agent_space(params = {}) ⇒ Types::DeleteAgentSpaceOutput
Deletes an agent space and all of its associated resources, including pentests, findings, and artifacts.
1501 1502 1503 1504 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1501 def delete_agent_space(params = {}, = {}) req = build_request(:delete_agent_space, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes an application and its associated configuration, including IAM Identity Center settings.
1524 1525 1526 1527 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1524 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_artifact(params = {}) ⇒ Struct
Deletes an artifact from an agent space.
1550 1551 1552 1553 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1550 def delete_artifact(params = {}, = {}) req = build_request(:delete_artifact, params) req.send_request() end |
#delete_integration(params = {}) ⇒ Struct
Deletes an integration with a third-party provider.
1572 1573 1574 1575 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1572 def delete_integration(params = {}, = {}) req = build_request(:delete_integration, params) req.send_request() end |
#delete_membership(params = {}) ⇒ Struct
Deletes a membership, revoking a user’s access to an agent space.
1607 1608 1609 1610 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1607 def delete_membership(params = {}, = {}) req = build_request(:delete_membership, params) req.send_request() end |
#delete_target_domain(params = {}) ⇒ Types::DeleteTargetDomainOutput
Deletes a target domain registration. After deletion, the domain can no longer be used for penetration testing.
1636 1637 1638 1639 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1636 def delete_target_domain(params = {}, = {}) req = build_request(:delete_target_domain, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Retrieves information about an application.
1675 1676 1677 1678 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1675 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_artifact(params = {}) ⇒ Types::GetArtifactOutput
Retrieves an artifact from an agent space.
1716 1717 1718 1719 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1716 def get_artifact(params = {}, = {}) req = build_request(:get_artifact, params) req.send_request() end |
#get_integration(params = {}) ⇒ Types::GetIntegrationOutput
Retrieves information about an integration.
1754 1755 1756 1757 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1754 def get_integration(params = {}, = {}) req = build_request(:get_integration, params) req.send_request() end |
#initiate_provider_registration(params = {}) ⇒ Types::InitiateProviderRegistrationOutput
Initiates the OAuth registration flow with a third-party provider. Returns a redirect URL and CSRF state token for completing the authorization.
1787 1788 1789 1790 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1787 def initiate_provider_registration(params = {}, = {}) req = build_request(:initiate_provider_registration, params) req.send_request() end |
#list_agent_spaces(params = {}) ⇒ Types::ListAgentSpacesOutput
Returns a paginated list of agent space summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1830 1831 1832 1833 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1830 def list_agent_spaces(params = {}, = {}) req = build_request(:list_agent_spaces, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Returns a paginated list of application summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1873 1874 1875 1876 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1873 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_artifacts(params = {}) ⇒ Types::ListArtifactsOutput
Returns a paginated list of artifact summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1920 1921 1922 1923 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1920 def list_artifacts(params = {}, = {}) req = build_request(:list_artifacts, params) req.send_request() end |
#list_discovered_endpoints(params = {}) ⇒ Types::ListDiscoveredEndpointsOutput
Returns a paginated list of endpoints discovered during a pentest job execution.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1980 1981 1982 1983 |
# File 'lib/aws-sdk-securityagent/client.rb', line 1980 def list_discovered_endpoints(params = {}, = {}) req = build_request(:list_discovered_endpoints, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsOutput
Lists the security findings for a pentest job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2058 2059 2060 2061 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2058 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_integrated_resources(params = {}) ⇒ Types::ListIntegratedResourcesOutput
Lists the integrated resources for an agent space, optionally filtered by integration or resource type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2118 2119 2120 2121 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2118 def list_integrated_resources(params = {}, = {}) req = build_request(:list_integrated_resources, params) req.send_request() end |
#list_integrations(params = {}) ⇒ Types::ListIntegrationsOutput
Lists the integrations in your account, optionally filtered by provider or provider type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2170 2171 2172 2173 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2170 def list_integrations(params = {}, = {}) req = build_request(:list_integrations, params) req.send_request() end |
#list_memberships(params = {}) ⇒ Types::ListMembershipsResponse
Returns a paginated list of membership summaries for the specified agent space within an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2234 2235 2236 2237 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2234 def list_memberships(params = {}, = {}) req = build_request(:list_memberships, params) req.send_request() end |
#list_pentest_job_tasks(params = {}) ⇒ Types::ListPentestJobTasksOutput
Returns a paginated list of task summaries for the specified pentest job, optionally filtered by step name or category.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2300 2301 2302 2303 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2300 def list_pentest_job_tasks(params = {}, = {}) req = build_request(:list_pentest_job_tasks, params) req.send_request() end |
#list_pentest_jobs_for_pentest(params = {}) ⇒ Types::ListPentestJobsForPentestOutput
Returns a paginated list of pentest job summaries for the specified pentest configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2354 2355 2356 2357 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2354 def list_pentest_jobs_for_pentest(params = {}, = {}) req = build_request(:list_pentest_jobs_for_pentest, params) req.send_request() end |
#list_pentests(params = {}) ⇒ Types::ListPentestsOutput
Returns a paginated list of pentest summaries for the specified agent space.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2403 2404 2405 2406 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2403 def list_pentests(params = {}, = {}) req = build_request(:list_pentests, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns the tags associated with the specified resource.
2432 2433 2434 2435 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2432 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_target_domains(params = {}) ⇒ Types::ListTargetDomainsOutput
Returns a paginated list of target domain summaries in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2474 2475 2476 2477 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2474 def list_target_domains(params = {}, = {}) req = build_request(:list_target_domains, params) req.send_request() end |
#start_code_remediation(params = {}) ⇒ Struct
Initiates code remediation for one or more security findings. This creates pull requests in integrated repositories to fix the identified vulnerabilities.
2506 2507 2508 2509 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2506 def start_code_remediation(params = {}, = {}) req = build_request(:start_code_remediation, params) req.send_request() end |
#start_pentest_job(params = {}) ⇒ Types::StartPentestJobOutput
Starts a new pentest job for a pentest configuration. The job executes the security tests defined in the pentest.
2551 2552 2553 2554 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2551 def start_pentest_job(params = {}, = {}) req = build_request(:start_pentest_job, params) req.send_request() end |
#stop_pentest_job(params = {}) ⇒ Struct
Stops a running pentest job. The job transitions to a stopping state and then to stopped after cleanup completes.
2578 2579 2580 2581 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2578 def stop_pentest_job(params = {}, = {}) req = build_request(:stop_pentest_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
2606 2607 2608 2609 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2606 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
2632 2633 2634 2635 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2632 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_agent_space(params = {}) ⇒ Types::UpdateAgentSpaceOutput
Updates the configuration of an existing agent space, including its name, description, AWS resources, target domains, and code review settings.
2730 2731 2732 2733 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2730 def update_agent_space(params = {}, = {}) req = build_request(:update_agent_space, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::UpdateApplicationResponse
Updates the configuration of an existing application, including the IAM role and default KMS key.
2768 2769 2770 2771 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2768 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_finding(params = {}) ⇒ Struct
Updates the status or risk level of a security finding.
2802 2803 2804 2805 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2802 def update_finding(params = {}, = {}) req = build_request(:update_finding, params) req.send_request() end |
#update_integrated_resources(params = {}) ⇒ Struct
Updates the integrated resources for an agent space, including their capabilities.
2848 2849 2850 2851 |
# File 'lib/aws-sdk-securityagent/client.rb', line 2848 def update_integrated_resources(params = {}, = {}) req = build_request(:update_integrated_resources, params) req.send_request() end |
#update_pentest(params = {}) ⇒ Types::UpdatePentestOutput
Updates an existing pentest configuration.
3001 3002 3003 3004 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3001 def update_pentest(params = {}, = {}) req = build_request(:update_pentest, params) req.send_request() end |
#update_target_domain(params = {}) ⇒ Types::UpdateTargetDomainOutput
Updates the verification method for a target domain.
3050 3051 3052 3053 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3050 def update_target_domain(params = {}, = {}) req = build_request(:update_target_domain, params) req.send_request() end |
#verify_target_domain(params = {}) ⇒ Types::VerifyTargetDomainOutput
Initiates verification of a target domain. This checks whether the domain ownership verification token has been properly configured.
3091 3092 3093 3094 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3091 def verify_target_domain(params = {}, = {}) req = build_request(:verify_target_domain, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3120 3121 3122 |
# File 'lib/aws-sdk-securityagent/client.rb', line 3120 def waiter_names [] end |