Class: Aws::SecurityAgent::Types::AWSResources
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::AWSResources
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
The AWS resources associated with an agent space, including VPCs, log groups, S3 buckets, secrets, Lambda functions, and IAM roles.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#iam_roles ⇒ Array<String>
The IAM roles associated with the agent space.
-
#lambda_function_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Lambda functions associated with the agent space.
-
#log_groups ⇒ Array<String>
The Amazon Resource Names (ARNs) of the CloudWatch log groups associated with the agent space.
-
#s3_buckets ⇒ Array<String>
The Amazon Resource Names (ARNs) of the S3 buckets associated with the agent space.
-
#secret_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Secrets Manager secrets associated with the agent space.
-
#vpcs ⇒ Array<Types::VpcConfig>
The VPC configurations associated with the agent space.
Instance Attribute Details
#iam_roles ⇒ Array<String>
The IAM roles associated with the agent space.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/aws-sdk-securityagent/types.rb', line 46 class AWSResources < Struct.new( :vpcs, :log_groups, :s3_buckets, :secret_arns, :lambda_function_arns, :iam_roles) SENSITIVE = [] include Aws::Structure end |
#lambda_function_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Lambda functions associated with the agent space.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/aws-sdk-securityagent/types.rb', line 46 class AWSResources < Struct.new( :vpcs, :log_groups, :s3_buckets, :secret_arns, :lambda_function_arns, :iam_roles) SENSITIVE = [] include Aws::Structure end |
#log_groups ⇒ Array<String>
The Amazon Resource Names (ARNs) of the CloudWatch log groups associated with the agent space.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/aws-sdk-securityagent/types.rb', line 46 class AWSResources < Struct.new( :vpcs, :log_groups, :s3_buckets, :secret_arns, :lambda_function_arns, :iam_roles) SENSITIVE = [] include Aws::Structure end |
#s3_buckets ⇒ Array<String>
The Amazon Resource Names (ARNs) of the S3 buckets associated with the agent space.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/aws-sdk-securityagent/types.rb', line 46 class AWSResources < Struct.new( :vpcs, :log_groups, :s3_buckets, :secret_arns, :lambda_function_arns, :iam_roles) SENSITIVE = [] include Aws::Structure end |
#secret_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the Secrets Manager secrets associated with the agent space.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/aws-sdk-securityagent/types.rb', line 46 class AWSResources < Struct.new( :vpcs, :log_groups, :s3_buckets, :secret_arns, :lambda_function_arns, :iam_roles) SENSITIVE = [] include Aws::Structure end |
#vpcs ⇒ Array<Types::VpcConfig>
The VPC configurations associated with the agent space.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/aws-sdk-securityagent/types.rb', line 46 class AWSResources < Struct.new( :vpcs, :log_groups, :s3_buckets, :secret_arns, :lambda_function_arns, :iam_roles) SENSITIVE = [] include Aws::Structure end |