Class: Aws::SecurityAgent::Types::Actor
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::Actor
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents an actor used during penetration testing. An actor defines a user or entity that interacts with the target application, including authentication credentials and target URIs.
Constant Summary collapse
- SENSITIVE =
[:mfa_forwarding_address]
Instance Attribute Summary collapse
-
#authentication ⇒ Types::Authentication
The authentication configuration for the actor.
-
#description ⇒ String
A description of the actor.
-
#enable_email_mfa ⇒ Boolean
Whether email-based MFA is enabled for this actor.
-
#identifier ⇒ String
The unique identifier for the actor.
-
#mfa_forwarding_address ⇒ String
Server-generated email forwarding address for receiving MFA codes.
-
#uris ⇒ Array<String>
The list of URIs that the actor targets during testing.
Instance Attribute Details
#authentication ⇒ Types::Authentication
The authentication configuration for the actor.
101 102 103 104 105 106 107 108 109 110 |
# File 'lib/aws-sdk-securityagent/types.rb', line 101 class Actor < Struct.new( :identifier, :uris, :authentication, :description, :enable_email_mfa, :mfa_forwarding_address) SENSITIVE = [:mfa_forwarding_address] include Aws::Structure end |
#description ⇒ String
A description of the actor.
101 102 103 104 105 106 107 108 109 110 |
# File 'lib/aws-sdk-securityagent/types.rb', line 101 class Actor < Struct.new( :identifier, :uris, :authentication, :description, :enable_email_mfa, :mfa_forwarding_address) SENSITIVE = [:mfa_forwarding_address] include Aws::Structure end |
#enable_email_mfa ⇒ Boolean
Whether email-based MFA is enabled for this actor.
101 102 103 104 105 106 107 108 109 110 |
# File 'lib/aws-sdk-securityagent/types.rb', line 101 class Actor < Struct.new( :identifier, :uris, :authentication, :description, :enable_email_mfa, :mfa_forwarding_address) SENSITIVE = [:mfa_forwarding_address] include Aws::Structure end |
#identifier ⇒ String
The unique identifier for the actor.
101 102 103 104 105 106 107 108 109 110 |
# File 'lib/aws-sdk-securityagent/types.rb', line 101 class Actor < Struct.new( :identifier, :uris, :authentication, :description, :enable_email_mfa, :mfa_forwarding_address) SENSITIVE = [:mfa_forwarding_address] include Aws::Structure end |
#mfa_forwarding_address ⇒ String
Server-generated email forwarding address for receiving MFA codes.
101 102 103 104 105 106 107 108 109 110 |
# File 'lib/aws-sdk-securityagent/types.rb', line 101 class Actor < Struct.new( :identifier, :uris, :authentication, :description, :enable_email_mfa, :mfa_forwarding_address) SENSITIVE = [:mfa_forwarding_address] include Aws::Structure end |
#uris ⇒ Array<String>
The list of URIs that the actor targets during testing.
101 102 103 104 105 106 107 108 109 110 |
# File 'lib/aws-sdk-securityagent/types.rb', line 101 class Actor < Struct.new( :identifier, :uris, :authentication, :description, :enable_email_mfa, :mfa_forwarding_address) SENSITIVE = [:mfa_forwarding_address] include Aws::Structure end |