Class: Aws::SecurityAgent::Types::Actor

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents an actor used during penetration testing. An actor defines a user or entity that interacts with the target application, including authentication credentials and target URIs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authenticationTypes::Authentication

The authentication configuration for the actor.



93
94
95
96
97
98
99
100
# File 'lib/aws-sdk-securityagent/types.rb', line 93

class Actor < Struct.new(
  :identifier,
  :uris,
  :authentication,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the actor.

Returns:

  • (String)


93
94
95
96
97
98
99
100
# File 'lib/aws-sdk-securityagent/types.rb', line 93

class Actor < Struct.new(
  :identifier,
  :uris,
  :authentication,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier for the actor.

Returns:

  • (String)


93
94
95
96
97
98
99
100
# File 'lib/aws-sdk-securityagent/types.rb', line 93

class Actor < Struct.new(
  :identifier,
  :uris,
  :authentication,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#urisArray<String>

The list of URIs that the actor targets during testing.

Returns:

  • (Array<String>)


93
94
95
96
97
98
99
100
# File 'lib/aws-sdk-securityagent/types.rb', line 93

class Actor < Struct.new(
  :identifier,
  :uris,
  :authentication,
  :description)
  SENSITIVE = []
  include Aws::Structure
end