Class: Aws::SecurityAgent::Types::Actor
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::Actor
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents an actor used during penetration testing. An actor defines a user or entity that interacts with the target application, including authentication credentials and target URIs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication ⇒ Types::Authentication
The authentication configuration for the actor.
-
#description ⇒ String
A description of the actor.
-
#identifier ⇒ String
The unique identifier for the actor.
-
#uris ⇒ Array<String>
The list of URIs that the actor targets during testing.
Instance Attribute Details
#authentication ⇒ Types::Authentication
The authentication configuration for the actor.
93 94 95 96 97 98 99 100 |
# File 'lib/aws-sdk-securityagent/types.rb', line 93 class Actor < Struct.new( :identifier, :uris, :authentication, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the actor.
93 94 95 96 97 98 99 100 |
# File 'lib/aws-sdk-securityagent/types.rb', line 93 class Actor < Struct.new( :identifier, :uris, :authentication, :description) SENSITIVE = [] include Aws::Structure end |