Class: Aws::SecurityAgent::Types::AddArtifactInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::AddArtifactInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to add the artifact to.
-
#artifact_content ⇒ String
The binary content of the artifact to upload.
-
#artifact_type ⇒ String
The file type of the artifact.
-
#file_name ⇒ String
The file name of the artifact.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to add the artifact to.
121 122 123 124 125 126 127 128 |
# File 'lib/aws-sdk-securityagent/types.rb', line 121 class AddArtifactInput < Struct.new( :agent_space_id, :artifact_content, :artifact_type, :file_name) SENSITIVE = [] include Aws::Structure end |
#artifact_content ⇒ String
The binary content of the artifact to upload.
121 122 123 124 125 126 127 128 |
# File 'lib/aws-sdk-securityagent/types.rb', line 121 class AddArtifactInput < Struct.new( :agent_space_id, :artifact_content, :artifact_type, :file_name) SENSITIVE = [] include Aws::Structure end |
#artifact_type ⇒ String
The file type of the artifact. Valid values include TXT, PNG, JPEG, MD, PDF, DOCX, DOC, JSON, and YAML.
121 122 123 124 125 126 127 128 |
# File 'lib/aws-sdk-securityagent/types.rb', line 121 class AddArtifactInput < Struct.new( :agent_space_id, :artifact_content, :artifact_type, :file_name) SENSITIVE = [] include Aws::Structure end |
#file_name ⇒ String
The file name of the artifact.
121 122 123 124 125 126 127 128 |
# File 'lib/aws-sdk-securityagent/types.rb', line 121 class AddArtifactInput < Struct.new( :agent_space_id, :artifact_content, :artifact_type, :file_name) SENSITIVE = [] include Aws::Structure end |