Class: Aws::SecurityAgent::Types::AgentSpaceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::AgentSpaceSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains summary information about an agent space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#created_at ⇒ Time
The date and time the agent space was created, in UTC format.
-
#name ⇒ String
The name of the agent space.
-
#updated_at ⇒ Time
The date and time the agent space was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-securityagent/types.rb', line 220 class AgentSpaceSummary < Struct.new( :agent_space_id, :name, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the agent space was created, in UTC format.
220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-securityagent/types.rb', line 220 class AgentSpaceSummary < Struct.new( :agent_space_id, :name, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the agent space.
220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-securityagent/types.rb', line 220 class AgentSpaceSummary < Struct.new( :agent_space_id, :name, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the agent space was last updated, in UTC format.
220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-securityagent/types.rb', line 220 class AgentSpaceSummary < Struct.new( :agent_space_id, :name, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |