Class: Aws::SecurityAgent::Types::ApplicationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ApplicationSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains summary information about an application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The unique identifier of the application.
-
#application_name ⇒ String
The name of the application.
-
#default_kms_key_id ⇒ String
The identifier of the default AWS KMS key used to encrypt data for the application.
-
#domain ⇒ String
The domain associated with the application.
Instance Attribute Details
#application_id ⇒ String
The unique identifier of the application.
250 251 252 253 254 255 256 257 |
# File 'lib/aws-sdk-securityagent/types.rb', line 250 class ApplicationSummary < Struct.new( :application_id, :application_name, :domain, :default_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#application_name ⇒ String
The name of the application.
250 251 252 253 254 255 256 257 |
# File 'lib/aws-sdk-securityagent/types.rb', line 250 class ApplicationSummary < Struct.new( :application_id, :application_name, :domain, :default_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#default_kms_key_id ⇒ String
The identifier of the default AWS KMS key used to encrypt data for the application.
250 251 252 253 254 255 256 257 |
# File 'lib/aws-sdk-securityagent/types.rb', line 250 class ApplicationSummary < Struct.new( :application_id, :application_name, :domain, :default_kms_key_id) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The domain associated with the application.
250 251 252 253 254 255 256 257 |
# File 'lib/aws-sdk-securityagent/types.rb', line 250 class ApplicationSummary < Struct.new( :application_id, :application_name, :domain, :default_kms_key_id) SENSITIVE = [] include Aws::Structure end |