Class: Aws::SecurityAgent::Types::ArtifactMetadataItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ArtifactMetadataItem
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains metadata about an artifact.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the artifact.
-
#artifact_id ⇒ String
The unique identifier of the artifact.
-
#file_name ⇒ String
The file name of the artifact.
-
#updated_at ⇒ Time
The date and time the artifact was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the artifact.
299 300 301 302 303 304 305 306 |
# File 'lib/aws-sdk-securityagent/types.rb', line 299 class ArtifactMetadataItem < Struct.new( :agent_space_id, :artifact_id, :file_name, :updated_at) SENSITIVE = [] include Aws::Structure end |
#artifact_id ⇒ String
The unique identifier of the artifact.
299 300 301 302 303 304 305 306 |
# File 'lib/aws-sdk-securityagent/types.rb', line 299 class ArtifactMetadataItem < Struct.new( :agent_space_id, :artifact_id, :file_name, :updated_at) SENSITIVE = [] include Aws::Structure end |
#file_name ⇒ String
The file name of the artifact.
299 300 301 302 303 304 305 306 |
# File 'lib/aws-sdk-securityagent/types.rb', line 299 class ArtifactMetadataItem < Struct.new( :agent_space_id, :artifact_id, :file_name, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the artifact was last updated, in UTC format.
299 300 301 302 303 304 305 306 |
# File 'lib/aws-sdk-securityagent/types.rb', line 299 class ArtifactMetadataItem < Struct.new( :agent_space_id, :artifact_id, :file_name, :updated_at) SENSITIVE = [] include Aws::Structure end |