Class: Aws::SecurityAgent::Types::BatchDeleteCodeReviewsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchDeleteCodeReviewsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchDeleteCodeReviews operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deleted ⇒ Array<String>
The list of identifiers of the code reviews that were successfully deleted.
-
#failed ⇒ Array<Types::DeleteCodeReviewFailure>
The list of code reviews that failed to delete, including the reason for each failure.
Instance Attribute Details
#deleted ⇒ Array<String>
The list of identifiers of the code reviews that were successfully deleted.
524 525 526 527 528 529 |
# File 'lib/aws-sdk-securityagent/types.rb', line 524 class BatchDeleteCodeReviewsOutput < Struct.new( :deleted, :failed) SENSITIVE = [] include Aws::Structure end |
#failed ⇒ Array<Types::DeleteCodeReviewFailure>
The list of code reviews that failed to delete, including the reason for each failure.
524 525 526 527 528 529 |
# File 'lib/aws-sdk-securityagent/types.rb', line 524 class BatchDeleteCodeReviewsOutput < Struct.new( :deleted, :failed) SENSITIVE = [] include Aws::Structure end |