Class: Aws::SecurityAgent::Types::BatchDeleteThreatModelsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchDeleteThreatModelsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for deleting multiple threat models.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the threat models to delete.
-
#threat_model_ids ⇒ Array<String>
The list of threat model identifiers to delete.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the threat models to delete.
611 612 613 614 615 616 |
# File 'lib/aws-sdk-securityagent/types.rb', line 611 class BatchDeleteThreatModelsInput < Struct.new( :threat_model_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#threat_model_ids ⇒ Array<String>
The list of threat model identifiers to delete.
611 612 613 614 615 616 |
# File 'lib/aws-sdk-securityagent/types.rb', line 611 class BatchDeleteThreatModelsInput < Struct.new( :threat_model_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |