Class: Aws::SecurityAgent::Types::BatchDeleteThreatModelsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchDeleteThreatModelsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchDeleteThreatModels operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deleted ⇒ Array<String>
The list of threat model identifiers that were successfully deleted.
-
#failed ⇒ Array<Types::DeleteThreatModelFailure>
The list of threat models that failed to delete, including the reason for each failure.
Instance Attribute Details
#deleted ⇒ Array<String>
The list of threat model identifiers that were successfully deleted.
631 632 633 634 635 636 |
# File 'lib/aws-sdk-securityagent/types.rb', line 631 class BatchDeleteThreatModelsOutput < Struct.new( :deleted, :failed) SENSITIVE = [] include Aws::Structure end |
#failed ⇒ Array<Types::DeleteThreatModelFailure>
The list of threat models that failed to delete, including the reason for each failure.
631 632 633 634 635 636 |
# File 'lib/aws-sdk-securityagent/types.rb', line 631 class BatchDeleteThreatModelsOutput < Struct.new( :deleted, :failed) SENSITIVE = [] include Aws::Structure end |