Class: Aws::SecurityAgent::Types::BatchGetArtifactMetadataInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetArtifactMetadataInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the artifacts.
-
#artifact_ids ⇒ Array<String>
The list of artifact identifiers to retrieve metadata for.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the artifacts.
474 475 476 477 478 479 |
# File 'lib/aws-sdk-securityagent/types.rb', line 474 class BatchGetArtifactMetadataInput < Struct.new( :agent_space_id, :artifact_ids) SENSITIVE = [] include Aws::Structure end |
#artifact_ids ⇒ Array<String>
The list of artifact identifiers to retrieve metadata for.
474 475 476 477 478 479 |
# File 'lib/aws-sdk-securityagent/types.rb', line 474 class BatchGetArtifactMetadataInput < Struct.new( :agent_space_id, :artifact_ids) SENSITIVE = [] include Aws::Structure end |