Class: Aws::SecurityAgent::Types::BatchGetPentestJobTasksInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetPentestJobTasksInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for retrieving multiple tasks associated with a pentest job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the tasks.
-
#task_ids ⇒ Array<String>
The list of task identifiers to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the tasks.
543 544 545 546 547 548 |
# File 'lib/aws-sdk-securityagent/types.rb', line 543 class BatchGetPentestJobTasksInput < Struct.new( :agent_space_id, :task_ids) SENSITIVE = [] include Aws::Structure end |
#task_ids ⇒ Array<String>
The list of task identifiers to retrieve.
543 544 545 546 547 548 |
# File 'lib/aws-sdk-securityagent/types.rb', line 543 class BatchGetPentestJobTasksInput < Struct.new( :agent_space_id, :task_ids) SENSITIVE = [] include Aws::Structure end |