Class: Aws::SecurityAgent::Types::BatchGetThreatModelJobTasksOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the BatchGetThreatModelJobTasks operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#not_foundArray<String>

The list of task identifiers that were not found.

Returns:

  • (Array<String>)


1125
1126
1127
1128
1129
1130
# File 'lib/aws-sdk-securityagent/types.rb', line 1125

class BatchGetThreatModelJobTasksOutput < Struct.new(
  :threat_model_job_tasks,
  :not_found)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_job_tasksArray<Types::ThreatModelJobTask>

The list of threat model job tasks that were found.

Returns:



1125
1126
1127
1128
1129
1130
# File 'lib/aws-sdk-securityagent/types.rb', line 1125

class BatchGetThreatModelJobTasksOutput < Struct.new(
  :threat_model_job_tasks,
  :not_found)
  SENSITIVE = []
  include Aws::Structure
end