Class: Aws::SecurityAgent::Types::BatchGetThreatModelJobTasksOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetThreatModelJobTasksOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchGetThreatModelJobTasks operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#not_found ⇒ Array<String>
The list of task identifiers that were not found.
-
#threat_model_job_tasks ⇒ Array<Types::ThreatModelJobTask>
The list of threat model job tasks that were found.
Instance Attribute Details
#not_found ⇒ Array<String>
The list of task identifiers that were not found.
1125 1126 1127 1128 1129 1130 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1125 class BatchGetThreatModelJobTasksOutput < Struct.new( :threat_model_job_tasks, :not_found) SENSITIVE = [] include Aws::Structure end |
#threat_model_job_tasks ⇒ Array<Types::ThreatModelJobTask>
The list of threat model job tasks that were found.
1125 1126 1127 1128 1129 1130 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1125 class BatchGetThreatModelJobTasksOutput < Struct.new( :threat_model_job_tasks, :not_found) SENSITIVE = [] include Aws::Structure end |