Class: Aws::SecurityAgent::Types::BatchGetThreatModelJobsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetThreatModelJobsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for BatchGetThreatModelJobs operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the threat model jobs.
-
#threat_model_job_ids ⇒ Array<String>
The list of threat model job identifiers to retrieve.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the threat model jobs.
1145 1146 1147 1148 1149 1150 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1145 class BatchGetThreatModelJobsInput < Struct.new( :threat_model_job_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#threat_model_job_ids ⇒ Array<String>
The list of threat model job identifiers to retrieve.
1145 1146 1147 1148 1149 1150 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1145 class BatchGetThreatModelJobsInput < Struct.new( :threat_model_job_ids, :agent_space_id) SENSITIVE = [] include Aws::Structure end |