Class: Aws::SecurityAgent::Types::BatchGetThreatModelJobsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchGetThreatModelJobsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the BatchGetThreatModelJobs operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#not_found ⇒ Array<String>
The list of threat model job identifiers that were not found.
-
#threat_model_jobs ⇒ Array<Types::ThreatModelJob>
The list of threat model jobs that were found.
Instance Attribute Details
#not_found ⇒ Array<String>
The list of threat model job identifiers that were not found.
1164 1165 1166 1167 1168 1169 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1164 class BatchGetThreatModelJobsOutput < Struct.new( :threat_model_jobs, :not_found) SENSITIVE = [] include Aws::Structure end |
#threat_model_jobs ⇒ Array<Types::ThreatModelJob>
The list of threat model jobs that were found.
1164 1165 1166 1167 1168 1169 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1164 class BatchGetThreatModelJobsOutput < Struct.new( :threat_model_jobs, :not_found) SENSITIVE = [] include Aws::Structure end |