Class: Aws::SecurityAgent::Types::BatchSecurityRequirementError

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains information about an error that occurred for a specific security requirement during a batch operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:

  • (String)


1265
1266
1267
1268
1269
1270
1271
# File 'lib/aws-sdk-securityagent/types.rb', line 1265

class BatchSecurityRequirementError < Struct.new(
  :security_requirement_name,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message.

Returns:

  • (String)


1265
1266
1267
1268
1269
1270
1271
# File 'lib/aws-sdk-securityagent/types.rb', line 1265

class BatchSecurityRequirementError < Struct.new(
  :security_requirement_name,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#security_requirement_nameString

The name of the security requirement that caused the error.

Returns:

  • (String)


1265
1266
1267
1268
1269
1270
1271
# File 'lib/aws-sdk-securityagent/types.rb', line 1265

class BatchSecurityRequirementError < Struct.new(
  :security_requirement_name,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end