Class: Aws::SecurityAgent::Types::BatchSecurityRequirementError
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BatchSecurityRequirementError
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains information about an error that occurred for a specific security requirement during a batch operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#message ⇒ String
The error message.
-
#security_requirement_name ⇒ String
The name of the security requirement that caused the error.
Instance Attribute Details
#code ⇒ String
The error code.
1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1265 class BatchSecurityRequirementError < Struct.new( :security_requirement_name, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message.
1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1265 class BatchSecurityRequirementError < Struct.new( :security_requirement_name, :code, :message) SENSITIVE = [] include Aws::Structure end |
#security_requirement_name ⇒ String
The name of the security requirement that caused the error.
1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1265 class BatchSecurityRequirementError < Struct.new( :security_requirement_name, :code, :message) SENSITIVE = [] include Aws::Structure end |