Class: Aws::SecurityAgent::Types::BitbucketIntegrationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::BitbucketIntegrationInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
The configuration for creating a Bitbucket integration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The OAuth 2.0 authorization code returned from the consent redirect.
-
#installation_id ⇒ String
The Atlassian installation identifier, available from the Atlassian administration console.
-
#state ⇒ String
The CSRF state token echoed back from the OAuth redirect.
-
#workspace ⇒ String
The Bitbucket workspace slug that identifies the workspace to integrate, for example acme-corp.
Instance Attribute Details
#code ⇒ String
The OAuth 2.0 authorization code returned from the consent redirect.
1332 1333 1334 1335 1336 1337 1338 1339 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1332 class BitbucketIntegrationInput < Struct.new( :installation_id, :workspace, :code, :state) SENSITIVE = [] include Aws::Structure end |
#installation_id ⇒ String
The Atlassian installation identifier, available from the Atlassian administration console.
1332 1333 1334 1335 1336 1337 1338 1339 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1332 class BitbucketIntegrationInput < Struct.new( :installation_id, :workspace, :code, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The CSRF state token echoed back from the OAuth redirect.
1332 1333 1334 1335 1336 1337 1338 1339 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1332 class BitbucketIntegrationInput < Struct.new( :installation_id, :workspace, :code, :state) SENSITIVE = [] include Aws::Structure end |
#workspace ⇒ String
The Bitbucket workspace slug that identifies the workspace to integrate, for example acme-corp.
1332 1333 1334 1335 1336 1337 1338 1339 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1332 class BitbucketIntegrationInput < Struct.new( :installation_id, :workspace, :code, :state) SENSITIVE = [] include Aws::Structure end |