Class: Aws::SecurityAgent::Types::CodeLocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CodeLocation
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a location in source code associated with a security finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_path ⇒ String
The absolute path to the file containing the code location.
-
#label ⇒ String
The role of this location in the vulnerability, such as source or sink.
-
#line_end ⇒ Integer
The ending line number of the code location.
-
#line_start ⇒ Integer
The starting line number of the code location.
Instance Attribute Details
#file_path ⇒ String
The absolute path to the file containing the code location.
896 897 898 899 900 901 902 903 |
# File 'lib/aws-sdk-securityagent/types.rb', line 896 class CodeLocation < Struct.new( :file_path, :line_start, :line_end, :label) SENSITIVE = [] include Aws::Structure end |
#label ⇒ String
The role of this location in the vulnerability, such as source or sink.
896 897 898 899 900 901 902 903 |
# File 'lib/aws-sdk-securityagent/types.rb', line 896 class CodeLocation < Struct.new( :file_path, :line_start, :line_end, :label) SENSITIVE = [] include Aws::Structure end |
#line_end ⇒ Integer
The ending line number of the code location.
896 897 898 899 900 901 902 903 |
# File 'lib/aws-sdk-securityagent/types.rb', line 896 class CodeLocation < Struct.new( :file_path, :line_start, :line_end, :label) SENSITIVE = [] include Aws::Structure end |
#line_start ⇒ Integer
The starting line number of the code location.
896 897 898 899 900 901 902 903 |
# File 'lib/aws-sdk-securityagent/types.rb', line 896 class CodeLocation < Struct.new( :file_path, :line_start, :line_end, :label) SENSITIVE = [] include Aws::Structure end |