Class: Aws::SecurityAgent::Types::CodeReview

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a code review configuration that defines the parameters for automated security-focused code analysis, including target assets and logging configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the code review.

Returns:

  • (String)


1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-securityagent/types.rb', line 1577

class CodeReview < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets included in the code review.

Returns:



1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-securityagent/types.rb', line 1577

class CodeReview < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The code remediation strategy for the code review.

Returns:

  • (String)


1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-securityagent/types.rb', line 1577

class CodeReview < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_idString

The unique identifier of the code review.

Returns:

  • (String)


1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-securityagent/types.rb', line 1577

class CodeReview < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the code review was created, in UTC format.

Returns:

  • (Time)


1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-securityagent/types.rb', line 1577

class CodeReview < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the code review.



1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-securityagent/types.rb', line 1577

class CodeReview < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the code review.

Returns:

  • (String)


1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-securityagent/types.rb', line 1577

class CodeReview < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the code review.

Returns:

  • (String)


1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-securityagent/types.rb', line 1577

class CodeReview < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the code review was last updated, in UTC format.

Returns:

  • (Time)


1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-securityagent/types.rb', line 1577

class CodeReview < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#validation_modeString

The validation mode for the code review. Valid values are SIMULATED and DISABLED.

Returns:

  • (String)


1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
# File 'lib/aws-sdk-securityagent/types.rb', line 1577

class CodeReview < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end