Class: Aws::SecurityAgent::Types::CodeReviewJob
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CodeReviewJob
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a code review job, which is an execution instance of a code review. A code review job progresses through preflight, static analysis, and finalizing steps.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_remediation_strategy ⇒ String
The code remediation strategy for the code review job.
-
#code_review_id ⇒ String
The unique identifier of the code review associated with the job.
-
#code_review_job_id ⇒ String
The unique identifier of the code review job.
-
#created_at ⇒ Time
The date and time the code review job was created, in UTC format.
-
#documents ⇒ Array<Types::DocumentInfo>
The list of documents providing context for the code review job.
-
#error_information ⇒ Types::ErrorInformation
Error information if the code review job encountered an error.
-
#execution_context ⇒ Array<Types::ExecutionContext>
The execution context messages for the code review job.
-
#integrated_repositories ⇒ Array<Types::IntegratedRepository>
The list of integrated repositories associated with the code review job.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the code review job.
-
#overview ⇒ String
An overview of the code review job results.
-
#service_role ⇒ String
The IAM service role used for the code review job.
-
#source_code ⇒ Array<Types::SourceCodeRepository>
The list of source code repositories analyzed during the code review job.
-
#status ⇒ String
The current status of the code review job.
-
#steps ⇒ Array<Types::Step>
The list of steps in the code review job execution.
-
#title ⇒ String
The title of the code review job.
-
#updated_at ⇒ Time
The date and time the code review job was last updated, in UTC format.
Instance Attribute Details
#code_remediation_strategy ⇒ String
The code remediation strategy for the code review job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_id ⇒ String
The unique identifier of the code review associated with the job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_job_id ⇒ String
The unique identifier of the code review job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the code review job was created, in UTC format.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#documents ⇒ Array<Types::DocumentInfo>
The list of documents providing context for the code review job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#error_information ⇒ Types::ErrorInformation
Error information if the code review job encountered an error.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#execution_context ⇒ Array<Types::ExecutionContext>
The execution context messages for the code review job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#integrated_repositories ⇒ Array<Types::IntegratedRepository>
The list of integrated repositories associated with the code review job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the code review job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#overview ⇒ String
An overview of the code review job results.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role used for the code review job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#source_code ⇒ Array<Types::SourceCodeRepository>
The list of source code repositories analyzed during the code review job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the code review job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#steps ⇒ Array<Types::Step>
The list of steps in the code review job execution.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the code review job.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the code review job was last updated, in UTC format.
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1086 class CodeReviewJob < Struct.new( :code_review_job_id, :code_review_id, :title, :overview, :status, :documents, :source_code, :steps, :execution_context, :service_role, :log_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |