Class: Aws::SecurityAgent::Types::CodeReviewJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a code review job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_review_idString

The unique identifier of the code review associated with the job.

Returns:

  • (String)


1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/aws-sdk-securityagent/types.rb', line 1136

class CodeReviewJobSummary < Struct.new(
  :code_review_job_id,
  :code_review_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_job_idString

The unique identifier of the code review job.

Returns:

  • (String)


1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/aws-sdk-securityagent/types.rb', line 1136

class CodeReviewJobSummary < Struct.new(
  :code_review_job_id,
  :code_review_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the code review job was created, in UTC format.

Returns:

  • (Time)


1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/aws-sdk-securityagent/types.rb', line 1136

class CodeReviewJobSummary < Struct.new(
  :code_review_job_id,
  :code_review_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the code review job.

Returns:

  • (String)


1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/aws-sdk-securityagent/types.rb', line 1136

class CodeReviewJobSummary < Struct.new(
  :code_review_job_id,
  :code_review_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the code review job.

Returns:

  • (String)


1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/aws-sdk-securityagent/types.rb', line 1136

class CodeReviewJobSummary < Struct.new(
  :code_review_job_id,
  :code_review_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the code review job was last updated, in UTC format.

Returns:

  • (Time)


1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/aws-sdk-securityagent/types.rb', line 1136

class CodeReviewJobSummary < Struct.new(
  :code_review_job_id,
  :code_review_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end