Class: Aws::SecurityAgent::Types::CodeReviewJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CodeReviewJobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains summary information about a code review job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_review_id ⇒ String
The unique identifier of the code review associated with the job.
-
#code_review_job_id ⇒ String
The unique identifier of the code review job.
-
#created_at ⇒ Time
The date and time the code review job was created, in UTC format.
-
#status ⇒ String
The current status of the code review job.
-
#title ⇒ String
The title of the code review job.
-
#updated_at ⇒ Time
The date and time the code review job was last updated, in UTC format.
Instance Attribute Details
#code_review_id ⇒ String
The unique identifier of the code review associated with the job.
1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1136 class CodeReviewJobSummary < Struct.new( :code_review_job_id, :code_review_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_job_id ⇒ String
The unique identifier of the code review job.
1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1136 class CodeReviewJobSummary < Struct.new( :code_review_job_id, :code_review_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the code review job was created, in UTC format.
1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1136 class CodeReviewJobSummary < Struct.new( :code_review_job_id, :code_review_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the code review job.
1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1136 class CodeReviewJobSummary < Struct.new( :code_review_job_id, :code_review_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the code review job.
1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1136 class CodeReviewJobSummary < Struct.new( :code_review_job_id, :code_review_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the code review job was last updated, in UTC format.
1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1136 class CodeReviewJobSummary < Struct.new( :code_review_job_id, :code_review_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |