Class: Aws::SecurityAgent::Types::ConflictException
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ConflictException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
The request could not be completed due to a conflict with the current state of the resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Error description.
Instance Attribute Details
#message ⇒ String
Error description.
798 799 800 801 802 |
# File 'lib/aws-sdk-securityagent/types.rb', line 798 class ConflictException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |