Class: Aws::SecurityAgent::Types::CreateAgentSpaceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateAgentSpaceInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for creating a new agent space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_resources ⇒ Types::AWSResources
The AWS resources to associate with the agent space.
-
#code_review_settings ⇒ Types::CodeReviewSettings
The code review settings for the agent space.
-
#description ⇒ String
A description of the agent space.
-
#kms_key_id ⇒ String
The identifier of the AWS KMS key to use for encrypting data in the agent space.
-
#name ⇒ String
The name of the agent space.
-
#tags ⇒ Hash<String,String>
The tags to associate with the agent space.
-
#target_domain_ids ⇒ Array<String>
The list of target domain identifiers to associate with the agent space.
Instance Attribute Details
#aws_resources ⇒ Types::AWSResources
The AWS resources to associate with the agent space.
838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/aws-sdk-securityagent/types.rb', line 838 class CreateAgentSpaceInput < Struct.new( :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#code_review_settings ⇒ Types::CodeReviewSettings
The code review settings for the agent space.
838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/aws-sdk-securityagent/types.rb', line 838 class CreateAgentSpaceInput < Struct.new( :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the agent space.
838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/aws-sdk-securityagent/types.rb', line 838 class CreateAgentSpaceInput < Struct.new( :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier of the AWS KMS key to use for encrypting data in the agent space.
838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/aws-sdk-securityagent/types.rb', line 838 class CreateAgentSpaceInput < Struct.new( :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the agent space.
838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/aws-sdk-securityagent/types.rb', line 838 class CreateAgentSpaceInput < Struct.new( :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to associate with the agent space.
838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/aws-sdk-securityagent/types.rb', line 838 class CreateAgentSpaceInput < Struct.new( :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#target_domain_ids ⇒ Array<String>
The list of target domain identifiers to associate with the agent space.
838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/aws-sdk-securityagent/types.rb', line 838 class CreateAgentSpaceInput < Struct.new( :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |