Class: Aws::SecurityAgent::Types::CreateApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateApplicationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_kms_key_id ⇒ String
The identifier of the default AWS KMS key to use for encrypting data in the application.
-
#idc_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM Identity Center instance to associate with the application.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to associate with the application.
-
#tags ⇒ Hash<String,String>
The tags to associate with the application.
Instance Attribute Details
#default_kms_key_id ⇒ String
The identifier of the default AWS KMS key to use for encrypting data in the application.
927 928 929 930 931 932 933 934 |
# File 'lib/aws-sdk-securityagent/types.rb', line 927 class CreateApplicationRequest < Struct.new( :idc_instance_arn, :role_arn, :default_kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#idc_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM Identity Center instance to associate with the application.
927 928 929 930 931 932 933 934 |
# File 'lib/aws-sdk-securityagent/types.rb', line 927 class CreateApplicationRequest < Struct.new( :idc_instance_arn, :role_arn, :default_kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to associate with the application.
927 928 929 930 931 932 933 934 |
# File 'lib/aws-sdk-securityagent/types.rb', line 927 class CreateApplicationRequest < Struct.new( :idc_instance_arn, :role_arn, :default_kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to associate with the application.
927 928 929 930 931 932 933 934 |
# File 'lib/aws-sdk-securityagent/types.rb', line 927 class CreateApplicationRequest < Struct.new( :idc_instance_arn, :role_arn, :default_kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |