Class: Aws::SecurityAgent::Types::CreateCodeReviewInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateCodeReviewInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for creating a new code review.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to create the code review in.
-
#assets ⇒ Types::Assets
The assets to include in the code review, such as documents and source code.
-
#code_remediation_strategy ⇒ String
The code remediation strategy for the code review.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the code review.
-
#service_role ⇒ String
The IAM service role to use for the code review.
-
#title ⇒ String
The title of the code review.
-
#validation_mode ⇒ String
The validation mode for the code review.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to create the code review in.
2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2229 class CreateCodeReviewInput < Struct.new( :title, :agent_space_id, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets to include in the code review, such as documents and source code.
2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2229 class CreateCodeReviewInput < Struct.new( :title, :agent_space_id, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The code remediation strategy for the code review. Valid values are AUTOMATIC and DISABLED.
2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2229 class CreateCodeReviewInput < Struct.new( :title, :agent_space_id, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the code review.
2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2229 class CreateCodeReviewInput < Struct.new( :title, :agent_space_id, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role to use for the code review.
2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2229 class CreateCodeReviewInput < Struct.new( :title, :agent_space_id, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the code review.
2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2229 class CreateCodeReviewInput < Struct.new( :title, :agent_space_id, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode) SENSITIVE = [] include Aws::Structure end |
#validation_mode ⇒ String
The validation mode for the code review. Valid values are SIMULATED and DISABLED.
2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2229 class CreateCodeReviewInput < Struct.new( :title, :agent_space_id, :assets, :service_role, :log_config, :code_remediation_strategy, :validation_mode) SENSITIVE = [] include Aws::Structure end |