Class: Aws::SecurityAgent::Types::CreateCodeReviewOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the CreateCodeReview operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the code review.

Returns:

  • (String)


2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-securityagent/types.rb', line 2286

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets included in the code review.

Returns:



2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-securityagent/types.rb', line 2286

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The code remediation strategy for the code review.

Returns:

  • (String)


2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-securityagent/types.rb', line 2286

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_idString

The unique identifier of the created code review.

Returns:

  • (String)


2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-securityagent/types.rb', line 2286

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the code review was created, in UTC format.

Returns:

  • (Time)


2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-securityagent/types.rb', line 2286

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the code review.



2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-securityagent/types.rb', line 2286

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the code review.

Returns:

  • (String)


2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-securityagent/types.rb', line 2286

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the code review.

Returns:

  • (String)


2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-securityagent/types.rb', line 2286

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the code review was last updated, in UTC format.

Returns:

  • (Time)


2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-securityagent/types.rb', line 2286

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#validation_modeString

The validation mode for the code review.

Returns:

  • (String)


2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
# File 'lib/aws-sdk-securityagent/types.rb', line 2286

class CreateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end