Class: Aws::SecurityAgent::Types::CreateIntegrationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateIntegrationInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input ⇒ Types::ProviderInput
The provider-specific input required to create the integration.
-
#integration_display_name ⇒ String
The display name for the integration.
-
#kms_key_id ⇒ String
The identifier of the AWS KMS key to use for encrypting data associated with the integration.
-
#provider ⇒ String
The integration provider.
-
#tags ⇒ Hash<String,String>
The tags to associate with the integration.
Instance Attribute Details
#input ⇒ Types::ProviderInput
The provider-specific input required to create the integration.
971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-securityagent/types.rb', line 971 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#integration_display_name ⇒ String
The display name for the integration.
971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-securityagent/types.rb', line 971 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier of the AWS KMS key to use for encrypting data associated with the integration.
971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-securityagent/types.rb', line 971 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The integration provider. Currently, only GITHUB is supported.
971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-securityagent/types.rb', line 971 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to associate with the integration.
971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-securityagent/types.rb', line 971 class CreateIntegrationInput < Struct.new( :provider, :input, :integration_display_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |