Class: Aws::SecurityAgent::Types::CreateMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateMembershipRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Request structure for adding a single member to an agent space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to grant access to.
-
#application_id ⇒ String
The unique identifier of the application that contains the agent space.
-
#config ⇒ Types::MembershipConfig
The configuration for the membership, such as the user role.
-
#member_type ⇒ String
The type of member.
-
#membership_id ⇒ String
The unique identifier for the membership.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to grant access to.
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1018 class CreateMembershipRequest < Struct.new( :application_id, :agent_space_id, :membership_id, :member_type, :config) SENSITIVE = [] include Aws::Structure end |
#application_id ⇒ String
The unique identifier of the application that contains the agent space.
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1018 class CreateMembershipRequest < Struct.new( :application_id, :agent_space_id, :membership_id, :member_type, :config) SENSITIVE = [] include Aws::Structure end |
#config ⇒ Types::MembershipConfig
The configuration for the membership, such as the user role.
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1018 class CreateMembershipRequest < Struct.new( :application_id, :agent_space_id, :membership_id, :member_type, :config) SENSITIVE = [] include Aws::Structure end |
#member_type ⇒ String
The type of member. Currently, only USER is supported.
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1018 class CreateMembershipRequest < Struct.new( :application_id, :agent_space_id, :membership_id, :member_type, :config) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique identifier for the membership.
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1018 class CreateMembershipRequest < Struct.new( :application_id, :agent_space_id, :membership_id, :member_type, :config) SENSITIVE = [] include Aws::Structure end |