Class: Aws::SecurityAgent::Types::CreatePentestInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for creating a new pentest.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space to create the pentest in.

Returns:

  • (String)


1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-securityagent/types.rb', line 1077

class CreatePentestInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets to include in the pentest, such as endpoints, actors, documents, and source code.

Returns:



1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-securityagent/types.rb', line 1077

class CreatePentestInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The code remediation strategy for the pentest. Valid values are AUTOMATIC and DISABLED.

Returns:

  • (String)


1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-securityagent/types.rb', line 1077

class CreatePentestInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_risk_typesArray<String>

The list of risk types to exclude from the pentest.

Returns:

  • (Array<String>)


1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-securityagent/types.rb', line 1077

class CreatePentestInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the pentest.



1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-securityagent/types.rb', line 1077

class CreatePentestInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#network_traffic_configTypes::NetworkTrafficConfig

The network traffic configuration for the pentest, including custom headers and traffic rules.



1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-securityagent/types.rb', line 1077

class CreatePentestInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role to use for the pentest.

Returns:

  • (String)


1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-securityagent/types.rb', line 1077

class CreatePentestInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the pentest.

Returns:

  • (String)


1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-securityagent/types.rb', line 1077

class CreatePentestInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

The VPC configuration for the pentest.

Returns:



1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-securityagent/types.rb', line 1077

class CreatePentestInput < Struct.new(
  :title,
  :agent_space_id,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end