Class: Aws::SecurityAgent::Types::CreatePentestInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreatePentestInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for creating a new pentest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to create the pentest in.
-
#assets ⇒ Types::Assets
The assets to include in the pentest, such as endpoints, actors, documents, and source code.
-
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest.
-
#exclude_risk_types ⇒ Array<String>
The list of risk types to exclude from the pentest.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest.
-
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest, including custom headers and traffic rules.
-
#service_role ⇒ String
The IAM service role to use for the pentest.
-
#title ⇒ String
The title of the pentest.
-
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to create the pentest in.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1077 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets to include in the pentest, such as endpoints, actors, documents, and source code.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1077 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest. Valid values are AUTOMATIC and DISABLED.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1077 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#exclude_risk_types ⇒ Array<String>
The list of risk types to exclude from the pentest.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1077 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1077 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest, including custom headers and traffic rules.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1077 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role to use for the pentest.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1077 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the pentest.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1077 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1077 class CreatePentestInput < Struct.new( :title, :agent_space_id, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |