Class: Aws::SecurityAgent::Types::CreatePrivateConnectionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreatePrivateConnectionInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mode ⇒ Types::PrivateConnectionMode
The configuration for the private connection.
-
#private_connection_name ⇒ String
A unique name for the private connection within your account.
-
#tags ⇒ Hash<String,String>
The tags to attach to the private connection.
Instance Attribute Details
#mode ⇒ Types::PrivateConnectionMode
The configuration for the private connection. Specify either a service-managed or a self-managed mode.
2526 2527 2528 2529 2530 2531 2532 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2526 class CreatePrivateConnectionInput < Struct.new( :private_connection_name, :mode, :tags) SENSITIVE = [] include Aws::Structure end |
#private_connection_name ⇒ String
A unique name for the private connection within your account.
2526 2527 2528 2529 2530 2531 2532 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2526 class CreatePrivateConnectionInput < Struct.new( :private_connection_name, :mode, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to attach to the private connection.
2526 2527 2528 2529 2530 2531 2532 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2526 class CreatePrivateConnectionInput < Struct.new( :private_connection_name, :mode, :tags) SENSITIVE = [] include Aws::Structure end |