Class: Aws::SecurityAgent::Types::CreatePrivateConnectionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreatePrivateConnectionOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_expiry_time ⇒ Time
The date and time the connection’s certificate expires, in UTC format.
-
#dns_resolution ⇒ String
The DNS resolution mode for the resource gateway.
-
#failure_message ⇒ String
A message describing why the private connection entered a failed state, if applicable.
-
#host_address ⇒ String
The IP address or DNS name of the target resource.
-
#name ⇒ String
The name of the private connection.
-
#resource_configuration_id ⇒ String
The identifier or ARN of the VPC Lattice resource configuration.
-
#resource_gateway_id ⇒ String
The identifier or ARN of the VPC Lattice resource gateway.
-
#status ⇒ String
The current status of the private connection.
-
#tags ⇒ Hash<String,String>
The tags attached to the private connection.
-
#type ⇒ String
The type of the private connection, indicating whether it is service-managed or self-managed.
-
#vpc_id ⇒ String
The identifier of the VPC the resource gateway is created in.
Instance Attribute Details
#certificate_expiry_time ⇒ Time
The date and time the connection’s certificate expires, in UTC format.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#dns_resolution ⇒ String
The DNS resolution mode for the resource gateway.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
A message describing why the private connection entered a failed state, if applicable.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#host_address ⇒ String
The IP address or DNS name of the target resource.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the private connection.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_configuration_id ⇒ String
The identifier or ARN of the VPC Lattice resource configuration.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_gateway_id ⇒ String
The identifier or ARN of the VPC Lattice resource gateway.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the private connection.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags attached to the private connection.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the private connection, indicating whether it is service-managed or self-managed.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The identifier of the VPC the resource gateway is created in.
2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2583 class CreatePrivateConnectionOutput < Struct.new( :name, :type, :status, :resource_gateway_id, :host_address, :vpc_id, :resource_configuration_id, :certificate_expiry_time, :dns_resolution, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |