Class: Aws::SecurityAgent::Types::CreateThreatModelInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::CreateThreatModelInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for creating a new threat model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to create the threat model in.
-
#assets ⇒ Types::Assets
The assets to include in the threat model.
-
#description ⇒ String
A description of the application or system being threat modeled.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the threat model.
-
#report_destination ⇒ Types::ReportDestination
The destination for publishing scan reports to an integrated document provider.
-
#scope_docs ⇒ Array<Types::DocumentInfo>
The scoped documents for the agent to focus on during threat modeling.
-
#service_role ⇒ String
The IAM service role to use for the threat model.
-
#title ⇒ String
The title of the threat model.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to create the threat model in.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2887 class CreateThreatModelInput < Struct.new( :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :report_destination) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets to include in the threat model.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2887 class CreateThreatModelInput < Struct.new( :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :report_destination) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the application or system being threat modeled.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2887 class CreateThreatModelInput < Struct.new( :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :report_destination) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the threat model.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2887 class CreateThreatModelInput < Struct.new( :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :report_destination) SENSITIVE = [] include Aws::Structure end |
#report_destination ⇒ Types::ReportDestination
The destination for publishing scan reports to an integrated document provider.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2887 class CreateThreatModelInput < Struct.new( :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :report_destination) SENSITIVE = [] include Aws::Structure end |
#scope_docs ⇒ Array<Types::DocumentInfo>
The scoped documents for the agent to focus on during threat modeling.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2887 class CreateThreatModelInput < Struct.new( :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :report_destination) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role to use for the threat model.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2887 class CreateThreatModelInput < Struct.new( :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :report_destination) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the threat model.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2887 class CreateThreatModelInput < Struct.new( :title, :agent_space_id, :description, :assets, :scope_docs, :service_role, :log_config, :report_destination) SENSITIVE = [] include Aws::Structure end |