Class: Aws::SecurityAgent::Types::DeleteMembershipRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Request structure for removing a single member from an agent space.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space to revoke access from.

Returns:

  • (String)


1987
1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-securityagent/types.rb', line 1987

class DeleteMembershipRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :membership_id,
  :member_type)
  SENSITIVE = []
  include Aws::Structure
end

#application_idString

The unique identifier of the application that contains the agent space.

Returns:

  • (String)


1987
1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-securityagent/types.rb', line 1987

class DeleteMembershipRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :membership_id,
  :member_type)
  SENSITIVE = []
  include Aws::Structure
end

#member_typeString

The type of member to remove.

Returns:

  • (String)


1987
1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-securityagent/types.rb', line 1987

class DeleteMembershipRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :membership_id,
  :member_type)
  SENSITIVE = []
  include Aws::Structure
end

#membership_idString

The unique identifier of the membership to delete.

Returns:

  • (String)


1987
1988
1989
1990
1991
1992
1993
1994
# File 'lib/aws-sdk-securityagent/types.rb', line 1987

class DeleteMembershipRequest < Struct.new(
  :application_id,
  :agent_space_id,
  :membership_id,
  :member_type)
  SENSITIVE = []
  include Aws::Structure
end