Class: Aws::SecurityAgent::Types::DeletePentestFailure

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains information about a pentest that failed to delete.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#pentest_idString

The unique identifier of the pentest that failed to delete.

Returns:

  • (String)


1360
1361
1362
1363
1364
1365
# File 'lib/aws-sdk-securityagent/types.rb', line 1360

class DeletePentestFailure < Struct.new(
  :pentest_id,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The reason the pentest failed to delete.

Returns:

  • (String)


1360
1361
1362
1363
1364
1365
# File 'lib/aws-sdk-securityagent/types.rb', line 1360

class DeletePentestFailure < Struct.new(
  :pentest_id,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end