Class: Aws::SecurityAgent::Types::DeletePentestFailure
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::DeletePentestFailure
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains information about a pentest that failed to delete.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pentest_id ⇒ String
The unique identifier of the pentest that failed to delete.
-
#reason ⇒ String
The reason the pentest failed to delete.
Instance Attribute Details
#pentest_id ⇒ String
The unique identifier of the pentest that failed to delete.
1360 1361 1362 1363 1364 1365 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1360 class DeletePentestFailure < Struct.new( :pentest_id, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason the pentest failed to delete.
1360 1361 1362 1363 1364 1365 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1360 class DeletePentestFailure < Struct.new( :pentest_id, :reason) SENSITIVE = [] include Aws::Structure end |