Class: Aws::SecurityAgent::Types::DeleteThreatModelFailure
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::DeleteThreatModelFailure
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains information about a threat model that failed to delete.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#reason ⇒ String
The reason the threat model failed to delete.
-
#threat_model_id ⇒ String
The unique identifier of the threat model that failed to delete.
Instance Attribute Details
#reason ⇒ String
The reason the threat model failed to delete.
3379 3380 3381 3382 3383 3384 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3379 class DeleteThreatModelFailure < Struct.new( :threat_model_id, :reason) SENSITIVE = [] include Aws::Structure end |
#threat_model_id ⇒ String
The unique identifier of the threat model that failed to delete.
3379 3380 3381 3382 3383 3384 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3379 class DeleteThreatModelFailure < Struct.new( :threat_model_id, :reason) SENSITIVE = [] include Aws::Structure end |