Class: Aws::SecurityAgent::Types::DiffSource

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Note:

DiffSource is a union - when making an API calls you must set exactly one of the members.

Source of the diff for a differential code scan.

Direct Known Subclasses

S3Uri, Unknown

Defined Under Namespace

Classes: S3Uri, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_uriString

S3 URI pointing to a unified diff file. The file must be in standard unified diff format and stored in an S3 bucket connected to your Agent Space.

Returns:

  • (String)


3475
3476
3477
3478
3479
3480
3481
3482
3483
3484
# File 'lib/aws-sdk-securityagent/types.rb', line 3475

class DiffSource < Struct.new(
  :s3_uri,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3Uri < DiffSource; end
  class Unknown < DiffSource; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3475
3476
3477
# File 'lib/aws-sdk-securityagent/types.rb', line 3475

def unknown
  @unknown
end