Class: Aws::SecurityAgent::Types::DiffSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::DiffSource
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Note:
DiffSource is a union - when making an API calls you must set exactly one of the members.
Source of the diff for a differential code scan.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_uri ⇒ String
S3 URI pointing to a unified diff file.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#s3_uri ⇒ String
S3 URI pointing to a unified diff file. The file must be in standard unified diff format and stored in an S3 bucket connected to your Agent Space.
3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3475 class DiffSource < Struct.new( :s3_uri, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3Uri < DiffSource; end class Unknown < DiffSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3475 3476 3477 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3475 def unknown @unknown end |