Class: Aws::SecurityAgent::Types::DiscoveredEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::DiscoveredEndpoint
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents an endpoint discovered during a pentest job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space associated with the discovered endpoint.
-
#description ⇒ String
A description of the discovered endpoint.
-
#evidence ⇒ String
The evidence that led to the discovery of the endpoint.
-
#operation ⇒ String
The HTTP operation associated with the discovered endpoint.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job that discovered the endpoint.
-
#task_id ⇒ String
The unique identifier of the task that discovered the endpoint.
-
#uri ⇒ String
The URI of the discovered endpoint.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space associated with the discovered endpoint.
1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1429 class DiscoveredEndpoint < Struct.new( :uri, :pentest_job_id, :task_id, :agent_space_id, :evidence, :operation, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the discovered endpoint.
1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1429 class DiscoveredEndpoint < Struct.new( :uri, :pentest_job_id, :task_id, :agent_space_id, :evidence, :operation, :description) SENSITIVE = [] include Aws::Structure end |
#evidence ⇒ String
The evidence that led to the discovery of the endpoint.
1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1429 class DiscoveredEndpoint < Struct.new( :uri, :pentest_job_id, :task_id, :agent_space_id, :evidence, :operation, :description) SENSITIVE = [] include Aws::Structure end |
#operation ⇒ String
The HTTP operation associated with the discovered endpoint.
1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1429 class DiscoveredEndpoint < Struct.new( :uri, :pentest_job_id, :task_id, :agent_space_id, :evidence, :operation, :description) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job that discovered the endpoint.
1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1429 class DiscoveredEndpoint < Struct.new( :uri, :pentest_job_id, :task_id, :agent_space_id, :evidence, :operation, :description) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task that discovered the endpoint.
1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1429 class DiscoveredEndpoint < Struct.new( :uri, :pentest_job_id, :task_id, :agent_space_id, :evidence, :operation, :description) SENSITIVE = [] include Aws::Structure end |
#uri ⇒ String
The URI of the discovered endpoint.
1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1429 class DiscoveredEndpoint < Struct.new( :uri, :pentest_job_id, :task_id, :agent_space_id, :evidence, :operation, :description) SENSITIVE = [] include Aws::Structure end |