Class: Aws::SecurityAgent::Types::DocumentInfo

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a document that provides context for security testing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifact_idString

The unique identifier of the artifact associated with the document.

Returns:

  • (String)


1478
1479
1480
1481
1482
1483
# File 'lib/aws-sdk-securityagent/types.rb', line 1478

class DocumentInfo < Struct.new(
  :s3_location,
  :artifact_id)
  SENSITIVE = []
  include Aws::Structure
end

#s3_locationString

The Amazon S3 location of the document.

Returns:

  • (String)


1478
1479
1480
1481
1482
1483
# File 'lib/aws-sdk-securityagent/types.rb', line 1478

class DocumentInfo < Struct.new(
  :s3_location,
  :artifact_id)
  SENSITIVE = []
  include Aws::Structure
end