Class: Aws::SecurityAgent::Types::ExecutionContext
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ExecutionContext
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains contextual information about the execution of a pentest job, such as errors, warnings, or informational messages.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context ⇒ String
The context message.
-
#context_type ⇒ String
The type of context.
-
#timestamp ⇒ Time
The date and time the context was recorded, in UTC format.
Instance Attribute Details
#context ⇒ String
The context message.
1538 1539 1540 1541 1542 1543 1544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1538 class ExecutionContext < Struct.new( :context_type, :context, :timestamp) SENSITIVE = [] include Aws::Structure end |
#context_type ⇒ String
The type of context. Valid values include ERROR, CLIENT_ERROR, WARNING, and INFO.
1538 1539 1540 1541 1542 1543 1544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1538 class ExecutionContext < Struct.new( :context_type, :context, :timestamp) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
The date and time the context was recorded, in UTC format.
1538 1539 1540 1541 1542 1543 1544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1538 class ExecutionContext < Struct.new( :context_type, :context, :timestamp) SENSITIVE = [] include Aws::Structure end |