Class: Aws::SecurityAgent::Types::Finding
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::Finding
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a security finding discovered during a pentest job. A finding contains details about a vulnerability, including its risk level, confidence, and remediation status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space associated with the finding.
-
#attack_script ⇒ String
The attack script used to reproduce the finding.
-
#code_remediation_task ⇒ Types::CodeRemediationTask
The code remediation task associated with the finding, if code remediation was initiated.
-
#confidence ⇒ String
The confidence level of the finding.
-
#created_at ⇒ Time
The date and time the finding was created, in UTC format.
-
#description ⇒ String
A description of the finding.
-
#finding_id ⇒ String
The unique identifier of the finding.
-
#last_updated_by ⇒ String
The identifier of the entity that last updated the finding.
-
#name ⇒ String
The name of the finding.
-
#pentest_id ⇒ String
The unique identifier of the pentest associated with the finding.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job that produced the finding.
-
#reasoning ⇒ String
The reasoning behind the finding, explaining why it was identified as a vulnerability.
-
#risk_level ⇒ String
The risk level of the finding.
-
#risk_score ⇒ String
The numerical risk score of the finding.
-
#risk_type ⇒ String
The type of security risk identified by the finding.
-
#status ⇒ String
The current status of the finding.
-
#task_id ⇒ String
The unique identifier of the task that produced the finding.
-
#updated_at ⇒ Time
The date and time the finding was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space associated with the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#attack_script ⇒ String
The attack script used to reproduce the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_remediation_task ⇒ Types::CodeRemediationTask
The code remediation task associated with the finding, if code remediation was initiated.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#confidence ⇒ String
The confidence level of the finding. Valid values include FALSE_POSITIVE, UNCONFIRMED, LOW, MEDIUM, and HIGH.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the finding was created, in UTC format.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#finding_id ⇒ String
The unique identifier of the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_by ⇒ String
The identifier of the entity that last updated the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest associated with the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job that produced the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#reasoning ⇒ String
The reasoning behind the finding, explaining why it was identified as a vulnerability.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_level ⇒ String
The risk level of the finding. Valid values include UNKNOWN, INFORMATIONAL, LOW, MEDIUM, HIGH, and CRITICAL.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_score ⇒ String
The numerical risk score of the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_type ⇒ String
The type of security risk identified by the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the finding. Valid values include ACTIVE, RESOLVED, ACCEPTED, and FALSE_POSITIVE.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task that produced the finding.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the finding was last updated, in UTC format.
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1630 class Finding < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :task_id, :name, :description, :status, :risk_type, :risk_level, :risk_score, :reasoning, :confidence, :attack_script, :code_remediation_task, :last_updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |