Class: Aws::SecurityAgent::Types::FindingSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::FindingSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains summary information about a security finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space associated with the finding.
-
#code_review_id ⇒ String
The unique identifier of the code review associated with the finding.
-
#code_review_job_id ⇒ String
The unique identifier of the code review job that produced the finding.
-
#confidence ⇒ String
The confidence level of the finding.
-
#created_at ⇒ Time
The date and time the finding was created, in UTC format.
-
#finding_id ⇒ String
The unique identifier of the finding.
-
#name ⇒ String
The name of the finding.
-
#pentest_id ⇒ String
The unique identifier of the pentest associated with the finding.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job that produced the finding.
-
#risk_level ⇒ String
The risk level of the finding.
-
#risk_type ⇒ String
The type of security risk identified by the finding.
-
#status ⇒ String
The current status of the finding.
-
#updated_at ⇒ Time
The date and time the finding was last updated, in UTC format.
-
#validation_status ⇒ String
The simulated validation status of the finding.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space associated with the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_id ⇒ String
The unique identifier of the code review associated with the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_job_id ⇒ String
The unique identifier of the code review job that produced the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#confidence ⇒ String
The confidence level of the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the finding was created, in UTC format.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#finding_id ⇒ String
The unique identifier of the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest associated with the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job that produced the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_level ⇒ String
The risk level of the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_type ⇒ String
The type of security risk identified by the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the finding was last updated, in UTC format.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#validation_status ⇒ String
The simulated validation status of the finding.
3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3912 class FindingSummary < Struct.new( :finding_id, :agent_space_id, :pentest_id, :pentest_job_id, :code_review_id, :code_review_job_id, :name, :status, :risk_type, :risk_level, :confidence, :validation_status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |