Class: Aws::SecurityAgent::Types::FindingSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a security finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space associated with the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_idString

The unique identifier of the code review associated with the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_job_idString

The unique identifier of the code review job that produced the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#confidenceString

The confidence level of the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the finding was created, in UTC format.

Returns:

  • (Time)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#finding_idString

The unique identifier of the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest associated with the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job that produced the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#risk_levelString

The risk level of the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#risk_typeString

The type of security risk identified by the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the finding was last updated, in UTC format.

Returns:

  • (Time)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#validation_statusString

The simulated validation status of the finding.

Returns:

  • (String)


3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
# File 'lib/aws-sdk-securityagent/types.rb', line 3855

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :code_review_id,
  :code_review_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :validation_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end