Class: Aws::SecurityAgent::Types::FindingSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a security finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space associated with the finding.

Returns:

  • (String)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#confidenceString

The confidence level of the finding.

Returns:

  • (String)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the finding was created, in UTC format.

Returns:

  • (Time)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#finding_idString

The unique identifier of the finding.

Returns:

  • (String)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the finding.

Returns:

  • (String)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest associated with the finding.

Returns:

  • (String)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job that produced the finding.

Returns:

  • (String)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#risk_levelString

The risk level of the finding.

Returns:

  • (String)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#risk_typeString

The type of security risk identified by the finding.

Returns:

  • (String)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the finding.

Returns:

  • (String)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the finding was last updated, in UTC format.

Returns:

  • (Time)


1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
# File 'lib/aws-sdk-securityagent/types.rb', line 1702

class FindingSummary < Struct.new(
  :finding_id,
  :agent_space_id,
  :pentest_id,
  :pentest_job_id,
  :name,
  :status,
  :risk_type,
  :risk_level,
  :confidence,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end