Class: Aws::SecurityAgent::Types::GetIntegrationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::GetIntegrationOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name of the integration.
-
#installation_id ⇒ String
The installation identifier from the integration provider.
-
#integration_id ⇒ String
The unique identifier of the integration.
-
#kms_key_id ⇒ String
The identifier of the AWS KMS key used to encrypt data associated with the integration.
-
#provider ⇒ String
The integration provider.
-
#provider_type ⇒ String
The type of the integration provider.
Instance Attribute Details
#display_name ⇒ String
The display name of the integration.
1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1857 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#installation_id ⇒ String
The installation identifier from the integration provider.
1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1857 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#integration_id ⇒ String
The unique identifier of the integration.
1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1857 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier of the AWS KMS key used to encrypt data associated with the integration.
1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1857 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The integration provider.
1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1857 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#provider_type ⇒ String
The type of the integration provider.
1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1857 class GetIntegrationOutput < Struct.new( :integration_id, :installation_id, :provider, :provider_type, :display_name, :kms_key_id) SENSITIVE = [] include Aws::Structure end |