Class: Aws::SecurityAgent::Types::GitHubResourceCapabilities
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::GitHubResourceCapabilities
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
The capabilities enabled for a GitHub resource integration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#leave_comments ⇒ Boolean
Indicates whether the integration can leave comments on pull requests.
-
#remediate_code ⇒ Boolean
Indicates whether the integration can create code remediation pull requests.
Instance Attribute Details
#leave_comments ⇒ Boolean
Indicates whether the integration can leave comments on pull requests.
1957 1958 1959 1960 1961 1962 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1957 class GitHubResourceCapabilities < Struct.new( :leave_comments, :remediate_code) SENSITIVE = [] include Aws::Structure end |
#remediate_code ⇒ Boolean
Indicates whether the integration can create code remediation pull requests.
1957 1958 1959 1960 1961 1962 |
# File 'lib/aws-sdk-securityagent/types.rb', line 1957 class GitHubResourceCapabilities < Struct.new( :leave_comments, :remediate_code) SENSITIVE = [] include Aws::Structure end |