Class: Aws::SecurityAgent::Types::ImportSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ImportSource
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Note:
ImportSource is a union - when making an API calls you must set exactly one of the members.
The source from which to import security requirements. Currently supports document uploads.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#documents ⇒ Array<Types::SecurityRequirementArtifact>
The list of documents to extract security requirements from.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#documents ⇒ Array<Types::SecurityRequirementArtifact>
The list of documents to extract security requirements from.
4417 4418 4419 4420 4421 4422 4423 4424 4425 4426 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4417 class ImportSource < Struct.new( :documents, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Documents < ImportSource; end class Unknown < ImportSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4417 4418 4419 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4417 def unknown @unknown end |