Class: Aws::SecurityAgent::Types::ImportSource

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Note:

ImportSource is a union - when making an API calls you must set exactly one of the members.

The source from which to import security requirements. Currently supports document uploads.

Direct Known Subclasses

Documents, Unknown

Defined Under Namespace

Classes: Documents, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#documentsArray<Types::SecurityRequirementArtifact>

The list of documents to extract security requirements from.



4407
4408
4409
4410
4411
4412
4413
4414
4415
4416
# File 'lib/aws-sdk-securityagent/types.rb', line 4407

class ImportSource < Struct.new(
  :documents,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Documents < ImportSource; end
  class Unknown < ImportSource; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4407
4408
4409
# File 'lib/aws-sdk-securityagent/types.rb', line 4407

def unknown
  @unknown
end