Class: Aws::SecurityAgent::Types::IntegratedDocument
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::IntegratedDocument
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
A reference to a document in a third-party provider, such as a Confluence page linked via an integration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#integration_id ⇒ String
The identifier of the integration that provides access to the document.
-
#resource_id ⇒ String
The provider-specific resource identifier for the document.
Instance Attribute Details
#integration_id ⇒ String
The identifier of the integration that provides access to the document.
4463 4464 4465 4466 4467 4468 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4463 class IntegratedDocument < Struct.new( :integration_id, :resource_id) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The provider-specific resource identifier for the document.
4463 4464 4465 4466 4467 4468 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4463 class IntegratedDocument < Struct.new( :integration_id, :resource_id) SENSITIVE = [] include Aws::Structure end |