Class: Aws::SecurityAgent::Types::IntegratedRepository
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::IntegratedRepository
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a code repository that is integrated with the service through a third-party provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#branch ⇒ String
An optional override for the repository branch.
-
#integration_id ⇒ String
The unique identifier of the integration that provides access to the repository.
-
#provider_resource_id ⇒ String
The provider-specific resource identifier for the repository.
Instance Attribute Details
#branch ⇒ String
An optional override for the repository branch.
4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4488 class IntegratedRepository < Struct.new( :integration_id, :provider_resource_id, :branch) SENSITIVE = [] include Aws::Structure end |
#integration_id ⇒ String
The unique identifier of the integration that provides access to the repository.
4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4488 class IntegratedRepository < Struct.new( :integration_id, :provider_resource_id, :branch) SENSITIVE = [] include Aws::Structure end |
#provider_resource_id ⇒ String
The provider-specific resource identifier for the repository.
4488 4489 4490 4491 4492 4493 4494 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4488 class IntegratedRepository < Struct.new( :integration_id, :provider_resource_id, :branch) SENSITIVE = [] include Aws::Structure end |