Class: Aws::SecurityAgent::Types::IntegratedRepository
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::IntegratedRepository
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a code repository that is integrated with the service through a third-party provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#integration_id ⇒ String
The unique identifier of the integration that provides access to the repository.
-
#provider_resource_id ⇒ String
The provider-specific resource identifier for the repository.
Instance Attribute Details
#integration_id ⇒ String
The unique identifier of the integration that provides access to the repository.
2734 2735 2736 2737 2738 2739 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2734 class IntegratedRepository < Struct.new( :integration_id, :provider_resource_id) SENSITIVE = [] include Aws::Structure end |
#provider_resource_id ⇒ String
The provider-specific resource identifier for the repository.
2734 2735 2736 2737 2738 2739 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2734 class IntegratedRepository < Struct.new( :integration_id, :provider_resource_id) SENSITIVE = [] include Aws::Structure end |