Class: Aws::SecurityAgent::Types::IntegratedRepository

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a code repository that is integrated with the service through a third-party provider.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#integration_idString

The unique identifier of the integration that provides access to the repository.

Returns:

  • (String)


2050
2051
2052
2053
2054
2055
# File 'lib/aws-sdk-securityagent/types.rb', line 2050

class IntegratedRepository < Struct.new(
  :integration_id,
  :provider_resource_id)
  SENSITIVE = []
  include Aws::Structure
end

#provider_resource_idString

The provider-specific resource identifier for the repository.

Returns:

  • (String)


2050
2051
2052
2053
2054
2055
# File 'lib/aws-sdk-securityagent/types.rb', line 2050

class IntegratedRepository < Struct.new(
  :integration_id,
  :provider_resource_id)
  SENSITIVE = []
  include Aws::Structure
end