Class: Aws::SecurityAgent::Types::IntegratedResourceMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::IntegratedResourceMetadata
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Note:
IntegratedResourceMetadata is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of IntegratedResourceMetadata corresponding to the set member.
Contains metadata about an integrated resource. This is a union type that contains provider-specific metadata.
Direct Known Subclasses
Defined Under Namespace
Classes: GithubRepository, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#github_repository ⇒ Types::GitHubRepositoryMetadata
The GitHub repository metadata.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#github_repository ⇒ Types::GitHubRepositoryMetadata
The GitHub repository metadata.
2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2110 class IntegratedResourceMetadata < Struct.new( :github_repository, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GithubRepository < IntegratedResourceMetadata; end class Unknown < IntegratedResourceMetadata; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2110 2111 2112 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2110 def unknown @unknown end |