Class: Aws::SecurityAgent::Types::ListCodeReviewJobTasksInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListCodeReviewJobTasksInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for listing tasks associated with a code review job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#category_name ⇒ String
Filter tasks by category name.
-
#code_review_job_id ⇒ String
The unique identifier of the code review job to list tasks for.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#step_name ⇒ String
Filter tasks by step name.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4971 class ListCodeReviewJobTasksInput < Struct.new( :agent_space_id, :max_results, :code_review_job_id, :step_name, :category_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#category_name ⇒ String
Filter tasks by category name.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4971 class ListCodeReviewJobTasksInput < Struct.new( :agent_space_id, :max_results, :code_review_job_id, :step_name, :category_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#code_review_job_id ⇒ String
The unique identifier of the code review job to list tasks for.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4971 class ListCodeReviewJobTasksInput < Struct.new( :agent_space_id, :max_results, :code_review_job_id, :step_name, :category_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4971 class ListCodeReviewJobTasksInput < Struct.new( :agent_space_id, :max_results, :code_review_job_id, :step_name, :category_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4971 class ListCodeReviewJobTasksInput < Struct.new( :agent_space_id, :max_results, :code_review_job_id, :step_name, :category_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#step_name ⇒ String
Filter tasks by step name.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4971 class ListCodeReviewJobTasksInput < Struct.new( :agent_space_id, :max_results, :code_review_job_id, :step_name, :category_name, :next_token) SENSITIVE = [] include Aws::Structure end |