Class: Aws::SecurityAgent::Types::ListCodeReviewsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListCodeReviewsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for listing code reviews with optional filtering.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to list code reviews for.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to list code reviews for.
5077 5078 5079 5080 5081 5082 5083 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5077 class ListCodeReviewsInput < Struct.new( :max_results, :next_token, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
5077 5078 5079 5080 5081 5082 5083 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5077 class ListCodeReviewsInput < Struct.new( :max_results, :next_token, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5077 5078 5079 5080 5081 5082 5083 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5077 class ListCodeReviewsInput < Struct.new( :max_results, :next_token, :agent_space_id) SENSITIVE = [] include Aws::Structure end |