Class: Aws::SecurityAgent::Types::ListDiscoveredEndpointsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListDiscoveredEndpointsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for ListDiscoveredEndpoints operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job to list discovered endpoints for.
-
#prefix ⇒ String
A prefix to filter discovered endpoints by URI.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
5135 5136 5137 5138 5139 5140 5141 5142 5143 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5135 class ListDiscoveredEndpointsInput < Struct.new( :max_results, :pentest_job_id, :agent_space_id, :prefix, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
5135 5136 5137 5138 5139 5140 5141 5142 5143 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5135 class ListDiscoveredEndpointsInput < Struct.new( :max_results, :pentest_job_id, :agent_space_id, :prefix, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5135 5136 5137 5138 5139 5140 5141 5142 5143 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5135 class ListDiscoveredEndpointsInput < Struct.new( :max_results, :pentest_job_id, :agent_space_id, :prefix, :next_token) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job to list discovered endpoints for.
5135 5136 5137 5138 5139 5140 5141 5142 5143 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5135 class ListDiscoveredEndpointsInput < Struct.new( :max_results, :pentest_job_id, :agent_space_id, :prefix, :next_token) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
A prefix to filter discovered endpoints by URI.
5135 5136 5137 5138 5139 5140 5141 5142 5143 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5135 class ListDiscoveredEndpointsInput < Struct.new( :max_results, :pentest_job_id, :agent_space_id, :prefix, :next_token) SENSITIVE = [] include Aws::Structure end |