Class: Aws::SecurityAgent::Types::ListDiscoveredEndpointsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListDiscoveredEndpointsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the ListDiscoveredEndpoints operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#discovered_endpoints ⇒ Array<Types::DiscoveredEndpoint>
The list of discovered endpoints.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
Instance Attribute Details
#discovered_endpoints ⇒ Array<Types::DiscoveredEndpoint>
The list of discovered endpoints.
5160 5161 5162 5163 5164 5165 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5160 class ListDiscoveredEndpointsOutput < Struct.new( :discovered_endpoints, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5160 5161 5162 5163 5164 5165 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5160 class ListDiscoveredEndpointsOutput < Struct.new( :discovered_endpoints, :next_token) SENSITIVE = [] include Aws::Structure end |