Class: Aws::SecurityAgent::Types::ListFindingsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListFindingsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for ListFindings operation with filtering support.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#code_review_job_id ⇒ String
The unique identifier of the code review job to list findings for.
-
#confidence ⇒ String
Filter findings by confidence level.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#name ⇒ String
Filter findings by name.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job to list findings for.
-
#risk_level ⇒ String
Filter findings by risk level.
-
#risk_type ⇒ String
Filter findings by risk type.
-
#status ⇒ String
Filter findings by status.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5215 class ListFindingsInput < Struct.new( :max_results, :pentest_job_id, :code_review_job_id, :agent_space_id, :next_token, :risk_type, :risk_level, :status, :confidence, :name) SENSITIVE = [] include Aws::Structure end |
#code_review_job_id ⇒ String
The unique identifier of the code review job to list findings for. Mutually exclusive with pentestJobId.
5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5215 class ListFindingsInput < Struct.new( :max_results, :pentest_job_id, :code_review_job_id, :agent_space_id, :next_token, :risk_type, :risk_level, :status, :confidence, :name) SENSITIVE = [] include Aws::Structure end |
#confidence ⇒ String
Filter findings by confidence level.
5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5215 class ListFindingsInput < Struct.new( :max_results, :pentest_job_id, :code_review_job_id, :agent_space_id, :next_token, :risk_type, :risk_level, :status, :confidence, :name) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5215 class ListFindingsInput < Struct.new( :max_results, :pentest_job_id, :code_review_job_id, :agent_space_id, :next_token, :risk_type, :risk_level, :status, :confidence, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Filter findings by name.
5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5215 class ListFindingsInput < Struct.new( :max_results, :pentest_job_id, :code_review_job_id, :agent_space_id, :next_token, :risk_type, :risk_level, :status, :confidence, :name) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5215 class ListFindingsInput < Struct.new( :max_results, :pentest_job_id, :code_review_job_id, :agent_space_id, :next_token, :risk_type, :risk_level, :status, :confidence, :name) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job to list findings for.
5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5215 class ListFindingsInput < Struct.new( :max_results, :pentest_job_id, :code_review_job_id, :agent_space_id, :next_token, :risk_type, :risk_level, :status, :confidence, :name) SENSITIVE = [] include Aws::Structure end |
#risk_level ⇒ String
Filter findings by risk level.
5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5215 class ListFindingsInput < Struct.new( :max_results, :pentest_job_id, :code_review_job_id, :agent_space_id, :next_token, :risk_type, :risk_level, :status, :confidence, :name) SENSITIVE = [] include Aws::Structure end |
#risk_type ⇒ String
Filter findings by risk type.
5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5215 class ListFindingsInput < Struct.new( :max_results, :pentest_job_id, :code_review_job_id, :agent_space_id, :next_token, :risk_type, :risk_level, :status, :confidence, :name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Filter findings by status.
5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5215 class ListFindingsInput < Struct.new( :max_results, :pentest_job_id, :code_review_job_id, :agent_space_id, :next_token, :risk_type, :risk_level, :status, :confidence, :name) SENSITIVE = [] include Aws::Structure end |