Class: Aws::SecurityAgent::Types::ListIntegratedResourcesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListIntegratedResourcesInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to list integrated resources for.
-
#integration_id ⇒ String
The unique identifier of the integration to filter by.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#resource_type ⇒ String
The type of resource to filter by.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to list integrated resources for.
5278 5279 5280 5281 5282 5283 5284 5285 5286 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5278 class ListIntegratedResourcesInput < Struct.new( :agent_space_id, :integration_id, :resource_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#integration_id ⇒ String
The unique identifier of the integration to filter by.
5278 5279 5280 5281 5282 5283 5284 5285 5286 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5278 class ListIntegratedResourcesInput < Struct.new( :agent_space_id, :integration_id, :resource_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
5278 5279 5280 5281 5282 5283 5284 5285 5286 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5278 class ListIntegratedResourcesInput < Struct.new( :agent_space_id, :integration_id, :resource_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5278 5279 5280 5281 5282 5283 5284 5285 5286 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5278 class ListIntegratedResourcesInput < Struct.new( :agent_space_id, :integration_id, :resource_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource to filter by.
5278 5279 5280 5281 5282 5283 5284 5285 5286 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5278 class ListIntegratedResourcesInput < Struct.new( :agent_space_id, :integration_id, :resource_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |