Class: Aws::SecurityAgent::Types::ListIntegrationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListIntegrationsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::IntegrationFilter
A filter to apply to the list of integrations.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
Instance Attribute Details
#filter ⇒ Types::IntegrationFilter
A filter to apply to the list of integrations.
5325 5326 5327 5328 5329 5330 5331 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5325 class ListIntegrationsInput < Struct.new( :filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
5325 5326 5327 5328 5329 5330 5331 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5325 class ListIntegrationsInput < Struct.new( :filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5325 5326 5327 5328 5329 5330 5331 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5325 class ListIntegrationsInput < Struct.new( :filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |