Class: Aws::SecurityAgent::Types::ListIntegrationsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListIntegrationsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#integration_summaries ⇒ Array<Types::IntegrationSummary>
The list of integration summaries.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
Instance Attribute Details
#integration_summaries ⇒ Array<Types::IntegrationSummary>
The list of integration summaries.
5346 5347 5348 5349 5350 5351 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5346 class ListIntegrationsOutput < Struct.new( :integration_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5346 5347 5348 5349 5350 5351 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5346 class ListIntegrationsOutput < Struct.new( :integration_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |