Class: Aws::SecurityAgent::Types::ListMembershipsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListMembershipsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Request structure for listing agent space members.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to list memberships for.
-
#application_id ⇒ String
The unique identifier of the application that contains the agent space.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#member_type ⇒ String
Filter memberships by member type.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to list memberships for.
5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5381 class ListMembershipsRequest < Struct.new( :application_id, :agent_space_id, :member_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#application_id ⇒ String
The unique identifier of the application that contains the agent space.
5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5381 class ListMembershipsRequest < Struct.new( :application_id, :agent_space_id, :member_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5381 class ListMembershipsRequest < Struct.new( :application_id, :agent_space_id, :member_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#member_type ⇒ String
Filter memberships by member type.
5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5381 class ListMembershipsRequest < Struct.new( :application_id, :agent_space_id, :member_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5381 5382 5383 5384 5385 5386 5387 5388 5389 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5381 class ListMembershipsRequest < Struct.new( :application_id, :agent_space_id, :member_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |