Class: Aws::SecurityAgent::Types::ListPentestJobTasksOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListPentestJobTasksOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the ListPentestJobTasks operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#task_summaries ⇒ Array<Types::TaskSummary>
The list of task summaries.
Instance Attribute Details
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5471 5472 5473 5474 5475 5476 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5471 class ListPentestJobTasksOutput < Struct.new( :task_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#task_summaries ⇒ Array<Types::TaskSummary>
The list of task summaries.
5471 5472 5473 5474 5475 5476 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5471 class ListPentestJobTasksOutput < Struct.new( :task_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |