Class: Aws::SecurityAgent::Types::ListPentestsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListPentestsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for listing pentests with optional filtering.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to list pentests for.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to list pentests for.
5551 5552 5553 5554 5555 5556 5557 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5551 class ListPentestsInput < Struct.new( :max_results, :next_token, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
5551 5552 5553 5554 5555 5556 5557 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5551 class ListPentestsInput < Struct.new( :max_results, :next_token, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5551 5552 5553 5554 5555 5556 5557 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5551 class ListPentestsInput < Struct.new( :max_results, :next_token, :agent_space_id) SENSITIVE = [] include Aws::Structure end |