Class: Aws::SecurityAgent::Types::ListPentestsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListPentestsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the ListPentests operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#pentest_summaries ⇒ Array<Types::PentestSummary>
The list of pentest summaries.
Instance Attribute Details
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5574 5575 5576 5577 5578 5579 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5574 class ListPentestsOutput < Struct.new( :pentest_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#pentest_summaries ⇒ Array<Types::PentestSummary>
The list of pentest summaries.
5574 5575 5576 5577 5578 5579 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5574 class ListPentestsOutput < Struct.new( :pentest_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |