Class: Aws::SecurityAgent::Types::ListSecurityRequirementsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListSecurityRequirementsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in a single request.
-
#next_token ⇒ String
The pagination token from a previous request to retrieve the next page of results.
-
#pack_id ⇒ String
The unique identifier of the security requirement pack to list requirements for.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in a single request.
5694 5695 5696 5697 5698 5699 5700 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5694 class ListSecurityRequirementsInput < Struct.new( :pack_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token from a previous request to retrieve the next page of results.
5694 5695 5696 5697 5698 5699 5700 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5694 class ListSecurityRequirementsInput < Struct.new( :pack_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#pack_id ⇒ String
The unique identifier of the security requirement pack to list requirements for.
5694 5695 5696 5697 5698 5699 5700 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5694 class ListSecurityRequirementsInput < Struct.new( :pack_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |