Class: Aws::SecurityAgent::Types::ListTargetDomainsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListTargetDomainsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for listing target domains.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in a single call.
5763 5764 5765 5766 5767 5768 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5763 class ListTargetDomainsInput < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5763 5764 5765 5766 5767 5768 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5763 class ListTargetDomainsInput < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |