Class: Aws::SecurityAgent::Types::ListTargetDomainsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListTargetDomainsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the ListTargetDomains operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#target_domain_summaries ⇒ Array<Types::TargetDomainSummary>
The list of target domain summaries.
Instance Attribute Details
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the nextToken value returned from the previous request.
5785 5786 5787 5788 5789 5790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5785 class ListTargetDomainsOutput < Struct.new( :target_domain_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#target_domain_summaries ⇒ Array<Types::TargetDomainSummary>
The list of target domain summaries.
5785 5786 5787 5788 5789 5790 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5785 class ListTargetDomainsOutput < Struct.new( :target_domain_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |