Class: Aws::SecurityAgent::Types::ListThreatModelJobTasksInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ListThreatModelJobTasksInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for listing tasks associated with a threat model job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#threat_model_job_id ⇒ String
The unique identifier of the threat model job to list tasks for.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
5813 5814 5815 5816 5817 5818 5819 5820 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5813 class ListThreatModelJobTasksInput < Struct.new( :agent_space_id, :max_results, :threat_model_job_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call.
5813 5814 5815 5816 5817 5818 5819 5820 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5813 class ListThreatModelJobTasksInput < Struct.new( :agent_space_id, :max_results, :threat_model_job_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
5813 5814 5815 5816 5817 5818 5819 5820 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5813 class ListThreatModelJobTasksInput < Struct.new( :agent_space_id, :max_results, :threat_model_job_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#threat_model_job_id ⇒ String
The unique identifier of the threat model job to list tasks for.
5813 5814 5815 5816 5817 5818 5819 5820 |
# File 'lib/aws-sdk-securityagent/types.rb', line 5813 class ListThreatModelJobTasksInput < Struct.new( :agent_space_id, :max_results, :threat_model_job_id, :next_token) SENSITIVE = [] include Aws::Structure end |