Class: Aws::SecurityAgent::Types::MemberMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Note:

MemberMetadata is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MemberMetadata corresponding to the set member.

Contains metadata about a member. This is a union type that contains member-type-specific metadata.

Direct Known Subclasses

Unknown, User

Defined Under Namespace

Classes: Unknown, User

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2922
2923
2924
# File 'lib/aws-sdk-securityagent/types.rb', line 2922

def unknown
  @unknown
end

#userTypes::UserMetadata

The user metadata for the member.

Returns:



2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
# File 'lib/aws-sdk-securityagent/types.rb', line 2922

class MemberMetadata < Struct.new(
  :user,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class User < MemberMetadata; end
  class Unknown < MemberMetadata; end
end