Class: Aws::SecurityAgent::Types::MemberMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::MemberMetadata
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Note:
MemberMetadata is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MemberMetadata corresponding to the set member.
Contains metadata about a member. This is a union type that contains member-type-specific metadata.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#user ⇒ Types::UserMetadata
The user metadata for the member.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
2922 2923 2924 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2922 def unknown @unknown end |
#user ⇒ Types::UserMetadata
The user metadata for the member.
2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2922 class MemberMetadata < Struct.new( :user, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class User < MemberMetadata; end class Unknown < MemberMetadata; end end |