Class: Aws::SecurityAgent::Types::MembershipConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::MembershipConfig
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Note:
MembershipConfig is a union - when making an API calls you must set exactly one of the members.
Note:
MembershipConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MembershipConfig corresponding to the set member.
The configuration for a membership. This is a union type that contains member-type-specific configuration.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#user ⇒ Types::UserConfig
The user configuration for the membership.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
2946 2947 2948 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2946 def unknown @unknown end |
#user ⇒ Types::UserConfig
The user configuration for the membership.
2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 |
# File 'lib/aws-sdk-securityagent/types.rb', line 2946 class MembershipConfig < Struct.new( :user, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class User < MembershipConfig; end class Unknown < MembershipConfig; end end |