Class: Aws::SecurityAgent::Types::MembershipSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::MembershipSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains summary information about a membership.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#application_id ⇒ String
The unique identifier of the application.
-
#config ⇒ Types::MembershipConfig
The configuration for the membership.
-
#created_at ⇒ Time
The date and time the membership was created, in UTC format.
-
#created_by ⇒ String
The identifier of the entity that created the membership.
-
#member_type ⇒ String
The type of member.
-
#membership_id ⇒ String
The unique identifier of the membership.
-
#metadata ⇒ Types::MemberMetadata
The metadata for the member.
-
#updated_at ⇒ Time
The date and time the membership was last updated, in UTC format.
-
#updated_by ⇒ String
The identifier of the entity that last updated the membership.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3001 class MembershipSummary < Struct.new( :membership_id, :application_id, :agent_space_id, :member_type, :config, :metadata, :created_at, :updated_at, :created_by, :updated_by) SENSITIVE = [] include Aws::Structure end |
#application_id ⇒ String
The unique identifier of the application.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3001 class MembershipSummary < Struct.new( :membership_id, :application_id, :agent_space_id, :member_type, :config, :metadata, :created_at, :updated_at, :created_by, :updated_by) SENSITIVE = [] include Aws::Structure end |
#config ⇒ Types::MembershipConfig
The configuration for the membership.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3001 class MembershipSummary < Struct.new( :membership_id, :application_id, :agent_space_id, :member_type, :config, :metadata, :created_at, :updated_at, :created_by, :updated_by) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the membership was created, in UTC format.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3001 class MembershipSummary < Struct.new( :membership_id, :application_id, :agent_space_id, :member_type, :config, :metadata, :created_at, :updated_at, :created_by, :updated_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The identifier of the entity that created the membership.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3001 class MembershipSummary < Struct.new( :membership_id, :application_id, :agent_space_id, :member_type, :config, :metadata, :created_at, :updated_at, :created_by, :updated_by) SENSITIVE = [] include Aws::Structure end |
#member_type ⇒ String
The type of member.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3001 class MembershipSummary < Struct.new( :membership_id, :application_id, :agent_space_id, :member_type, :config, :metadata, :created_at, :updated_at, :created_by, :updated_by) SENSITIVE = [] include Aws::Structure end |
#membership_id ⇒ String
The unique identifier of the membership.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3001 class MembershipSummary < Struct.new( :membership_id, :application_id, :agent_space_id, :member_type, :config, :metadata, :created_at, :updated_at, :created_by, :updated_by) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Types::MemberMetadata
The metadata for the member.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3001 class MembershipSummary < Struct.new( :membership_id, :application_id, :agent_space_id, :member_type, :config, :metadata, :created_at, :updated_at, :created_by, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the membership was last updated, in UTC format.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3001 class MembershipSummary < Struct.new( :membership_id, :application_id, :agent_space_id, :member_type, :config, :metadata, :created_at, :updated_at, :created_by, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The identifier of the entity that last updated the membership.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3001 class MembershipSummary < Struct.new( :membership_id, :application_id, :agent_space_id, :member_type, :config, :metadata, :created_at, :updated_at, :created_by, :updated_by) SENSITIVE = [] include Aws::Structure end |