Class: Aws::SecurityAgent::Types::NetworkTrafficConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::NetworkTrafficConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
The network traffic configuration for a pentest, including custom headers and traffic rules.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_headers ⇒ Array<Types::CustomHeader>
The list of custom HTTP headers to include in network traffic during testing.
-
#rules ⇒ Array<Types::NetworkTrafficRule>
The list of network traffic rules that control which URLs are allowed or denied during testing.
Instance Attribute Details
#custom_headers ⇒ Array<Types::CustomHeader>
The list of custom HTTP headers to include in network traffic during testing.
3031 3032 3033 3034 3035 3036 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3031 class NetworkTrafficConfig < Struct.new( :rules, :custom_headers) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::NetworkTrafficRule>
The list of network traffic rules that control which URLs are allowed or denied during testing.
3031 3032 3033 3034 3035 3036 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3031 class NetworkTrafficConfig < Struct.new( :rules, :custom_headers) SENSITIVE = [] include Aws::Structure end |