Class: Aws::SecurityAgent::Types::NetworkTrafficRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::NetworkTrafficRule
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
A rule that controls network traffic during penetration testing by allowing or denying traffic to specific URL patterns.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#effect ⇒ String
The effect of the rule.
-
#network_traffic_rule_type ⇒ String
The type of the network traffic rule.
-
#pattern ⇒ String
The URL pattern to match for the rule.
Instance Attribute Details
#effect ⇒ String
The effect of the rule. Valid values are ALLOW and DENY.
3056 3057 3058 3059 3060 3061 3062 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3056 class NetworkTrafficRule < Struct.new( :effect, :pattern, :network_traffic_rule_type) SENSITIVE = [] include Aws::Structure end |
#network_traffic_rule_type ⇒ String
The type of the network traffic rule. Currently, only URL is supported.
3056 3057 3058 3059 3060 3061 3062 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3056 class NetworkTrafficRule < Struct.new( :effect, :pattern, :network_traffic_rule_type) SENSITIVE = [] include Aws::Structure end |
#pattern ⇒ String
The URL pattern to match for the rule.
3056 3057 3058 3059 3060 3061 3062 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3056 class NetworkTrafficRule < Struct.new( :effect, :pattern, :network_traffic_rule_type) SENSITIVE = [] include Aws::Structure end |