Class: Aws::SecurityAgent::Types::Pentest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a pentest configuration that defines the parameters for security testing, including target assets, risk type exclusions, and infrastructure settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the pentest.

Returns:

  • (String)


6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets included in the pentest.

Returns:



6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#clean_up_strategyString

Strategy for cleaning up resources after pentest job completion.

Returns:

  • (String)


6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The code remediation strategy for the pentest.

Returns:

  • (String)


6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the pentest was created, in UTC format.

Returns:

  • (Time)


6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#disable_managed_skillsArray<String>

A list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.

Returns:

  • (Array<String>)


6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_risk_typesArray<String>

The list of risk types excluded from the pentest.

Returns:

  • (Array<String>)


6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the pentest.



6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_traffic_configTypes::NetworkTrafficConfig

The network traffic configuration for the pentest.



6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest.

Returns:

  • (String)


6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the pentest.

Returns:

  • (String)


6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the pentest.

Returns:

  • (String)


6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the pentest was last updated, in UTC format.

Returns:

  • (Time)


6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

The VPC configuration for the pentest.

Returns:



6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
# File 'lib/aws-sdk-securityagent/types.rb', line 6117

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end