Class: Aws::SecurityAgent::Types::Pentest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::Pentest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a pentest configuration that defines the parameters for security testing, including target assets, risk type exclusions, and infrastructure settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
-
#assets ⇒ Types::Assets
The assets included in the pentest.
-
#clean_up_strategy ⇒ String
Strategy for cleaning up resources after pentest job completion.
-
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest.
-
#created_at ⇒ Time
The date and time the pentest was created, in UTC format.
-
#disable_managed_skills ⇒ Array<String>
A list of managed skills to disable for this pentest.
-
#exclude_risk_types ⇒ Array<String>
The list of risk types excluded from the pentest.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest.
-
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest.
-
#pentest_id ⇒ String
The unique identifier of the pentest.
-
#service_role ⇒ String
The IAM service role used for the pentest.
-
#title ⇒ String
The title of the pentest.
-
#updated_at ⇒ Time
The date and time the pentest was last updated, in UTC format.
-
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets included in the pentest.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#clean_up_strategy ⇒ String
Strategy for cleaning up resources after pentest job completion.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the pentest was created, in UTC format.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#disable_managed_skills ⇒ Array<String>
A list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#exclude_risk_types ⇒ Array<String>
The list of risk types excluded from the pentest.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role used for the pentest.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the pentest.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the pentest was last updated, in UTC format.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest.
6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6117 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |