Class: Aws::SecurityAgent::Types::Pentest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a pentest configuration that defines the parameters for security testing, including target assets, risk type exclusions, and infrastructure settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the pentest.

Returns:

  • (String)


3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets included in the pentest.

Returns:



3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The code remediation strategy for the pentest.

Returns:

  • (String)


3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the pentest was created, in UTC format.

Returns:

  • (Time)


3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_risk_typesArray<String>

The list of risk types excluded from the pentest.

Returns:

  • (Array<String>)


3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the pentest.



3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_traffic_configTypes::NetworkTrafficConfig

The network traffic configuration for the pentest.



3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest.

Returns:

  • (String)


3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the pentest.

Returns:

  • (String)


3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the pentest.

Returns:

  • (String)


3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the pentest was last updated, in UTC format.

Returns:

  • (Time)


3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

The VPC configuration for the pentest.

Returns:



3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/aws-sdk-securityagent/types.rb', line 3118

class Pentest < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end