Class: Aws::SecurityAgent::Types::Pentest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::Pentest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a pentest configuration that defines the parameters for security testing, including target assets, risk type exclusions, and infrastructure settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
-
#assets ⇒ Types::Assets
The assets included in the pentest.
-
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest.
-
#created_at ⇒ Time
The date and time the pentest was created, in UTC format.
-
#exclude_risk_types ⇒ Array<String>
The list of risk types excluded from the pentest.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest.
-
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest.
-
#pentest_id ⇒ String
The unique identifier of the pentest.
-
#service_role ⇒ String
The IAM service role used for the pentest.
-
#title ⇒ String
The title of the pentest.
-
#updated_at ⇒ Time
The date and time the pentest was last updated, in UTC format.
-
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets included in the pentest.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the pentest was created, in UTC format.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#exclude_risk_types ⇒ Array<String>
The list of risk types excluded from the pentest.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role used for the pentest.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the pentest.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the pentest was last updated, in UTC format.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest.
3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3118 class Pentest < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |