Class: Aws::SecurityAgent::Types::PentestJob
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::PentestJob
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a pentest job, which is an execution instance of a pentest. A pentest job progresses through preflight, static analysis, pentest, and finalizing steps.
Constant Summary collapse
- SENSITIVE =
[:trusted_ca_certificates]
Instance Attribute Summary collapse
-
#actors ⇒ Array<Types::Actor>
The list of actors used during the pentest job.
-
#allowed_domains ⇒ Array<Types::Endpoint>
The list of domains allowed during the pentest job.
-
#clean_up_strategy ⇒ String
Strategy for cleaning up resources after pentest job completion.
-
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest job.
-
#created_at ⇒ Time
The date and time the pentest job was created, in UTC format.
-
#disable_managed_skills ⇒ Array<String>
A list of managed skills disabled for this pentest job.
-
#documents ⇒ Array<Types::DocumentInfo>
The list of documents providing context for the pentest job.
-
#endpoints ⇒ Array<Types::Endpoint>
The list of endpoints being tested in the pentest job.
-
#error_information ⇒ Types::ErrorInformation
Error information if the pentest job encountered an error.
-
#exclude_paths ⇒ Array<Types::Endpoint>
The list of paths excluded from the pentest job.
-
#exclude_risk_types ⇒ Array<String>
The list of risk types excluded from the pentest job.
-
#execution_context ⇒ Array<Types::ExecutionContext>
The execution context messages for the pentest job.
-
#integrated_repositories ⇒ Array<Types::IntegratedRepository>
The list of integrated repositories associated with the pentest job.
-
#job_type ⇒ String
The type of the pentest job.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest job.
-
#max_task_hours ⇒ Float
The maximum number of billable task hours allowed for this pentest job.
-
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest job.
-
#overview ⇒ String
An overview of the pentest job results.
-
#pentest_id ⇒ String
The unique identifier of the pentest associated with the job.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job.
-
#selected_finding_ids ⇒ Array<String>
The list of finding identifiers selected for revalidation.
-
#service_role ⇒ String
The IAM service role used for the pentest job.
-
#source_code ⇒ Array<Types::SourceCodeRepository>
The list of source code repositories analyzed during the pentest job.
-
#status ⇒ String
The current status of the pentest job.
-
#steps ⇒ Array<Types::Step>
The list of steps in the pentest job execution.
-
#title ⇒ String
The title of the pentest job.
-
#trusted_ca_certificates ⇒ Array<Types::TrustedCaCertificate>
The trust anchors used to validate target endpoint TLS certificates during the pentest job.
-
#updated_at ⇒ Time
The date and time the pentest job was last updated, in UTC format.
-
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest job.
Instance Attribute Details
#actors ⇒ Array<Types::Actor>
The list of actors used during the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#allowed_domains ⇒ Array<Types::Endpoint>
The list of domains allowed during the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#clean_up_strategy ⇒ String
Strategy for cleaning up resources after pentest job completion.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#created_at ⇒ Time
The date and time the pentest job was created, in UTC format.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#disable_managed_skills ⇒ Array<String>
A list of managed skills disabled for this pentest job. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#documents ⇒ Array<Types::DocumentInfo>
The list of documents providing context for the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#endpoints ⇒ Array<Types::Endpoint>
The list of endpoints being tested in the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#error_information ⇒ Types::ErrorInformation
Error information if the pentest job encountered an error.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#exclude_paths ⇒ Array<Types::Endpoint>
The list of paths excluded from the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#exclude_risk_types ⇒ Array<String>
The list of risk types excluded from the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#execution_context ⇒ Array<Types::ExecutionContext>
The execution context messages for the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#integrated_repositories ⇒ Array<Types::IntegratedRepository>
The list of integrated repositories associated with the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#job_type ⇒ String
The type of the pentest job. Valid values are FULL and REVALIDATION.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#max_task_hours ⇒ Float
The maximum number of billable task hours allowed for this pentest job. If the cumulative task hours reach this limit, the job is gracefully stopped.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#overview ⇒ String
An overview of the pentest job results.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest associated with the job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#selected_finding_ids ⇒ Array<String>
The list of finding identifiers selected for revalidation. Present only when jobType is REVALIDATION.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#service_role ⇒ String
The IAM service role used for the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#source_code ⇒ Array<Types::SourceCodeRepository>
The list of source code repositories analyzed during the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#status ⇒ String
The current status of the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#steps ⇒ Array<Types::Step>
The list of steps in the pentest job execution.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#title ⇒ String
The title of the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#trusted_ca_certificates ⇒ Array<Types::TrustedCaCertificate>
The trust anchors used to validate target endpoint TLS certificates during the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the pentest job was last updated, in UTC format.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6378 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :trusted_ca_certificates, :code_remediation_strategy, :clean_up_strategy, :disable_managed_skills, :max_task_hours, :job_type, :selected_finding_ids, :created_at, :updated_at) SENSITIVE = [:trusted_ca_certificates] include Aws::Structure end |