Class: Aws::SecurityAgent::Types::PentestJob

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a pentest job, which is an execution instance of a pentest. A pentest job progresses through preflight, static analysis, pentest, and finalizing steps.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actorsArray<Types::Actor>

The list of actors used during the pentest job.

Returns:



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_domainsArray<Types::Endpoint>

The list of domains allowed during the pentest job.

Returns:



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#clean_up_strategyString

Strategy for cleaning up resources after pentest job completion.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The code remediation strategy for the pentest job.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the pentest job was created, in UTC format.

Returns:

  • (Time)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#disable_managed_skillsArray<String>

A list of managed skills disabled for this pentest job. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.

Returns:

  • (Array<String>)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#documentsArray<Types::DocumentInfo>

The list of documents providing context for the pentest job.

Returns:



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#endpointsArray<Types::Endpoint>

The list of endpoints being tested in the pentest job.

Returns:



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#error_informationTypes::ErrorInformation

Error information if the pentest job encountered an error.



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_pathsArray<Types::Endpoint>

The list of paths excluded from the pentest job.

Returns:



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_risk_typesArray<String>

The list of risk types excluded from the pentest job.

Returns:

  • (Array<String>)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_contextArray<Types::ExecutionContext>

The execution context messages for the pentest job.

Returns:



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#integrated_repositoriesArray<Types::IntegratedRepository>

The list of integrated repositories associated with the pentest job.

Returns:



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the pentest job.



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_traffic_configTypes::NetworkTrafficConfig

The network traffic configuration for the pentest job.



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#overviewString

An overview of the pentest job results.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest associated with the job.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the pentest job.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#source_codeArray<Types::SourceCodeRepository>

The list of source code repositories analyzed during the pentest job.

Returns:



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the pentest job.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#stepsArray<Types::Step>

The list of steps in the pentest job execution.

Returns:



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the pentest job.

Returns:

  • (String)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the pentest job was last updated, in UTC format.

Returns:

  • (Time)


6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

The VPC configuration for the pentest job.

Returns:



6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
# File 'lib/aws-sdk-securityagent/types.rb', line 6244

class PentestJob < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :overview,
  :status,
  :endpoints,
  :actors,
  :documents,
  :source_code,
  :exclude_paths,
  :allowed_domains,
  :exclude_risk_types,
  :steps,
  :execution_context,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :error_information,
  :integrated_repositories,
  :code_remediation_strategy,
  :clean_up_strategy,
  :disable_managed_skills,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end