Class: Aws::SecurityAgent::Types::PentestJob
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::PentestJob
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents a pentest job, which is an execution instance of a pentest. A pentest job progresses through preflight, static analysis, pentest, and finalizing steps.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actors ⇒ Array<Types::Actor>
The list of actors used during the pentest job.
-
#allowed_domains ⇒ Array<Types::Endpoint>
The list of domains allowed during the pentest job.
-
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest job.
-
#created_at ⇒ Time
The date and time the pentest job was created, in UTC format.
-
#documents ⇒ Array<Types::DocumentInfo>
The list of documents providing context for the pentest job.
-
#endpoints ⇒ Array<Types::Endpoint>
The list of endpoints being tested in the pentest job.
-
#error_information ⇒ Types::ErrorInformation
Error information if the pentest job encountered an error.
-
#exclude_paths ⇒ Array<Types::Endpoint>
The list of paths excluded from the pentest job.
-
#exclude_risk_types ⇒ Array<String>
The list of risk types excluded from the pentest job.
-
#execution_context ⇒ Array<Types::ExecutionContext>
The execution context messages for the pentest job.
-
#integrated_repositories ⇒ Array<Types::IntegratedRepository>
The list of integrated repositories associated with the pentest job.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest job.
-
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest job.
-
#overview ⇒ String
An overview of the pentest job results.
-
#pentest_id ⇒ String
The unique identifier of the pentest associated with the job.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job.
-
#service_role ⇒ String
The IAM service role used for the pentest job.
-
#source_code ⇒ Array<Types::SourceCodeRepository>
The list of source code repositories analyzed during the pentest job.
-
#status ⇒ String
The current status of the pentest job.
-
#steps ⇒ Array<Types::Step>
The list of steps in the pentest job execution.
-
#title ⇒ String
The title of the pentest job.
-
#updated_at ⇒ Time
The date and time the pentest job was last updated, in UTC format.
-
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest job.
Instance Attribute Details
#actors ⇒ Array<Types::Actor>
The list of actors used during the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#allowed_domains ⇒ Array<Types::Endpoint>
The list of domains allowed during the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The code remediation strategy for the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the pentest job was created, in UTC format.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#documents ⇒ Array<Types::DocumentInfo>
The list of documents providing context for the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#endpoints ⇒ Array<Types::Endpoint>
The list of endpoints being tested in the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#error_information ⇒ Types::ErrorInformation
Error information if the pentest job encountered an error.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#exclude_paths ⇒ Array<Types::Endpoint>
The list of paths excluded from the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#exclude_risk_types ⇒ Array<String>
The list of risk types excluded from the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#execution_context ⇒ Array<Types::ExecutionContext>
The execution context messages for the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#integrated_repositories ⇒ Array<Types::IntegratedRepository>
The list of integrated repositories associated with the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The network traffic configuration for the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#overview ⇒ String
An overview of the pentest job results.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest associated with the job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role used for the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#source_code ⇒ Array<Types::SourceCodeRepository>
The list of source code repositories analyzed during the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#steps ⇒ Array<Types::Step>
The list of steps in the pentest job execution.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the pentest job was last updated, in UTC format.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC configuration for the pentest job.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3234 class PentestJob < Struct.new( :pentest_job_id, :pentest_id, :title, :overview, :status, :endpoints, :actors, :documents, :source_code, :exclude_paths, :allowed_domains, :exclude_risk_types, :steps, :execution_context, :service_role, :log_config, :vpc_config, :network_traffic_config, :error_information, :integrated_repositories, :code_remediation_strategy, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |