Class: Aws::SecurityAgent::Types::PentestJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a pentest job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time the pentest job was created, in UTC format.

Returns:

  • (Time)


4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
# File 'lib/aws-sdk-securityagent/types.rb', line 4147

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest associated with the job.

Returns:

  • (String)


4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
# File 'lib/aws-sdk-securityagent/types.rb', line 4147

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job.

Returns:

  • (String)


4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
# File 'lib/aws-sdk-securityagent/types.rb', line 4147

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the pentest job.

Returns:

  • (String)


4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
# File 'lib/aws-sdk-securityagent/types.rb', line 4147

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the pentest job.

Returns:

  • (String)


4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
# File 'lib/aws-sdk-securityagent/types.rb', line 4147

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the pentest job was last updated, in UTC format.

Returns:

  • (Time)


4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
# File 'lib/aws-sdk-securityagent/types.rb', line 4147

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end