Class: Aws::SecurityAgent::Types::PentestJobSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a pentest job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time the pentest job was created, in UTC format.

Returns:

  • (Time)


3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
# File 'lib/aws-sdk-securityagent/types.rb', line 3290

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest associated with the job.

Returns:

  • (String)


3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
# File 'lib/aws-sdk-securityagent/types.rb', line 3290

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job.

Returns:

  • (String)


3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
# File 'lib/aws-sdk-securityagent/types.rb', line 3290

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the pentest job.

Returns:

  • (String)


3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
# File 'lib/aws-sdk-securityagent/types.rb', line 3290

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the pentest job.

Returns:

  • (String)


3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
# File 'lib/aws-sdk-securityagent/types.rb', line 3290

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the pentest job was last updated, in UTC format.

Returns:

  • (Time)


3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
# File 'lib/aws-sdk-securityagent/types.rb', line 3290

class PentestJobSummary < Struct.new(
  :pentest_job_id,
  :pentest_id,
  :title,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end