Class: Aws::SecurityAgent::Types::PentestSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a pentest.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the pentest.

Returns:

  • (String)


3325
3326
3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-securityagent/types.rb', line 3325

class PentestSummary < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the pentest was created, in UTC format.

Returns:

  • (Time)


3325
3326
3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-securityagent/types.rb', line 3325

class PentestSummary < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest.

Returns:

  • (String)


3325
3326
3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-securityagent/types.rb', line 3325

class PentestSummary < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the pentest.

Returns:

  • (String)


3325
3326
3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-securityagent/types.rb', line 3325

class PentestSummary < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the pentest was last updated, in UTC format.

Returns:

  • (Time)


3325
3326
3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-securityagent/types.rb', line 3325

class PentestSummary < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end