Class: Aws::SecurityAgent::Types::PrivateConnectionMode
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::PrivateConnectionMode
- Includes:
- Aws::Structure, Aws::Structure::Union
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
PrivateConnectionMode is a union - when making an API calls you must set exactly one of the members.
The configuration for a private connection. Specify either a service-managed or a self-managed mode.
Direct Known Subclasses
Defined Under Namespace
Classes: SelfManaged, ServiceManaged, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#self_managed ⇒ Types::SelfManagedInput
The configuration for a self-managed private connection, where you manage your own resource configuration.
-
#service_managed ⇒ Types::ServiceManagedInput
The configuration for a service-managed private connection, where the service manages the resource gateway lifecycle.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#self_managed ⇒ Types::SelfManagedInput
The configuration for a self-managed private connection, where you manage your own resource configuration.
6364 6365 6366 6367 6368 6369 6370 6371 6372 6373 6374 6375 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6364 class PrivateConnectionMode < Struct.new( :service_managed, :self_managed, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ServiceManaged < PrivateConnectionMode; end class SelfManaged < PrivateConnectionMode; end class Unknown < PrivateConnectionMode; end end |
#service_managed ⇒ Types::ServiceManagedInput
The configuration for a service-managed private connection, where the service manages the resource gateway lifecycle.
6364 6365 6366 6367 6368 6369 6370 6371 6372 6373 6374 6375 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6364 class PrivateConnectionMode < Struct.new( :service_managed, :self_managed, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ServiceManaged < PrivateConnectionMode; end class SelfManaged < PrivateConnectionMode; end class Unknown < PrivateConnectionMode; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6364 6365 6366 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6364 def unknown @unknown end |