Class: Aws::SecurityAgent::Types::ReportDestination
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ReportDestination
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Destination for publishing scan reports to an integrated document provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_id ⇒ String
The container identifier where the report will be published.
-
#document_id ⇒ String
The existing document identifier to update instead of creating a new document.
-
#integration_id ⇒ String
The integration identifier for the document provider.
-
#parent_id ⇒ String
The parent document identifier under which the report will be created.
Instance Attribute Details
#container_id ⇒ String
The container identifier where the report will be published.
6550 6551 6552 6553 6554 6555 6556 6557 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6550 class ReportDestination < Struct.new( :integration_id, :container_id, :parent_id, :document_id) SENSITIVE = [] include Aws::Structure end |
#document_id ⇒ String
The existing document identifier to update instead of creating a new document.
6550 6551 6552 6553 6554 6555 6556 6557 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6550 class ReportDestination < Struct.new( :integration_id, :container_id, :parent_id, :document_id) SENSITIVE = [] include Aws::Structure end |
#integration_id ⇒ String
The integration identifier for the document provider.
6550 6551 6552 6553 6554 6555 6556 6557 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6550 class ReportDestination < Struct.new( :integration_id, :container_id, :parent_id, :document_id) SENSITIVE = [] include Aws::Structure end |
#parent_id ⇒ String
The parent document identifier under which the report will be created.
6550 6551 6552 6553 6554 6555 6556 6557 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6550 class ReportDestination < Struct.new( :integration_id, :container_id, :parent_id, :document_id) SENSITIVE = [] include Aws::Structure end |