Class: Aws::SecurityAgent::Types::ResourceNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ResourceNotFoundException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
The specified resource was not found. Verify that the resource identifier is correct and that the resource exists in the specified agent space or account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Error description.
Instance Attribute Details
#message ⇒ String
Error description.
3392 3393 3394 3395 3396 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3392 class ResourceNotFoundException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |