Class: Aws::SecurityAgent::Types::SecurityRequirementPackSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a security requirement pack.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time the security requirement pack was created, in UTC format.

Returns:

  • (Time)


6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
# File 'lib/aws-sdk-securityagent/types.rb', line 6639

class SecurityRequirementPackSummary < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the security requirement pack.

Returns:

  • (String)


6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
# File 'lib/aws-sdk-securityagent/types.rb', line 6639

class SecurityRequirementPackSummary < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#management_typeString

The management type of the pack.

Returns:

  • (String)


6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
# File 'lib/aws-sdk-securityagent/types.rb', line 6639

class SecurityRequirementPackSummary < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the security requirement pack.

Returns:

  • (String)


6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
# File 'lib/aws-sdk-securityagent/types.rb', line 6639

class SecurityRequirementPackSummary < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pack_idString

The unique identifier of the security requirement pack.

Returns:

  • (String)


6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
# File 'lib/aws-sdk-securityagent/types.rb', line 6639

class SecurityRequirementPackSummary < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the security requirement pack.

Returns:

  • (String)


6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
# File 'lib/aws-sdk-securityagent/types.rb', line 6639

class SecurityRequirementPackSummary < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the security requirement pack was last updated, in UTC format.

Returns:

  • (Time)


6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
# File 'lib/aws-sdk-securityagent/types.rb', line 6639

class SecurityRequirementPackSummary < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_nameString

The vendor name for AWS managed packs.

Returns:

  • (String)


6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
# File 'lib/aws-sdk-securityagent/types.rb', line 6639

class SecurityRequirementPackSummary < Struct.new(
  :pack_id,
  :name,
  :description,
  :vendor_name,
  :management_type,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end