Class: Aws::SecurityAgent::Types::ServiceManagedInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ServiceManagedInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
The configuration for a service-managed private connection.
Constant Summary collapse
- SENSITIVE =
[:certificate]
Instance Attribute Summary collapse
-
#certificate ⇒ String
The certificate for the private connection.
-
#dns_resolution ⇒ String
The DNS resolution mode for the resource gateway.
-
#host_address ⇒ String
The IP address or DNS name of the target resource.
-
#ip_address_type ⇒ String
The IP address type of the service-managed resource gateway.
-
#ipv4_addresses_per_eni ⇒ Integer
The number of IPv4 addresses in each elastic network interface for the service-managed resource gateway.
-
#port_ranges ⇒ Array<String>
The TCP port ranges that a consumer can use to access the resource.
-
#security_group_ids ⇒ Array<String>
The security groups to attach to the service-managed resource gateway.
-
#subnet_ids ⇒ Array<String>
The subnets that the service-managed resource gateway spans.
-
#vpc_id ⇒ String
The VPC to create the service-managed resource gateway in.
Instance Attribute Details
#certificate ⇒ String
The certificate for the private connection.
6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 6761 6762 6763 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6751 class ServiceManagedInput < Struct.new( :host_address, :vpc_id, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :port_ranges, :certificate, :dns_resolution) SENSITIVE = [:certificate] include Aws::Structure end |
#dns_resolution ⇒ String
The DNS resolution mode for the resource gateway. Defaults to PUBLIC when not set.
6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 6761 6762 6763 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6751 class ServiceManagedInput < Struct.new( :host_address, :vpc_id, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :port_ranges, :certificate, :dns_resolution) SENSITIVE = [:certificate] include Aws::Structure end |
#host_address ⇒ String
The IP address or DNS name of the target resource.
6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 6761 6762 6763 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6751 class ServiceManagedInput < Struct.new( :host_address, :vpc_id, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :port_ranges, :certificate, :dns_resolution) SENSITIVE = [:certificate] include Aws::Structure end |
#ip_address_type ⇒ String
The IP address type of the service-managed resource gateway.
6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 6761 6762 6763 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6751 class ServiceManagedInput < Struct.new( :host_address, :vpc_id, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :port_ranges, :certificate, :dns_resolution) SENSITIVE = [:certificate] include Aws::Structure end |
#ipv4_addresses_per_eni ⇒ Integer
The number of IPv4 addresses in each elastic network interface for the service-managed resource gateway.
6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 6761 6762 6763 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6751 class ServiceManagedInput < Struct.new( :host_address, :vpc_id, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :port_ranges, :certificate, :dns_resolution) SENSITIVE = [:certificate] include Aws::Structure end |
#port_ranges ⇒ Array<String>
The TCP port ranges that a consumer can use to access the resource.
6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 6761 6762 6763 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6751 class ServiceManagedInput < Struct.new( :host_address, :vpc_id, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :port_ranges, :certificate, :dns_resolution) SENSITIVE = [:certificate] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The security groups to attach to the service-managed resource gateway.
6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 6761 6762 6763 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6751 class ServiceManagedInput < Struct.new( :host_address, :vpc_id, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :port_ranges, :certificate, :dns_resolution) SENSITIVE = [:certificate] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The subnets that the service-managed resource gateway spans.
6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 6761 6762 6763 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6751 class ServiceManagedInput < Struct.new( :host_address, :vpc_id, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :port_ranges, :certificate, :dns_resolution) SENSITIVE = [:certificate] include Aws::Structure end |
#vpc_id ⇒ String
The VPC to create the service-managed resource gateway in.
6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 6761 6762 6763 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6751 class ServiceManagedInput < Struct.new( :host_address, :vpc_id, :subnet_ids, :security_group_ids, :ip_address_type, :ipv4_addresses_per_eni, :port_ranges, :certificate, :dns_resolution) SENSITIVE = [:certificate] include Aws::Structure end |