Class: Aws::SecurityAgent::Types::StartCodeRemediationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::StartCodeRemediationInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for the StartCodeRemediation operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#finding_ids ⇒ Array<String>
The list of finding identifiers to initiate code remediation for.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job that produced the findings.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3429 class StartCodeRemediationInput < Struct.new( :agent_space_id, :pentest_job_id, :finding_ids) SENSITIVE = [] include Aws::Structure end |
#finding_ids ⇒ Array<String>
The list of finding identifiers to initiate code remediation for.
3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3429 class StartCodeRemediationInput < Struct.new( :agent_space_id, :pentest_job_id, :finding_ids) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job that produced the findings.
3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3429 class StartCodeRemediationInput < Struct.new( :agent_space_id, :pentest_job_id, :finding_ids) SENSITIVE = [] include Aws::Structure end |