Class: Aws::SecurityAgent::Types::StartCodeReviewJobInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for starting the execution of a code review.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


6848
6849
6850
6851
6852
6853
6854
# File 'lib/aws-sdk-securityagent/types.rb', line 6848

class StartCodeReviewJobInput < Struct.new(
  :agent_space_id,
  :code_review_id,
  :diff_source)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_idString

The unique identifier of the code review to start a job for.

Returns:

  • (String)


6848
6849
6850
6851
6852
6853
6854
# File 'lib/aws-sdk-securityagent/types.rb', line 6848

class StartCodeReviewJobInput < Struct.new(
  :agent_space_id,
  :code_review_id,
  :diff_source)
  SENSITIVE = []
  include Aws::Structure
end

#diff_sourceTypes::DiffSource

Source of the diff for a differential scan. When present, the job analyzes only the changed lines instead of performing a full scan.

Returns:



6848
6849
6850
6851
6852
6853
6854
# File 'lib/aws-sdk-securityagent/types.rb', line 6848

class StartCodeReviewJobInput < Struct.new(
  :agent_space_id,
  :code_review_id,
  :diff_source)
  SENSITIVE = []
  include Aws::Structure
end