Class: Aws::SecurityAgent::Types::StartCodeReviewJobInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::StartCodeReviewJobInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for starting the execution of a code review.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#code_review_id ⇒ String
The unique identifier of the code review to start a job for.
-
#diff_source ⇒ Types::DiffSource
Source of the diff for a differential scan.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6848 class StartCodeReviewJobInput < Struct.new( :agent_space_id, :code_review_id, :diff_source) SENSITIVE = [] include Aws::Structure end |
#code_review_id ⇒ String
The unique identifier of the code review to start a job for.
6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6848 class StartCodeReviewJobInput < Struct.new( :agent_space_id, :code_review_id, :diff_source) SENSITIVE = [] include Aws::Structure end |
#diff_source ⇒ Types::DiffSource
Source of the diff for a differential scan. When present, the job analyzes only the changed lines instead of performing a full scan.
6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-securityagent/types.rb', line 6848 class StartCodeReviewJobInput < Struct.new( :agent_space_id, :code_review_id, :diff_source) SENSITIVE = [] include Aws::Structure end |