Class: Aws::SecurityAgent::Types::StartPentestJobInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for starting the execution of a pentest.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-securityagent/types.rb', line 7013

class StartPentestJobInput < Struct.new(
  :agent_space_id,
  :pentest_id,
  :job_type,
  :selected_finding_ids)
  SENSITIVE = []
  include Aws::Structure
end

#job_typeString

The type of pentest job to start. Valid values are FULL and REVALIDATION. When set to REVALIDATION, the selectedFindingIds parameter is required.

Returns:

  • (String)


7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-securityagent/types.rb', line 7013

class StartPentestJobInput < Struct.new(
  :agent_space_id,
  :pentest_id,
  :job_type,
  :selected_finding_ids)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest to start a job for.

Returns:

  • (String)


7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-securityagent/types.rb', line 7013

class StartPentestJobInput < Struct.new(
  :agent_space_id,
  :pentest_id,
  :job_type,
  :selected_finding_ids)
  SENSITIVE = []
  include Aws::Structure
end

#selected_finding_idsArray<String>

The list of finding identifiers to revalidate. Required when jobType is REVALIDATION. Each finding must belong to the same agent space and pentest.

Returns:

  • (Array<String>)


7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-securityagent/types.rb', line 7013

class StartPentestJobInput < Struct.new(
  :agent_space_id,
  :pentest_id,
  :job_type,
  :selected_finding_ids)
  SENSITIVE = []
  include Aws::Structure
end