Class: Aws::SecurityAgent::Types::StartPentestJobInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::StartPentestJobInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for starting the execution of a pentest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#job_type ⇒ String
The type of pentest job to start.
-
#pentest_id ⇒ String
The unique identifier of the pentest to start a job for.
-
#selected_finding_ids ⇒ Array<String>
The list of finding identifiers to revalidate.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
7013 7014 7015 7016 7017 7018 7019 7020 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7013 class StartPentestJobInput < Struct.new( :agent_space_id, :pentest_id, :job_type, :selected_finding_ids) SENSITIVE = [] include Aws::Structure end |
#job_type ⇒ String
The type of pentest job to start. Valid values are FULL and REVALIDATION. When set to REVALIDATION, the selectedFindingIds parameter is required.
7013 7014 7015 7016 7017 7018 7019 7020 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7013 class StartPentestJobInput < Struct.new( :agent_space_id, :pentest_id, :job_type, :selected_finding_ids) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest to start a job for.
7013 7014 7015 7016 7017 7018 7019 7020 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7013 class StartPentestJobInput < Struct.new( :agent_space_id, :pentest_id, :job_type, :selected_finding_ids) SENSITIVE = [] include Aws::Structure end |
#selected_finding_ids ⇒ Array<String>
The list of finding identifiers to revalidate. Required when jobType is REVALIDATION. Each finding must belong to the same agent space and pentest.
7013 7014 7015 7016 7017 7018 7019 7020 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7013 class StartPentestJobInput < Struct.new( :agent_space_id, :pentest_id, :job_type, :selected_finding_ids) SENSITIVE = [] include Aws::Structure end |