Class: Aws::SecurityAgent::Types::StartPentestJobInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::StartPentestJobInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for starting the execution of a pentest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#pentest_id ⇒ String
The unique identifier of the pentest to start a job for.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
3455 3456 3457 3458 3459 3460 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3455 class StartPentestJobInput < Struct.new( :agent_space_id, :pentest_id) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest to start a job for.
3455 3456 3457 3458 3459 3460 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3455 class StartPentestJobInput < Struct.new( :agent_space_id, :pentest_id) SENSITIVE = [] include Aws::Structure end |