Class: Aws::SecurityAgent::Types::StartPentestJobOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the StartPentestJob operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-securityagent/types.rb', line 3494

class StartPentestJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the pentest job was created, in UTC format.

Returns:

  • (Time)


3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-securityagent/types.rb', line 3494

class StartPentestJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest.

Returns:

  • (String)


3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-securityagent/types.rb', line 3494

class StartPentestJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the started pentest job.

Returns:

  • (String)


3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-securityagent/types.rb', line 3494

class StartPentestJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the pentest job.

Returns:

  • (String)


3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-securityagent/types.rb', line 3494

class StartPentestJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the pentest job.

Returns:

  • (String)


3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-securityagent/types.rb', line 3494

class StartPentestJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the pentest job was last updated, in UTC format.

Returns:

  • (Time)


3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-securityagent/types.rb', line 3494

class StartPentestJobOutput < Struct.new(
  :title,
  :status,
  :created_at,
  :updated_at,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id)
  SENSITIVE = []
  include Aws::Structure
end