Class: Aws::SecurityAgent::Types::StartPentestJobOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::StartPentestJobOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the StartPentestJob operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#created_at ⇒ Time
The date and time the pentest job was created, in UTC format.
-
#pentest_id ⇒ String
The unique identifier of the pentest.
-
#pentest_job_id ⇒ String
The unique identifier of the started pentest job.
-
#status ⇒ String
The current status of the pentest job.
-
#title ⇒ String
The title of the pentest job.
-
#updated_at ⇒ Time
The date and time the pentest job was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3494 class StartPentestJobOutput < Struct.new( :title, :status, :created_at, :updated_at, :pentest_id, :pentest_job_id, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the pentest job was created, in UTC format.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3494 class StartPentestJobOutput < Struct.new( :title, :status, :created_at, :updated_at, :pentest_id, :pentest_job_id, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3494 class StartPentestJobOutput < Struct.new( :title, :status, :created_at, :updated_at, :pentest_id, :pentest_job_id, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the started pentest job.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3494 class StartPentestJobOutput < Struct.new( :title, :status, :created_at, :updated_at, :pentest_id, :pentest_job_id, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the pentest job.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3494 class StartPentestJobOutput < Struct.new( :title, :status, :created_at, :updated_at, :pentest_id, :pentest_job_id, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the pentest job.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3494 class StartPentestJobOutput < Struct.new( :title, :status, :created_at, :updated_at, :pentest_id, :pentest_job_id, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the pentest job was last updated, in UTC format.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3494 class StartPentestJobOutput < Struct.new( :title, :status, :created_at, :updated_at, :pentest_id, :pentest_job_id, :agent_space_id) SENSITIVE = [] include Aws::Structure end |