Class: Aws::SecurityAgent::Types::StopPentestJobInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::StopPentestJobInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for stopping the execution of a pentest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job to stop.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
3549 3550 3551 3552 3553 3554 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3549 class StopPentestJobInput < Struct.new( :agent_space_id, :pentest_job_id) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job to stop.
3549 3550 3551 3552 3553 3554 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3549 class StopPentestJobInput < Struct.new( :agent_space_id, :pentest_job_id) SENSITIVE = [] include Aws::Structure end |