Class: Aws::SecurityAgent::Types::Task

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents an individual security test task within a pentest job. Each task targets a specific risk type or endpoint and executes independently.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#categoriesArray<Types::Category>

The list of categories assigned to the task.

Returns:



3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the task was created, in UTC format.

Returns:

  • (Time)


3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the task.

Returns:

  • (String)


3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_statusString

The current execution status of the task.

Returns:

  • (String)


3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#logs_locationTypes::LogLocation

The location of the task execution logs.

Returns:



3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest associated with the task.

Returns:

  • (String)


3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job that contains the task.

Returns:

  • (String)


3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#risk_typeString

The type of security risk the task is testing for.

Returns:

  • (String)


3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#target_endpointTypes::Endpoint

The target endpoint being tested by the task.

Returns:



3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The unique identifier of the task.

Returns:

  • (String)


3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the task.

Returns:

  • (String)


3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the task was last updated, in UTC format.

Returns:

  • (Time)


3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
# File 'lib/aws-sdk-securityagent/types.rb', line 3715

class Task < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :description,
  :categories,
  :risk_type,
  :target_endpoint,
  :execution_status,
  :logs_location,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end