Class: Aws::SecurityAgent::Types::Task
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::Task
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents an individual security test task within a pentest job. Each task targets a specific risk type or endpoint and executes independently.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#categories ⇒ Array<Types::Category>
The list of categories assigned to the task.
-
#created_at ⇒ Time
The date and time the task was created, in UTC format.
-
#description ⇒ String
A description of the task.
-
#execution_status ⇒ String
The current execution status of the task.
-
#logs_location ⇒ Types::LogLocation
The location of the task execution logs.
-
#pentest_id ⇒ String
The unique identifier of the pentest associated with the task.
-
#pentest_job_id ⇒ String
The unique identifier of the pentest job that contains the task.
-
#risk_type ⇒ String
The type of security risk the task is testing for.
-
#target_endpoint ⇒ Types::Endpoint
The target endpoint being tested by the task.
-
#task_id ⇒ String
The unique identifier of the task.
-
#title ⇒ String
The title of the task.
-
#updated_at ⇒ Time
The date and time the task was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#categories ⇒ Array<Types::Category>
The list of categories assigned to the task.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the task was created, in UTC format.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the task.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#execution_status ⇒ String
The current execution status of the task.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#logs_location ⇒ Types::LogLocation
The location of the task execution logs.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest associated with the task.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#pentest_job_id ⇒ String
The unique identifier of the pentest job that contains the task.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#risk_type ⇒ String
The type of security risk the task is testing for.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#target_endpoint ⇒ Types::Endpoint
The target endpoint being tested by the task.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the task.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the task was last updated, in UTC format.
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3715 class Task < Struct.new( :task_id, :pentest_id, :pentest_job_id, :agent_space_id, :title, :description, :categories, :risk_type, :target_endpoint, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |