Class: Aws::SecurityAgent::Types::TaskSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Contains summary information about a task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
# File 'lib/aws-sdk-securityagent/types.rb', line 3773

class TaskSummary < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :risk_type,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the task was created, in UTC format.

Returns:

  • (Time)


3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
# File 'lib/aws-sdk-securityagent/types.rb', line 3773

class TaskSummary < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :risk_type,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_statusString

The current execution status of the task.

Returns:

  • (String)


3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
# File 'lib/aws-sdk-securityagent/types.rb', line 3773

class TaskSummary < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :risk_type,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest associated with the task.

Returns:

  • (String)


3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
# File 'lib/aws-sdk-securityagent/types.rb', line 3773

class TaskSummary < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :risk_type,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_job_idString

The unique identifier of the pentest job that contains the task.

Returns:

  • (String)


3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
# File 'lib/aws-sdk-securityagent/types.rb', line 3773

class TaskSummary < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :risk_type,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#risk_typeString

The type of security risk the task is testing for.

Returns:

  • (String)


3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
# File 'lib/aws-sdk-securityagent/types.rb', line 3773

class TaskSummary < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :risk_type,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The unique identifier of the task.

Returns:

  • (String)


3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
# File 'lib/aws-sdk-securityagent/types.rb', line 3773

class TaskSummary < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :risk_type,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the task.

Returns:

  • (String)


3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
# File 'lib/aws-sdk-securityagent/types.rb', line 3773

class TaskSummary < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :risk_type,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the task was last updated, in UTC format.

Returns:

  • (Time)


3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
# File 'lib/aws-sdk-securityagent/types.rb', line 3773

class TaskSummary < Struct.new(
  :task_id,
  :pentest_id,
  :pentest_job_id,
  :agent_space_id,
  :title,
  :risk_type,
  :execution_status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end