Class: Aws::SecurityAgent::Types::Threat

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a threat identified during threat modeling.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anchorTypes::ThreatAnchorShape

The DFD element this threat is anchored to.



7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#commentsString

Optional customer comment on the threat.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the threat was created, in UTC format.

Returns:

  • (Time)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

Who created this threat.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#evidenceArray<Types::ThreatEvidenceShape>

The source code files supporting the threat.

Returns:



7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#impacted_assetsArray<String>

The specific assets affected by the threat.

Returns:

  • (Array<String>)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#impacted_goalArray<String>

The security goals affected by the threat.

Returns:

  • (Array<String>)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#prerequisitesString

The conditions required for the threat to be exploitable.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#recommendationString

The recommended mitigation guidance for this threat.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

The severity level of the threat.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statementString

The natural-language threat statement.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the threat.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#strideArray<String>

The STRIDE categories applicable to this threat.

Returns:

  • (Array<String>)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_actionString

What the threat source can do.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_idString

The unique identifier of the threat.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_impactString

The direct consequence of the threat action.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_job_idString

The unique identifier of the threat model job that produced the threat.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_sourceString

The actor or origin of the threat.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

A short title summarizing the threat.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the threat was last updated, in UTC format.

Returns:

  • (Time)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

Who last updated this threat.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
# File 'lib/aws-sdk-securityagent/types.rb', line 7562

class Threat < Struct.new(
  :threat_id,
  :threat_job_id,
  :title,
  :statement,
  :severity,
  :status,
  :comments,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :stride,
  :recommendation,
  :created_by,
  :updated_by,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end