Class: Aws::SecurityAgent::Types::ThreatModel

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a threat model configuration that defines the parameters for automated threat analysis, including target assets and logging configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the threat model.

Returns:

  • (String)


7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/aws-sdk-securityagent/types.rb', line 7592

class ThreatModel < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets included in the threat model.

Returns:



7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/aws-sdk-securityagent/types.rb', line 7592

class ThreatModel < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the threat model was created, in UTC format.

Returns:

  • (Time)


7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/aws-sdk-securityagent/types.rb', line 7592

class ThreatModel < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the application or system being threat modeled.

Returns:

  • (String)


7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/aws-sdk-securityagent/types.rb', line 7592

class ThreatModel < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the threat model.



7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/aws-sdk-securityagent/types.rb', line 7592

class ThreatModel < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#scope_docsArray<Types::DocumentInfo>

The scoped documents for the agent to focus on during threat modeling.

Returns:



7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/aws-sdk-securityagent/types.rb', line 7592

class ThreatModel < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the threat model.

Returns:

  • (String)


7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/aws-sdk-securityagent/types.rb', line 7592

class ThreatModel < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_idString

The unique identifier of the threat model.

Returns:

  • (String)


7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/aws-sdk-securityagent/types.rb', line 7592

class ThreatModel < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the threat model.

Returns:

  • (String)


7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/aws-sdk-securityagent/types.rb', line 7592

class ThreatModel < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the threat model was last updated, in UTC format.

Returns:

  • (Time)


7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
# File 'lib/aws-sdk-securityagent/types.rb', line 7592

class ThreatModel < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end