Class: Aws::SecurityAgent::Types::ThreatModelJob

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Represents a threat model job, which is an execution instance of a threat model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the threat model job was created, in UTC format.

Returns:

  • (Time)


7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#documentsArray<Types::DocumentInfo>

The list of documents used for threat modeling.

Returns:



7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#error_informationTypes::ErrorInformation

Error information if the threat model job encountered an error.



7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#execution_end_timeTime

The date and time the threat model job execution ended, in UTC format.

Returns:

  • (Time)


7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#execution_start_timeTime

The date and time the threat model job execution started, in UTC format.

Returns:

  • (Time)


7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#integrated_repositoriesArray<Types::IntegratedRepository>

The list of integrated repositories used for threat modeling.

Returns:



7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#scope_docsArray<Types::DocumentInfo>

The scoped documents for the agent to focus on during threat modeling.

Returns:



7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#source_codeArray<Types::SourceCodeRepository>

The list of source code repositories used for threat modeling.

Returns:



7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the threat model job.

Returns:

  • (String)


7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#system_overviewString

The system overview generated during threat modeling.

Returns:

  • (String)


7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_idString

The unique identifier of the threat model associated with the job.

Returns:

  • (String)


7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_job_idString

The unique identifier of the threat model job.

Returns:

  • (String)


7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the threat model job.

Returns:

  • (String)


7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the threat model job was last updated, in UTC format.

Returns:

  • (Time)


7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/aws-sdk-securityagent/types.rb', line 7649

class ThreatModelJob < Struct.new(
  :threat_model_job_id,
  :threat_model_id,
  :agent_space_id,
  :title,
  :status,
  :created_at,
  :updated_at,
  :execution_start_time,
  :execution_end_time,
  :source_code,
  :integrated_repositories,
  :documents,
  :scope_docs,
  :error_information,
  :system_overview)
  SENSITIVE = []
  include Aws::Structure
end