Class: Aws::SecurityAgent::Types::ThreatModelJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ThreatModelJobSummary
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains summary information about a threat model job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#created_at ⇒ Time
The date and time the threat model job was created, in UTC format.
-
#status ⇒ String
The current status of the threat model job.
-
#threat_model_id ⇒ String
The unique identifier of the threat model associated with the job.
-
#threat_model_job_id ⇒ String
The unique identifier of the threat model job.
-
#title ⇒ String
The title of the threat model job.
-
#updated_at ⇒ Time
The date and time the threat model job was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7702 class ThreatModelJobSummary < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the threat model job was created, in UTC format.
7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7702 class ThreatModelJobSummary < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the threat model job.
7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7702 class ThreatModelJobSummary < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_model_id ⇒ String
The unique identifier of the threat model associated with the job.
7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7702 class ThreatModelJobSummary < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_model_job_id ⇒ String
The unique identifier of the threat model job.
7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7702 class ThreatModelJobSummary < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the threat model job.
7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7702 class ThreatModelJobSummary < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the threat model job was last updated, in UTC format.
7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7702 class ThreatModelJobSummary < Struct.new( :threat_model_job_id, :threat_model_id, :agent_space_id, :title, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |