Class: Aws::SecurityAgent::Types::ThreatModelJobTask
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::ThreatModelJobTask
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Represents an individual task within a threat model job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space.
-
#created_at ⇒ Time
The date and time the task was created, in UTC format.
-
#description ⇒ String
A description of the task.
-
#execution_status ⇒ String
The current execution status of the task.
-
#logs_location ⇒ Types::LogLocation
The location of the task execution logs.
-
#task_id ⇒ String
The unique identifier of the task.
-
#threat_model_id ⇒ String
The unique identifier of the threat model associated with the task.
-
#threat_model_job_id ⇒ String
The unique identifier of the threat model job that contains the task.
-
#title ⇒ String
The title of the task.
-
#updated_at ⇒ Time
The date and time the task was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space.
7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7759 class ThreatModelJobTask < Struct.new( :task_id, :threat_model_id, :threat_model_job_id, :agent_space_id, :title, :description, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the task was created, in UTC format.
7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7759 class ThreatModelJobTask < Struct.new( :task_id, :threat_model_id, :threat_model_job_id, :agent_space_id, :title, :description, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the task.
7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7759 class ThreatModelJobTask < Struct.new( :task_id, :threat_model_id, :threat_model_job_id, :agent_space_id, :title, :description, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#execution_status ⇒ String
The current execution status of the task.
7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7759 class ThreatModelJobTask < Struct.new( :task_id, :threat_model_id, :threat_model_job_id, :agent_space_id, :title, :description, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#logs_location ⇒ Types::LogLocation
The location of the task execution logs.
7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7759 class ThreatModelJobTask < Struct.new( :task_id, :threat_model_id, :threat_model_job_id, :agent_space_id, :title, :description, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task.
7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7759 class ThreatModelJobTask < Struct.new( :task_id, :threat_model_id, :threat_model_job_id, :agent_space_id, :title, :description, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_model_id ⇒ String
The unique identifier of the threat model associated with the task.
7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7759 class ThreatModelJobTask < Struct.new( :task_id, :threat_model_id, :threat_model_job_id, :agent_space_id, :title, :description, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_model_job_id ⇒ String
The unique identifier of the threat model job that contains the task.
7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7759 class ThreatModelJobTask < Struct.new( :task_id, :threat_model_id, :threat_model_job_id, :agent_space_id, :title, :description, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the task.
7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7759 class ThreatModelJobTask < Struct.new( :task_id, :threat_model_id, :threat_model_job_id, :agent_space_id, :title, :description, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the task was last updated, in UTC format.
7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-securityagent/types.rb', line 7759 class ThreatModelJobTask < Struct.new( :task_id, :threat_model_id, :threat_model_job_id, :agent_space_id, :title, :description, :execution_status, :logs_location, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |