Class: Aws::SecurityAgent::Types::UpdateAgentSpaceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateAgentSpaceInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for updating an agent space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space to update.
-
#aws_resources ⇒ Types::AWSResources
The updated AWS resources to associate with the agent space.
-
#code_review_settings ⇒ Types::CodeReviewSettings
The updated code review settings for the agent space.
-
#description ⇒ String
The updated description of the agent space.
-
#name ⇒ String
The updated name of the agent space.
-
#target_domain_ids ⇒ Array<String>
The updated list of target domain identifiers to associate with the agent space.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space to update.
3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3865 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |
#aws_resources ⇒ Types::AWSResources
The updated AWS resources to associate with the agent space.
3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3865 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |
#code_review_settings ⇒ Types::CodeReviewSettings
The updated code review settings for the agent space.
3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3865 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The updated description of the agent space.
3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3865 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated name of the agent space.
3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3865 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |
#target_domain_ids ⇒ Array<String>
The updated list of target domain identifiers to associate with the agent space.
3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3865 class UpdateAgentSpaceInput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings) SENSITIVE = [] include Aws::Structure end |