Class: Aws::SecurityAgent::Types::UpdateAgentSpaceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateAgentSpaceOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the UpdateAgentSpace operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the updated agent space.
-
#aws_resources ⇒ Types::AWSResources
The AWS resources associated with the agent space.
-
#code_review_settings ⇒ Types::CodeReviewSettings
The code review settings for the agent space.
-
#created_at ⇒ Time
The date and time the agent space was created, in UTC format.
-
#description ⇒ String
The description of the agent space.
-
#name ⇒ String
The name of the agent space.
-
#target_domain_ids ⇒ Array<String>
The list of target domain identifiers associated with the agent space.
-
#updated_at ⇒ Time
The date and time the agent space was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the updated agent space.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3913 class UpdateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#aws_resources ⇒ Types::AWSResources
The AWS resources associated with the agent space.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3913 class UpdateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#code_review_settings ⇒ Types::CodeReviewSettings
The code review settings for the agent space.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3913 class UpdateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the agent space was created, in UTC format.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3913 class UpdateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the agent space.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3913 class UpdateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the agent space.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3913 class UpdateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#target_domain_ids ⇒ Array<String>
The list of target domain identifiers associated with the agent space.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3913 class UpdateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the agent space was last updated, in UTC format.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3913 class UpdateAgentSpaceOutput < Struct.new( :agent_space_id, :name, :description, :aws_resources, :target_domain_ids, :code_review_settings, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |