Class: Aws::SecurityAgent::Types::UpdateCodeReviewInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for updating an existing code review.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the code review.

Returns:

  • (String)


8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
# File 'lib/aws-sdk-securityagent/types.rb', line 8137

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The updated assets for the code review.

Returns:



8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
# File 'lib/aws-sdk-securityagent/types.rb', line 8137

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The updated code remediation strategy for the code review.

Returns:

  • (String)


8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
# File 'lib/aws-sdk-securityagent/types.rb', line 8137

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_idString

The unique identifier of the code review to update.

Returns:

  • (String)


8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
# File 'lib/aws-sdk-securityagent/types.rb', line 8137

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The updated CloudWatch Logs configuration for the code review.



8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
# File 'lib/aws-sdk-securityagent/types.rb', line 8137

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The updated IAM service role for the code review.

Returns:

  • (String)


8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
# File 'lib/aws-sdk-securityagent/types.rb', line 8137

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The updated title of the code review.

Returns:

  • (String)


8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
# File 'lib/aws-sdk-securityagent/types.rb', line 8137

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#validation_modeString

The updated validation mode for the code review. Valid values are SIMULATED and DISABLED.

Returns:

  • (String)


8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
# File 'lib/aws-sdk-securityagent/types.rb', line 8137

class UpdateCodeReviewInput < Struct.new(
  :code_review_id,
  :agent_space_id,
  :title,
  :assets,
  :service_role,
  :log_config,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end