Class: Aws::SecurityAgent::Types::UpdateCodeReviewInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateCodeReviewInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for updating an existing code review.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the code review.
-
#assets ⇒ Types::Assets
The updated assets for the code review.
-
#code_remediation_strategy ⇒ String
The updated code remediation strategy for the code review.
-
#code_review_id ⇒ String
The unique identifier of the code review to update.
-
#log_config ⇒ Types::CloudWatchLog
The updated CloudWatch Logs configuration for the code review.
-
#service_role ⇒ String
The updated IAM service role for the code review.
-
#title ⇒ String
The updated title of the code review.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the code review.
4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4955 class UpdateCodeReviewInput < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The updated assets for the code review.
4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4955 class UpdateCodeReviewInput < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The updated code remediation strategy for the code review.
4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4955 class UpdateCodeReviewInput < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#code_review_id ⇒ String
The unique identifier of the code review to update.
4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4955 class UpdateCodeReviewInput < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The updated CloudWatch Logs configuration for the code review.
4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4955 class UpdateCodeReviewInput < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The updated IAM service role for the code review.
4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4955 class UpdateCodeReviewInput < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The updated title of the code review.
4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4955 class UpdateCodeReviewInput < Struct.new( :code_review_id, :agent_space_id, :title, :assets, :service_role, :log_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |