Class: Aws::SecurityAgent::Types::UpdateCodeReviewOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the UpdateCodeReview operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the code review.

Returns:

  • (String)


8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
# File 'lib/aws-sdk-securityagent/types.rb', line 8195

class UpdateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets included in the code review.

Returns:



8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
# File 'lib/aws-sdk-securityagent/types.rb', line 8195

class UpdateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The code remediation strategy for the code review.

Returns:

  • (String)


8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
# File 'lib/aws-sdk-securityagent/types.rb', line 8195

class UpdateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#code_review_idString

The unique identifier of the code review.

Returns:

  • (String)


8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
# File 'lib/aws-sdk-securityagent/types.rb', line 8195

class UpdateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the code review was created, in UTC format.

Returns:

  • (Time)


8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
# File 'lib/aws-sdk-securityagent/types.rb', line 8195

class UpdateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the code review.



8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
# File 'lib/aws-sdk-securityagent/types.rb', line 8195

class UpdateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the code review.

Returns:

  • (String)


8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
# File 'lib/aws-sdk-securityagent/types.rb', line 8195

class UpdateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the code review.

Returns:

  • (String)


8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
# File 'lib/aws-sdk-securityagent/types.rb', line 8195

class UpdateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the code review was last updated, in UTC format.

Returns:

  • (Time)


8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
# File 'lib/aws-sdk-securityagent/types.rb', line 8195

class UpdateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end

#validation_modeString

The validation mode for the code review.

Returns:

  • (String)


8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
# File 'lib/aws-sdk-securityagent/types.rb', line 8195

class UpdateCodeReviewOutput < Struct.new(
  :code_review_id,
  :title,
  :created_at,
  :updated_at,
  :assets,
  :service_role,
  :log_config,
  :agent_space_id,
  :code_remediation_strategy,
  :validation_mode)
  SENSITIVE = []
  include Aws::Structure
end