Class: Aws::SecurityAgent::Types::UpdateFindingInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateFindingInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for updating an existing security finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the finding.
-
#finding_id ⇒ String
The unique identifier of the finding to update.
-
#risk_level ⇒ String
The updated risk level for the finding.
-
#status ⇒ String
The updated status for the finding.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the finding.
3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3982 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :risk_level, :status) SENSITIVE = [] include Aws::Structure end |
#finding_id ⇒ String
The unique identifier of the finding to update.
3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3982 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :risk_level, :status) SENSITIVE = [] include Aws::Structure end |
#risk_level ⇒ String
The updated risk level for the finding.
3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3982 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :risk_level, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The updated status for the finding.
3982 3983 3984 3985 3986 3987 3988 3989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 3982 class UpdateFindingInput < Struct.new( :finding_id, :agent_space_id, :risk_level, :status) SENSITIVE = [] include Aws::Structure end |