Class: Aws::SecurityAgent::Types::UpdatePentestInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for updating an existing pentest.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the pentest.

Returns:

  • (String)


8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The updated assets for the pentest.

Returns:



8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The updated code remediation strategy for the pentest.

Returns:

  • (String)


8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end

#disable_managed_skillsArray<String>

The updated list of managed skills to disable for this pentest. Valid values include FINDING_PERSONALIZATION and LOGIN_OPTIMIZATION.

Returns:

  • (Array<String>)


8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_risk_typesArray<String>

The updated list of risk types to exclude from the pentest.

Returns:

  • (Array<String>)


8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The updated CloudWatch Logs configuration for the pentest.



8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end

#network_traffic_configTypes::NetworkTrafficConfig

The updated network traffic configuration for the pentest.



8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest to update.

Returns:

  • (String)


8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The updated IAM service role for the pentest.

Returns:

  • (String)


8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The updated title of the pentest.

Returns:

  • (String)


8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

The updated VPC configuration for the pentest.

Returns:



8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
# File 'lib/aws-sdk-securityagent/types.rb', line 8356

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy,
  :disable_managed_skills)
  SENSITIVE = []
  include Aws::Structure
end