Class: Aws::SecurityAgent::Types::UpdatePentestInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for updating an existing pentest.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the pentest.

Returns:

  • (String)


4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
# File 'lib/aws-sdk-securityagent/types.rb', line 4067

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The updated assets for the pentest.

Returns:



4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
# File 'lib/aws-sdk-securityagent/types.rb', line 4067

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#code_remediation_strategyString

The updated code remediation strategy for the pentest.

Returns:

  • (String)


4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
# File 'lib/aws-sdk-securityagent/types.rb', line 4067

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#exclude_risk_typesArray<String>

The updated list of risk types to exclude from the pentest.

Returns:

  • (Array<String>)


4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
# File 'lib/aws-sdk-securityagent/types.rb', line 4067

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The updated CloudWatch Logs configuration for the pentest.



4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
# File 'lib/aws-sdk-securityagent/types.rb', line 4067

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#network_traffic_configTypes::NetworkTrafficConfig

The updated network traffic configuration for the pentest.



4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
# File 'lib/aws-sdk-securityagent/types.rb', line 4067

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#pentest_idString

The unique identifier of the pentest to update.

Returns:

  • (String)


4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
# File 'lib/aws-sdk-securityagent/types.rb', line 4067

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The updated IAM service role for the pentest.

Returns:

  • (String)


4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
# File 'lib/aws-sdk-securityagent/types.rb', line 4067

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The updated title of the pentest.

Returns:

  • (String)


4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
# File 'lib/aws-sdk-securityagent/types.rb', line 4067

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

The updated VPC configuration for the pentest.

Returns:



4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
# File 'lib/aws-sdk-securityagent/types.rb', line 4067

class UpdatePentestInput < Struct.new(
  :pentest_id,
  :agent_space_id,
  :title,
  :assets,
  :exclude_risk_types,
  :service_role,
  :log_config,
  :vpc_config,
  :network_traffic_config,
  :code_remediation_strategy)
  SENSITIVE = []
  include Aws::Structure
end