Class: Aws::SecurityAgent::Types::UpdatePentestInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdatePentestInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for updating an existing pentest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
-
#assets ⇒ Types::Assets
The updated assets for the pentest.
-
#code_remediation_strategy ⇒ String
The updated code remediation strategy for the pentest.
-
#exclude_risk_types ⇒ Array<String>
The updated list of risk types to exclude from the pentest.
-
#log_config ⇒ Types::CloudWatchLog
The updated CloudWatch Logs configuration for the pentest.
-
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The updated network traffic configuration for the pentest.
-
#pentest_id ⇒ String
The unique identifier of the pentest to update.
-
#service_role ⇒ String
The updated IAM service role for the pentest.
-
#title ⇒ String
The updated title of the pentest.
-
#vpc_config ⇒ Types::VpcConfig
The updated VPC configuration for the pentest.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4067 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The updated assets for the pentest.
4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4067 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#code_remediation_strategy ⇒ String
The updated code remediation strategy for the pentest.
4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4067 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#exclude_risk_types ⇒ Array<String>
The updated list of risk types to exclude from the pentest.
4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4067 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The updated CloudWatch Logs configuration for the pentest.
4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4067 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#network_traffic_config ⇒ Types::NetworkTrafficConfig
The updated network traffic configuration for the pentest.
4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4067 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest to update.
4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4067 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The updated IAM service role for the pentest.
4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4067 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The updated title of the pentest.
4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4067 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The updated VPC configuration for the pentest.
4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4067 class UpdatePentestInput < Struct.new( :pentest_id, :agent_space_id, :title, :assets, :exclude_risk_types, :service_role, :log_config, :vpc_config, :network_traffic_config, :code_remediation_strategy) SENSITIVE = [] include Aws::Structure end |