Class: Aws::SecurityAgent::Types::UpdatePentestOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdatePentestOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the UpdatePentest operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
-
#assets ⇒ Types::Assets
The assets included in the pentest.
-
#created_at ⇒ Time
The date and time the pentest was created, in UTC format.
-
#exclude_risk_types ⇒ Array<String>
The list of risk types excluded from the pentest.
-
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest.
-
#pentest_id ⇒ String
The unique identifier of the pentest.
-
#service_role ⇒ String
The IAM service role used for the pentest.
-
#title ⇒ String
The title of the pentest.
-
#updated_at ⇒ Time
The date and time the pentest was last updated, in UTC format.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the pentest.
4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4122 class UpdatePentestOutput < Struct.new( :pentest_id, :title, :created_at, :updated_at, :assets, :exclude_risk_types, :service_role, :log_config, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The assets included in the pentest.
4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4122 class UpdatePentestOutput < Struct.new( :pentest_id, :title, :created_at, :updated_at, :assets, :exclude_risk_types, :service_role, :log_config, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the pentest was created, in UTC format.
4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4122 class UpdatePentestOutput < Struct.new( :pentest_id, :title, :created_at, :updated_at, :assets, :exclude_risk_types, :service_role, :log_config, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#exclude_risk_types ⇒ Array<String>
The list of risk types excluded from the pentest.
4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4122 class UpdatePentestOutput < Struct.new( :pentest_id, :title, :created_at, :updated_at, :assets, :exclude_risk_types, :service_role, :log_config, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The CloudWatch Logs configuration for the pentest.
4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4122 class UpdatePentestOutput < Struct.new( :pentest_id, :title, :created_at, :updated_at, :assets, :exclude_risk_types, :service_role, :log_config, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#pentest_id ⇒ String
The unique identifier of the pentest.
4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4122 class UpdatePentestOutput < Struct.new( :pentest_id, :title, :created_at, :updated_at, :assets, :exclude_risk_types, :service_role, :log_config, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The IAM service role used for the pentest.
4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4122 class UpdatePentestOutput < Struct.new( :pentest_id, :title, :created_at, :updated_at, :assets, :exclude_risk_types, :service_role, :log_config, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the pentest.
4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4122 class UpdatePentestOutput < Struct.new( :pentest_id, :title, :created_at, :updated_at, :assets, :exclude_risk_types, :service_role, :log_config, :agent_space_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the pentest was last updated, in UTC format.
4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4122 class UpdatePentestOutput < Struct.new( :pentest_id, :title, :created_at, :updated_at, :assets, :exclude_risk_types, :service_role, :log_config, :agent_space_id) SENSITIVE = [] include Aws::Structure end |