Class: Aws::SecurityAgent::Types::UpdateSecurityRequirementEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateSecurityRequirementEntry
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains the details for updating an existing security requirement within a pack. The name is an immutable identifier used to locate the requirement and cannot be modified.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The updated description of the security requirement.
-
#domain ⇒ String
The updated security domain the requirement belongs to.
-
#evaluation ⇒ String
The updated evaluation criteria used to assess compliance with this requirement.
-
#name ⇒ String
The name of the security requirement to update.
-
#remediation ⇒ String
The updated remediation steps when the requirement is not met.
Instance Attribute Details
#description ⇒ String
The updated description of the security requirement.
8553 8554 8555 8556 8557 8558 8559 8560 8561 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8553 class UpdateSecurityRequirementEntry < Struct.new( :name, :description, :domain, :evaluation, :remediation) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The updated security domain the requirement belongs to.
8553 8554 8555 8556 8557 8558 8559 8560 8561 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8553 class UpdateSecurityRequirementEntry < Struct.new( :name, :description, :domain, :evaluation, :remediation) SENSITIVE = [] include Aws::Structure end |
#evaluation ⇒ String
The updated evaluation criteria used to assess compliance with this requirement.
8553 8554 8555 8556 8557 8558 8559 8560 8561 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8553 class UpdateSecurityRequirementEntry < Struct.new( :name, :description, :domain, :evaluation, :remediation) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the security requirement to update. This is an immutable identifier and cannot be changed once the requirement is created.
8553 8554 8555 8556 8557 8558 8559 8560 8561 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8553 class UpdateSecurityRequirementEntry < Struct.new( :name, :description, :domain, :evaluation, :remediation) SENSITIVE = [] include Aws::Structure end |
#remediation ⇒ String
The updated remediation steps when the requirement is not met.
8553 8554 8555 8556 8557 8558 8559 8560 8561 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8553 class UpdateSecurityRequirementEntry < Struct.new( :name, :description, :domain, :evaluation, :remediation) SENSITIVE = [] include Aws::Structure end |