Class: Aws::SecurityAgent::Types::UpdateSecurityRequirementEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateSecurityRequirementEntry
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Contains the details for updating an existing security requirement within a pack. The name is an immutable identifier used to locate the requirement and cannot be modified.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The updated description of the security requirement.
-
#domain ⇒ String
The updated security domain the requirement belongs to.
-
#evaluation ⇒ String
The updated evaluation criteria used to assess compliance with this requirement.
-
#name ⇒ String
The name of the security requirement to update.
-
#remediation ⇒ String
The updated remediation steps when the requirement is not met.
Instance Attribute Details
#description ⇒ String
The updated description of the security requirement.
8536 8537 8538 8539 8540 8541 8542 8543 8544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8536 class UpdateSecurityRequirementEntry < Struct.new( :name, :description, :domain, :evaluation, :remediation) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The updated security domain the requirement belongs to.
8536 8537 8538 8539 8540 8541 8542 8543 8544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8536 class UpdateSecurityRequirementEntry < Struct.new( :name, :description, :domain, :evaluation, :remediation) SENSITIVE = [] include Aws::Structure end |
#evaluation ⇒ String
The updated evaluation criteria used to assess compliance with this requirement.
8536 8537 8538 8539 8540 8541 8542 8543 8544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8536 class UpdateSecurityRequirementEntry < Struct.new( :name, :description, :domain, :evaluation, :remediation) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the security requirement to update. This is an immutable identifier and cannot be changed once the requirement is created.
8536 8537 8538 8539 8540 8541 8542 8543 8544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8536 class UpdateSecurityRequirementEntry < Struct.new( :name, :description, :domain, :evaluation, :remediation) SENSITIVE = [] include Aws::Structure end |
#remediation ⇒ String
The updated remediation steps when the requirement is not met.
8536 8537 8538 8539 8540 8541 8542 8543 8544 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8536 class UpdateSecurityRequirementEntry < Struct.new( :name, :description, :domain, :evaluation, :remediation) SENSITIVE = [] include Aws::Structure end |