Class: Aws::SecurityAgent::Types::UpdateThreatInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for updating an existing threat.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#anchorTypes::ThreatAnchorShape

The updated DFD element this threat is anchored to.



8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#commentsString

Optional customer comment.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#evidenceArray<Types::ThreatEvidenceShape>

The updated source code files supporting the threat.

Returns:



8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#impacted_assetsArray<String>

The updated list of specific assets affected by the threat.

Returns:

  • (Array<String>)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#impacted_goalArray<String>

The updated security goals affected by the threat.

Returns:

  • (Array<String>)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#prerequisitesString

The updated conditions required for the threat to be exploitable.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#recommendationString

The updated recommended mitigation guidance for this threat.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

The updated severity level of the threat.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#statementString

The updated natural-language threat statement.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The updated status of the threat.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#threat_actionString

The updated description of what the threat source can do.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#threat_idString

The unique identifier of the threat to update.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#threat_impactString

The updated direct consequence of the threat action.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#threat_sourceString

The updated actor or origin of the threat.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

A short title summarizing the threat.

Returns:

  • (String)


8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
# File 'lib/aws-sdk-securityagent/types.rb', line 8731

class UpdateThreatInput < Struct.new(
  :threat_id,
  :agent_space_id,
  :title,
  :status,
  :comments,
  :statement,
  :severity,
  :threat_source,
  :prerequisites,
  :threat_action,
  :threat_impact,
  :impacted_goal,
  :impacted_assets,
  :anchor,
  :evidence,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end