Class: Aws::SecurityAgent::Types::UpdateThreatModelInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Input for updating an existing threat model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the threat model.

Returns:

  • (String)


8791
8792
8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
# File 'lib/aws-sdk-securityagent/types.rb', line 8791

class UpdateThreatModelInput < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The updated assets for the threat model.

Returns:



8791
8792
8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
# File 'lib/aws-sdk-securityagent/types.rb', line 8791

class UpdateThreatModelInput < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The updated description of the application or system being threat modeled.

Returns:

  • (String)


8791
8792
8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
# File 'lib/aws-sdk-securityagent/types.rb', line 8791

class UpdateThreatModelInput < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The updated CloudWatch Logs configuration for the threat model.



8791
8792
8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
# File 'lib/aws-sdk-securityagent/types.rb', line 8791

class UpdateThreatModelInput < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config)
  SENSITIVE = []
  include Aws::Structure
end

#scope_docsArray<Types::DocumentInfo>

The updated scoped documents for the agent to focus on during threat modeling.

Returns:



8791
8792
8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
# File 'lib/aws-sdk-securityagent/types.rb', line 8791

class UpdateThreatModelInput < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The updated IAM service role for the threat model.

Returns:

  • (String)


8791
8792
8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
# File 'lib/aws-sdk-securityagent/types.rb', line 8791

class UpdateThreatModelInput < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_idString

The unique identifier of the threat model to update.

Returns:

  • (String)


8791
8792
8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
# File 'lib/aws-sdk-securityagent/types.rb', line 8791

class UpdateThreatModelInput < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The updated title of the threat model.

Returns:

  • (String)


8791
8792
8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
# File 'lib/aws-sdk-securityagent/types.rb', line 8791

class UpdateThreatModelInput < Struct.new(
  :threat_model_id,
  :agent_space_id,
  :title,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config)
  SENSITIVE = []
  include Aws::Structure
end