Class: Aws::SecurityAgent::Types::UpdateThreatModelInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateThreatModelInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for updating an existing threat model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the threat model.
-
#assets ⇒ Types::Assets
The updated assets for the threat model.
-
#description ⇒ String
The updated description of the application or system being threat modeled.
-
#log_config ⇒ Types::CloudWatchLog
The updated CloudWatch Logs configuration for the threat model.
-
#scope_docs ⇒ Array<Types::DocumentInfo>
The updated scoped documents for the agent to focus on during threat modeling.
-
#service_role ⇒ String
The updated IAM service role for the threat model.
-
#threat_model_id ⇒ String
The unique identifier of the threat model to update.
-
#title ⇒ String
The updated title of the threat model.
Instance Attribute Details
#agent_space_id ⇒ String
The unique identifier of the agent space that contains the threat model.
8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8791 class UpdateThreatModelInput < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config) SENSITIVE = [] include Aws::Structure end |
#assets ⇒ Types::Assets
The updated assets for the threat model.
8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8791 class UpdateThreatModelInput < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The updated description of the application or system being threat modeled.
8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8791 class UpdateThreatModelInput < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config) SENSITIVE = [] include Aws::Structure end |
#log_config ⇒ Types::CloudWatchLog
The updated CloudWatch Logs configuration for the threat model.
8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8791 class UpdateThreatModelInput < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config) SENSITIVE = [] include Aws::Structure end |
#scope_docs ⇒ Array<Types::DocumentInfo>
The updated scoped documents for the agent to focus on during threat modeling.
8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8791 class UpdateThreatModelInput < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The updated IAM service role for the threat model.
8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8791 class UpdateThreatModelInput < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config) SENSITIVE = [] include Aws::Structure end |
#threat_model_id ⇒ String
The unique identifier of the threat model to update.
8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8791 class UpdateThreatModelInput < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The updated title of the threat model.
8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8791 class UpdateThreatModelInput < Struct.new( :threat_model_id, :agent_space_id, :title, :description, :assets, :scope_docs, :service_role, :log_config) SENSITIVE = [] include Aws::Structure end |