Class: Aws::SecurityAgent::Types::UpdateThreatModelOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-securityagent/types.rb

Overview

Output for the UpdateThreatModel operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_space_idString

The unique identifier of the agent space that contains the threat model.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
# File 'lib/aws-sdk-securityagent/types.rb', line 8850

class UpdateThreatModelOutput < Struct.new(
  :threat_model_id,
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#assetsTypes::Assets

The assets included in the threat model.

Returns:



8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
# File 'lib/aws-sdk-securityagent/types.rb', line 8850

class UpdateThreatModelOutput < Struct.new(
  :threat_model_id,
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the threat model was created, in UTC format.

Returns:

  • (Time)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
# File 'lib/aws-sdk-securityagent/types.rb', line 8850

class UpdateThreatModelOutput < Struct.new(
  :threat_model_id,
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the application or system being threat modeled.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
# File 'lib/aws-sdk-securityagent/types.rb', line 8850

class UpdateThreatModelOutput < Struct.new(
  :threat_model_id,
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#log_configTypes::CloudWatchLog

The CloudWatch Logs configuration for the threat model.



8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
# File 'lib/aws-sdk-securityagent/types.rb', line 8850

class UpdateThreatModelOutput < Struct.new(
  :threat_model_id,
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#scope_docsArray<Types::DocumentInfo>

The scoped documents for the agent to focus on during threat modeling.

Returns:



8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
# File 'lib/aws-sdk-securityagent/types.rb', line 8850

class UpdateThreatModelOutput < Struct.new(
  :threat_model_id,
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The IAM service role used for the threat model.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
# File 'lib/aws-sdk-securityagent/types.rb', line 8850

class UpdateThreatModelOutput < Struct.new(
  :threat_model_id,
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#threat_model_idString

The unique identifier of the threat model.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
# File 'lib/aws-sdk-securityagent/types.rb', line 8850

class UpdateThreatModelOutput < Struct.new(
  :threat_model_id,
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the threat model.

Returns:

  • (String)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
# File 'lib/aws-sdk-securityagent/types.rb', line 8850

class UpdateThreatModelOutput < Struct.new(
  :threat_model_id,
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the threat model was last updated, in UTC format.

Returns:

  • (Time)


8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
# File 'lib/aws-sdk-securityagent/types.rb', line 8850

class UpdateThreatModelOutput < Struct.new(
  :threat_model_id,
  :title,
  :agent_space_id,
  :description,
  :assets,
  :scope_docs,
  :service_role,
  :log_config,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end