Class: Aws::SecurityAgent::Types::UpdateThreatOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UpdateThreatOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Output for the UpdateThreat operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anchor ⇒ Types::ThreatAnchorShape
The DFD element this threat is anchored to.
-
#comments ⇒ String
Optional customer comment on the threat.
-
#created_at ⇒ Time
The date and time the threat was created, in UTC format.
-
#created_by ⇒ String
Who created this threat.
-
#evidence ⇒ Array<Types::ThreatEvidenceShape>
The source code files supporting the threat.
-
#impacted_assets ⇒ Array<String>
The specific assets affected by the threat.
-
#impacted_goal ⇒ Array<String>
The security goals affected by the threat.
-
#prerequisites ⇒ String
The conditions required for the threat to be exploitable.
-
#recommendation ⇒ String
The recommended mitigation guidance for this threat.
-
#severity ⇒ String
The severity level of the threat.
-
#statement ⇒ String
The natural-language threat statement.
-
#status ⇒ String
The current status of the threat.
-
#stride ⇒ Array<String>
The STRIDE categories applicable to this threat.
-
#threat_action ⇒ String
What the threat source can do.
-
#threat_id ⇒ String
The unique identifier of the threat.
-
#threat_impact ⇒ String
The direct consequence of the threat action.
-
#threat_job_id ⇒ String
The unique identifier of the threat model job the threat belongs to.
-
#threat_source ⇒ String
The actor or origin of the threat.
-
#title ⇒ String
A short title summarizing the threat.
-
#updated_at ⇒ Time
The date and time the threat was last updated, in UTC format.
-
#updated_by ⇒ String
Who last updated this threat.
Instance Attribute Details
#anchor ⇒ Types::ThreatAnchorShape
The DFD element this threat is anchored to.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#comments ⇒ String
Optional customer comment on the threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the threat was created, in UTC format.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
Who created this threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#evidence ⇒ Array<Types::ThreatEvidenceShape>
The source code files supporting the threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#impacted_assets ⇒ Array<String>
The specific assets affected by the threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#impacted_goal ⇒ Array<String>
The security goals affected by the threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#prerequisites ⇒ String
The conditions required for the threat to be exploitable.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#recommendation ⇒ String
The recommended mitigation guidance for this threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
The severity level of the threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#statement ⇒ String
The natural-language threat statement.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#stride ⇒ Array<String>
The STRIDE categories applicable to this threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_action ⇒ String
What the threat source can do.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_id ⇒ String
The unique identifier of the threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_impact ⇒ String
The direct consequence of the threat action.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_job_id ⇒ String
The unique identifier of the threat model job the threat belongs to.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#threat_source ⇒ String
The actor or origin of the threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
A short title summarizing the threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the threat was last updated, in UTC format.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
Who last updated this threat.
8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-securityagent/types.rb', line 8965 class UpdateThreatOutput < Struct.new( :threat_id, :threat_job_id, :title, :statement, :severity, :status, :comments, :stride, :threat_source, :prerequisites, :threat_action, :threat_impact, :impacted_goal, :impacted_assets, :anchor, :evidence, :recommendation, :created_by, :updated_by, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |