Class: Aws::SecurityAgent::Types::UserConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::UserConfig
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
The configuration for a user membership, including the role assigned to the user within the agent space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#role ⇒ String
The role assigned to the user.
Instance Attribute Details
#role ⇒ String
The role assigned to the user. Currently, only MEMBER is supported.
4208 4209 4210 4211 4212 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4208 class UserConfig < Struct.new( :role) SENSITIVE = [] include Aws::Structure end |