Class: Aws::SecurityAgent::Types::VerifyTargetDomainInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecurityAgent::Types::VerifyTargetDomainInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-securityagent/types.rb
Overview
Input for verifying ownership for a registered target domain in an agent space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target_domain_id ⇒ String
The unique identifier of the target domain to verify.
Instance Attribute Details
#target_domain_id ⇒ String
The unique identifier of the target domain to verify.
4307 4308 4309 4310 4311 |
# File 'lib/aws-sdk-securityagent/types.rb', line 4307 class VerifyTargetDomainInput < Struct.new( :target_domain_id) SENSITIVE = [] include Aws::Structure end |